static const char *es_strings = "\"  -a               Cancel all jobs (cancel).\" = \"  -a               Cancelar todos los trabajos (cancelar).\";\n"
"\"  -c COPIES\" = \"  -c COPIAS\";\n"
"\"  -d PRINTER       Specify printer.\" = \"  -d PRINTER       Especifique la impresora.\";\n"
"\"  -j JOB-ID        Specify job ID (cancel).\" = \"  -j JOB-ID        Especifique el ID de trabajo (cancel.)\";\n"
"\"  -m DRIVER-NAME   Specify driver (add/modify).\" = \"  -m DRIVER-NAME   Especificar controlador (add/modify.)\";\n"
"\"  -n COPIES        Specify number of copies (submit).\" = \"  -n COPIES        Especifique el número de copias (presente.)\";\n"
"\"  -o %s=%s (default)\" = \"  -o %s=%s (por defecto)\";\n"
"\"  -o NAME=VALUE    Specify option (add,modify,server,submit).\" = \"  -o NAME=VALUE    Especifique la opción (add,modify,server,submit.)\";\n"
"\"  -o print-darkness=-100 to 100\" = \"  -o print-darkness=-100 a 100\";\n"
"\"  -o printer-darkness=0 to 100\" = \"  -o printer-darkness=0 a 100\";\n"
"\"  -o printer-geo-location='geo:LATITUDE,LONGITUDE'\" = \"  -o printer-geo-location='geo:LATITUDE,LONGITUDE\";\n"
"\"  -o printer-location='LOCATION'\" = \"  -o printer-locations='LOCATION\";\n"
"\"  -o printer-organization='ORGANIZATION'\" = \"  -o printer-organization='ORGANIZACIÓN\";\n"
"\"  -o printer-organizational-unit='UNIT/SECTION'\" = \"  -o printer-organizational-unit='UNIT/SECTION\";\n"
"\"  -u URI           Specify ipp: or ipps: printer/server.\" = \"  -u URI           Especifique ipp: o ipps: impresora/servidor.\";\n"
"\"  -v DEVICE-URI    Specify socket: or usb: device (add/modify).\" = \"  -v DEVICE-URI    Especifique el socket: o usb: dispositivo (add/modify.)\";\n"
"\"  add PRINTER      Add a printer.\" = \"  add PRINTER      Añadir una impresora.\";\n"
"\"  autoadd          Automatically add supported printers.\" = \"  autoadd          Agregue automáticamente impresoras compatibles.\";\n"
"\"  cancel           Cancel one or more jobs.\" = \"  cancel           Cancelar uno o más trabajos.\";\n"
"\"  default          Set the default printer.\" = \"  default          Establecer la impresora predeterminada.\";\n"
"\"  delete           Delete a printer.\" = \"  delete           Eliminar una impresora.\";\n"
"\"  devices          List devices.\" = \"  devices          Dispositivos Listos.\";\n"
"\"  drivers          List drivers.\" = \"conductores List drivers.\";\n"
"\"  jobs             List jobs.\" = \"  jobs             Empleo Listos.\";\n"
"\"  modify           Modify a printer.\" = \"  modify           Modifique una impresora.\";\n"
"\"  options          List printer options.\" = \"  options          Listar opciones de impresora.\";\n"
"\"  pause            Pause printing for a printer.\" = \"  pause            Impresión de pausa para una impresora.\";\n"
"\"  printers         List printers.\" = \"  printers         Lista de impresoras.\";\n"
"\"  resume           Resume printing for a printer.\" = \"  resume           Resumir la impresión para una impresora.\";\n"
"\"  server           Run a server.\" = \"  server           Ejecute un servidor.\";\n"
"\"  shutdown         Shutdown a running server.\" = \"  shutdown          Apaga un servidor en funcionamiento.\";\n"
"\"  status           Show server/printer/job status.\" = \"  status           Mostrar el estado del servidor/printer/job.\";\n"
"\"  submit           Submit a file for printing.\" = \"  submit           Enviar un archivo para imprimir.\";\n"
"\"%04d-%02d-%02d at %02d:%02d:%02d\" = \"%04d-%02d-%02d at %02d:%02d:%02d\";\n"
"\"%d days ago at %02d:%02d:%02d\" = \"hace %d días a las %02d:%02d:%02d\";\n"
"\"%d inches/sec\" = \"%d pulgadas/sec\";\n"
"\"%d job\" = \"%d trabajo\";\n"
/* Media size in millimeters */
"\"%d x %dmm\" = \"%d x %d mm\";\n"
"\"%ddpi\" = \"%d dpi\";\n"
"\"%dx%ddpi\" = \"%d x %d dpi\";\n"
/* Media size in inches */
"\"%g x %g\\\"\" = \"%g x %g \\\"\";\n"
/* size (type+borderless) */
"\"%s (%s%s)\" = \"%s ( %s %s )\";\n"
/* size (type+borderless) from source/tray */
"\"%s (%s%s) from %s\" = \"%s (%s%s) de %s\";\n"
/* Source/Tray Media */
"\"%s Media\" = \"%s Media\";\n"
"\"%s: Bad 'server-port' value.\" = \"%s: Mal valor de puerto de servidor.\";\n"
"\"%s: Bad job ID.\" = \"Mala identificación de trabajo.\";\n"
"\"%s: Bad printer URI '%s'.\" = \"%s: Bad printer URI '%s'.\";\n"
"\"%s: Cannot specify more than one sub-command.\" = \"%s: No se puede especificar más de un sub-command.\";\n"
"\"%s: Empty print file received on the standard input.\" = \"%s: Archivo de impresión vacío recibido en la entrada estándar.\";\n"
"\"%s: Failed to create a system.\" = \"%s: Failed to create a system.\";\n"
"\"%s: Missing '-d PRINTER'.\" = \"Desaparecido '-d PRINTER. '\";\n"
"\"%s: Missing '-m DRIVER-NAME'.\" = \"Perdiendo mi ADN. '\";\n"
"\"%s: Missing '-v DEVICE-URI'.\" = \"- Perdiendo a la policía. '\";\n"
"\"%s: Missing copy count after '-n'.\" = \"%s: Una copia perdida cuenta después de -n.\";\n"
"\"%s: Missing device URI after '-v'.\" = \"%s: Dispositivo perdido URI después de -v.\";\n"
"\"%s: Missing driver name after '-m'.\" = \"%s: Falta el nombre del conductor después de -m.\";\n"
"\"%s: Missing filename after '--'.\" = \"%s: Desapareciendo el nombre de archivo después de '--'.\";\n"
"\"%s: Missing hostname after '-h'.\" = \"%s: Desapareciendo el nombre de host después de -h.\";\n"
"\"%s: Missing job ID after '-j'.\" = \"%s: Falta de identificación de trabajo después de -j.\";\n"
"\"%s: Missing option(s) after '-o'.\" = \"%s: opción oscurecer después de -o.\";\n"
"\"%s: Missing printer URI after '-u'.\" = \"%s: Impresora desaparecida URI después de -u.\";\n"
"\"%s: Missing printer name after '-d'.\" = \"%s: Falta el nombre de la impresora después de -d.\";\n"
"\"%s: Missing space after '-o'.\" = \"%s: Falta espacio después de -o.\";\n"
"\"%s: Missing title after '-t'.\" = \"%s: Perder el título después de -t.\";\n"
"\"%s: No default printer available.\" = \"%s: No hay impresora predeterminada disponible.\";\n"
"\"%s: No files to print.\" = \"%s: No hay archivos que imprimir.\";\n"
"\"%s: Server is not running.\" = \"%s: El servidor no está funcionando.\";\n"
"\"%s: Sub-command '%s' does not accept files.\" = \"%s: Sub-command '%s' no acepta archivos.\";\n"
"\"%s: Sub-command 'autoadd' is not supported.\" = \"%s: Autoadd subcommand no es compatible.\";\n"
"\"%s: Too many files.\" = \"%s: Demasiados archivos.\";\n"
"\"%s: Unable to access '%s': %s\" = \"%s: Incapaz de acceder a '%s': %s\";\n"
"\"%s: Unable to add printer: %s\" = \"%s: Incapaz de añadir la impresora: %s\";\n"
"\"%s: Unable to cancel job: %s\" = \"%s: Incapaz de cancelar el trabajo: %s\";\n"
"\"%s: Unable to connect to printer at '%s:%d': %s\" = \"%s: Incapaz de conectarse a la impresora en '%s:%d': %s\";\n"
"\"%s: Unable to connect to server: %s\" = \"%s: Incapaz de conectarse al servidor: %s\";\n"
"\"%s: Unable to create temporary file: %s\" = \"%s: Incapaz de crear un archivo temporal: %s\";\n"
"\"%s: Unable to delete printer: %s\" = \"%s: Incapaz de eliminar la impresora: %s\";\n"
"\"%s: Unable to get available devices: %s\" = \"%s: No se pueden obtener los dispositivos disponibles: %s\";\n"
"\"%s: Unable to get information for '%s': %s\" = \"%s: Incapaz de obtener información para '%s': %s\";\n"
"\"%s: Unable to get information for printer: %s\" = \"%s: Incapaz de obtener información para la impresora: %s\";\n"
"\"%s: Unable to get printer options: %s\" = \"%s: Incapaz de obtener opciones de impresora: %s\";\n"
"\"%s: Unable to modify printer: %s\" = \"%s: Incapaz de modificar la impresora: %s\";\n"
"\"%s: Unable to pause printer: %s\" = \"%s: Incapacidad para detener la impresora: %s\";\n"
"\"%s: Unable to print '%s': %s\" = \"%s: Incapaz de imprimir '%s': %s\";\n"
"\"%s: Unable to resume printer: %s\" = \"%s: Incapaz de reanudar la impresora: %s\";\n"
"\"%s: Unable to set default printer: %s\" = \"%s: Incapaz de configurar la impresora predeterminada: %s\";\n"
"\"%s: Unable to shutdown server: %s\" = \"%s: Incapaz de apagar el servidor: %s\";\n"
"\"%s: Unable to start server: %s\" = \"%s: Incapaz de iniciar servidor: %s\";\n"
"\"%s: Unable to write to temporary file: %s\" = \"%s: Incapaz de escribir al archivo temporal: %s\";\n"
"\"%s: Unknown option '%s'.\" = \"%s: Opción desconocida '%s'.\";\n"
"\"%s: Unknown option '-%c'.\" = \"%s: Opción desconocida '-%c'.\";\n"
"\"%s: Unknown sub-command '%s'.\" = \"%s: Unknown sub-command '%s'.\";\n"
"\"%s: Unsupported URI scheme '%s'.\" = \"%s: Unsupported URI scheme '%s'.\";\n"
"\"%s: Warning - user credentials are not supported in URIs.\" = \"%s: Advertencia - las credenciales del usuario no son compatibles con URIs.\";\n"
"\", Borderless\" = \", sin fronteras\";\n"
"\"A printer with that name already exists.\" = \"Una impresora con ese nombre ya existe.\";\n"
"\"Aborted %s\" = \"Abortado %s\";\n"
"\"Add Printer\" = \"Añadir impresora\";\n"
"\"Admin Group\" = \"Admin Group\";\n"
"\"Afghanistan\" = \"Afganistán\";\n"
"\"Albania\" = \"Albania\";\n"
"\"Algeria\" = \"Argelia\";\n"
"\"American Samoa\" = \"Samoa Americana\";\n"
"\"Andorra\" = \"Andorra\";\n"
"\"Angola\" = \"Angola\";\n"
"\"Anguilla\" = \"Anguila\";\n"
"\"Antarctica\" = \"Antártida\";\n"
"\"Antigua and Barbuda\" = \"Antigua y Barbuda\";\n"
"\"Argentina\" = \"Argentina\";\n"
"\"Armenia\" = \"Armenia\";\n"
"\"Aruba\" = \"Aruba\";\n"
"\"Australia\" = \"Australia\";\n"
"\"Austria\" = \"Austria\";\n"
"\"Auto\" = \"Auto\";\n"
"\"Auto-Detect Driver\" = \"Auto-Detect Driver\";\n"
"\"Azerbaijan\" = \"Azerbaiyán\";\n"
"\"Bad administration group.\" = \"Grupo de mala administración.\";\n"
"\"Bad port number.\" = \"Mal número de puerto.\";\n"
"\"Bad print group.\" = \"Grupo de impresión malo.\";\n"
"\"Bad printer defaults.\" = \"Impresoras malas.\";\n"
"\"Bahamas\" = \"Bahamas\";\n"
"\"Bahrain\" = \"Bahrein\";\n"
"\"Bangladesh\" = \"Bangladesh\";\n"
"\"Barbados\" = \"Barbados\";\n"
"\"Belarus\" = \"Belarús\";\n"
"\"Belgium\" = \"Bélgica\";\n"
"\"Belize\" = \"Belice\";\n"
"\"Benin\" = \"Benin\";\n"
"\"Bermuda\" = \"Bermudas\";\n"
"\"Bhutan\" = \"Bhután\";\n"
"\"Bolivia (Plurinational State of)\" = \"Bolivia (Estado Plurinacional de)\";\n"
"\"Bonaire, Sint Eustatius and Saba\" = \"Bonaire, Sint Eustatius y Saba\";\n"
"\"Borderless\" = \"Sin fronteras\";\n"
"\"Bosnia and Herzegovina\" = \"Bosnia y Herzegovina\";\n"
"\"Botswana\" = \"Botswana\";\n"
"\"Bouvet Island\" = \"Bouvet Island\";\n"
"\"Brazil\" = \"Brasil\";\n"
"\"British Indian Ocean Territory\" = \"British Indian Ocean Territory\";\n"
"\"Brunei Darussalam\" = \"Brunei Darussalam\";\n"
"\"Bulgaria\" = \"Bulgaria\";\n"
"\"Burkina Faso\" = \"Burkina Faso\";\n"
"\"Burundi\" = \"Burundi\";\n"
"\"Cabo Verde\" = \"Cabo Verde\";\n"
"\"Cambodia\" = \"Camboya\";\n"
"\"Cameroon\" = \"Camerún\";\n"
"\"Canada\" = \"Canadá\";\n"
"\"Cancel All Jobs\" = \"Cancelar Todos los trabajos\";\n"
"\"Cancel Job\" = \"Cancelar trabajo\";\n"
"\"Canceled %s\" = \"Cancelado %s\";\n"
"\"Canceling\" = \"Cancelación\";\n"
"\"Cayman Islands\" = \"Islas Caimán\";\n"
"\"Central African Republic\" = \"República Centroafricana\";\n"
"\"Certificate created.\" = \"Certificado creado.\";\n"
"\"Certificate installed.\" = \"Certificado instalado.\";\n"
"\"Certificate request created.\" = \"Solicitud de certificado creada.\";\n"
"\"Chad\" = \"Chad\";\n"
"\"Change Access Password\" = \"Cambiar contraseña\";\n"
"\"Change Log Level\" = \"Nivel de registro de cambios\";\n"
"\"Change Network Settings\" = \"Cambiar la configuración de la red\";\n"
"\"Change Wi-Fi Network\" = \"Cambiar red Wi-Fi\";\n"
"\"Changes Saved.\" = \"Cambios guardados.\";\n"
"\"Changes saved.\" = \"Cambios salvados.\";\n"
"\"Chile\" = \"Chile\";\n"
"\"China\" = \"China\";\n"
"\"Christmas Island\" = \"Isla de Navidad\";\n"
"\"City/Locality\" = \"Ciudad/Localidad\";\n"
"\"Cocos (Keeling) Islands\" = \"Islas Cocos (Keeling)\";\n"
"\"Colombia\" = \"Colombia\";\n"
"\"Comoros\" = \"Comoras\";\n"
"\"Completed %s\" = \"Completado %s\";\n"
"\"Configuration\" = \"Configuración\";\n"
"\"Configure Media\" = \"Configure Media\";\n"
"\"Confirm Cancel All\" = \"Confirmación Todos\";\n"
"\"Confirm Delete Printer\" = \"Confirmar la impresora\";\n"
"\"Congo\" = \"Congo\";\n"
"\"Congo, Democratic Republic of the\" = \"Congo, República Democrática del Congo\";\n"
"\"Contact\" = \"Contacto\";\n"
"\"Cook Islands\" = \"Islas Cook\";\n"
"\"Costa Rica\" = \"Costa Rica\";\n"
"\"Create Certificate Signing Request\" = \"Crear solicitud de registro de certificados\";\n"
"\"Create New Certificate\" = \"Crear nuevo certificado\";\n"
"\"Create New TLS Certificate\" = \"Crear nuevo certificado TLS\";\n"
"\"Create TLS Certificate Request\" = \"Crear TLS Solicitud de certificado\";\n"
"\"Croatia\" = \"Croacia\";\n"
"\"Cuba\" = \"Cuba\";\n"
"\"Curaçao\" = \"Curaao\";\n"
"\"Current Password\" = \"Contraseña actual\";\n"
"\"Custom Size\" = \"Tamaño personalizado\";\n"
"\"Cyprus\" = \"Chipre\";\n"
"\"Czechia\" = \"Czechia\";\n"
"\"Côte d'Ivoire\" = \"Cte d'Ivoire\";\n"
"\"DHCP\" = \"DHCP\";\n"
"\"DHCP w/Manual Address\" = \"DHCP con dirección manual\";\n"
"\"DNS-SD Service Name\" = \"DNS-SD Nombre del servicio\";\n"
"\"Debugging\" = \"Debugging\";\n"
"\"Default printer set.\" = \"Juego de impresora predeterminado.\";\n"
"\"Delete\" = \"Suprimir\";\n"
"\"Delete Printer\" = \"Eliminar la impresora\";\n"
"\"Denmark\" = \"Dinamarca\";\n"
"\"Djibouti\" = \"Djibouti\";\n"
"\"Domain Name\" = \"Nombre del dominio\";\n"
"\"Dominica\" = \"Dominica\";\n"
"\"Dominican Republic\" = \"República Dominicana\";\n"
"\"Download Certificate Request File\" = \"Descargar certificado Solicitar archivo\";\n"
"\"Ecuador\" = \"Ecuador\";\n"
"\"Egypt\" = \"Egipto\";\n"
"\"El Salvador\" = \"El Salvador\";\n"
"\"Equatorial Guinea\" = \"Guinea Ecuatorial\";\n"
"\"Eritrea\" = \"Eritrea\";\n"
"\"Errors\" = \"Errores\";\n"
"\"Estonia\" = \"Estonia\";\n"
"\"Eswatini\" = \"Eswatini\";\n"
"\"Ethiopia\" = \"Etiopía\";\n"
"\"Falkland Islands (Malvinas)\" = \"Islas Malvinas (Falkland Islands)\";\n"
"\"Faroe Islands\" = \"Islas Feroe\";\n"
"\"Fatal Errors/Conditions\" = \"Errores/Condiciones fatales\";\n"
"\"Fiji\" = \"Fiji\";\n"
"\"Finland\" = \"Finlandia\";\n"
"\"France\" = \"Francia\";\n"
"\"French Guiana\" = \"Guayana Francesa\";\n"
"\"French Polynesia\" = \"Polinesia Francesa\";\n"
"\"French Southern Territories\" = \"Territorios del Sur\";\n"
"\"Gabon\" = \"Gabón\";\n"
"\"Gambia\" = \"Gambia\";\n"
"\"Georgia\" = \"Georgia\";\n"
"\"Germany\" = \"Alemania\";\n"
"\"Ghana\" = \"Ghana\";\n"
"\"Gibraltar\" = \"Gibraltar\";\n"
"\"Greece\" = \"Grecia\";\n"
"\"Greenland\" = \"Groenlandia\";\n"
"\"Grenada\" = \"Granada\";\n"
"\"Group changes saved.\" = \"Cambios de grupo guardados.\";\n"
"\"Guadeloupe\" = \"Guadalupe\";\n"
"\"Guam\" = \"Guam\";\n"
"\"Guatemala\" = \"Guatemala\";\n"
"\"Guernsey\" = \"Guernsey\";\n"
"\"Guinea\" = \"Guinea\";\n"
"\"Guinea-Bissau\" = \"Guinea-Bissau\";\n"
"\"Guyana\" = \"Guyana\";\n"
"\"Haiti\" = \"Haití\";\n"
"\"Heard Island and McDonald Islands\" = \"Heard Island y McDonald Islands\";\n"
"\"Hidden SSID\" = \"SSID oculto\";\n"
"\"Hold Job\" = \"Mantener el empleo\";\n"
"\"Hold New Jobs\" = \"Mantener los nuevos empleos\";\n"
"\"Holding new jobs.\" = \"Mantener nuevos puestos de trabajo.\";\n"
"\"Holy See\" = \"Santa Sede\";\n"
"\"Honduras\" = \"Honduras\";\n"
"\"Hong Kong\" = \"Hong Kong\";\n"
"\"Hostname\" = \"Nombre de host\";\n"
"\"Human-Readable Location\" = \"Ubicación legible por humanos\";\n"
"\"Hungary\" = \"Hungría\";\n"
"\"IPv4 Address\" = \"Dirección IPv4\";\n"
"\"IPv4 Configuration\" = \"Configuración IPv4\";\n"
"\"IPv4 Gateway\" = \"Puerta de enlace IPv4\";\n"
"\"IPv4 Netmask\" = \"Máscara de red IPv4\";\n"
"\"IPv6 Address\" = \"Direcciones IPv6\";\n"
"\"IPv6 Configuration\" = \"Configuración IPv6\";\n"
"\"IPv6 Link-Local\" = \"Enlace local IPv6\";\n"
"\"IPv6 Prefix Length\" = \"Longitud del prefijo IPv6\";\n"
"\"Iceland\" = \"Islandia\";\n"
"\"Identify Printer\" = \"Identifique la impresora\";\n"
"\"India\" = \"India\";\n"
"\"Indonesia\" = \"Indonesia\";\n"
"\"Informational\" = \"Información\";\n"
"\"Install TLS Certificate\" = \"Instala TLS Certificado\";\n"
"\"Invalid IPv4 address.\" = \"Dirección IPv4 incorrecta.\";\n"
"\"Invalid IPv4 netmask.\" = \"Máscara de red IPv4 incorrecta.\";\n"
"\"Invalid IPv6 address.\" = \"Dirección IPv6 incorrecta.\";\n"
"\"Invalid IPv6 prefix length.\" = \"Longitud del prefijo IPv6 incorrecto.\";\n"
"\"Invalid Job ID.\" = \"ID de trabajo inválido.\";\n"
"\"Invalid certificate or private key.\" = \"Certificado inválido o clave privada.\";\n"
"\"Invalid form data.\" = \"Datos de formulario inválidos.\";\n"
"\"Invalid form submission.\" = \"Sumisión de formulario inválido.\";\n"
"\"Invalid job ID.\" = \"ID de trabajo inválido.\";\n"
"\"Invalid network configuration.\" = \"Configuración de red incorrecta.\";\n"
"\"Iran (Islamic Republic of)\" = \"Irán (República Islámica del)\";\n"
"\"Iraq\" = \"Iraq\";\n"
"\"Ireland\" = \"Irlanda\";\n"
"\"Isle of Man\" = \"Isla de Man\";\n"
"\"Israel\" = \"Israel\";\n"
"\"Italy\" = \"Italia\";\n"
"\"Jamaica\" = \"Jamaica\";\n"
"\"Japan\" = \"Japón\";\n"
"\"Jersey\" = \"Jersey\";\n"
"\"Job #\" = \"Job\";\n"
"\"Job canceled.\" = \"Trabajo cancelado.\";\n"
"\"Job held.\" = \"Puesto ocupado.\";\n"
"\"Job released.\" = \"Trabajo liberado.\";\n"
"\"Jobs\" = \"Empleo\";\n"
"\"Joining Wi-Fi Network\" = \"Unirse a la red Wi-Fi\";\n"
"\"Jordan\" = \"Jordania\";\n"
"\"Kazakhstan\" = \"Kazajstán\";\n"
"\"Kenya\" = \"Kenya\";\n"
"\"Kiribati\" = \"Kiribati\";\n"
"\"Korea (Democratic People's Republic of)\" = \"Corea (República Popular Democrática de)\";\n"
"\"Korea, Republic of\" = \"Corea, República de Corea\";\n"
"\"Kuwait\" = \"Kuwait\";\n"
"\"Kyrgyzstan\" = \"Kirguistán\";\n"
"\"Landscape\" = \"Paisaje\";\n"
"\"Lao People's Democratic Republic\" = \"República Democrática Popular Lao\";\n"
"\"Latvia\" = \"Letonia\";\n"
"\"Lebanon\" = \"Líbano\";\n"
"\"Lesotho\" = \"Lesotho\";\n"
"\"Level\" = \"Nivel\";\n"
"\"Liberia\" = \"Liberia\";\n"
"\"Libya\" = \"Libia\";\n"
"\"Liechtenstein\" = \"Liechtenstein\";\n"
"\"Lithuania\" = \"Lituania\";\n"
"\"Location\" = \"Ubicación\";\n"
"\"Log Level\" = \"Nivel de registro\";\n"
"\"Logging\" = \"Registro\";\n"
"\"Logs\" = \"Logs\";\n"
"\"Luxembourg\" = \"Luxemburgo\";\n"
"\"Macao\" = \"Macao\";\n"
"\"Madagascar\" = \"Madagascar\";\n"
"\"Malawi\" = \"Malawi\";\n"
"\"Malaysia\" = \"Malasia\";\n"
"\"Maldives\" = \"Maldivas\";\n"
"\"Mali\" = \"Malí\";\n"
"\"Malta\" = \"Malta\";\n"
"\"Manual Configuration\" = \"Configuración manual\";\n"
"\"Marshall Islands\" = \"Islas Marshall\";\n"
"\"Martinique\" = \"Martinica\";\n"
"\"Mauritania\" = \"Mauritania\";\n"
"\"Mauritius\" = \"Mauricio\";\n"
"\"Mayotte\" = \"Mayotte\";\n"
"\"Media\" = \"Media\";\n"
"\"Mexico\" = \"México\";\n"
"\"Micronesia (Federated States of)\" = \"Micronesia (Estados Federados de)\";\n"
"\"Missing action.\" = \"Falta de acción.\";\n"
"\"Missing job ID.\" = \"Falta el identificador del trabajo.\";\n"
"\"Missing network name.\" = \"Falta el nombre de la red.\";\n"
"\"Missing private key.\" = \"Falta la llave privada.\";\n"
"\"Moldova, Republic of\" = \"República de Moldova\";\n"
"\"Monaco\" = \"Mónaco\";\n"
"\"Mongolia\" = \"Mongolia\";\n"
"\"Montenegro\" = \"Montenegro\";\n"
"\"Montserrat\" = \"Montserrat\";\n"
"\"Morocco\" = \"Marruecos\";\n"
"\"Mozambique\" = \"Mozambique\";\n"
"\"Myanmar\" = \"Myanmar\";\n"
"\"Name\" = \"Nombre\";\n"
"\"Namibia\" = \"Namibia\";\n"
"\"Nauru\" = \"Nauru\";\n"
"\"Nepal\" = \"Nepal\";\n"
"\"Netherlands\" = \"Países Bajos\";\n"
"\"Network\" = \"Red\";\n"
"\"Network Printer\" = \"Impresora de red\";\n"
"\"Networking\" = \"Redes\";\n"
"\"New Caledonia\" = \"Nueva Caledonia\";\n"
"\"New Zealand\" = \"Nueva Zelandia\";\n"
"\"Nicaragua\" = \"Nicaragua\";\n"
"\"Niger\" = \"Níger\";\n"
"\"Nigeria\" = \"Nigeria\";\n"
"\"Niue\" = \"Niue\";\n"
"\"No default printer set.\" = \"No hay configuración de impresora predeterminada.\";\n"
"\"No jobs in history.\" = \"No hay trabajos en la historia.\";\n"
"\"Norfolk Island\" = \"Norfolk Island\";\n"
"\"North Macedonia\" = \"North Macedonia\";\n"
"\"Northern Mariana Islands\" = \"Islas Marianas del Norte\";\n"
"\"Norway\" = \"Noruega\";\n"
"\"Not set\" = \"No está listo.\";\n"
"\"Off\" = \"Apagado\";\n"
"\"Offset\" = \"Offset\";\n"
"\"Oman\" = \"Omán\";\n"
"\"Options:\" = \"Opciones:\";\n"
"\"Organization\" = \"Organización\";\n"
"\"Organization Name\" = \"Nombre de la Organización\";\n"
"\"Other Settings\" = \"Otras configuraciones\";\n"
"\"Pakistan\" = \"Pakistán\";\n"
"\"Palau\" = \"Palau\";\n"
"\"Palestine, State of\" = \"Palestina, Estado de Palestina\";\n"
"\"Panama\" = \"Panamá\";\n"
"\"Papua New Guinea\" = \"Papua Nueva Guinea\";\n"
"\"Paraguay\" = \"Paraguay\";\n"
"\"Password\" = \"Contraseña\";\n"
"\"Password changed.\" = \"La contraseña cambió.\";\n"
"\"Password must be at least eight characters long and contain at least one uppercase letter, one lowercase letter, and one digit.\" = \"La contraseña debe tener al menos ocho caracteres de largo y contener al menos una letra mayúscula, una letra minúscula y un dígito.\";\n"
"\"Passwords do not match.\" = \"Las contraseñas no coinciden.\";\n"
"\"Pause Printing\" = \"Impresión de pausa\";\n"
"\"Peru\" = \"Perú\";\n"
"\"Philippines\" = \"Philippines\";\n"
"\"Pitcairn\" = \"Pitcairn\";\n"
"\"Please enter a hostname or IP address for the printer.\" = \"Por favor introduzca un nombre de host o dirección IP para la impresora.\";\n"
"\"Please enter a printer name.\" = \"Por favor, introduzca un nombre de impresora.\";\n"
"\"Please select a device.\" = \"Por favor, seleccione un dispositivo.\";\n"
"\"Please select a driver.\" = \"Por favor, seleccione un conductor.\";\n"
"\"Please select a valid log level.\" = \"Seleccione un nivel de registro válido.\";\n"
"\"Poland\" = \"Polonia\";\n"
"\"Portrait\" = \"Retrato\";\n"
"\"Portugal\" = \"Portugal\";\n"
"\"Primary DNS\" = \"DNS principal\";\n"
"\"Print Group\" = \"Print Group\";\n"
"\"Print Test Page\" = \"Página de prueba de impresión\";\n"
"\"Print job options:\" = \"Opciones de trabajo para imprimir:\";\n"
"\"Printer identified.\" = \"Impresora identificada.\";\n"
"\"Printer is currently active.\" = \"La impresora está activa.\";\n"
"\"Printer names must start with a letter or underscore and cannot contain special characters.\" = \"Los nombres de las impresoras deben comenzar con una letra o subrayar y no pueden contener caracteres especiales.\";\n"
"\"Printer options:\" = \"Opciones de impresión:\";\n"
"\"Printer paused.\" = \"La impresora se detuvo.\";\n"
"\"Printer pausing.\" = \"Impresora pausando.\";\n"
"\"Printer resuming.\" = \"Reanuda la impresora.\";\n"
"\"Printers\" = \"Impresoras\";\n"
"\"Printing Defaults\" = \"Impresos\";\n"
"\"Puerto Rico\" = \"Puerto Rico\";\n"
"\"Qatar\" = \"Qatar\";\n"
"\"Queued %s\" = \"En espera %s\";\n"
"\"Release Held New Jobs\" = \"Liberación de nuevos puestos de trabajo\";\n"
"\"Release Job\" = \"Liberar el trabajo\";\n"
"\"Released held new jobs.\" = \"Se han reanudado los nuevos trabajos en pausa.\";\n"
"\"Reprint Job\" = \"Reprint Job\";\n"
"\"Reprinted job.\" = \"Trabajo reeditado.\";\n"
"\"Resume Printing\" = \"Resume Printing\";\n"
"\"Reverse Landscape\" = \"Paisaje inverso\";\n"
"\"Reverse Portrait\" = \"Retrato inverso\";\n"
"\"Romania\" = \"Rumania\";\n"
/* Running, STATE since DATE REASONS */
"\"Running, %s since %s%s.\" = \"Corriendo, %s desde %s %s .\";\n"
"\"Russian Federation\" = \"Russian Federation\";\n"
"\"Rwanda\" = \"Rwanda\";\n"
"\"Réunion\" = \"Corrección\";\n"
"\"Saint Barthélemy\" = \"Saint Barthlemy\";\n"
"\"Saint Helena, Ascension and Tristan da Cunha\" = \"Santa Elena, Ascensión y Tristán da Cunha\";\n"
"\"Saint Kitts and Nevis\" = \"Saint Kitts y Nevis\";\n"
"\"Saint Lucia\" = \"Santa Lucía\";\n"
"\"Saint Martin (French part)\" = \"Saint Martin (parte francesa)\";\n"
"\"Saint Pierre and Miquelon\" = \"Saint Pierre y Miquelon\";\n"
"\"Saint Vincent and the Grenadines\" = \"San Vicente y las Granadinas\";\n"
"\"Samoa\" = \"Samoa\";\n"
"\"San Marino\" = \"San Marino\";\n"
"\"Sao Tome and Principe\" = \"Santo Tomé y Príncipe\";\n"
"\"Saudi Arabia\" = \"Arabia Saudita\";\n"
"\"Save Changes\" = \"Guardar cambios\";\n"
"\"Secondary DNS\" = \"DNS secundarias\";\n"
"\"Security\" = \"Seguridad\";\n"
"\"Select Driver\" = \"Select Driver\";\n"
"\"Senegal\" = \"Senegal\";\n"
"\"Serbia\" = \"Serbia\";\n"
"\"Server is not running.\" = \"El servidor no está funcionando.\";\n"
"\"Set Access Password\" = \"Establecer contraseña\";\n"
"\"Set as Default\" = \"Set as Default\";\n"
"\"Seychelles\" = \"Seychelles\";\n"
"\"Sierra Leone\" = \"Sierra Leona\";\n"
"\"Singapore\" = \"Singapur\";\n"
"\"Sint Maarten (Dutch part)\" = \"Sint Maarten (parte holandesa)\";\n"
"\"Slovakia\" = \"Eslovaquia\";\n"
"\"Slovenia\" = \"Eslovenia\";\n"
"\"Solomon Islands\" = \"Islas Salomón\";\n"
"\"Somalia\" = \"Somalia\";\n"
"\"South Africa\" = \"Sudáfrica\";\n"
"\"South Georgia and the South Sandwich Islands\" = \"South Georgia and the South Sandwich Islands\";\n"
"\"South Sudan\" = \"Sudán del Sur\";\n"
"\"Spain\" = \"España\";\n"
"\"Sri Lanka\" = \"Sri Lanka\";\n"
"\"Started %s\" = \"Empezó %s\";\n"
"\"Status\" = \"Situación\";\n"
"\"Sub-commands:\" = \"Subcomandantes:\";\n"
"\"Sudan\" = \"Sudán\";\n"
"\"Supplies\" = \"Suministros\";\n"
"\"Suriname\" = \"Suriname\";\n"
"\"Svalbard and Jan Mayen\" = \"Svalbard y Jan Mayen\";\n"
"\"Sweden\" = \"Suecia\";\n"
"\"Switzerland\" = \"Suiza\";\n"
"\"Syrian Arab Republic\" = \"República Árabe Siria\";\n"
"\"Taiwan, Province of China\" = \"Taiwán, Provincia de China\";\n"
"\"Tajikistan\" = \"Tayikistán\";\n"
"\"Tanzania, United Republic of\" = \"República Unida de Tanzanía\";\n"
"\"Test page printed.\" = \"Ficha de prueba impresa.\";\n"
"\"Thailand\" = \"Tailandia\";\n"
"\"This form creates a certificate signing request ('CSR') that you can send to a Certificate Authority ('CA') to obtain a trusted TLS certificate. The private key is saved separately for use with the certificate you get from the CA.\" = \"Este formulario crea una solicitud de firma de certificados (CSR) que puede enviar a una Autoridad de Certificados (CA) para obtener un certificado TLS de confianza. La clave privada se guarda por separado para su uso con el certificado que obtiene de la CA.\";\n"
"\"This form creates a new 'self-signed' TLS certificate for secure printing. Self-signed certificates are not automatically trusted by web browsers.\" = \"Este formulario crea un nuevo certificado TLS auto-firmado para impresión segura. Los navegadores web no confían automáticamente certificados auto-firmados.\";\n"
"\"This form will install a trusted TLS certificate you have obtained from a Certificate Authority ('CA'). Once installed, it will be used immediately.\" = \"Este formulario instalará un certificado TLS de confianza que haya obtenido de una Autoridad de Certificados (CA.) Una vez instalado, se utilizará inmediatamente.\";\n"
"\"Timor-Leste\" = \"Timor-Leste\";\n"
"\"Togo\" = \"Togo\";\n"
"\"Tokelau\" = \"Tokelau\";\n"
"\"Tonga\" = \"Tonga\";\n"
"\"Trinidad and Tobago\" = \"Trinidad y Tabago\";\n"
"\"Tunisia\" = \"Túnez\";\n"
"\"Turkey\" = \"Turquía\";\n"
"\"Turkmenistan\" = \"Turkmenistán\";\n"
"\"Turks and Caicos Islands\" = \"Islas Turcas y Caicos\";\n"
"\"Tuvalu\" = \"Tuvalu\";\n"
"\"Uganda\" = \"Uganda\";\n"
"\"Ukraine\" = \"Ucrania\";\n"
"\"Unable to access test print file.\" = \"Incapaz de acceder al archivo de impresión de prueba.\";\n"
"\"Unable to copy print job.\" = \"Incapaz de copiar el trabajo de impresión.\";\n"
"\"Unable to create certificate request.\" = \"Incapaz de crear solicitud de certificado.\";\n"
"\"Unable to create certificate.\" = \"Incapaz de crear certificado.\";\n"
"\"Unable to create test print job.\" = \"Incapaz de crear trabajo de impresión de prueba.\";\n"
"\"Unable to identify printer.\" = \"Incapaz de identificar la impresora.\";\n"
"\"Unable to lookup address.\" = \"Incapaz de buscar la dirección.\";\n"
"\"Unable to use that driver.\" = \"Incapaz de usar ese conductor.\";\n"
"\"United Arab Emirates\" = \"Emiratos Árabes Unidos\";\n"
"\"United Kingdom\" = \"Reino Unido\";\n"
"\"United Kingdom of Great Britain and Northern Ireland\" = \"Reino Unido de Gran Bretaña e Irlanda del Norte\";\n"
"\"United States Minor Outlying Islands\" = \"Islas Menores de los Estados Unidos\";\n"
"\"United States of America\" = \"Estados Unidos de América\";\n"
"\"Unknown\" = \"Desconocida\";\n"
"\"Unknown action.\" = \"Acción desconocida.\";\n"
"\"Unknown form action.\" = \"Acción de forma desconocida.\";\n"
"\"Unknown form request.\" = \"Solicitud de formulario desconocido.\";\n"
"\"Updating Network Configuration\" = \"Actualizar la configuración de red\";\n"
"\"Uruguay\" = \"Uruguay\";\n"
"\"Usage: %s SUB-COMMAND [OPTIONS] [FILENAME]\\n\" = \"Usage: %s SUB-COMMAND [OPTIONS] [FILENAME]\\n\";\n"
"\"Use My Position\" = \"Usar mi posición\";\n"
"\"Users\" = \"Usuarios\";\n"
"\"Uzbekistan\" = \"Uzbekistán\";\n"
"\"Vanuatu\" = \"Vanuatu\";\n"
"\"Venezuela (Bolivarian Republic of)\" = \"Venezuela (República Bolivariana de)\";\n"
"\"Version %s\" = \"Versión %s\";\n"
"\"Viet Nam\" = \"Viet Nam\";\n"
"\"View Logs\" = \"Ver los registros\";\n"
"\"Virgin Islands (British)\" = \"Islas Vírgenes (British)\";\n"
"\"Virgin Islands (U.S.)\" = \"Islas Vírgenes (U.S)\";\n"
"\"Wallis and Futuna\" = \"Wallis y Futuna\";\n"
"\"Warning\" = \"Advertencia\";\n"
"\"Western Sahara\" = \"Sáhara Occidental\";\n"
"\"Wi-Fi Configuration\" = \"Configuración Wi-Fi\";\n"
"\"Wi-Fi Network\" = \"Wi-Fi Network\";\n"
"\"Width\" = \"Width\";\n"
"\"Wrong old password.\" = \"contraseña vieja incorrecta.\";\n"
"\"Yemen\" = \"Yemen\";\n"
"\"Zambia\" = \"Zambia\";\n"
"\"Zimbabwe\" = \"Zimbabwe\";\n"
"\"at %02d:%02d:%02d\" = \"en %02d:%02d:%02d\";\n"
/* IPP attribute, keyword, and enum (integer) localizations */
"\"copies\" = \"Número de copias\";\n"
"\"default printer\" = \"impresora predeterminada\";\n"
"\"finishings\" = \"Acabado\";\n"
"\"finishings.10\" = \"Fold\";\n"
"\"finishings.100\" = \"Z plegable\";\n"
"\"finishings.101\" = \"Ingeniería Z plegable\";\n"
"\"finishings.11\" = \"Corte\";\n"
"\"finishings.12\" = \"Bale\";\n"
"\"finishings.13\" = \"Booklet maker\";\n"
"\"finishings.15\" = \"Coat\";\n"
"\"finishings.16\" = \"Laminate\";\n"
"\"finishings.20\" = \"Parte superior izquierda\";\n"
"\"finishings.21\" = \"Fondo básico izquierdo\";\n"
"\"finishings.22\" = \"Parte superior derecha\";\n"
"\"finishings.23\" = \"Parte inferior derecha\";\n"
"\"finishings.24\" = \"Punto izquierdo\";\n"
"\"finishings.25\" = \"Parte superior\";\n"
"\"finishings.26\" = \"Sutura de borde derecha\";\n"
"\"finishings.27\" = \"Parte inferior de la puntada\";\n"
"\"finishings.28\" = \"2 grapas a la izquierda\";\n"
"\"finishings.29\" = \"2 grapas en la parte superior\";\n"
"\"finishings.3\" = \"Ninguno\";\n"
"\"finishings.30\" = \"2 grapas a la derecha\";\n"
"\"finishings.31\" = \"2 grapas en la parte inferior\";\n"
"\"finishings.32\" = \"3 grapas a la izquierda\";\n"
"\"finishings.33\" = \"3 grapas en la parte superior\";\n"
"\"finishings.34\" = \"3 grapas a la derecha\";\n"
"\"finishings.35\" = \"3 grapas en la parte inferior\";\n"
"\"finishings.4\" = \"Grado\";\n"
"\"finishings.5\" = \"Punch\";\n"
"\"finishings.50\" = \"Bind izquierda\";\n"
"\"finishings.51\" = \"Parte superior\";\n"
"\"finishings.52\" = \"Apunta derecho\";\n"
"\"finishings.53\" = \"Parte inferior\";\n"
"\"finishings.6\" = \"Cubierta\";\n"
"\"finishings.60\" = \"Cortar después de cada página\";\n"
"\"finishings.61\" = \"Corte después de cada documento\";\n"
"\"finishings.62\" = \"Corte después de cada set\";\n"
"\"finishings.63\" = \"Cortar después del trabajo\";\n"
"\"finishings.7\" = \"Bind\";\n"
"\"finishings.70\" = \"Punch superior izquierdo\";\n"
"\"finishings.71\" = \"Punch inferior izquierdo\";\n"
"\"finishings.72\" = \"Punch superior derecho\";\n"
"\"finishings.73\" = \"Punch fondo derecho\";\n"
"\"finishings.74\" = \"2-hole punch left\";\n"
"\"finishings.75\" = \"Top de 2 agujeros\";\n"
"\"finishings.76\" = \"2 agujeros derecho\";\n"
"\"finishings.77\" = \"Parte inferior de 2 agujeros\";\n"
"\"finishings.78\" = \"3-hole punch left\";\n"
"\"finishings.79\" = \"Top de 3 hoyos\";\n"
"\"finishings.8\" = \"Sutura de asiento\";\n"
"\"finishings.80\" = \"3 agujeros derecho\";\n"
"\"finishings.81\" = \"3-hole punch bottom\";\n"
"\"finishings.82\" = \"4-hole punch left\";\n"
"\"finishings.83\" = \"Top de 4 agujeros\";\n"
"\"finishings.84\" = \"4 agujeros derecho\";\n"
"\"finishings.85\" = \"4 agujeros abajo\";\n"
"\"finishings.86\" = \"Golpe de agujero múltiple izquierda\";\n"
"\"finishings.87\" = \"Top de perforación de agujeros múltiples\";\n"
"\"finishings.88\" = \"Multi-hole punch right\";\n"
"\"finishings.89\" = \"Fondo de perforación de agujeros múltiples\";\n"
"\"finishings.9\" = \"Sutura de borde\";\n"
"\"finishings.90\" = \"Pliegue de acordeón\";\n"
"\"finishings.91\" = \"Doble puerta\";\n"
"\"finishings.92\" = \"Puerta plegable\";\n"
"\"finishings.93\" = \"Media pliegue\";\n"
"\"finishings.94\" = \"Media Z plegable\";\n"
"\"finishings.95\" = \"Puerta izquierda\";\n"
"\"finishings.96\" = \"Carta plegable\";\n"
"\"finishings.97\" = \"Pliegue paralelo\";\n"
"\"finishings.98\" = \"Cargador\";\n"
"\"finishings.99\" = \"Puerta derecha\";\n"
"\"holding new jobs\" = \"ocupar nuevos puestos\";\n"
"\"job-state-reasons.aborted-by-system\" = \"Para.\";\n"
"\"job-state-reasons.compression-error\" = \"Error de descompresión.\";\n"
"\"job-state-reasons.document-format-error\" = \"Error de formato de documento.\";\n"
"\"job-state-reasons.document-password-error\" = \"Error de contraseña de documento.\";\n"
"\"job-state-reasons.document-permission-error\" = \"Error de permiso de documento.\";\n"
"\"job-state-reasons.document-unprintable-error\" = \"Documente error imprimible.\";\n"
"\"job-state-reasons.errors-detected\" = \"Errores detectados.\";\n"
"\"job-state-reasons.job-canceled-at-device\" = \"Cancelado en la impresora.\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"Cancelado por el usuario.\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"Impresión.\";\n"
"\"job-state-reasons.job-completed-with-errors\" = \"Imprimido con errores.\";\n"
"\"job-state-reasons.job-completed-with-warnings\" = \"Imprimido con advertencias.\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"Datos insuficientes.\";\n"
"\"job-state-reasons.job-fetchable\" = \"Increíble.\";\n"
"\"job-state-reasons.job-incoming\" = \"Entrando.\";\n"
"\"job-state-reasons.job-printing\" = \"Impresión.\";\n"
"\"job-state-reasons.job-queued\" = \"Preparando para imprimir.\";\n"
"\"job-state-reasons.job-spooling\" = \"Compartir.\";\n"
"\"job-state-reasons.none\" = \"Esperando.\";\n"
"\"job-state-reasons.printer-stopped\" = \"Impresora fuera de línea.\";\n"
"\"job-state-reasons.printer-stopped-partly\" = \"La impresora paró parcialmente.\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"Para.\";\n"
"\"job-state-reasons.queued-in-device\" = \"Listo.\";\n"
"\"job-state-reasons.warnings-detected\" = \"Advertencias detectadas.\";\n"
"\"job-state.3\" = \"Pendiente\";\n"
"\"job-state.4\" = \"Soldado\";\n"
"\"job-state.5\" = \"Procesamiento\";\n"
"\"job-state.6\" = \"Detenido\";\n"
"\"job-state.7\" = \"Cancelado\";\n"
"\"job-state.8\" = \"Abortados\";\n"
"\"job-state.9\" = \"Completado\";\n"
"\"joining\" = \"unirse\";\n"
"\"media\" = \"Media\";\n"
"\"media-col\" = \"Media\";\n"
"\"media-size\" = \"Tamaño de los medios\";\n"
"\"media-size-name\" = \"Tamaño de los medios\";\n"
"\"media-source\" = \"Input Tray\";\n"
"\"media-source.alternate\" = \"Suplente\";\n"
"\"media-source.alternate-roll\" = \"Rollo alternativo\";\n"
"\"media-source.auto\" = \"Automático\";\n"
"\"media-source.bottom\" = \"Bottom\";\n"
"\"media-source.by-pass-tray\" = \"Bandera multiusos\";\n"
"\"media-source.center\" = \"Center\";\n"
"\"media-source.disc\" = \"Disco\";\n"
"\"media-source.envelope\" = \"Envelope\";\n"
"\"media-source.hagaki\" = \"Hagaki\";\n"
"\"media-source.large-capacity\" = \"Gran capacidad\";\n"
"\"media-source.left\" = \"Izquierda\";\n"
"\"media-source.main\" = \"Main\";\n"
"\"media-source.main-roll\" = \"Rollo principal\";\n"
"\"media-source.manual\" = \"Manual\";\n"
"\"media-source.middle\" = \"Medio ambiente\";\n"
"\"media-source.photo\" = \"Foto\";\n"
"\"media-source.rear\" = \"Rear\";\n"
"\"media-source.right\" = \"Bien.\";\n"
"\"media-source.roll-1\" = \"Rollo 1\";\n"
"\"media-source.roll-10\" = \"Rollo 10\";\n"
"\"media-source.roll-2\" = \"Rollo 2\";\n"
"\"media-source.roll-3\" = \"Rollo 3\";\n"
"\"media-source.roll-4\" = \"Rollo 4\";\n"
"\"media-source.roll-5\" = \"Rollo 5\";\n"
"\"media-source.roll-6\" = \"Rollo 6\";\n"
"\"media-source.roll-7\" = \"Rollo 7\";\n"
"\"media-source.roll-8\" = \"Rollo 8\";\n"
"\"media-source.roll-9\" = \"Rollo 9\";\n"
"\"media-source.side\" = \"Lado\";\n"
"\"media-source.top\" = \"Top\";\n"
"\"media-source.tray-1\" = \"Tray 1\";\n"
"\"media-source.tray-10\" = \"Tray 10\";\n"
"\"media-source.tray-11\" = \"Tray 11\";\n"
"\"media-source.tray-12\" = \"Tray 12\";\n"
"\"media-source.tray-13\" = \"Tray 13\";\n"
"\"media-source.tray-14\" = \"Tray 14\";\n"
"\"media-source.tray-15\" = \"Tray 15\";\n"
"\"media-source.tray-16\" = \"Tray 16\";\n"
"\"media-source.tray-17\" = \"Tray 17\";\n"
"\"media-source.tray-18\" = \"Tray 18\";\n"
"\"media-source.tray-19\" = \"Tray 19\";\n"
"\"media-source.tray-2\" = \"Tray 2\";\n"
"\"media-source.tray-20\" = \"Tray 20\";\n"
"\"media-source.tray-3\" = \"Tray 3\";\n"
"\"media-source.tray-4\" = \"Tray 4\";\n"
"\"media-source.tray-5\" = \"Tray 5\";\n"
"\"media-source.tray-6\" = \"Tray 6\";\n"
"\"media-source.tray-7\" = \"Tray 7\";\n"
"\"media-source.tray-8\" = \"Tray 8\";\n"
"\"media-source.tray-9\" = \"Tray 9\";\n"
"\"media-tracking\" = \"Seguimiento de medios\";\n"
"\"media-tracking.continuous\" = \"Continua\";\n"
"\"media-tracking.gap\" = \"Gap\";\n"
"\"media-tracking.mark\" = \"Mark\";\n"
"\"media-tracking.web\" = \"Web\";\n"
"\"media-type\" = \"Tipo de medio\";\n"
"\"media-type.aluminum\" = \"Aluminio\";\n"
"\"media-type.auto\" = \"Automático\";\n"
"\"media-type.back-print-film\" = \"Imágenes de impresión\";\n"
"\"media-type.cardboard\" = \"Cartón\";\n"
"\"media-type.cardstock\" = \"Cardstock\";\n"
"\"media-type.cd\" = \"CD\";\n"
"\"media-type.continuous\" = \"Continua\";\n"
"\"media-type.continuous-long\" = \"Extremo continuo\";\n"
"\"media-type.continuous-short\" = \"corto continuo\";\n"
"\"media-type.corrugated-board\" = \"Tablero ondulado\";\n"
"\"media-type.disc\" = \"Disco óptico\";\n"
"\"media-type.disc-glossy\" = \"Disco óptico brillante\";\n"
"\"media-type.disc-high-gloss\" = \"Disco óptico de alto brillo\";\n"
"\"media-type.disc-matte\" = \"Disco óptico mate\";\n"
"\"media-type.disc-satin\" = \"Disco óptico Satin\";\n"
"\"media-type.disc-semi-gloss\" = \"Disco óptico semi-gloss\";\n"
"\"media-type.double-wall\" = \"Doble pared\";\n"
"\"media-type.dry-film\" = \"Cine seco\";\n"
"\"media-type.dvd\" = \"DVD\";\n"
"\"media-type.embossing-foil\" = \"Incrustación de láminas\";\n"
"\"media-type.end-board\" = \"Junta final\";\n"
"\"media-type.envelope\" = \"Envelope\";\n"
"\"media-type.envelope-archival\" = \"Sobre Archival\";\n"
"\"media-type.envelope-bond\" = \"Envoltorio de huesos\";\n"
"\"media-type.envelope-coated\" = \"Sobre coado\";\n"
"\"media-type.envelope-cotton\" = \"Sobre de algodón\";\n"
"\"media-type.envelope-fine\" = \"Envoltura fina\";\n"
"\"media-type.envelope-heavyweight\" = \"Sobres pesados\";\n"
"\"media-type.envelope-inkjet\" = \"Sobre de inyección de tinta\";\n"
"\"media-type.envelope-lightweight\" = \"Sobre ligero\";\n"
"\"media-type.envelope-plain\" = \"Envoltura plana\";\n"
"\"media-type.envelope-preprinted\" = \"Sobre impreso\";\n"
"\"media-type.envelope-window\" = \"Sobre ventana\";\n"
"\"media-type.fabric\" = \"Tejido\";\n"
"\"media-type.fabric-archival\" = \"Tejido de arquitectura\";\n"
"\"media-type.fabric-glossy\" = \"Tela brillante\";\n"
"\"media-type.fabric-high-gloss\" = \"Tejido alto brillo\";\n"
"\"media-type.fabric-matte\" = \"Tejido mate\";\n"
"\"media-type.fabric-semi-gloss\" = \"Tejido semi-gloss\";\n"
"\"media-type.fabric-waterproof\" = \"Tejido impermeable\";\n"
"\"media-type.film\" = \"Film\";\n"
"\"media-type.flexo-base\" = \"Base flexible\";\n"
"\"media-type.flexo-photo-polymer\" = \"Polómero de foto Flexo\";\n"
"\"media-type.flute\" = \"Fluido\";\n"
"\"media-type.foil\" = \"Foil\";\n"
"\"media-type.full-cut-tabs\" = \"pestañas de corte completo\";\n"
"\"media-type.glass\" = \"Cristal\";\n"
"\"media-type.glass-colored\" = \"Color de vidrio\";\n"
"\"media-type.glass-opaque\" = \"Opaque de vidrio\";\n"
"\"media-type.glass-surfaced\" = \"Vidrio en superficie\";\n"
"\"media-type.glass-textured\" = \"Textura de vidrio\";\n"
"\"media-type.gravure-cylinder\" = \"Cilindro de gravure\";\n"
"\"media-type.image-setter-paper\" = \"Papel de setter de imagen\";\n"
"\"media-type.imaging-cylinder\" = \"Cilindro de imagen\";\n"
"\"media-type.labels\" = \"Etiquetas\";\n"
"\"media-type.labels-colored\" = \"Etiquetas de colores\";\n"
"\"media-type.labels-glossy\" = \"Etiquetas brillantesy\";\n"
"\"media-type.labels-high-gloss\" = \"Altas etiquetas de brillo\";\n"
"\"media-type.labels-inkjet\" = \"Etiquetas de inyección de tinta\";\n"
"\"media-type.labels-matte\" = \"Etiquetas de la materia\";\n"
"\"media-type.labels-permanent\" = \"Etiquetas permanentes\";\n"
"\"media-type.labels-satin\" = \"Etiquetas Satin\";\n"
"\"media-type.labels-security\" = \"Etiquetas de seguridad\";\n"
"\"media-type.labels-semi-gloss\" = \"Etiquetas semi-gloss\";\n"
"\"media-type.laminating-foil\" = \"Laminating foil\";\n"
"\"media-type.letterhead\" = \"Letterhead\";\n"
"\"media-type.metal\" = \"Metal\";\n"
"\"media-type.metal-glossy\" = \"Metal brillante\";\n"
"\"media-type.metal-high-gloss\" = \"Metal alto brillo\";\n"
"\"media-type.metal-matte\" = \"Matte de metal\";\n"
"\"media-type.metal-satin\" = \"Metal satinado\";\n"
"\"media-type.metal-semi-gloss\" = \"Metal semi brillo\";\n"
"\"media-type.mounting-tape\" = \"Cinta de montaje\";\n"
"\"media-type.multi-layer\" = \"Multi capa\";\n"
"\"media-type.multi-part-form\" = \"Forma de múltiples piezas\";\n"
"\"media-type.other\" = \"Otros\";\n"
"\"media-type.paper\" = \"Documento\";\n"
"\"media-type.photographic\" = \"Papel fotográfico\";\n"
"\"media-type.photographic-archival\" = \"Archivo fotográfico\";\n"
"\"media-type.photographic-film\" = \"Cine fotográfico\";\n"
"\"media-type.photographic-glossy\" = \"Papel fotográfico brillante\";\n"
"\"media-type.photographic-high-gloss\" = \"Papel fotográfico alto brillo\";\n"
"\"media-type.photographic-matte\" = \"Papel fotográfico mate\";\n"
"\"media-type.photographic-satin\" = \"Papel fotográfico Satin\";\n"
"\"media-type.photographic-semi-gloss\" = \"Papel fotográfico semi-gloss\";\n"
"\"media-type.plastic\" = \"Plástico\";\n"
"\"media-type.plastic-archival\" = \"Archivo de plástico\";\n"
"\"media-type.plastic-colored\" = \"Color de plástico\";\n"
"\"media-type.plastic-glossy\" = \"Plástico brillante\";\n"
"\"media-type.plastic-high-gloss\" = \"Plástico alto brillo\";\n"
"\"media-type.plastic-matte\" = \"Aparato plástico\";\n"
"\"media-type.plastic-satin\" = \"satinado plástico\";\n"
"\"media-type.plastic-semi-gloss\" = \"Plástico semi brillante\";\n"
"\"media-type.plate\" = \"Placa\";\n"
"\"media-type.polyester\" = \"Poliéster\";\n"
"\"media-type.pre-cut-tabs\" = \"pestañas de corte pre\";\n"
"\"media-type.roll\" = \"Roll\";\n"
"\"media-type.screen\" = \"Pantalla\";\n"
"\"media-type.screen-paged\" = \"Paged\";\n"
"\"media-type.self-adhesive\" = \"Auto adhesivo\";\n"
"\"media-type.self-adhesive-film\" = \"Película autoadhesiva\";\n"
"\"media-type.shrink-foil\" = \"Barbacoa\";\n"
"\"media-type.single-face\" = \"Cara individual\";\n"
"\"media-type.single-wall\" = \"Pared individual\";\n"
"\"media-type.sleeve\" = \"Sleeve\";\n"
"\"media-type.stationery\" = \"Papelería\";\n"
"\"media-type.stationery-archival\" = \"Archivo de papelería\";\n"
"\"media-type.stationery-coated\" = \"Papel coado\";\n"
"\"media-type.stationery-cotton\" = \"Algodón de papelería\";\n"
"\"media-type.stationery-fine\" = \"Papel de aluminio\";\n"
"\"media-type.stationery-heavyweight\" = \"Papel pesado\";\n"
"\"media-type.stationery-heavyweight-coated\" = \"Papelería pesada recubierto\";\n"
"\"media-type.stationery-inkjet\" = \"Papel de inyección de tinta\";\n"
"\"media-type.stationery-letterhead\" = \"Letterhead\";\n"
"\"media-type.stationery-lightweight\" = \"Papel ligero\";\n"
"\"media-type.stationery-preprinted\" = \"Papel impreso\";\n"
"\"media-type.stationery-prepunched\" = \"Papel picado\";\n"
"\"media-type.tab-stock\" = \"Tab stock\";\n"
"\"media-type.tractor\" = \"Tractor\";\n"
"\"media-type.transfer\" = \"Transferencia\";\n"
"\"media-type.transparency\" = \"Transparencia\";\n"
"\"media-type.triple-wall\" = \"Triple pared\";\n"
"\"media-type.wet-film\" = \"Película húmeda\";\n"
"\"media.choice_iso_a4_210x297mm_na_letter_8.5x11in\" = \"A4 o US Letter\";\n"
"\"media.iso_2a0_1189x1682mm\" = \"2a0\";\n"
"\"media.iso_a0_841x1189mm\" = \"A0\";\n"
"\"media.iso_a0x3_1189x2523mm\" = \"A0x3\";\n"
"\"media.iso_a10_26x37mm\" = \"A10\";\n"
"\"media.iso_a1_594x841mm\" = \"A1\";\n"
"\"media.iso_a1x3_841x1783mm\" = \"A1x3\";\n"
"\"media.iso_a1x4_841x2378mm\" = \"A1x4\";\n"
"\"media.iso_a2_420x594mm\" = \"A2\";\n"
"\"media.iso_a2x3_594x1261mm\" = \"A2x3\";\n"
"\"media.iso_a2x4_594x1682mm\" = \"A2x4\";\n"
"\"media.iso_a2x5_594x2102mm\" = \"A2x5\";\n"
"\"media.iso_a3-extra_322x445mm\" = \"A3 (extra)\";\n"
"\"media.iso_a3_297x420mm\" = \"A3\";\n"
"\"media.iso_a3x3_420x891mm\" = \"A3x3\";\n"
"\"media.iso_a3x4_420x1189mm\" = \"A3x4\";\n"
"\"media.iso_a3x5_420x1486mm\" = \"A3x5\";\n"
"\"media.iso_a3x6_420x1783mm\" = \"A3x6\";\n"
"\"media.iso_a3x7_420x2080mm\" = \"A3x7\";\n"
"\"media.iso_a4-extra_235.5x322.3mm\" = \"A4 (extra)\";\n"
"\"media.iso_a4-tab_225x297mm\" = \"A4 (tab)\";\n"
"\"media.iso_a4_210x297mm\" = \"A4\";\n"
"\"media.iso_a4x3_297x630mm\" = \"A4x3\";\n"
"\"media.iso_a4x4_297x841mm\" = \"A4x4\";\n"
"\"media.iso_a4x5_297x1051mm\" = \"A4x5\";\n"
"\"media.iso_a4x6_297x1261mm\" = \"A4x6\";\n"
"\"media.iso_a4x7_297x1471mm\" = \"A4x7\";\n"
"\"media.iso_a4x8_297x1682mm\" = \"A4x8\";\n"
"\"media.iso_a4x9_297x1892mm\" = \"A4x9\";\n"
"\"media.iso_a5-extra_174x235mm\" = \"A5 (extra)\";\n"
"\"media.iso_a5_148x210mm\" = \"A5\";\n"
"\"media.iso_a6_105x148mm\" = \"A6\";\n"
"\"media.iso_a7_74x105mm\" = \"A7\";\n"
"\"media.iso_a8_52x74mm\" = \"A8\";\n"
"\"media.iso_a9_37x52mm\" = \"A9\";\n"
"\"media.iso_b0_1000x1414mm\" = \"B0\";\n"
"\"media.iso_b10_31x44mm\" = \"B10\";\n"
"\"media.iso_b1_707x1000mm\" = \"B1\";\n"
"\"media.iso_b2_500x707mm\" = \"B2\";\n"
"\"media.iso_b3_353x500mm\" = \"B3\";\n"
"\"media.iso_b4_250x353mm\" = \"B4\";\n"
"\"media.iso_b5-extra_201x276mm\" = \"B5 (extra)\";\n"
"\"media.iso_b5_176x250mm\" = \"B5 Envelope\";\n"
"\"media.iso_b6_125x176mm\" = \"B6\";\n"
"\"media.iso_b6c4_125x324mm\" = \"B6/C4Envelope\";\n"
"\"media.iso_b7_88x125mm\" = \"B7\";\n"
"\"media.iso_b8_62x88mm\" = \"B8\";\n"
"\"media.iso_b9_44x62mm\" = \"B9\";\n"
"\"media.iso_c0_917x1297mm\" = \"C0 Envelope\";\n"
"\"media.iso_c10_28x40mm\" = \"C10 Envelope\";\n"
"\"media.iso_c1_648x917mm\" = \"C1 Envelope\";\n"
"\"media.iso_c2_458x648mm\" = \"C2 Envelope\";\n"
"\"media.iso_c3_324x458mm\" = \"C3 Envelope\";\n"
"\"media.iso_c4_229x324mm\" = \"C4 Envelope\";\n"
"\"media.iso_c5_162x229mm\" = \"C5 Envelope\";\n"
"\"media.iso_c6_114x162mm\" = \"C6 Envelope\";\n"
"\"media.iso_c6c5_114x229mm\" = \"C6/C5 Envelope\";\n"
"\"media.iso_c7_81x114mm\" = \"C7 Envelope\";\n"
"\"media.iso_c7c6_81x162mm\" = \"C7/C6 Envelope\";\n"
"\"media.iso_c8_57x81mm\" = \"C8 Envelope\";\n"
"\"media.iso_c9_40x57mm\" = \"C9 Envelope\";\n"
"\"media.iso_dl_110x220mm\" = \"DL Envelope\";\n"
"\"media.iso_ra0_860x1220mm\" = \"ISO RA0\";\n"
"\"media.iso_ra1_610x860mm\" = \"ISO RA1\";\n"
"\"media.iso_ra2_430x610mm\" = \"ISO RA2\";\n"
"\"media.iso_ra3_305x430mm\" = \"ISO RA3\";\n"
"\"media.iso_ra4_215x305mm\" = \"ISO RA4\";\n"
"\"media.iso_sra0_900x1280mm\" = \"ISO SRA0\";\n"
"\"media.iso_sra1_640x900mm\" = \"ISO SRA1\";\n"
"\"media.iso_sra2_450x640mm\" = \"ISO SRA2\";\n"
"\"media.iso_sra3_320x450mm\" = \"ISO SRA3\";\n"
"\"media.iso_sra4_225x320mm\" = \"ISO SRA4\";\n"
"\"media.jis_b0_1030x1456mm\" = \"JIS B0\";\n"
"\"media.jis_b10_32x45mm\" = \"JIS B10\";\n"
"\"media.jis_b1_728x1030mm\" = \"JIS B1\";\n"
"\"media.jis_b2_515x728mm\" = \"JIS B2\";\n"
"\"media.jis_b3_364x515mm\" = \"JIS B3\";\n"
"\"media.jis_b4_257x364mm\" = \"JIS B4\";\n"
"\"media.jis_b5_182x257mm\" = \"JIS B5\";\n"
"\"media.jis_b6_128x182mm\" = \"JIS B6\";\n"
"\"media.jis_b7_91x128mm\" = \"JIS B7\";\n"
"\"media.jis_b8_64x91mm\" = \"JIS B8\";\n"
"\"media.jis_b9_45x64mm\" = \"JIS B9\";\n"
"\"media.jis_exec_216x330mm\" = \"JIS Executive\";\n"
"\"media.jpn_chou2_111.1x146mm\" = \"Envelope Chou 2\";\n"
"\"media.jpn_chou3_120x235mm\" = \"Envelope Chou 3\";\n"
"\"media.jpn_chou40_90x225mm\" = \"Envelope Chou 40\";\n"
"\"media.jpn_chou4_90x205mm\" = \"Envelope Chou 4\";\n"
"\"media.jpn_hagaki_100x148mm\" = \"Hagaki\";\n"
"\"media.jpn_kahu_240x322.1mm\" = \"Envelope Kahu\";\n"
"\"media.jpn_kaku2_240x332mm\" = \"Envelope Kahu 2\";\n"
"\"media.jpn_oufuku_148x200mm\" = \"Oufuku Responder Postcard\";\n"
"\"media.jpn_you4_105x235mm\" = \"Envelope Tú 4\";\n"
"\"media.na_a2_4.375x5.75in\" = \"Envelope A2\";\n"
"\"media.na_c5_6.5x9.5in\" = \"Envelope C5\";\n"
"\"media.na_executive_7.25x10.5in\" = \"Executive\";\n"
"\"media.na_fanfold-eur_8.5x12in\" = \"European Fanfold\";\n"
"\"media.na_fanfold-us_11x14.875in\" = \"US Fanfold\";\n"
"\"media.na_foolscap_8.5x13in\" = \"Foolscap\";\n"
"\"media.na_invoice_5.5x8.5in\" = \"Estado\";\n"
"\"media.na_legal-extra_9.5x15in\" = \"US Legal (Extra)\";\n"
"\"media.na_legal_8.5x14in\" = \"US Legal\";\n"
"\"media.na_letter-extra_9.5x12in\" = \"Carta de los Estados Unidos (Extra)\";\n"
"\"media.na_letter-plus_8.5x12.69in\" = \"Carta de los Estados Unidos (Plus)\";\n"
"\"media.na_letter_8.5x11in\" = \"Carta de los Estados Unidos\";\n"
"\"media.na_monarch_3.875x7.5in\" = \"Envelope Monarch\";\n"
"\"media.na_number-10_4.125x9.5in\" = \"Envelope #10\";\n"
"\"media.na_number-11_4.5x10.375in\" = \"Envelope #11\";\n"
"\"media.na_number-12_4.75x11in\" = \"Envelope #12\";\n"
"\"media.na_number-14_5x11.5in\" = \"Envelope #14\";\n"
"\"media.na_number-9_3.875x8.875in\" = \"Envelope #9\";\n"
"\"media.na_personal_3.625x6.5in\" = \"Envelope Personal\";\n"
"\"media.na_quarto_8.5x10.83in\" = \"Quarto\";\n"
"\"media.om_folio-sp_215x315mm\" = \"Folio\";\n"
"\"media.om_folio_210x330mm\" = \"Folio (especial)\";\n"
"\"media.om_invite_220x220mm\" = \"Invitación de Envelope\";\n"
"\"media.om_italian_110x230mm\" = \"Envelope Italian\";\n"
"\"media.om_juuro-ku-kai_198x275mm\" = \"198 x 275 mm\";\n"
"\"media.om_large-photo_200x300\" = \"200 x 300\";\n"
"\"media.om_medium-photo_130x180mm\" = \"130 x 180 mm\";\n"
"\"media.om_pa-kai_267x389mm\" = \"267 x 389m m\";\n"
"\"media.om_postfix_114x229mm\" = \"Envelope Postfix\";\n"
"\"media.prc_10_324x458mm\" = \"Envelope chinese #10\";\n"
"\"media.prc_16k_146x215mm\" = \"Chino 16k\";\n"
"\"media.prc_1_102x165mm\" = \"Envelope chinese #1\";\n"
"\"media.prc_2_102x176mm\" = \"Envelope chinese #2\";\n"
"\"media.prc_32k_97x151mm\" = \"Chino 32k\";\n"
"\"media.prc_3_125x176mm\" = \"Envelope chinese #3\";\n"
"\"media.prc_4_110x208mm\" = \"Envelope chinese #4\";\n"
"\"media.prc_5_110x220mm\" = \"Envelope chinese #5\";\n"
"\"media.prc_6_120x320mm\" = \"Envelope chinese #6\";\n"
"\"media.prc_7_160x230mm\" = \"Envelope chinese #7\";\n"
"\"media.prc_8_120x309mm\" = \"Envelope chinese #8\";\n"
"\"media.roc_16k_7.75x10.75in\" = \"ROC 16k\";\n"
"\"media.roc_8k_10.75x15.5in\" = \"ROC 8k\";\n"
"\"not configured\" = \"no configurado\";\n"
"\"not visible\" = \"no visible\";\n"
"\"off\" = \"apagado\";\n"
"\"on\" = \"on\";\n"
"\"orientation-requested\" = \"Orientación\";\n"
"\"orientation-requested.3\" = \"Retrato\";\n"
"\"orientation-requested.4\" = \"Paisaje\";\n"
"\"orientation-requested.5\" = \"Paisaje inverso\";\n"
"\"orientation-requested.6\" = \"Retrato inverso\";\n"
"\"orientation-requested.7\" = \"Ninguno\";\n"
"\"output-bin\" = \"Output Tray\";\n"
"\"output-bin.auto\" = \"Automático\";\n"
"\"output-bin.bottom\" = \"Bottom\";\n"
"\"output-bin.center\" = \"Center\";\n"
"\"output-bin.face-down\" = \"Cara abajo.\";\n"
"\"output-bin.face-up\" = \"Cara arriba\";\n"
"\"output-bin.large-capacity\" = \"Gran capacidad\";\n"
"\"output-bin.left\" = \"Izquierda\";\n"
"\"output-bin.mailbox-1\" = \"Mailbox 1\";\n"
"\"output-bin.mailbox-10\" = \"Mailbox 10\";\n"
"\"output-bin.mailbox-2\" = \"Mailbox 2\";\n"
"\"output-bin.mailbox-3\" = \"Mailbox 3\";\n"
"\"output-bin.mailbox-4\" = \"Mailbox 4\";\n"
"\"output-bin.mailbox-5\" = \"Mailbox 5\";\n"
"\"output-bin.mailbox-6\" = \"Mailbox 6\";\n"
"\"output-bin.mailbox-7\" = \"Mailbox 7\";\n"
"\"output-bin.mailbox-8\" = \"Mailbox 8\";\n"
"\"output-bin.mailbox-9\" = \"Mailbox 9\";\n"
"\"output-bin.middle\" = \"Medio ambiente\";\n"
"\"output-bin.my-mailbox\" = \"Mi buzón de correo\";\n"
"\"output-bin.rear\" = \"Rear\";\n"
"\"output-bin.right\" = \"Bien.\";\n"
"\"output-bin.side\" = \"Lado\";\n"
"\"output-bin.stacker-1\" = \"Stacker 1\";\n"
"\"output-bin.stacker-10\" = \"Stacker 10\";\n"
"\"output-bin.stacker-2\" = \"Stacker 2\";\n"
"\"output-bin.stacker-3\" = \"Stacker 3\";\n"
"\"output-bin.stacker-4\" = \"Stacker 4\";\n"
"\"output-bin.stacker-5\" = \"Stacker 5\";\n"
"\"output-bin.stacker-6\" = \"Stacker 6\";\n"
"\"output-bin.stacker-7\" = \"Stacker 7\";\n"
"\"output-bin.stacker-8\" = \"Stacker 8\";\n"
"\"output-bin.stacker-9\" = \"Stacker 9\";\n"
"\"output-bin.top\" = \"Top\";\n"
"\"output-bin.tray-1\" = \"Tray 1\";\n"
"\"output-bin.tray-10\" = \"Tray 10\";\n"
"\"output-bin.tray-2\" = \"Tray 2\";\n"
"\"output-bin.tray-3\" = \"Tray 3\";\n"
"\"output-bin.tray-4\" = \"Tray 4\";\n"
"\"output-bin.tray-5\" = \"Tray 5\";\n"
"\"output-bin.tray-6\" = \"Tray 6\";\n"
"\"output-bin.tray-7\" = \"Tray 7\";\n"
"\"output-bin.tray-8\" = \"Tray 8\";\n"
"\"output-bin.tray-9\" = \"Tray 9\";\n"
"\"print-color-mode\" = \"Modo de impresión\";\n"
"\"print-color-mode.auto\" = \"Automático\";\n"
"\"print-color-mode.auto-monochrome\" = \"Auto monocromo\";\n"
"\"print-color-mode.bi-level\" = \"Texto\";\n"
"\"print-color-mode.color\" = \"Color\";\n"
"\"print-color-mode.highlight\" = \"Highlight\";\n"
"\"print-color-mode.monochrome\" = \"Monocromo\";\n"
"\"print-color-mode.process-bi-level\" = \"Texto del proceso\";\n"
"\"print-color-mode.process-monochrome\" = \"Proceso monocromo\";\n"
"\"print-content-optimize\" = \"Optimize For\";\n"
"\"print-content-optimize.auto\" = \"Automático\";\n"
"\"print-content-optimize.graphic\" = \"Gráficos\";\n"
"\"print-content-optimize.photo\" = \"Foto\";\n"
"\"print-content-optimize.text\" = \"Texto\";\n"
"\"print-content-optimize.text-and-graphic\" = \"Texto y gráficos\";\n"
"\"print-darkness\" = \"Imprimir Oscuridad\";\n"
"\"print-quality\" = \"Calidad de impresión\";\n"
"\"print-quality.3\" = \"Proyecto\";\n"
"\"print-quality.4\" = \"Normal\";\n"
"\"print-quality.5\" = \"Mejor\";\n"
"\"print-scaling\" = \"Escalada\";\n"
"\"print-scaling.auto\" = \"Automático\";\n"
"\"print-scaling.auto-fit\" = \"Auto-fit\";\n"
"\"print-scaling.fill\" = \"Relleno\";\n"
"\"print-scaling.fit\" = \"Fit\";\n"
"\"print-scaling.none\" = \"Ninguno\";\n"
"\"print-speed\" = \"Velocidad de impresión\";\n"
"\"printer-resolution\" = \"Resolución\";\n"
"\"printer-state-reasons.cover-open\" = \"Cubierta abierta.\";\n"
"\"printer-state-reasons.door-open\" = \"Puerta abierta.\";\n"
"\"printer-state-reasons.identify-printer-requested\" = \"Identifique la impresora.\";\n"
"\"printer-state-reasons.input-tray-missing\" = \"Falta la bandeja de papel.\";\n"
"\"printer-state-reasons.marker-supply-empty\" = \"De tinta.\";\n"
"\"printer-state-reasons.marker-supply-low\" = \"Tinta baja.\";\n"
"\"printer-state-reasons.marker-waste-almost-full\" = \"La basura casi llena.\";\n"
"\"printer-state-reasons.marker-waste-full\" = \"basura llena.\";\n"
"\"printer-state-reasons.media-empty\" = \"De papel.\";\n"
"\"printer-state-reasons.media-jam\" = \"Mermelada de papel.\";\n"
"\"printer-state-reasons.media-low\" = \"Reemplaza el papel pronto.\";\n"
"\"printer-state-reasons.media-needed\" = \"Papel de carga.\";\n"
"\"printer-state-reasons.none\" = \"Listo.\";\n"
"\"printer-state-reasons.offline\" = \"Sin conexión.\";\n"
"\"printer-state-reasons.other\" = \"Ver la impresora.\";\n"
"\"printer-state-reasons.spool-area-full\" = \"Impresora ocupada.\";\n"
"\"printer-state-reasons.toner-empty\" = \"Fuera de toner.\";\n"
"\"printer-state-reasons.toner-low\" = \"Toner bajo.\";\n"
"\"printer-state.3\" = \"Idle\";\n"
"\"printer-state.4\" = \"Procesamiento\";\n"
"\"printer-state.5\" = \"Detenido\";\n"
"\"sides\" = \"Impresión de 2 asientos\";\n"
"\"sides.one-sided\" = \"Fuera.\";\n"
"\"sides.two-sided-long-edge\" = \"En (portrait)\";\n"
"\"sides.two-sided-short-edge\" = \"En (paisaje)\";\n"
"\"unable to join\" = \"incapaz de unirse\";\n"
"\"yesterday at %02d:%02d:%02d\" = \"ayer a las %02d:%02d:%02d\";\n"
"\"Åland Islands\" = \"Islas\";\n";
