static const char *nb_NO_strings = "\"  -a               Cancel all jobs (cancel).\" = \"  -a               Avbryt alle jobber.\";\n"
"\"  -c COPIES\" = \"  -c Kopier\";\n"
"\"  -d PRINTER       Specify printer.\" = \"  -d PRINTER       Angi skriver.\";\n"
"\"  -j JOB-ID        Specify job ID (cancel).\" = \"  -j JOB-ID        Specify job ID (cancel).\";\n"
"\"  -m DRIVER-NAME   Specify driver (add/modify).\" = \"  -m DRIVER-NAME   Specify driver (add/modify).\";\n"
"\"  -n COPIES        Specify number of copies (submit).\" = \"  -n COPIES        Specify number of copies (submit).\";\n"
"\"  -o %s=%s (default)\" = \"  -o %s=%s (default)\";\n"
"\"  -o NAME=VALUE    Specify option (add,modify,server,submit).\" = \"  -o NAME=VALUE    Specify option (add,modify,server,submit).\";\n"
"\"  -o print-darkness=-100 to 100\" = \"  -o print-darkness=-100 til 100\";\n"
"\"  -o printer-darkness=0 to 100\" = \"  -o printer-darkness=0 til 100\";\n"
"\"  -o printer-geo-location='geo:LATITUDE,LONGITUDE'\" = \"  -o printer-geo-location='geo:LATITUDE,LONGITUDE'\";\n"
"\"  -o printer-location='LOCATION'\" = \"  -o printer-location='LOCATION'\";\n"
"\"  -o printer-organization='ORGANIZATION'\" = \"  -o printer-organization='ORGANIZATION'\";\n"
"\"  -o printer-organizational-unit='UNIT/SECTION'\" = \"  -o printer-organizational-unit='UNIT/SECTION'\";\n"
"\"  -u URI           Specify ipp: or ipps: printer/server.\" = \"  -u URI           Specify ipp: or ipps: printer/server.\";\n"
"\"  -v DEVICE-URI    Specify socket: or usb: device (add/modify).\" = \"  -v DEVICE-URI    Specify socket: or usb: device (add/modify).\";\n"
"\"  add PRINTER      Add a printer.\" = \"  add PRINTER      Add a printer.\";\n"
"\"  autoadd          Automatically add supported printers.\" = \"  autoadd          Automatically add supported printers.\";\n"
"\"  cancel           Cancel one or more jobs.\" = \"  cancel           Cancel one or more jobs.\";\n"
"\"  default          Set the default printer.\" = \"  default          Set the default printer.\";\n"
"\"  delete           Delete a printer.\" = \"  delete           Delete a printer.\";\n"
"\"  devices          List devices.\" = \"  devices          List devices.\";\n"
"\"  drivers          List drivers.\" = \"  drivers          List drivers.\";\n"
"\"  jobs             List jobs.\" = \"  jobs             List jobs.\";\n"
"\"  modify           Modify a printer.\" = \"  modify           Modify a printer.\";\n"
"\"  options          List printer options.\" = \"  options          List printer options.\";\n"
"\"  pause            Pause printing for a printer.\" = \"  pause            Pause printing for a printer.\";\n"
"\"  printers         List printers.\" = \"  printers         List printers.\";\n"
"\"  resume           Resume printing for a printer.\" = \"  resume           Resume printing for a printer.\";\n"
"\"  server           Run a server.\" = \"  server           Run a server.\";\n"
"\"  shutdown         Shutdown a running server.\" = \"  shutdown         Shutdown a running server.\";\n"
"\"  status           Show server/printer/job status.\" = \"  status           Show server/printer/job status.\";\n"
"\"  submit           Submit a file for printing.\" = \"  submit           Submit a file for printing.\";\n"
"\"%04d-%02d-%02d at %02d:%02d:%02d\" = \"%04d-%02d-%02d at %02d:%02d:%02d\";\n"
"\"%d days ago at %02d:%02d:%02d\" = \"%d days ago at %02d:%02d:%02d\";\n"
"\"%d inches/sec\" = \"%d inches/sec\";\n"
"\"%d job\" = \"%d job\";\n"
/* Media size in millimeters */
"\"%d x %dmm\" = \"%d x %dmm\";\n"
"\"%ddpi\" = \"%ddpi\";\n"
"\"%dx%ddpi\" = \"%dx%ddpi\";\n"
/* Media size in inches */
"\"%g x %g\\\"\" = \"%g x %g\\\"\";\n"
/* size (type+borderless) */
"\"%s (%s%s)\" = \"%s (%s%s)\";\n"
/* size (type+borderless) from source/tray */
"\"%s (%s%s) from %s\" = \"%s (%s%s) from %s\";\n"
/* Source/Tray Media */
"\"%s Media\" = \"%s Media\";\n"
"\"%s: Bad 'server-port' value.\" = \"%s: Bad 'server-port' value.\";\n"
"\"%s: Bad job ID.\" = \"%s: Bad job ID.\";\n"
"\"%s: Bad printer URI '%s'.\" = \"%s: Bad printer URI '%s'.\";\n"
"\"%s: Cannot specify more than one sub-command.\" = \"%s: Cannot specify more than one sub-command.\";\n"
"\"%s: Empty print file received on the standard input.\" = \"%s: Empty print file received on the standard input.\";\n"
"\"%s: Failed to create a system.\" = \"%s: Failed to create a system.\";\n"
"\"%s: Missing '-d PRINTER'.\" = \"%s: Missing '-d PRINTER'.\";\n"
"\"%s: Missing '-m DRIVER-NAME'.\" = \"%s: Missing '-m DRIVER-NAME'.\";\n"
"\"%s: Missing '-v DEVICE-URI'.\" = \"%s: Missing '-v DEVICE-URI'.\";\n"
"\"%s: Missing copy count after '-n'.\" = \"%s: Missing copy count after '-n'.\";\n"
"\"%s: Missing device URI after '-v'.\" = \"%s: Missing device URI after '-v'.\";\n"
"\"%s: Missing driver name after '-m'.\" = \"%s: Missing driver name after '-m'.\";\n"
"\"%s: Missing filename after '--'.\" = \"%s: Missing filename after '--'.\";\n"
"\"%s: Missing hostname after '-h'.\" = \"%s: Missing hostname after '-h'.\";\n"
"\"%s: Missing job ID after '-j'.\" = \"%s: Missing job ID after '-j'.\";\n"
"\"%s: Missing option(s) after '-o'.\" = \"%s: Missing option(s) after '-o'.\";\n"
"\"%s: Missing printer URI after '-u'.\" = \"%s: Missing printer URI after '-u'.\";\n"
"\"%s: Missing printer name after '-d'.\" = \"%s: Missing printer name after '-d'.\";\n"
"\"%s: Missing space after '-o'.\" = \"%s: Missing space after '-o'.\";\n"
"\"%s: Missing title after '-t'.\" = \"%s: Missing title after '-t'.\";\n"
"\"%s: No default printer available.\" = \"%s: No default printer available.\";\n"
"\"%s: No files to print.\" = \"%s: No files to print.\";\n"
"\"%s: Server is not running.\" = \"%s: Server is not running.\";\n"
"\"%s: Sub-command '%s' does not accept files.\" = \"%s: Sub-command '%s' does not accept files.\";\n"
"\"%s: Sub-command 'autoadd' is not supported.\" = \"%s: Sub-command 'autoadd' is not supported.\";\n"
"\"%s: Too many files.\" = \"%s: Too many files.\";\n"
"\"%s: Unable to access '%s': %s\" = \"%s: Unable to access '%s': %s\";\n"
"\"%s: Unable to add printer: %s\" = \"%s: Unable to add printer: %s\";\n"
"\"%s: Unable to cancel job: %s\" = \"%s: Unable to cancel job: %s\";\n"
"\"%s: Unable to connect to printer at '%s:%d': %s\" = \"%s: Unable to connect to printer at '%s:%d': %s\";\n"
"\"%s: Unable to connect to server: %s\" = \"%s: Unable to connect to server: %s\";\n"
"\"%s: Unable to create temporary file: %s\" = \"%s: Unable to create temporary file: %s\";\n"
"\"%s: Unable to delete printer: %s\" = \"%s: Unable to delete printer: %s\";\n"
"\"%s: Unable to get available devices: %s\" = \"%s: Unable to get available devices: %s\";\n"
"\"%s: Unable to get information for '%s': %s\" = \"%s: Unable to get information for '%s': %s\";\n"
"\"%s: Unable to get information for printer: %s\" = \"%s: Unable to get information for printer: %s\";\n"
"\"%s: Unable to get printer options: %s\" = \"%s: Unable to get printer options: %s\";\n"
"\"%s: Unable to modify printer: %s\" = \"%s: Unable to modify printer: %s\";\n"
"\"%s: Unable to pause printer: %s\" = \"%s: Unable to pause printer: %s\";\n"
"\"%s: Unable to print '%s': %s\" = \"%s: Unable to print '%s': %s\";\n"
"\"%s: Unable to resume printer: %s\" = \"%s: Unable to resume printer: %s\";\n"
"\"%s: Unable to set default printer: %s\" = \"%s: Unable to set default printer: %s\";\n"
"\"%s: Unable to shutdown server: %s\" = \"%s: Unable to shutdown server: %s\";\n"
"\"%s: Unable to start server: %s\" = \"%s: Unable to start server: %s\";\n"
"\"%s: Unable to write to temporary file: %s\" = \"%s: Unable to write to temporary file: %s\";\n"
"\"%s: Unknown option '%s'.\" = \"%s: Unknown option '%s'.\";\n"
"\"%s: Unknown option '-%c'.\" = \"%s: Unknown option '-%c'.\";\n"
"\"%s: Unknown sub-command '%s'.\" = \"%s: Unknown sub-command '%s'.\";\n"
"\"%s: Unsupported URI scheme '%s'.\" = \"%s: Unsupported URI scheme '%s'.\";\n"
"\"%s: Warning - user credentials are not supported in URIs.\" = \"%s: Warning - user credentials are not supported in URIs.\";\n"
"\", Borderless\" = \", Borderless\";\n"
"\"A printer with that name already exists.\" = \"A printer with that name already exists.\";\n"
"\"Aborted %s\" = \"Aborted %s\";\n"
"\"Add Printer\" = \"Legg til skriver\";\n"
"\"Admin Group\" = \"Administratorgruppe\";\n"
"\"Afghanistan\" = \"Afghanistan\";\n"
"\"Albania\" = \"Albania\";\n"
"\"Algeria\" = \"Algerie\";\n"
"\"American Samoa\" = \"American Samoa\";\n"
"\"Andorra\" = \"Andorra\";\n"
"\"Angola\" = \"Angola\";\n"
"\"Anguilla\" = \"Anguilla\";\n"
"\"Antarctica\" = \"Antarctica\";\n"
"\"Antigua and Barbuda\" = \"Antigua and Barbuda\";\n"
"\"Argentina\" = \"Argentina\";\n"
"\"Armenia\" = \"Armenia\";\n"
"\"Aruba\" = \"Aruba\";\n"
"\"Australia\" = \"Australia\";\n"
"\"Austria\" = \"Austria\";\n"
"\"Auto\" = \"Auto\";\n"
"\"Auto-Detect Driver\" = \"Auto-Detect Driver\";\n"
"\"Azerbaijan\" = \"Azerbaijan\";\n"
"\"Bad administration group.\" = \"Bad administration group.\";\n"
"\"Bad port number.\" = \"Bad port number.\";\n"
"\"Bad print group.\" = \"Bad print group.\";\n"
"\"Bad printer defaults.\" = \"Bad printer defaults.\";\n"
"\"Bahamas\" = \"Bahamas\";\n"
"\"Bahrain\" = \"Bahrain\";\n"
"\"Bangladesh\" = \"Bangladesh\";\n"
"\"Barbados\" = \"Barbados\";\n"
"\"Belarus\" = \"Belarus\";\n"
"\"Belgium\" = \"Belgium\";\n"
"\"Belize\" = \"Belize\";\n"
"\"Benin\" = \"Benin\";\n"
"\"Bermuda\" = \"Bermuda\";\n"
"\"Bhutan\" = \"Bhutan\";\n"
"\"Bolivia (Plurinational State of)\" = \"Bolivia (Plurinational State of)\";\n"
"\"Bonaire, Sint Eustatius and Saba\" = \"Bonaire, Sint Eustatius and Saba\";\n"
"\"Borderless\" = \"Borderless\";\n"
"\"Bosnia and Herzegovina\" = \"Bosnia and Herzegovina\";\n"
"\"Botswana\" = \"Botswana\";\n"
"\"Bouvet Island\" = \"Bouvet Island\";\n"
"\"Brazil\" = \"Brazil\";\n"
"\"British Indian Ocean Territory\" = \"British Indian Ocean Territory\";\n"
"\"Brunei Darussalam\" = \"Brunei Darussalam\";\n"
"\"Bulgaria\" = \"Bulgaria\";\n"
"\"Burkina Faso\" = \"Burkina Faso\";\n"
"\"Burundi\" = \"Burundi\";\n"
"\"Cabo Verde\" = \"Cabo Verde\";\n"
"\"Cambodia\" = \"Cambodia\";\n"
"\"Cameroon\" = \"Cameroon\";\n"
"\"Canada\" = \"Canada\";\n"
"\"Cancel All Jobs\" = \"Avbryt alle jobber\";\n"
"\"Cancel Job\" = \"Avbryt jobb\";\n"
"\"Canceled %s\" = \"Canceled %s\";\n"
"\"Canceling\" = \"Canceling\";\n"
"\"Cayman Islands\" = \"Cayman Islands\";\n"
"\"Central African Republic\" = \"Central African Republic\";\n"
"\"Certificate created.\" = \"Certificate created.\";\n"
"\"Certificate installed.\" = \"Certificate installed.\";\n"
"\"Certificate request created.\" = \"Certificate request created.\";\n"
"\"Chad\" = \"Chad\";\n"
"\"Change Access Password\" = \"Endre administratorpassord\";\n"
"\"Change Log Level\" = \"Endre loggføringsnivå\";\n"
"\"Change Network Settings\" = \"Change Network Settings\";\n"
"\"Change Wi-Fi Network\" = \"Endre Wi-Fi-nettverk\";\n"
"\"Changes Saved.\" = \"Endringer lagret.\";\n"
"\"Changes saved.\" = \"Endringer lagret.\";\n"
"\"Chile\" = \"Chile\";\n"
"\"China\" = \"Kina\";\n"
"\"Christmas Island\" = \"Christmas Island\";\n"
"\"City/Locality\" = \"City/Locality\";\n"
"\"Cocos (Keeling) Islands\" = \"Cocos (Keeling) Islands\";\n"
"\"Colombia\" = \"Colombia\";\n"
"\"Comoros\" = \"Comoros\";\n"
"\"Completed %s\" = \"Completed %s\";\n"
"\"Configuration\" = \"Oppsett\";\n"
"\"Configure Media\" = \"Configure Media\";\n"
"\"Confirm Cancel All\" = \"Confirm Cancel All\";\n"
"\"Confirm Delete Printer\" = \"Confirm Delete Printer\";\n"
"\"Congo\" = \"Congo\";\n"
"\"Congo, Democratic Republic of the\" = \"Congo, Democratic Republic of the\";\n"
"\"Contact\" = \"Kontakt\";\n"
"\"Cook Islands\" = \"Cook Islands\";\n"
"\"Costa Rica\" = \"Costa Rica\";\n"
"\"Create Certificate Signing Request\" = \"Create Certificate Signing Request\";\n"
"\"Create New Certificate\" = \"Opprett nytt sertifikat\";\n"
"\"Create New TLS Certificate\" = \"Create New TLS Certificate\";\n"
"\"Create TLS Certificate Request\" = \"Create TLS Certificate Request\";\n"
"\"Croatia\" = \"Kroatia\";\n"
"\"Cuba\" = \"Kuba\";\n"
"\"Curaçao\" = \"Curaçao\";\n"
"\"Current Password\" = \"Nåværende passord\";\n"
"\"Custom Size\" = \"Egendefinert størrelse\";\n"
"\"Cyprus\" = \"Kypros\";\n"
"\"Czechia\" = \"Czechia\";\n"
"\"Côte d'Ivoire\" = \"Côte d'Ivoire\";\n"
"\"DHCP\" = \"DHCP\";\n"
"\"DHCP w/Manual Address\" = \"DHCP w/Manual Address\";\n"
"\"DNS-SD Service Name\" = \"DNS-SD Service Name\";\n"
"\"Debugging\" = \"Debugging\";\n"
"\"Default printer set.\" = \"Default printer set.\";\n"
"\"Delete\" = \"Slett\";\n"
"\"Delete Printer\" = \"Slett skriver\";\n"
"\"Denmark\" = \"Danmark\";\n"
"\"Djibouti\" = \"Djibouti\";\n"
"\"Domain Name\" = \"Domain Name\";\n"
"\"Dominica\" = \"Dominica\";\n"
"\"Dominican Republic\" = \"Dominican Republic\";\n"
"\"Download Certificate Request File\" = \"Download Certificate Request File\";\n"
"\"Ecuador\" = \"Ecuador\";\n"
"\"Egypt\" = \"Egypt\";\n"
"\"El Salvador\" = \"El Salvador\";\n"
"\"Equatorial Guinea\" = \"Equatorial Guinea\";\n"
"\"Eritrea\" = \"Eritrea\";\n"
"\"Errors\" = \"Errors\";\n"
"\"Estonia\" = \"Estonia\";\n"
"\"Eswatini\" = \"Eswatini\";\n"
"\"Ethiopia\" = \"Ethiopia\";\n"
"\"Falkland Islands (Malvinas)\" = \"Falkland Islands (Malvinas)\";\n"
"\"Faroe Islands\" = \"Faroe Islands\";\n"
"\"Fatal Errors/Conditions\" = \"Fatal Errors/Conditions\";\n"
"\"Fiji\" = \"Fiji\";\n"
"\"Finland\" = \"Finland\";\n"
"\"France\" = \"France\";\n"
"\"French Guiana\" = \"French Guiana\";\n"
"\"French Polynesia\" = \"French Polynesia\";\n"
"\"French Southern Territories\" = \"French Southern Territories\";\n"
"\"Gabon\" = \"Gabon\";\n"
"\"Gambia\" = \"Gambia\";\n"
"\"Georgia\" = \"Georgia\";\n"
"\"Germany\" = \"Germany\";\n"
"\"Ghana\" = \"Ghana\";\n"
"\"Gibraltar\" = \"Gibraltar\";\n"
"\"Greece\" = \"Greece\";\n"
"\"Greenland\" = \"Greenland\";\n"
"\"Grenada\" = \"Grenada\";\n"
"\"Group changes saved.\" = \"Group changes saved.\";\n"
"\"Guadeloupe\" = \"Guadeloupe\";\n"
"\"Guam\" = \"Guam\";\n"
"\"Guatemala\" = \"Guatemala\";\n"
"\"Guernsey\" = \"Guernsey\";\n"
"\"Guinea\" = \"Guinea\";\n"
"\"Guinea-Bissau\" = \"Guinea-Bissau\";\n"
"\"Guyana\" = \"Guyana\";\n"
"\"Haiti\" = \"Haiti\";\n"
"\"Heard Island and McDonald Islands\" = \"Heard Island and McDonald Islands\";\n"
"\"Hidden SSID\" = \"Hidden SSID\";\n"
"\"Hold Job\" = \"Hold Job\";\n"
"\"Hold New Jobs\" = \"Hold New Jobs\";\n"
"\"Holding new jobs.\" = \"Holding new jobs.\";\n"
"\"Holy See\" = \"Holy See\";\n"
"\"Honduras\" = \"Honduras\";\n"
"\"Hong Kong\" = \"Hong Kong\";\n"
"\"Hostname\" = \"Hostname\";\n"
"\"Human-Readable Location\" = \"Human-Readable Location\";\n"
"\"Hungary\" = \"Hungary\";\n"
"\"IPv4 Address\" = \"IPv4 Address\";\n"
"\"IPv4 Configuration\" = \"IPv4 Configuration\";\n"
"\"IPv4 Gateway\" = \"IPv4 Gateway\";\n"
"\"IPv4 Netmask\" = \"IPv4 Netmask\";\n"
"\"IPv6 Address\" = \"IPv6 Address\";\n"
"\"IPv6 Configuration\" = \"IPv6 Configuration\";\n"
"\"IPv6 Link-Local\" = \"IPv6 Link-Local\";\n"
"\"IPv6 Prefix Length\" = \"IPv6 Prefix Length\";\n"
"\"Iceland\" = \"Iceland\";\n"
"\"Identify Printer\" = \"Identify Printer\";\n"
"\"India\" = \"India\";\n"
"\"Indonesia\" = \"Indonesia\";\n"
"\"Informational\" = \"Informational\";\n"
"\"Install TLS Certificate\" = \"Installer TLS-sertifikat\";\n"
"\"Invalid IPv4 address.\" = \"Invalid IPv4 address.\";\n"
"\"Invalid IPv4 netmask.\" = \"Invalid IPv4 netmask.\";\n"
"\"Invalid IPv6 address.\" = \"Invalid IPv6 address.\";\n"
"\"Invalid IPv6 prefix length.\" = \"Invalid IPv6 prefix length.\";\n"
"\"Invalid Job ID.\" = \"Invalid Job ID.\";\n"
"\"Invalid certificate or private key.\" = \"Ugyldig sertifikat eller privat nøkkel.\";\n"
"\"Invalid form data.\" = \"Ugyldig skjemadata.\";\n"
"\"Invalid form submission.\" = \"Ugyldig skjemainnsendelse.\";\n"
"\"Invalid job ID.\" = \"Ugyldig jobb-ID.\";\n"
"\"Invalid network configuration.\" = \"Invalid network configuration.\";\n"
"\"Iran (Islamic Republic of)\" = \"Iran (Islamic Republic of)\";\n"
"\"Iraq\" = \"Irak\";\n"
"\"Ireland\" = \"Irland\";\n"
"\"Isle of Man\" = \"Isle of Man\";\n"
"\"Israel\" = \"Israel\";\n"
"\"Italy\" = \"Italia\";\n"
"\"Jamaica\" = \"Jamaica\";\n"
"\"Japan\" = \"Japan\";\n"
"\"Jersey\" = \"Jersey\";\n"
"\"Job #\" = \"Jobb #\";\n"
"\"Job canceled.\" = \"Job canceled.\";\n"
"\"Job held.\" = \"Job held.\";\n"
"\"Job released.\" = \"Job released.\";\n"
"\"Jobs\" = \"Jobber\";\n"
"\"Joining Wi-Fi Network\" = \"Joining Wi-Fi Network\";\n"
"\"Jordan\" = \"Jordan\";\n"
"\"Kazakhstan\" = \"Kazakhstan\";\n"
"\"Kenya\" = \"Kenya\";\n"
"\"Kiribati\" = \"Kiribati\";\n"
"\"Korea (Democratic People's Republic of)\" = \"Korea (Democratic People's Republic of)\";\n"
"\"Korea, Republic of\" = \"Korea, Republic of\";\n"
"\"Kuwait\" = \"Kuwait\";\n"
"\"Kyrgyzstan\" = \"Kyrgyzstan\";\n"
"\"Landscape\" = \"Liggende\";\n"
"\"Lao People's Democratic Republic\" = \"Lao People's Democratic Republic\";\n"
"\"Latvia\" = \"Latvia\";\n"
"\"Lebanon\" = \"Lebanon\";\n"
"\"Lesotho\" = \"Lesotho\";\n"
"\"Level\" = \"Nivå\";\n"
"\"Liberia\" = \"Liberia\";\n"
"\"Libya\" = \"Libya\";\n"
"\"Liechtenstein\" = \"Liechtenstein\";\n"
"\"Lithuania\" = \"Lithuania\";\n"
"\"Location\" = \"Location\";\n"
"\"Log Level\" = \"Loggføringsnivå\";\n"
"\"Logging\" = \"Logging\";\n"
"\"Logs\" = \"Logger\";\n"
"\"Luxembourg\" = \"Luxembourg\";\n"
"\"Macao\" = \"Macao\";\n"
"\"Madagascar\" = \"Madagascar\";\n"
"\"Malawi\" = \"Malawi\";\n"
"\"Malaysia\" = \"Malaysia\";\n"
"\"Maldives\" = \"Maldives\";\n"
"\"Mali\" = \"Mali\";\n"
"\"Malta\" = \"Malta\";\n"
"\"Manual Configuration\" = \"Manual Configuration\";\n"
"\"Marshall Islands\" = \"Marshall Islands\";\n"
"\"Martinique\" = \"Martinique\";\n"
"\"Mauritania\" = \"Mauritania\";\n"
"\"Mauritius\" = \"Mauritius\";\n"
"\"Mayotte\" = \"Mayotte\";\n"
"\"Media\" = \"Media\";\n"
"\"Mexico\" = \"Mexico\";\n"
"\"Micronesia (Federated States of)\" = \"Micronesia (Federated States of)\";\n"
"\"Missing action.\" = \"Missing action.\";\n"
"\"Missing job ID.\" = \"Missing job ID.\";\n"
"\"Missing network name.\" = \"Missing network name.\";\n"
"\"Missing private key.\" = \"Mangler privat nøkkel.\";\n"
"\"Moldova, Republic of\" = \"Moldova, Republic of\";\n"
"\"Monaco\" = \"Monaco\";\n"
"\"Mongolia\" = \"Mongolia\";\n"
"\"Montenegro\" = \"Montenegro\";\n"
"\"Montserrat\" = \"Montserrat\";\n"
"\"Morocco\" = \"Marokko\";\n"
"\"Mozambique\" = \"Mozambique\";\n"
"\"Myanmar\" = \"Myanmar\";\n"
"\"Name\" = \"Navn\";\n"
"\"Namibia\" = \"Namibia\";\n"
"\"Nauru\" = \"Nauru\";\n"
"\"Nepal\" = \"Nepal\";\n"
"\"Netherlands\" = \"Nederland\";\n"
"\"Network\" = \"Nettverk\";\n"
"\"Network Printer\" = \"Nettverksskriver\";\n"
"\"Networking\" = \"Networking\";\n"
"\"New Caledonia\" = \"New Caledonia\";\n"
"\"New Zealand\" = \"New Zealand\";\n"
"\"Nicaragua\" = \"Nicaragua\";\n"
"\"Niger\" = \"Niger\";\n"
"\"Nigeria\" = \"Nigeria\";\n"
"\"Niue\" = \"Niue\";\n"
"\"No default printer set.\" = \"No default printer set.\";\n"
"\"No jobs in history.\" = \"Ingen jobber i historikk.\";\n"
"\"Norfolk Island\" = \"Norfolk Island\";\n"
"\"North Macedonia\" = \"North Macedonia\";\n"
"\"Northern Mariana Islands\" = \"Northern Mariana Islands\";\n"
"\"Norway\" = \"Norway\";\n"
"\"Not set\" = \"Not set\";\n"
"\"Off\" = \"Off\";\n"
"\"Offset\" = \"Offset\";\n"
"\"Oman\" = \"Oman\";\n"
"\"Options:\" = \"Options:\";\n"
"\"Organization\" = \"Organisasjon\";\n"
"\"Organization Name\" = \"Organisasjonsnavn\";\n"
"\"Other Settings\" = \"Andre innstillinger\";\n"
"\"Pakistan\" = \"Pakistan\";\n"
"\"Palau\" = \"Palau\";\n"
"\"Palestine, State of\" = \"Palestine, State of\";\n"
"\"Panama\" = \"Panama\";\n"
"\"Papua New Guinea\" = \"Papua New Guinea\";\n"
"\"Paraguay\" = \"Paraguay\";\n"
"\"Password\" = \"Passord\";\n"
"\"Password changed.\" = \"Passord endret.\";\n"
"\"Password must be at least eight characters long and contain at least one uppercase letter, one lowercase letter, and one digit.\" = \"Password must be at least eight characters long and contain at least one uppercase letter, one lowercase letter, and one digit.\";\n"
"\"Passwords do not match.\" = \"Passordene samsvarer ikke.\";\n"
"\"Pause Printing\" = \"Pause Printing\";\n"
"\"Peru\" = \"Peru\";\n"
"\"Philippines\" = \"Philippines\";\n"
"\"Pitcairn\" = \"Pitcairn\";\n"
"\"Please enter a hostname or IP address for the printer.\" = \"Skriv inn vertsnavnet eller IP-adressen til skriveren.\";\n"
"\"Please enter a printer name.\" = \"Skriv inn et skrivernavn.\";\n"
"\"Please select a device.\" = \"Velg en enhet.\";\n"
"\"Please select a driver.\" = \"Please select a driver.\";\n"
"\"Please select a valid log level.\" = \"Velg et gyldig loggføringsnivå.\";\n"
"\"Poland\" = \"Polen\";\n"
"\"Portrait\" = \"Stående\";\n"
"\"Portugal\" = \"Portugal\";\n"
"\"Primary DNS\" = \"Primary DNS\";\n"
"\"Print Group\" = \"Skrivergruppe\";\n"
"\"Print Test Page\" = \"Skriv ut testside\";\n"
"\"Print job options:\" = \"Print job options:\";\n"
"\"Printer identified.\" = \"Skriver identifisert.\";\n"
"\"Printer is currently active.\" = \"Skriveren er i bruk.\";\n"
"\"Printer names must start with a letter or underscore and cannot contain special characters.\" = \"Printer names must start with a letter or underscore and cannot contain special characters.\";\n"
"\"Printer options:\" = \"Skriverinnstillinger:\";\n"
"\"Printer paused.\" = \"Skriver satt på pause.\";\n"
"\"Printer pausing.\" = \"Skriver tar pause.\";\n"
"\"Printer resuming.\" = \"Skriver gjenopptar utskrift.\";\n"
"\"Printers\" = \"Skrivere\";\n"
"\"Printing Defaults\" = \"Utskriftsforvalg\";\n"
"\"Puerto Rico\" = \"Puerto Rico\";\n"
"\"Qatar\" = \"Qatar\";\n"
"\"Queued %s\" = \"Queued %s\";\n"
"\"Release Held New Jobs\" = \"Release Held New Jobs\";\n"
"\"Release Job\" = \"Release Job\";\n"
"\"Released held new jobs.\" = \"Released held new jobs.\";\n"
"\"Reprint Job\" = \"Skriv ut jobb igjen\";\n"
"\"Reprinted job.\" = \"Reprinted job.\";\n"
"\"Resume Printing\" = \"Fortsett utskrift\";\n"
"\"Reverse Landscape\" = \"Omvendt liggende\";\n"
"\"Reverse Portrait\" = \"Omvendt stående\";\n"
"\"Romania\" = \"Romania\";\n"
/* Running, STATE since DATE REASONS */
"\"Running, %s since %s%s.\" = \"Running, %s since %s%s.\";\n"
"\"Russian Federation\" = \"Russian Federation\";\n"
"\"Rwanda\" = \"Rwanda\";\n"
"\"Réunion\" = \"Réunion\";\n"
"\"Saint Barthélemy\" = \"Saint Barthélemy\";\n"
"\"Saint Helena, Ascension and Tristan da Cunha\" = \"Saint Helena, Ascension and Tristan da Cunha\";\n"
"\"Saint Kitts and Nevis\" = \"Saint Kitts and Nevis\";\n"
"\"Saint Lucia\" = \"Saint Lucia\";\n"
"\"Saint Martin (French part)\" = \"Saint Martin (French part)\";\n"
"\"Saint Pierre and Miquelon\" = \"Saint Pierre and Miquelon\";\n"
"\"Saint Vincent and the Grenadines\" = \"Saint Vincent and the Grenadines\";\n"
"\"Samoa\" = \"Samoa\";\n"
"\"San Marino\" = \"San Marino\";\n"
"\"Sao Tome and Principe\" = \"Sao Tome and Principe\";\n"
"\"Saudi Arabia\" = \"Saudi Arabia\";\n"
"\"Save Changes\" = \"Save Changes\";\n"
"\"Secondary DNS\" = \"Secondary DNS\";\n"
"\"Security\" = \"Security\";\n"
"\"Select Driver\" = \"Select Driver\";\n"
"\"Senegal\" = \"Senegal\";\n"
"\"Serbia\" = \"Serbia\";\n"
"\"Server is not running.\" = \"Tjeneren kjører ikke.\";\n"
"\"Set Access Password\" = \"Sett tilgangspassord\";\n"
"\"Set as Default\" = \"Sett som forvalg\";\n"
"\"Seychelles\" = \"Seychelles\";\n"
"\"Sierra Leone\" = \"Sierra Leone\";\n"
"\"Singapore\" = \"Singapore\";\n"
"\"Sint Maarten (Dutch part)\" = \"Sint Maarten (Dutch part)\";\n"
"\"Slovakia\" = \"Slovakia\";\n"
"\"Slovenia\" = \"Slovenia\";\n"
"\"Solomon Islands\" = \"Solomon Islands\";\n"
"\"Somalia\" = \"Somalia\";\n"
"\"South Africa\" = \"South Africa\";\n"
"\"South Georgia and the South Sandwich Islands\" = \"South Georgia and the South Sandwich Islands\";\n"
"\"South Sudan\" = \"South Sudan\";\n"
"\"Spain\" = \"Spain\";\n"
"\"Sri Lanka\" = \"Sri Lanka\";\n"
"\"Started %s\" = \"Started %s\";\n"
"\"Status\" = \"Status\";\n"
"\"Sub-commands:\" = \"Sub-commands:\";\n"
"\"Sudan\" = \"Sudan\";\n"
"\"Supplies\" = \"Supplies\";\n"
"\"Suriname\" = \"Suriname\";\n"
"\"Svalbard and Jan Mayen\" = \"Svalbard and Jan Mayen\";\n"
"\"Sweden\" = \"Sweden\";\n"
"\"Switzerland\" = \"Switzerland\";\n"
"\"Syrian Arab Republic\" = \"Syrian Arab Republic\";\n"
"\"Taiwan, Province of China\" = \"Taiwan, Province of China\";\n"
"\"Tajikistan\" = \"Tajikistan\";\n"
"\"Tanzania, United Republic of\" = \"Tanzania, United Republic of\";\n"
"\"Test page printed.\" = \"Test page printed.\";\n"
"\"Thailand\" = \"Thailand\";\n"
"\"This form creates a certificate signing request ('CSR') that you can send to a Certificate Authority ('CA') to obtain a trusted TLS certificate. The private key is saved separately for use with the certificate you get from the CA.\" = \"This form creates a certificate signing request ('CSR') that you can send to a Certificate Authority ('CA') to obtain a trusted TLS certificate. The private key is saved separately for use with the certificate you get from the CA.\";\n"
"\"This form creates a new 'self-signed' TLS certificate for secure printing. Self-signed certificates are not automatically trusted by web browsers.\" = \"This form creates a new 'self-signed' TLS certificate for secure printing. Self-signed certificates are not automatically trusted by web browsers.\";\n"
"\"This form will install a trusted TLS certificate you have obtained from a Certificate Authority ('CA'). Once installed, it will be used immediately.\" = \"This form will install a trusted TLS certificate you have obtained from a Certificate Authority ('CA'). Once installed, it will be used immediately.\";\n"
"\"Timor-Leste\" = \"Timor-Leste\";\n"
"\"Togo\" = \"Togo\";\n"
"\"Tokelau\" = \"Tokelau\";\n"
"\"Tonga\" = \"Tonga\";\n"
"\"Trinidad and Tobago\" = \"Trinidad and Tobago\";\n"
"\"Tunisia\" = \"Tunisia\";\n"
"\"Turkey\" = \"Turkey\";\n"
"\"Turkmenistan\" = \"Turkmenistan\";\n"
"\"Turks and Caicos Islands\" = \"Turks and Caicos Islands\";\n"
"\"Tuvalu\" = \"Tuvalu\";\n"
"\"Uganda\" = \"Uganda\";\n"
"\"Ukraine\" = \"Ukraine\";\n"
"\"Unable to access test print file.\" = \"Unable to access test print file.\";\n"
"\"Unable to copy print job.\" = \"Unable to copy print job.\";\n"
"\"Unable to create certificate request.\" = \"Unable to create certificate request.\";\n"
"\"Unable to create certificate.\" = \"Kunne ikke opprette sertifikat.\";\n"
"\"Unable to create test print job.\" = \"Unable to create test print job.\";\n"
"\"Unable to identify printer.\" = \"Unable to identify printer.\";\n"
"\"Unable to lookup address.\" = \"Unable to lookup address.\";\n"
"\"Unable to use that driver.\" = \"Unable to use that driver.\";\n"
"\"United Arab Emirates\" = \"United Arab Emirates\";\n"
"\"United Kingdom\" = \"United Kingdom\";\n"
"\"United Kingdom of Great Britain and Northern Ireland\" = \"United Kingdom of Great Britain and Northern Ireland\";\n"
"\"United States Minor Outlying Islands\" = \"United States Minor Outlying Islands\";\n"
"\"United States of America\" = \"United States of America\";\n"
"\"Unknown\" = \"Ukjent\";\n"
"\"Unknown action.\" = \"Ukjent handling.\";\n"
"\"Unknown form action.\" = \"Ukjent skjemahandling.\";\n"
"\"Unknown form request.\" = \"Ukjent skjemaforespørsel.\";\n"
"\"Updating Network Configuration\" = \"Updating Network Configuration\";\n"
"\"Uruguay\" = \"Uruguay\";\n"
"\"Usage: %s SUB-COMMAND [OPTIONS] [FILENAME]\\n\" = \"Usage: %s SUB-COMMAND [OPTIONS] [FILENAME]\\n\";\n"
"\"Use My Position\" = \"Use My Position\";\n"
"\"Users\" = \"Brukere\";\n"
"\"Uzbekistan\" = \"Uzbekistan\";\n"
"\"Vanuatu\" = \"Vanuatu\";\n"
"\"Venezuela (Bolivarian Republic of)\" = \"Venezuela (Bolivarian Republic of)\";\n"
"\"Version %s\" = \"Version %s\";\n"
"\"Viet Nam\" = \"Viet Nam\";\n"
"\"View Logs\" = \"Vis loggføring\";\n"
"\"Virgin Islands (British)\" = \"Virgin Islands (British)\";\n"
"\"Virgin Islands (U.S.)\" = \"Virgin Islands (U.S.)\";\n"
"\"Wallis and Futuna\" = \"Wallis and Futuna\";\n"
"\"Warning\" = \"Advarsel\";\n"
"\"Western Sahara\" = \"Western Sahara\";\n"
"\"Wi-Fi Configuration\" = \"Wi-Fi-oppsett\";\n"
"\"Wi-Fi Network\" = \"Wi-Fi-nettverk\";\n"
"\"Width\" = \"Bredde\";\n"
"\"Wrong old password.\" = \"Feil gammelt passord.\";\n"
"\"Yemen\" = \"Yemen\";\n"
"\"Zambia\" = \"Zambia\";\n"
"\"Zimbabwe\" = \"Zimbabwe\";\n"
"\"at %02d:%02d:%02d\" = \"at %02d:%02d:%02d\";\n"
/* IPP attribute, keyword, and enum (integer) localizations */
"\"copies\" = \"Antall kopier\";\n"
"\"default printer\" = \"forvalgt skriver\";\n"
"\"finishings\" = \"Finisher\";\n"
"\"finishings.10\" = \"Fold\";\n"
"\"finishings.100\" = \"Z fold\";\n"
"\"finishings.101\" = \"Engineering Z fold\";\n"
"\"finishings.11\" = \"Cut\";\n"
"\"finishings.12\" = \"Bale\";\n"
"\"finishings.13\" = \"Booklet maker\";\n"
"\"finishings.15\" = \"Coat\";\n"
"\"finishings.16\" = \"Laminate\";\n"
"\"finishings.20\" = \"Staple top left\";\n"
"\"finishings.21\" = \"Staple bottom left\";\n"
"\"finishings.22\" = \"Staple top right\";\n"
"\"finishings.23\" = \"Staple bottom right\";\n"
"\"finishings.24\" = \"Edge stitch left\";\n"
"\"finishings.25\" = \"Edge stitch top\";\n"
"\"finishings.26\" = \"Edge stitch right\";\n"
"\"finishings.27\" = \"Edge stitch bottom\";\n"
"\"finishings.28\" = \"2 staples on left\";\n"
"\"finishings.29\" = \"2 staples on top\";\n"
"\"finishings.3\" = \"None\";\n"
"\"finishings.30\" = \"2 staples on right\";\n"
"\"finishings.31\" = \"2 staples on bottom\";\n"
"\"finishings.32\" = \"3 staples on left\";\n"
"\"finishings.33\" = \"3 staples on top\";\n"
"\"finishings.34\" = \"3 staples on right\";\n"
"\"finishings.35\" = \"3 staples on bottom\";\n"
"\"finishings.4\" = \"Staple\";\n"
"\"finishings.5\" = \"Punch\";\n"
"\"finishings.50\" = \"Bind left\";\n"
"\"finishings.51\" = \"Bind top\";\n"
"\"finishings.52\" = \"Bind right\";\n"
"\"finishings.53\" = \"Bind bottom\";\n"
"\"finishings.6\" = \"Cover\";\n"
"\"finishings.60\" = \"Cut after every page\";\n"
"\"finishings.61\" = \"Cut after every document\";\n"
"\"finishings.62\" = \"Cut after every set\";\n"
"\"finishings.63\" = \"Cut after job\";\n"
"\"finishings.7\" = \"Bind\";\n"
"\"finishings.70\" = \"Punch top left\";\n"
"\"finishings.71\" = \"Punch bottom left\";\n"
"\"finishings.72\" = \"Punch top right\";\n"
"\"finishings.73\" = \"Punch bottom right\";\n"
"\"finishings.74\" = \"2-hole punch left\";\n"
"\"finishings.75\" = \"2-hole punch top\";\n"
"\"finishings.76\" = \"2-hole punch right\";\n"
"\"finishings.77\" = \"2-hole punch bottom\";\n"
"\"finishings.78\" = \"3-hole punch left\";\n"
"\"finishings.79\" = \"3-hole punch top\";\n"
"\"finishings.8\" = \"Saddle stitch\";\n"
"\"finishings.80\" = \"3-hole punch right\";\n"
"\"finishings.81\" = \"3-hole punch bottom\";\n"
"\"finishings.82\" = \"4-hole punch left\";\n"
"\"finishings.83\" = \"4-hole punch top\";\n"
"\"finishings.84\" = \"4-hole punch right\";\n"
"\"finishings.85\" = \"4-hole punch bottom\";\n"
"\"finishings.86\" = \"Multi-hole punch left\";\n"
"\"finishings.87\" = \"Multi-hole punch top\";\n"
"\"finishings.88\" = \"Multi-hole punch right\";\n"
"\"finishings.89\" = \"Multi-hole punch bottom\";\n"
"\"finishings.9\" = \"Edge stitch\";\n"
"\"finishings.90\" = \"Accordion fold\";\n"
"\"finishings.91\" = \"Double gate fold\";\n"
"\"finishings.92\" = \"Gate fold\";\n"
"\"finishings.93\" = \"Half fold\";\n"
"\"finishings.94\" = \"Half Z fold\";\n"
"\"finishings.95\" = \"Left gate fold\";\n"
"\"finishings.96\" = \"Letter fold\";\n"
"\"finishings.97\" = \"Parallel fold\";\n"
"\"finishings.98\" = \"Poster fold\";\n"
"\"finishings.99\" = \"Right gate fold\";\n"
"\"holding new jobs\" = \"holding new jobs\";\n"
"\"job-state-reasons.aborted-by-system\" = \"Stopping.\";\n"
"\"job-state-reasons.compression-error\" = \"Decompression error.\";\n"
"\"job-state-reasons.document-format-error\" = \"Document format error.\";\n"
"\"job-state-reasons.document-password-error\" = \"Document password error.\";\n"
"\"job-state-reasons.document-permission-error\" = \"Document permission error.\";\n"
"\"job-state-reasons.document-unprintable-error\" = \"Document unprintable error.\";\n"
"\"job-state-reasons.errors-detected\" = \"Errors detected.\";\n"
"\"job-state-reasons.job-canceled-at-device\" = \"Canceled at printer.\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"Canceled by user.\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"Printed.\";\n"
"\"job-state-reasons.job-completed-with-errors\" = \"Printed with errors.\";\n"
"\"job-state-reasons.job-completed-with-warnings\" = \"Printed with warnings.\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"Insufficient data.\";\n"
"\"job-state-reasons.job-fetchable\" = \"Fetchable.\";\n"
"\"job-state-reasons.job-incoming\" = \"Incoming.\";\n"
"\"job-state-reasons.job-printing\" = \"Printing.\";\n"
"\"job-state-reasons.job-queued\" = \"Preparing to print.\";\n"
"\"job-state-reasons.job-spooling\" = \"Spooling.\";\n"
"\"job-state-reasons.none\" = \"Pending.\";\n"
"\"job-state-reasons.printer-stopped\" = \"Printer offline.\";\n"
"\"job-state-reasons.printer-stopped-partly\" = \"Printer partially stopped.\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"Stopping.\";\n"
"\"job-state-reasons.queued-in-device\" = \"Ready.\";\n"
"\"job-state-reasons.warnings-detected\" = \"Warnings detected.\";\n"
"\"job-state.3\" = \"Pending\";\n"
"\"job-state.4\" = \"Held\";\n"
"\"job-state.5\" = \"Processing\";\n"
"\"job-state.6\" = \"Stopped\";\n"
"\"job-state.7\" = \"Canceled\";\n"
"\"job-state.8\" = \"Aborted\";\n"
"\"job-state.9\" = \"Completed\";\n"
"\"joining\" = \"joining\";\n"
"\"media\" = \"Media\";\n"
"\"media-col\" = \"Media\";\n"
"\"media-size\" = \"Media Size\";\n"
"\"media-size-name\" = \"Media Size\";\n"
"\"media-source\" = \"Input Tray\";\n"
"\"media-source.alternate\" = \"Alternate\";\n"
"\"media-source.alternate-roll\" = \"Alternate roll\";\n"
"\"media-source.auto\" = \"Automatic\";\n"
"\"media-source.bottom\" = \"Bottom\";\n"
"\"media-source.by-pass-tray\" = \"Multipurpose tray\";\n"
"\"media-source.center\" = \"Center\";\n"
"\"media-source.disc\" = \"Disc\";\n"
"\"media-source.envelope\" = \"Envelope\";\n"
"\"media-source.hagaki\" = \"Hagaki\";\n"
"\"media-source.large-capacity\" = \"Large capacity\";\n"
"\"media-source.left\" = \"Left\";\n"
"\"media-source.main\" = \"Main\";\n"
"\"media-source.main-roll\" = \"Main roll\";\n"
"\"media-source.manual\" = \"Manual\";\n"
"\"media-source.middle\" = \"Middle\";\n"
"\"media-source.photo\" = \"Photo\";\n"
"\"media-source.rear\" = \"Rear\";\n"
"\"media-source.right\" = \"Right\";\n"
"\"media-source.roll-1\" = \"Roll 1\";\n"
"\"media-source.roll-10\" = \"Roll 10\";\n"
"\"media-source.roll-2\" = \"Roll 2\";\n"
"\"media-source.roll-3\" = \"Roll 3\";\n"
"\"media-source.roll-4\" = \"Roll 4\";\n"
"\"media-source.roll-5\" = \"Roll 5\";\n"
"\"media-source.roll-6\" = \"Roll 6\";\n"
"\"media-source.roll-7\" = \"Roll 7\";\n"
"\"media-source.roll-8\" = \"Roll 8\";\n"
"\"media-source.roll-9\" = \"Roll 9\";\n"
"\"media-source.side\" = \"Side\";\n"
"\"media-source.top\" = \"Top\";\n"
"\"media-source.tray-1\" = \"Tray 1\";\n"
"\"media-source.tray-10\" = \"Tray 10\";\n"
"\"media-source.tray-11\" = \"Tray 11\";\n"
"\"media-source.tray-12\" = \"Tray 12\";\n"
"\"media-source.tray-13\" = \"Tray 13\";\n"
"\"media-source.tray-14\" = \"Tray 14\";\n"
"\"media-source.tray-15\" = \"Tray 15\";\n"
"\"media-source.tray-16\" = \"Tray 16\";\n"
"\"media-source.tray-17\" = \"Tray 17\";\n"
"\"media-source.tray-18\" = \"Tray 18\";\n"
"\"media-source.tray-19\" = \"Tray 19\";\n"
"\"media-source.tray-2\" = \"Tray 2\";\n"
"\"media-source.tray-20\" = \"Tray 20\";\n"
"\"media-source.tray-3\" = \"Tray 3\";\n"
"\"media-source.tray-4\" = \"Tray 4\";\n"
"\"media-source.tray-5\" = \"Tray 5\";\n"
"\"media-source.tray-6\" = \"Tray 6\";\n"
"\"media-source.tray-7\" = \"Tray 7\";\n"
"\"media-source.tray-8\" = \"Tray 8\";\n"
"\"media-source.tray-9\" = \"Tray 9\";\n"
"\"media-tracking\" = \"Media Tracking\";\n"
"\"media-tracking.continuous\" = \"Continuous\";\n"
"\"media-tracking.gap\" = \"Gap\";\n"
"\"media-tracking.mark\" = \"Mark\";\n"
"\"media-tracking.web\" = \"Web\";\n"
"\"media-type\" = \"Media Type\";\n"
"\"media-type.aluminum\" = \"Aluminum\";\n"
"\"media-type.auto\" = \"Automatic\";\n"
"\"media-type.back-print-film\" = \"Back print film\";\n"
"\"media-type.cardboard\" = \"Cardboard\";\n"
"\"media-type.cardstock\" = \"Cardstock\";\n"
"\"media-type.cd\" = \"CD\";\n"
"\"media-type.continuous\" = \"Continuous\";\n"
"\"media-type.continuous-long\" = \"Continuous long\";\n"
"\"media-type.continuous-short\" = \"Continuous short\";\n"
"\"media-type.corrugated-board\" = \"Corrugated board\";\n"
"\"media-type.disc\" = \"Optical disc\";\n"
"\"media-type.disc-glossy\" = \"Glossy optical disc\";\n"
"\"media-type.disc-high-gloss\" = \"High gloss optical disc\";\n"
"\"media-type.disc-matte\" = \"Matte optical disc\";\n"
"\"media-type.disc-satin\" = \"Satin optical disc\";\n"
"\"media-type.disc-semi-gloss\" = \"Semi-gloss optical disc\";\n"
"\"media-type.double-wall\" = \"Double wall\";\n"
"\"media-type.dry-film\" = \"Dry film\";\n"
"\"media-type.dvd\" = \"DVD\";\n"
"\"media-type.embossing-foil\" = \"Embossing foil\";\n"
"\"media-type.end-board\" = \"End board\";\n"
"\"media-type.envelope\" = \"Envelope\";\n"
"\"media-type.envelope-archival\" = \"Archival envelope\";\n"
"\"media-type.envelope-bond\" = \"Bond envelope\";\n"
"\"media-type.envelope-coated\" = \"Coated envelope\";\n"
"\"media-type.envelope-cotton\" = \"Cotton envelope\";\n"
"\"media-type.envelope-fine\" = \"Fine envelope\";\n"
"\"media-type.envelope-heavyweight\" = \"Heavyweight envelope\";\n"
"\"media-type.envelope-inkjet\" = \"Inkjet envelope\";\n"
"\"media-type.envelope-lightweight\" = \"Lightweight envelope\";\n"
"\"media-type.envelope-plain\" = \"Plain envelope\";\n"
"\"media-type.envelope-preprinted\" = \"Preprinted envelope\";\n"
"\"media-type.envelope-window\" = \"Windowed envelope\";\n"
"\"media-type.fabric\" = \"Fabric\";\n"
"\"media-type.fabric-archival\" = \"Archival fabric\";\n"
"\"media-type.fabric-glossy\" = \"Glossy fabric\";\n"
"\"media-type.fabric-high-gloss\" = \"High gloss fabric\";\n"
"\"media-type.fabric-matte\" = \"Matte fabric\";\n"
"\"media-type.fabric-semi-gloss\" = \"Semi-gloss fabric\";\n"
"\"media-type.fabric-waterproof\" = \"Waterproof fabric\";\n"
"\"media-type.film\" = \"Film\";\n"
"\"media-type.flexo-base\" = \"Flexo base\";\n"
"\"media-type.flexo-photo-polymer\" = \"Flexo photo polymer\";\n"
"\"media-type.flute\" = \"Flute\";\n"
"\"media-type.foil\" = \"Foil\";\n"
"\"media-type.full-cut-tabs\" = \"Full cut tabs\";\n"
"\"media-type.glass\" = \"Glass\";\n"
"\"media-type.glass-colored\" = \"Glass colored\";\n"
"\"media-type.glass-opaque\" = \"Glass opaque\";\n"
"\"media-type.glass-surfaced\" = \"Glass surfaced\";\n"
"\"media-type.glass-textured\" = \"Glass textured\";\n"
"\"media-type.gravure-cylinder\" = \"Gravure cylinder\";\n"
"\"media-type.image-setter-paper\" = \"Image setter paper\";\n"
"\"media-type.imaging-cylinder\" = \"Imaging cylinder\";\n"
"\"media-type.labels\" = \"Labels\";\n"
"\"media-type.labels-colored\" = \"Colored labels\";\n"
"\"media-type.labels-glossy\" = \"Glossy labels\";\n"
"\"media-type.labels-high-gloss\" = \"High gloss labels\";\n"
"\"media-type.labels-inkjet\" = \"Inkjet labels\";\n"
"\"media-type.labels-matte\" = \"Matte labels\";\n"
"\"media-type.labels-permanent\" = \"Permanent labels\";\n"
"\"media-type.labels-satin\" = \"Satin labels\";\n"
"\"media-type.labels-security\" = \"Security labels\";\n"
"\"media-type.labels-semi-gloss\" = \"Semi-gloss labels\";\n"
"\"media-type.laminating-foil\" = \"Laminating foil\";\n"
"\"media-type.letterhead\" = \"Letterhead\";\n"
"\"media-type.metal\" = \"Metal\";\n"
"\"media-type.metal-glossy\" = \"Metal glossy\";\n"
"\"media-type.metal-high-gloss\" = \"Metal high gloss\";\n"
"\"media-type.metal-matte\" = \"Metal matte\";\n"
"\"media-type.metal-satin\" = \"Metal satin\";\n"
"\"media-type.metal-semi-gloss\" = \"Metal semi gloss\";\n"
"\"media-type.mounting-tape\" = \"Mounting tape\";\n"
"\"media-type.multi-layer\" = \"Multi layer\";\n"
"\"media-type.multi-part-form\" = \"Multi part form\";\n"
"\"media-type.other\" = \"Other\";\n"
"\"media-type.paper\" = \"Paper\";\n"
"\"media-type.photographic\" = \"Photo paper\";\n"
"\"media-type.photographic-archival\" = \"Photographic archival\";\n"
"\"media-type.photographic-film\" = \"Photo film\";\n"
"\"media-type.photographic-glossy\" = \"Glossy photo paper\";\n"
"\"media-type.photographic-high-gloss\" = \"High gloss photo paper\";\n"
"\"media-type.photographic-matte\" = \"Matte photo paper\";\n"
"\"media-type.photographic-satin\" = \"Satin photo paper\";\n"
"\"media-type.photographic-semi-gloss\" = \"Semi-gloss photo paper\";\n"
"\"media-type.plastic\" = \"Plastic\";\n"
"\"media-type.plastic-archival\" = \"Plastic archival\";\n"
"\"media-type.plastic-colored\" = \"Plastic colored\";\n"
"\"media-type.plastic-glossy\" = \"Plastic glossy\";\n"
"\"media-type.plastic-high-gloss\" = \"Plastic high gloss\";\n"
"\"media-type.plastic-matte\" = \"Plastic matte\";\n"
"\"media-type.plastic-satin\" = \"Plastic satin\";\n"
"\"media-type.plastic-semi-gloss\" = \"Plastic semi gloss\";\n"
"\"media-type.plate\" = \"Plate\";\n"
"\"media-type.polyester\" = \"Polyester\";\n"
"\"media-type.pre-cut-tabs\" = \"Pre cut tabs\";\n"
"\"media-type.roll\" = \"Roll\";\n"
"\"media-type.screen\" = \"Screen\";\n"
"\"media-type.screen-paged\" = \"Screen paged\";\n"
"\"media-type.self-adhesive\" = \"Self adhesive\";\n"
"\"media-type.self-adhesive-film\" = \"Self adhesive film\";\n"
"\"media-type.shrink-foil\" = \"Shrink foil\";\n"
"\"media-type.single-face\" = \"Single face\";\n"
"\"media-type.single-wall\" = \"Single wall\";\n"
"\"media-type.sleeve\" = \"Sleeve\";\n"
"\"media-type.stationery\" = \"Stationery\";\n"
"\"media-type.stationery-archival\" = \"Stationery archival\";\n"
"\"media-type.stationery-coated\" = \"Coated paper\";\n"
"\"media-type.stationery-cotton\" = \"Stationery cotton\";\n"
"\"media-type.stationery-fine\" = \"Vellum paper\";\n"
"\"media-type.stationery-heavyweight\" = \"Heavyweight paper\";\n"
"\"media-type.stationery-heavyweight-coated\" = \"Stationery heavyweight coated\";\n"
"\"media-type.stationery-inkjet\" = \"Stationery inkjet paper\";\n"
"\"media-type.stationery-letterhead\" = \"Letterhead\";\n"
"\"media-type.stationery-lightweight\" = \"Lightweight paper\";\n"
"\"media-type.stationery-preprinted\" = \"Preprinted paper\";\n"
"\"media-type.stationery-prepunched\" = \"Punched paper\";\n"
"\"media-type.tab-stock\" = \"Tab stock\";\n"
"\"media-type.tractor\" = \"Tractor\";\n"
"\"media-type.transfer\" = \"Transfer\";\n"
"\"media-type.transparency\" = \"Transparency\";\n"
"\"media-type.triple-wall\" = \"Triple wall\";\n"
"\"media-type.wet-film\" = \"Wet film\";\n"
"\"media.choice_iso_a4_210x297mm_na_letter_8.5x11in\" = \"A4 or US Letter\";\n"
"\"media.iso_2a0_1189x1682mm\" = \"2a0\";\n"
"\"media.iso_a0_841x1189mm\" = \"A0\";\n"
"\"media.iso_a0x3_1189x2523mm\" = \"A0x3\";\n"
"\"media.iso_a10_26x37mm\" = \"A10\";\n"
"\"media.iso_a1_594x841mm\" = \"A1\";\n"
"\"media.iso_a1x3_841x1783mm\" = \"A1x3\";\n"
"\"media.iso_a1x4_841x2378mm\" = \"A1x4\";\n"
"\"media.iso_a2_420x594mm\" = \"A2\";\n"
"\"media.iso_a2x3_594x1261mm\" = \"A2x3\";\n"
"\"media.iso_a2x4_594x1682mm\" = \"A2x4\";\n"
"\"media.iso_a2x5_594x2102mm\" = \"A2x5\";\n"
"\"media.iso_a3-extra_322x445mm\" = \"A3 (extra)\";\n"
"\"media.iso_a3_297x420mm\" = \"A3\";\n"
"\"media.iso_a3x3_420x891mm\" = \"A3x3\";\n"
"\"media.iso_a3x4_420x1189mm\" = \"A3x4\";\n"
"\"media.iso_a3x5_420x1486mm\" = \"A3x5\";\n"
"\"media.iso_a3x6_420x1783mm\" = \"A3x6\";\n"
"\"media.iso_a3x7_420x2080mm\" = \"A3x7\";\n"
"\"media.iso_a4-extra_235.5x322.3mm\" = \"A4 (extra)\";\n"
"\"media.iso_a4-tab_225x297mm\" = \"A4 (tab)\";\n"
"\"media.iso_a4_210x297mm\" = \"A4\";\n"
"\"media.iso_a4x3_297x630mm\" = \"A4x3\";\n"
"\"media.iso_a4x4_297x841mm\" = \"A4x4\";\n"
"\"media.iso_a4x5_297x1051mm\" = \"A4x5\";\n"
"\"media.iso_a4x6_297x1261mm\" = \"A4x6\";\n"
"\"media.iso_a4x7_297x1471mm\" = \"A4x7\";\n"
"\"media.iso_a4x8_297x1682mm\" = \"A4x8\";\n"
"\"media.iso_a4x9_297x1892mm\" = \"A4x9\";\n"
"\"media.iso_a5-extra_174x235mm\" = \"A5 (extra)\";\n"
"\"media.iso_a5_148x210mm\" = \"A5\";\n"
"\"media.iso_a6_105x148mm\" = \"A6\";\n"
"\"media.iso_a7_74x105mm\" = \"A7\";\n"
"\"media.iso_a8_52x74mm\" = \"A8\";\n"
"\"media.iso_a9_37x52mm\" = \"A9\";\n"
"\"media.iso_b0_1000x1414mm\" = \"B0\";\n"
"\"media.iso_b10_31x44mm\" = \"B10\";\n"
"\"media.iso_b1_707x1000mm\" = \"B1\";\n"
"\"media.iso_b2_500x707mm\" = \"B2\";\n"
"\"media.iso_b3_353x500mm\" = \"B3\";\n"
"\"media.iso_b4_250x353mm\" = \"B4\";\n"
"\"media.iso_b5-extra_201x276mm\" = \"B5 (extra)\";\n"
"\"media.iso_b5_176x250mm\" = \"B5 Envelope\";\n"
"\"media.iso_b6_125x176mm\" = \"B6\";\n"
"\"media.iso_b6c4_125x324mm\" = \"B6/C4Envelope\";\n"
"\"media.iso_b7_88x125mm\" = \"B7\";\n"
"\"media.iso_b8_62x88mm\" = \"B8\";\n"
"\"media.iso_b9_44x62mm\" = \"B9\";\n"
"\"media.iso_c0_917x1297mm\" = \"C0 Envelope\";\n"
"\"media.iso_c10_28x40mm\" = \"C10 Envelope\";\n"
"\"media.iso_c1_648x917mm\" = \"C1 Envelope\";\n"
"\"media.iso_c2_458x648mm\" = \"C2 Envelope\";\n"
"\"media.iso_c3_324x458mm\" = \"C3 Envelope\";\n"
"\"media.iso_c4_229x324mm\" = \"C4 Envelope\";\n"
"\"media.iso_c5_162x229mm\" = \"C5 Envelope\";\n"
"\"media.iso_c6_114x162mm\" = \"C6 Envelope\";\n"
"\"media.iso_c6c5_114x229mm\" = \"C6/C5 Envelope\";\n"
"\"media.iso_c7_81x114mm\" = \"C7 Envelope\";\n"
"\"media.iso_c7c6_81x162mm\" = \"C7/C6 Envelope\";\n"
"\"media.iso_c8_57x81mm\" = \"C8 Envelope\";\n"
"\"media.iso_c9_40x57mm\" = \"C9 Envelope\";\n"
"\"media.iso_dl_110x220mm\" = \"DL Envelope\";\n"
"\"media.iso_ra0_860x1220mm\" = \"ISO RA0\";\n"
"\"media.iso_ra1_610x860mm\" = \"ISO RA1\";\n"
"\"media.iso_ra2_430x610mm\" = \"ISO RA2\";\n"
"\"media.iso_ra3_305x430mm\" = \"ISO RA3\";\n"
"\"media.iso_ra4_215x305mm\" = \"ISO RA4\";\n"
"\"media.iso_sra0_900x1280mm\" = \"ISO SRA0\";\n"
"\"media.iso_sra1_640x900mm\" = \"ISO SRA1\";\n"
"\"media.iso_sra2_450x640mm\" = \"ISO SRA2\";\n"
"\"media.iso_sra3_320x450mm\" = \"ISO SRA3\";\n"
"\"media.iso_sra4_225x320mm\" = \"ISO SRA4\";\n"
"\"media.jis_b0_1030x1456mm\" = \"JIS B0\";\n"
"\"media.jis_b10_32x45mm\" = \"JIS B10\";\n"
"\"media.jis_b1_728x1030mm\" = \"JIS B1\";\n"
"\"media.jis_b2_515x728mm\" = \"JIS B2\";\n"
"\"media.jis_b3_364x515mm\" = \"JIS B3\";\n"
"\"media.jis_b4_257x364mm\" = \"JIS B4\";\n"
"\"media.jis_b5_182x257mm\" = \"JIS B5\";\n"
"\"media.jis_b6_128x182mm\" = \"JIS B6\";\n"
"\"media.jis_b7_91x128mm\" = \"JIS B7\";\n"
"\"media.jis_b8_64x91mm\" = \"JIS B8\";\n"
"\"media.jis_b9_45x64mm\" = \"JIS B9\";\n"
"\"media.jis_exec_216x330mm\" = \"JIS Executive\";\n"
"\"media.jpn_chou2_111.1x146mm\" = \"Envelope Chou 2\";\n"
"\"media.jpn_chou3_120x235mm\" = \"Envelope Chou 3\";\n"
"\"media.jpn_chou40_90x225mm\" = \"Envelope Chou 40\";\n"
"\"media.jpn_chou4_90x205mm\" = \"Envelope Chou 4\";\n"
"\"media.jpn_hagaki_100x148mm\" = \"Hagaki\";\n"
"\"media.jpn_kahu_240x322.1mm\" = \"Envelope Kahu\";\n"
"\"media.jpn_kaku2_240x332mm\" = \"Envelope Kahu 2\";\n"
"\"media.jpn_oufuku_148x200mm\" = \"Oufuku Reply Postcard\";\n"
"\"media.jpn_you4_105x235mm\" = \"Envelope You 4\";\n"
"\"media.na_a2_4.375x5.75in\" = \"Envelope A2\";\n"
"\"media.na_c5_6.5x9.5in\" = \"Envelope C5\";\n"
"\"media.na_executive_7.25x10.5in\" = \"Executive\";\n"
"\"media.na_fanfold-eur_8.5x12in\" = \"European Fanfold\";\n"
"\"media.na_fanfold-us_11x14.875in\" = \"US Fanfold\";\n"
"\"media.na_foolscap_8.5x13in\" = \"Foolscap\";\n"
"\"media.na_invoice_5.5x8.5in\" = \"Statement\";\n"
"\"media.na_legal-extra_9.5x15in\" = \"US Legal (Extra)\";\n"
"\"media.na_legal_8.5x14in\" = \"US Legal\";\n"
"\"media.na_letter-extra_9.5x12in\" = \"US Letter (Extra)\";\n"
"\"media.na_letter-plus_8.5x12.69in\" = \"US Letter (Plus)\";\n"
"\"media.na_letter_8.5x11in\" = \"US Letter\";\n"
"\"media.na_monarch_3.875x7.5in\" = \"Envelope Monarch\";\n"
"\"media.na_number-10_4.125x9.5in\" = \"Envelope #10\";\n"
"\"media.na_number-11_4.5x10.375in\" = \"Envelope #11\";\n"
"\"media.na_number-12_4.75x11in\" = \"Envelope #12\";\n"
"\"media.na_number-14_5x11.5in\" = \"Envelope #14\";\n"
"\"media.na_number-9_3.875x8.875in\" = \"Envelope #9\";\n"
"\"media.na_personal_3.625x6.5in\" = \"Envelope Personal\";\n"
"\"media.na_quarto_8.5x10.83in\" = \"Quarto\";\n"
"\"media.om_folio-sp_215x315mm\" = \"Folio\";\n"
"\"media.om_folio_210x330mm\" = \"Folio (Special)\";\n"
"\"media.om_invite_220x220mm\" = \"Envelope Invitation\";\n"
"\"media.om_italian_110x230mm\" = \"Envelope Italian\";\n"
"\"media.om_juuro-ku-kai_198x275mm\" = \"198 x 275mm\";\n"
"\"media.om_large-photo_200x300\" = \"200 x 300\";\n"
"\"media.om_medium-photo_130x180mm\" = \"130 x 180mm\";\n"
"\"media.om_pa-kai_267x389mm\" = \"267 x 389mm\";\n"
"\"media.om_postfix_114x229mm\" = \"Envelope Postfix\";\n"
"\"media.prc_10_324x458mm\" = \"Envelope chinese #10\";\n"
"\"media.prc_16k_146x215mm\" = \"Chinese 16k\";\n"
"\"media.prc_1_102x165mm\" = \"Envelope chinese #1\";\n"
"\"media.prc_2_102x176mm\" = \"Envelope chinese #2\";\n"
"\"media.prc_32k_97x151mm\" = \"Chinese 32k\";\n"
"\"media.prc_3_125x176mm\" = \"Envelope chinese #3\";\n"
"\"media.prc_4_110x208mm\" = \"Envelope chinese #4\";\n"
"\"media.prc_5_110x220mm\" = \"Envelope chinese #5\";\n"
"\"media.prc_6_120x320mm\" = \"Envelope chinese #6\";\n"
"\"media.prc_7_160x230mm\" = \"Envelope chinese #7\";\n"
"\"media.prc_8_120x309mm\" = \"Envelope chinese #8\";\n"
"\"media.roc_16k_7.75x10.75in\" = \"ROC 16k\";\n"
"\"media.roc_8k_10.75x15.5in\" = \"ROC 8k\";\n"
"\"not configured\" = \"not configured\";\n"
"\"not visible\" = \"not visible\";\n"
"\"off\" = \"off\";\n"
"\"on\" = \"on\";\n"
"\"orientation-requested\" = \"Orientation\";\n"
"\"orientation-requested.3\" = \"Portrait\";\n"
"\"orientation-requested.4\" = \"Landscape\";\n"
"\"orientation-requested.5\" = \"Reverse landscape\";\n"
"\"orientation-requested.6\" = \"Reverse portrait\";\n"
"\"orientation-requested.7\" = \"None\";\n"
"\"output-bin\" = \"Output Tray\";\n"
"\"output-bin.auto\" = \"Automatic\";\n"
"\"output-bin.bottom\" = \"Bottom\";\n"
"\"output-bin.center\" = \"Center\";\n"
"\"output-bin.face-down\" = \"Face down\";\n"
"\"output-bin.face-up\" = \"Face up\";\n"
"\"output-bin.large-capacity\" = \"Large capacity\";\n"
"\"output-bin.left\" = \"Left\";\n"
"\"output-bin.mailbox-1\" = \"Mailbox 1\";\n"
"\"output-bin.mailbox-10\" = \"Mailbox 10\";\n"
"\"output-bin.mailbox-2\" = \"Mailbox 2\";\n"
"\"output-bin.mailbox-3\" = \"Mailbox 3\";\n"
"\"output-bin.mailbox-4\" = \"Mailbox 4\";\n"
"\"output-bin.mailbox-5\" = \"Mailbox 5\";\n"
"\"output-bin.mailbox-6\" = \"Mailbox 6\";\n"
"\"output-bin.mailbox-7\" = \"Mailbox 7\";\n"
"\"output-bin.mailbox-8\" = \"Mailbox 8\";\n"
"\"output-bin.mailbox-9\" = \"Mailbox 9\";\n"
"\"output-bin.middle\" = \"Middle\";\n"
"\"output-bin.my-mailbox\" = \"My mailbox\";\n"
"\"output-bin.rear\" = \"Rear\";\n"
"\"output-bin.right\" = \"Right\";\n"
"\"output-bin.side\" = \"Side\";\n"
"\"output-bin.stacker-1\" = \"Stacker 1\";\n"
"\"output-bin.stacker-10\" = \"Stacker 10\";\n"
"\"output-bin.stacker-2\" = \"Stacker 2\";\n"
"\"output-bin.stacker-3\" = \"Stacker 3\";\n"
"\"output-bin.stacker-4\" = \"Stacker 4\";\n"
"\"output-bin.stacker-5\" = \"Stacker 5\";\n"
"\"output-bin.stacker-6\" = \"Stacker 6\";\n"
"\"output-bin.stacker-7\" = \"Stacker 7\";\n"
"\"output-bin.stacker-8\" = \"Stacker 8\";\n"
"\"output-bin.stacker-9\" = \"Stacker 9\";\n"
"\"output-bin.top\" = \"Top\";\n"
"\"output-bin.tray-1\" = \"Tray 1\";\n"
"\"output-bin.tray-10\" = \"Tray 10\";\n"
"\"output-bin.tray-2\" = \"Tray 2\";\n"
"\"output-bin.tray-3\" = \"Tray 3\";\n"
"\"output-bin.tray-4\" = \"Tray 4\";\n"
"\"output-bin.tray-5\" = \"Tray 5\";\n"
"\"output-bin.tray-6\" = \"Tray 6\";\n"
"\"output-bin.tray-7\" = \"Tray 7\";\n"
"\"output-bin.tray-8\" = \"Tray 8\";\n"
"\"output-bin.tray-9\" = \"Tray 9\";\n"
"\"print-color-mode\" = \"Print Mode\";\n"
"\"print-color-mode.auto\" = \"Automatic\";\n"
"\"print-color-mode.auto-monochrome\" = \"Auto monochrome\";\n"
"\"print-color-mode.bi-level\" = \"Text\";\n"
"\"print-color-mode.color\" = \"Color\";\n"
"\"print-color-mode.highlight\" = \"Highlight\";\n"
"\"print-color-mode.monochrome\" = \"Monochrome\";\n"
"\"print-color-mode.process-bi-level\" = \"Process Text\";\n"
"\"print-color-mode.process-monochrome\" = \"Process monochrome\";\n"
"\"print-content-optimize\" = \"Optimize For\";\n"
"\"print-content-optimize.auto\" = \"Automatic\";\n"
"\"print-content-optimize.graphic\" = \"Graphics\";\n"
"\"print-content-optimize.photo\" = \"Photo\";\n"
"\"print-content-optimize.text\" = \"Text\";\n"
"\"print-content-optimize.text-and-graphic\" = \"Text and graphics\";\n"
"\"print-darkness\" = \"Print Darkness\";\n"
"\"print-quality\" = \"Print Quality\";\n"
"\"print-quality.3\" = \"Draft\";\n"
"\"print-quality.4\" = \"Normal\";\n"
"\"print-quality.5\" = \"Best\";\n"
"\"print-scaling\" = \"Scaling\";\n"
"\"print-scaling.auto\" = \"Automatic\";\n"
"\"print-scaling.auto-fit\" = \"Auto-fit\";\n"
"\"print-scaling.fill\" = \"Fill\";\n"
"\"print-scaling.fit\" = \"Fit\";\n"
"\"print-scaling.none\" = \"None\";\n"
"\"print-speed\" = \"Print Speed\";\n"
"\"printer-resolution\" = \"Resolution\";\n"
"\"printer-state-reasons.cover-open\" = \"Cover open.\";\n"
"\"printer-state-reasons.door-open\" = \"Door open.\";\n"
"\"printer-state-reasons.identify-printer-requested\" = \"Identify printer.\";\n"
"\"printer-state-reasons.input-tray-missing\" = \"Paper tray missing.\";\n"
"\"printer-state-reasons.marker-supply-empty\" = \"Out of ink.\";\n"
"\"printer-state-reasons.marker-supply-low\" = \"Low ink.\";\n"
"\"printer-state-reasons.marker-waste-almost-full\" = \"Waste bin almost full.\";\n"
"\"printer-state-reasons.marker-waste-full\" = \"Waste bin full.\";\n"
"\"printer-state-reasons.media-empty\" = \"Out of paper.\";\n"
"\"printer-state-reasons.media-jam\" = \"Paper jam.\";\n"
"\"printer-state-reasons.media-low\" = \"Replace paper soon.\";\n"
"\"printer-state-reasons.media-needed\" = \"Load paper.\";\n"
"\"printer-state-reasons.none\" = \"Ready.\";\n"
"\"printer-state-reasons.offline\" = \"Offline.\";\n"
"\"printer-state-reasons.other\" = \"See printer.\";\n"
"\"printer-state-reasons.spool-area-full\" = \"Printer busy.\";\n"
"\"printer-state-reasons.toner-empty\" = \"Out of toner.\";\n"
"\"printer-state-reasons.toner-low\" = \"Toner low.\";\n"
"\"printer-state.3\" = \"Idle\";\n"
"\"printer-state.4\" = \"Processing\";\n"
"\"printer-state.5\" = \"Stopped\";\n"
"\"sides\" = \"2-Sided Printing\";\n"
"\"sides.one-sided\" = \"Off\";\n"
"\"sides.two-sided-long-edge\" = \"On (portrait)\";\n"
"\"sides.two-sided-short-edge\" = \"On (landscape)\";\n"
"\"unable to join\" = \"unable to join\";\n"
"\"yesterday at %02d:%02d:%02d\" = \"yesterday at %02d:%02d:%02d\";\n"
"\"Åland Islands\" = \"Åland Islands\";\n";
