static const char *de_strings = "\"  -a               Cancel all jobs (cancel).\" = \"  -a               Alle Jobs abbrechen (cancel).\";\n"
"\"  -c COPIES\" = \"  -c KOPIEN\";\n"
"\"  -d PRINTER       Specify printer.\" = \"  -d PRINTER       Drucker angeben.\";\n"
"\"  -j JOB-ID        Specify job ID (cancel).\" = \"  -j JOB-ID        Druckjob ID angeben (cancel).\";\n"
"\"  -m DRIVER-NAME   Specify driver (add/modify).\" = \"  -m DRIVER-NAME   Geben Sie den Treiber an (Hinzufügen/Ändern).\";\n"
"\"  -n COPIES        Specify number of copies (submit).\" = \"  -n COPIES        Geben Sie die Anzahl der Exemplare an.\";\n"
"\"  -o %s=%s (default)\" = \"  -o %s=%s (Standard)\";\n"
"\"  -o NAME=VALUE    Specify option (add,modify,server,submit).\" = \"  -o NAME=WERT     Option angeben (add,modify,server,submit).\";\n"
"\"  -o print-darkness=-100 to 100\" = \"  -o print-darkness=-100 bis 100\";\n"
"\"  -o printer-darkness=0 to 100\" = \"  -o printer-darkness=0 bis 100\";\n"
"\"  -o printer-geo-location='geo:LATITUDE,LONGITUDE'\" = \"  -o printer-geo-location='geo:LATITUDE,LONGITUDE\";\n"
"\"  -o printer-location='LOCATION'\" = \"  -o printer-location='ORT'\";\n"
"\"  -o printer-organization='ORGANIZATION'\" = \"  -o printer-organizationn='ORGANISATION'\";\n"
"\"  -o printer-organizational-unit='UNIT/SECTION'\" = \"  -o printer-organizational-unit='Abteilung'\";\n"
"\"  -u URI           Specify ipp: or ipps: printer/server.\" = \"  -u URI           Spezifizieren Sie ipp: oder ipps: Drucker/Server.\";\n"
"\"  -v DEVICE-URI    Specify socket: or usb: device (add/modify).\" = \"  -v DEVICE-URI    Schnittstelle / Socket  angeben: oder USB: Gerät (add/modify).\";\n"
"\"  add PRINTER      Add a printer.\" = \"  add PRINTER      Einen Drucker hinzufügen.\";\n"
"\"  autoadd          Automatically add supported printers.\" = \"  autoadd          Unterstützte Drucker automatisch hinzufügen.\";\n"
"\"  cancel           Cancel one or more jobs.\" = \"  cancel           Stornierung einer oder mehrerer Druckaufträge.\";\n"
"\"  default          Set the default printer.\" = \"  default          Setzen Sie den Standarddrucker.\";\n"
"\"  delete           Delete a printer.\" = \"  delete           Löschen eines Druckers.\";\n"
"\"  devices          List devices.\" = \"  devices          Geräte auflisten.\";\n"
"\"  drivers          List drivers.\" = \"  drivers          Treiber auflisten.\";\n"
"\"  jobs             List jobs.\" = \"  jobs             Aufträge auflisten.\";\n"
"\"  modify           Modify a printer.\" = \"  modify           Drucker ändern.\";\n"
"\"  options          List printer options.\" = \"  options          Liste der Druckeroptionen.\";\n"
"\"  pause            Pause printing for a printer.\" = \"  pause            Druck pausieren.\";\n"
"\"  printers         List printers.\" = \"  printers         Drucker auflisten.\";\n"
"\"  resume           Resume printing for a printer.\" = \"  resume           Druck fortsetzen.\";\n"
"\"  server           Run a server.\" = \"  server           Server ausführen.\";\n"
"\"  shutdown         Shutdown a running server.\" = \"  shutdown         Abschalten eines laufenden Servers.\";\n"
"\"  status           Show server/printer/job status.\" = \"  status           Server/Drucker/Auftragsstatus anzeigen.\";\n"
"\"  submit           Submit a file for printing.\" = \"  submit           Senden Sie eine Datei zum Drucken.\";\n"
"\"%04d-%02d-%02d at %02d:%02d:%02d\" = \"%04d-%02d-%02d at %02d:%02d:%02d\";\n"
"\"%d days ago at %02d:%02d:%02d\" = \"%d days ago at %02d:%02d:%02d\";\n"
"\"%d inches/sec\" = \"%d zoll/s\";\n"
"\"%d job\" = \"%d Job\";\n"
/* Media size in millimeters */
"\"%d x %dmm\" = \"%d x %d mm\";\n"
"\"%ddpi\" = \"%d dpi\";\n"
"\"%dx%ddpi\" = \"%d x %d dpi\";\n"
/* Media size in inches */
"\"%g x %g\\\"\" = \"%g x %g \\\"\";\n"
/* size (type+borderless) */
"\"%s (%s%s)\" = \"%s ( %s %s )\";\n"
/* size (type+borderless) from source/tray */
"\"%s (%s%s) from %s\" = \"%s (%s%s) aus %s\";\n"
/* Source/Tray Media */
"\"%s Media\" = \"%s Medien\";\n"
"\"%s: Bad 'server-port' value.\" = \"%s: Unpassender Server-Port.\";\n"
"\"%s: Bad job ID.\" = \"%s: Unpassende Job-ID.\";\n"
"\"%s: Bad printer URI '%s'.\" = \"%s: Unpassender Drucker URI '%s'.\";\n"
"\"%s: Cannot specify more than one sub-command.\" = \"%s: Kann nicht mehr als einen Unterbefehl angeben.\";\n"
"\"%s: Empty print file received on the standard input.\" = \"%s: Leere Druckdatei, die auf der Standardeingabe empfangen wurde.\";\n"
"\"%s: Failed to create a system.\" = \"%s: Erstellung eines Systems fehlgeschlagen.\";\n"
"\"%s: Missing '-d PRINTER'.\" = \"%s: Fehlende Option '-d PRINTER'.\";\n"
"\"%s: Missing '-m DRIVER-NAME'.\" = \"%s: Fehlende Option '-m DRIVER-NAME'.\";\n"
"\"%s: Missing '-v DEVICE-URI'.\" = \"%s: Fehlende Option '-v DEVICE-URI'.\";\n"
"\"%s: Missing copy count after '-n'.\" = \"%s: Fehlende Kopien-Anzahl nach -n.\";\n"
"\"%s: Missing device URI after '-v'.\" = \"%s: Fehlender Gerät URI nach -v.\";\n"
"\"%s: Missing driver name after '-m'.\" = \"%s: Fehlender Treibername nach -m.\";\n"
"\"%s: Missing filename after '--'.\" = \"%s: Fehlender Dateiname nach '--'.\";\n"
"\"%s: Missing hostname after '-h'.\" = \"%s: Fehlender Rechnername nach '-h'.\";\n"
"\"%s: Missing job ID after '-j'.\" = \"%s: Fehlende Auftrags-ID nach '-j'.\";\n"
"\"%s: Missing option(s) after '-o'.\" = \"%s: Fehlende Option(en) nach '-o'.\";\n"
"\"%s: Missing printer URI after '-u'.\" = \"%s: Fehlender Drucker URI nach '-u'.\";\n"
"\"%s: Missing printer name after '-d'.\" = \"%s: Fehlender Druckername nach '-d'.\";\n"
"\"%s: Missing space after '-o'.\" = \"%s: Fehlendes Leerzeichen nach '-o'.\";\n"
"\"%s: Missing title after '-t'.\" = \"%s: Fehlender Titel nach '-t'.\";\n"
"\"%s: No default printer available.\" = \"%s: Kein Standarddrucker verfügbar.\";\n"
"\"%s: No files to print.\" = \"%s: Keine Dateien zum Drucken.\";\n"
"\"%s: Server is not running.\" = \"%s: Server läuft nicht.\";\n"
"\"%s: Sub-command '%s' does not accept files.\" = \"%s: Unterbefehl '%s' akzeptiert keine Dateien.\";\n"
"\"%s: Sub-command 'autoadd' is not supported.\" = \"%s: Unterbefehl 'autoadd' wird nicht unterstützt.\";\n"
"\"%s: Too many files.\" = \"%s: Zu viele Dateien.\";\n"
"\"%s: Unable to access '%s': %s\" = \"%s: Zugriff auf '%s': %s nicht möglich\";\n"
"\"%s: Unable to add printer: %s\" = \"%s: Hinzufügen des Druckers nicht möglich: %s\";\n"
"\"%s: Unable to cancel job: %s\" = \"%s: Job %s konnte nicht storniert werden\";\n"
"\"%s: Unable to connect to printer at '%s:%d': %s\" = \"%s: Drucker konnte nicht verbunden werden: '%s:%d': %s\";\n"
"\"%s: Unable to connect to server: %s\" = \"%s: Verbindung zu Server nicht möglich: %s\";\n"
"\"%s: Unable to create temporary file: %s\" = \"%s: Temporäre Datei konnte nicht erstellt werden: %s\";\n"
"\"%s: Unable to delete printer: %s\" = \"%s: Drucker konnte nicht gelöscht werden: %s\";\n"
"\"%s: Unable to get available devices: %s\" = \"%s: Unable to get available devices: %s\";\n"
"\"%s: Unable to get information for '%s': %s\" = \"%s: Information nicht verfügbar '%s': %s\";\n"
"\"%s: Unable to get information for printer: %s\" = \"%s: Drucker-Information nicht verfügbar: %s\";\n"
"\"%s: Unable to get printer options: %s\" = \"%s: Druckeroptionen konnten nicht abgerufen werden: %s\";\n"
"\"%s: Unable to modify printer: %s\" = \"%s: Drucker konnte nicht geändert werden: %s\";\n"
"\"%s: Unable to pause printer: %s\" = \"%s: Drucker konnte nicht pausiert werden: %s\";\n"
"\"%s: Unable to print '%s': %s\" = \"%s: Konnte nicht gedruckt werden: %s ': %s\";\n"
"\"%s: Unable to resume printer: %s\" = \"%s: Drucker konnte nicht wieder gestartet werden: %s\";\n"
"\"%s: Unable to set default printer: %s\" = \"%s: Standard-Drucker konnte nicht festgelegt werden: %s\";\n"
"\"%s: Unable to shutdown server: %s\" = \"%s: Server konnte nicht heruntergefahren werden: %s\";\n"
"\"%s: Unable to start server: %s\" = \"%s: Server konnte nicht gestartet werden: %s\";\n"
"\"%s: Unable to write to temporary file: %s\" = \"%s: Konnte nicht in temporäre Datei schreiben: %s\";\n"
"\"%s: Unknown option '%s'.\" = \"%s: Unbekannte Option '%s'.\";\n"
"\"%s: Unknown option '-%c'.\" = \"%s: Unbekannte Option '-%c'.\";\n"
"\"%s: Unknown sub-command '%s'.\" = \"%s: Unbekannter Unterbefehl '%s'.\";\n"
"\"%s: Unsupported URI scheme '%s'.\" = \"%s: Nicht unterstütztes URI-System '%s'.\";\n"
"\"%s: Warning - user credentials are not supported in URIs.\" = \"%s: Warnung - Persönliche Benutzerinformationen werden nicht in URIs unterstützt.\";\n"
"\", Borderless\" = \", Randlos\";\n"
"\"A printer with that name already exists.\" = \"Ein Drucker mit diesem Namen existiert bereits.\";\n"
"\"Aborted %s\" = \"Aborted %s\";\n"
"\"Add Printer\" = \"Drucker hinzufügen\";\n"
"\"Admin Group\" = \"Admin Gruppe\";\n"
"\"Afghanistan\" = \"Afghanistan\";\n"
"\"Albania\" = \"Albanien\";\n"
"\"Algeria\" = \"Algerien\";\n"
"\"American Samoa\" = \"Amerikanisch-Samoa\";\n"
"\"Andorra\" = \"Andorra\";\n"
"\"Angola\" = \"Angola\";\n"
"\"Anguilla\" = \"Anguilla\";\n"
"\"Antarctica\" = \"Antarktis\";\n"
"\"Antigua and Barbuda\" = \"Antigua und Barbuda\";\n"
"\"Argentina\" = \"Argentinien\";\n"
"\"Armenia\" = \"Armenien\";\n"
"\"Aruba\" = \"Aruba\";\n"
"\"Australia\" = \"Australien\";\n"
"\"Austria\" = \"Österreich\";\n"
"\"Auto\" = \"Auto\";\n"
"\"Auto-Detect Driver\" = \"Treiber automatisch erkennen\";\n"
"\"Azerbaijan\" = \"Aserbaidschan\";\n"
"\"Bad administration group.\" = \"Unpassende Verwaltungsgruppe.\";\n"
"\"Bad port number.\" = \"Unpassende Port-Nummer.\";\n"
"\"Bad print group.\" = \"Unpassende Druckgruppe.\";\n"
"\"Bad printer defaults.\" = \"Unpassende Standard-Druckereinstellungen.\";\n"
"\"Bahamas\" = \"Bahamas\";\n"
"\"Bahrain\" = \"Bahrain\";\n"
"\"Bangladesh\" = \"Bangladesch\";\n"
"\"Barbados\" = \"Barbados\";\n"
"\"Belarus\" = \"Weißrussland\";\n"
"\"Belgium\" = \"Belgien\";\n"
"\"Belize\" = \"Belize\";\n"
"\"Benin\" = \"Benin\";\n"
"\"Bermuda\" = \"Bermuda\";\n"
"\"Bhutan\" = \"Bhutan\";\n"
"\"Bolivia (Plurinational State of)\" = \"Bolivien\";\n"
"\"Bonaire, Sint Eustatius and Saba\" = \"Bonaire, Sint Eustatius und Saba\";\n"
"\"Borderless\" = \"Randlos\";\n"
"\"Bosnia and Herzegovina\" = \"Bosnien und Herzegowina\";\n"
"\"Botswana\" = \"Botsuana\";\n"
"\"Bouvet Island\" = \"Bouvetinsel\";\n"
"\"Brazil\" = \"Brasilien\";\n"
"\"British Indian Ocean Territory\" = \"Britisches Territorium im Indischen Ozean\";\n"
"\"Brunei Darussalam\" = \"Brunei\";\n"
"\"Bulgaria\" = \"Bulgarien\";\n"
"\"Burkina Faso\" = \"Burkina Faso\";\n"
"\"Burundi\" = \"Burundi\";\n"
"\"Cabo Verde\" = \"Cap Verde\";\n"
"\"Cambodia\" = \"Kambodscha\";\n"
"\"Cameroon\" = \"Kamerun\";\n"
"\"Canada\" = \"Kanada\";\n"
"\"Cancel All Jobs\" = \"Alle Druckaufträge löschen\";\n"
"\"Cancel Job\" = \"Druckauftrag abbrechen\";\n"
"\"Canceled %s\" = \"Canceled %s\";\n"
"\"Canceling\" = \"Abbrechend\";\n"
"\"Cayman Islands\" = \"Cayman Inseln\";\n"
"\"Central African Republic\" = \"Zentralafrikanische Republik\";\n"
"\"Certificate created.\" = \"Zertifikat erstellt.\";\n"
"\"Certificate installed.\" = \"Zertifikat installiert.\";\n"
"\"Certificate request created.\" = \"Zertifikatsanfrage erstellt.\";\n"
"\"Chad\" = \"Tschad\";\n"
"\"Change Access Password\" = \"Zugangspasswort ändern\";\n"
"\"Change Log Level\" = \"Log Level ändern\";\n"
"\"Change Network Settings\" = \"Change Network Settings\";\n"
"\"Change Wi-Fi Network\" = \"WLAN-Netzwerk ändern\";\n"
"\"Changes Saved.\" = \"Änderungen gespeichert.\";\n"
"\"Changes saved.\" = \"Änderungen gespeichert.\";\n"
"\"Chile\" = \"Chile\";\n"
"\"China\" = \"China\";\n"
"\"Christmas Island\" = \"Weihnachtsinsel\";\n"
"\"City/Locality\" = \"City/Locality\";\n"
"\"Cocos (Keeling) Islands\" = \"Kakao (Keeling) Inseln\";\n"
"\"Colombia\" = \"Kolumbien\";\n"
"\"Comoros\" = \"Komoren\";\n"
"\"Completed %s\" = \"Completed %s\";\n"
"\"Configuration\" = \"Konfiguration\";\n"
"\"Configure Media\" = \"Medien konfigurieren\";\n"
"\"Confirm Cancel All\" = \"Abbruch bestätigen: Alle\";\n"
"\"Confirm Delete Printer\" = \"Löschung des Druckers bestätigen\";\n"
"\"Congo\" = \"Kongo\";\n"
"\"Congo, Democratic Republic of the\" = \"Kongo, Demokratische Republik\";\n"
"\"Contact\" = \"Kontakt\";\n"
"\"Cook Islands\" = \"Cookinseln\";\n"
"\"Costa Rica\" = \"Costa Rica\";\n"
"\"Create Certificate Signing Request\" = \"Signatur-Anfrage für Zertifikat erzeugen\";\n"
"\"Create New Certificate\" = \"Neues Zertifikat erstellen\";\n"
"\"Create New TLS Certificate\" = \"Neues TLS-Zertifikat erstellen\";\n"
"\"Create TLS Certificate Request\" = \"TLS Zertifikat Anfrage erzeugen\";\n"
"\"Croatia\" = \"Kroatien\";\n"
"\"Cuba\" = \"Kuba\";\n"
"\"Curaçao\" = \"Curaçao\";\n"
"\"Current Password\" = \"Aktuelles Passwort\";\n"
"\"Custom Size\" = \"Benutzerdefinierte Größe\";\n"
"\"Cyprus\" = \"Zypern\";\n"
"\"Czechia\" = \"Tschechien\";\n"
"\"Côte d'Ivoire\" = \"Côte d'Ivoire\";\n"
"\"DHCP\" = \"DHCP\";\n"
"\"DHCP w/Manual Address\" = \"DHCP w/Manual Address\";\n"
"\"DNS-SD Service Name\" = \"DNS-SD Service Name\";\n"
"\"Debugging\" = \"Fehleranalyse\";\n"
"\"Default printer set.\" = \"Standarddruckersatz.\";\n"
"\"Delete\" = \"Löschen\";\n"
"\"Delete Printer\" = \"Drucker löschen\";\n"
"\"Denmark\" = \"Dänemark\";\n"
"\"Djibouti\" = \"Dschibuti\";\n"
"\"Domain Name\" = \"Domain Name\";\n"
"\"Dominica\" = \"Dominica\";\n"
"\"Dominican Republic\" = \"Dominikanische Republik\";\n"
"\"Download Certificate Request File\" = \"Certificate Request File herunterladen\";\n"
"\"Ecuador\" = \"Ecuador\";\n"
"\"Egypt\" = \"Ägypten\";\n"
"\"El Salvador\" = \"El Salvador\";\n"
"\"Equatorial Guinea\" = \"Äquatorialguinea\";\n"
"\"Eritrea\" = \"Eritrea\";\n"
"\"Errors\" = \"Fehler\";\n"
"\"Estonia\" = \"Estland\";\n"
"\"Eswatini\" = \"Swasiland\";\n"
"\"Ethiopia\" = \"Äthiopien\";\n"
"\"Falkland Islands (Malvinas)\" = \"Falklandinseln (Malvinas)\";\n"
"\"Faroe Islands\" = \"Färöer\";\n"
"\"Fatal Errors/Conditions\" = \"Gravierende Fehler/Zustände\";\n"
"\"Fiji\" = \"Fidschi\";\n"
"\"Finland\" = \"Finnland\";\n"
"\"France\" = \"Frankreich\";\n"
"\"French Guiana\" = \"Französisch-Guayana\";\n"
"\"French Polynesia\" = \"Französisch-Polynesien\";\n"
"\"French Southern Territories\" = \"Französische südliche Gebiete\";\n"
"\"Gabon\" = \"Gabun\";\n"
"\"Gambia\" = \"Gambia\";\n"
"\"Georgia\" = \"Georgien\";\n"
"\"Germany\" = \"Deutschland\";\n"
"\"Ghana\" = \"Ghana\";\n"
"\"Gibraltar\" = \"Gibraltar\";\n"
"\"Greece\" = \"Griechenland\";\n"
"\"Greenland\" = \"Grönland\";\n"
"\"Grenada\" = \"Grenada\";\n"
"\"Group changes saved.\" = \"Gruppenänderungen gespeichert.\";\n"
"\"Guadeloupe\" = \"Guadeloupe\";\n"
"\"Guam\" = \"Guam\";\n"
"\"Guatemala\" = \"Guatemala\";\n"
"\"Guernsey\" = \"Guernsey\";\n"
"\"Guinea\" = \"Guinea\";\n"
"\"Guinea-Bissau\" = \"Guinea-Bissau\";\n"
"\"Guyana\" = \"Guyana\";\n"
"\"Haiti\" = \"Haiti\";\n"
"\"Heard Island and McDonald Islands\" = \"Heard Island und McDonald Inseln\";\n"
"\"Hidden SSID\" = \"Hidden SSID\";\n"
"\"Hold Job\" = \"Hold Job\";\n"
"\"Hold New Jobs\" = \"Hold New Jobs\";\n"
"\"Holding new jobs.\" = \"Holding new jobs.\";\n"
"\"Holy See\" = \"Heiliger Stuhl\";\n"
"\"Honduras\" = \"Honduras\";\n"
"\"Hong Kong\" = \"Hongkong\";\n"
"\"Hostname\" = \"Rechnername (Hostname)\";\n"
"\"Human-Readable Location\" = \"Ortsbezeichnung\";\n"
"\"Hungary\" = \"Ungarn\";\n"
"\"IPv4 Address\" = \"IPv4 Address\";\n"
"\"IPv4 Configuration\" = \"IPv4 Configuration\";\n"
"\"IPv4 Gateway\" = \"IPv4 Gateway\";\n"
"\"IPv4 Netmask\" = \"IPv4 Netmask\";\n"
"\"IPv6 Address\" = \"IPv6 Address\";\n"
"\"IPv6 Configuration\" = \"IPv6 Configuration\";\n"
"\"IPv6 Link-Local\" = \"IPv6 Link-Local\";\n"
"\"IPv6 Prefix Length\" = \"IPv6 Prefix Length\";\n"
"\"Iceland\" = \"Island\";\n"
"\"Identify Printer\" = \"Drucker identifizieren\";\n"
"\"India\" = \"Indien\";\n"
"\"Indonesia\" = \"Indonesien\";\n"
"\"Informational\" = \"Informativ\";\n"
"\"Install TLS Certificate\" = \"TLS Zertifikat installieren\";\n"
"\"Invalid IPv4 address.\" = \"Invalid IPv4 address.\";\n"
"\"Invalid IPv4 netmask.\" = \"Invalid IPv4 netmask.\";\n"
"\"Invalid IPv6 address.\" = \"Invalid IPv6 address.\";\n"
"\"Invalid IPv6 prefix length.\" = \"Invalid IPv6 prefix length.\";\n"
"\"Invalid Job ID.\" = \"Ungültige Auftragsnummer (Job-ID).\";\n"
"\"Invalid certificate or private key.\" = \"Zertifikat oder privater Schlüssel ungültig.\";\n"
"\"Invalid form data.\" = \"Formulardaten ungültig.\";\n"
"\"Invalid form submission.\" = \"Formulardaten ungültig.\";\n"
"\"Invalid job ID.\" = \"Auftragsnummer ungültig.\";\n"
"\"Invalid network configuration.\" = \"Invalid network configuration.\";\n"
"\"Iran (Islamic Republic of)\" = \"Iran (Islamische Republik)\";\n"
"\"Iraq\" = \"Irak\";\n"
"\"Ireland\" = \"Irland\";\n"
"\"Isle of Man\" = \"Isle of Man\";\n"
"\"Israel\" = \"Israel\";\n"
"\"Italy\" = \"Italien\";\n"
"\"Jamaica\" = \"Jamaika\";\n"
"\"Japan\" = \"Japan\";\n"
"\"Jersey\" = \"Jersey\";\n"
"\"Job #\" = \"Auftrag #\";\n"
"\"Job canceled.\" = \"Job canceled.\";\n"
"\"Job held.\" = \"Job held.\";\n"
"\"Job released.\" = \"Job released.\";\n"
"\"Jobs\" = \"Aufträge\";\n"
"\"Joining Wi-Fi Network\" = \"Joining Wi-Fi Network\";\n"
"\"Jordan\" = \"Jordanien\";\n"
"\"Kazakhstan\" = \"Kasachstan\";\n"
"\"Kenya\" = \"Kenia\";\n"
"\"Kiribati\" = \"Kiribati\";\n"
"\"Korea (Democratic People's Republic of)\" = \"Korea (Demokratische Volksrepublik)\";\n"
"\"Korea, Republic of\" = \"Korea, Republik\";\n"
"\"Kuwait\" = \"Kuwait\";\n"
"\"Kyrgyzstan\" = \"Kirgisistan\";\n"
"\"Landscape\" = \"Querformat\";\n"
"\"Lao People's Democratic Republic\" = \"Laos\";\n"
"\"Latvia\" = \"Lettland\";\n"
"\"Lebanon\" = \"Libanon\";\n"
"\"Lesotho\" = \"Lesotho\";\n"
"\"Level\" = \"Ebene\";\n"
"\"Liberia\" = \"Liberia\";\n"
"\"Libya\" = \"Libyen\";\n"
"\"Liechtenstein\" = \"Liechtenstein\";\n"
"\"Lithuania\" = \"Litauen\";\n"
"\"Location\" = \"Standort\";\n"
"\"Log Level\" = \"Protokollierungsstufe\";\n"
"\"Logging\" = \"Protokollierung\";\n"
"\"Logs\" = \"Protokolle\";\n"
"\"Luxembourg\" = \"Luxemburg\";\n"
"\"Macao\" = \"Macao\";\n"
"\"Madagascar\" = \"Madagaskar\";\n"
"\"Malawi\" = \"Malawi\";\n"
"\"Malaysia\" = \"Malaysia\";\n"
"\"Maldives\" = \"Malediven\";\n"
"\"Mali\" = \"Mali\";\n"
"\"Malta\" = \"Malta\";\n"
"\"Manual Configuration\" = \"Manual Configuration\";\n"
"\"Marshall Islands\" = \"Marshallinseln\";\n"
"\"Martinique\" = \"Martinique\";\n"
"\"Mauritania\" = \"Mauretanien\";\n"
"\"Mauritius\" = \"Mauritius\";\n"
"\"Mayotte\" = \"Mayotte\";\n"
"\"Media\" = \"Medien\";\n"
"\"Mexico\" = \"Mexiko\";\n"
"\"Micronesia (Federated States of)\" = \"Mikronesien (Bundesstaaten)\";\n"
"\"Missing action.\" = \"Fehlende Aktivität.\";\n"
"\"Missing job ID.\" = \"Missing job ID.\";\n"
"\"Missing network name.\" = \"Missing network name.\";\n"
"\"Missing private key.\" = \"Der private Schlüssel fehlt.\";\n"
"\"Moldova, Republic of\" = \"Republik Moldau\";\n"
"\"Monaco\" = \"Monaco\";\n"
"\"Mongolia\" = \"Mongolei\";\n"
"\"Montenegro\" = \"Montenegro\";\n"
"\"Montserrat\" = \"Montserrat\";\n"
"\"Morocco\" = \"Marokko\";\n"
"\"Mozambique\" = \"Mosambik\";\n"
"\"Myanmar\" = \"Myanmar\";\n"
"\"Name\" = \"Name\";\n"
"\"Namibia\" = \"Namibia\";\n"
"\"Nauru\" = \"Nauru\";\n"
"\"Nepal\" = \"Nepal\";\n"
"\"Netherlands\" = \"Niederlande\";\n"
"\"Network\" = \"Netzwerk\";\n"
"\"Network Printer\" = \"Netzwerkdrucker\";\n"
"\"Networking\" = \"Vernetzung\";\n"
"\"New Caledonia\" = \"Neukaledonien\";\n"
"\"New Zealand\" = \"Neuseeland\";\n"
"\"Nicaragua\" = \"Nicaragua\";\n"
"\"Niger\" = \"Niger\";\n"
"\"Nigeria\" = \"Nigeria\";\n"
"\"Niue\" = \"Niue\";\n"
"\"No default printer set.\" = \"Kein Standard-Drucker gesetzt.\";\n"
"\"No jobs in history.\" = \"Keine Aufträge in der Historie.\";\n"
"\"Norfolk Island\" = \"Norfolk Island\";\n"
"\"North Macedonia\" = \"Nordmakedonien\";\n"
"\"Northern Mariana Islands\" = \"Nördliche Marianen\";\n"
"\"Norway\" = \"Norwegen\";\n"
"\"Not set\" = \"Nicht gesetzt\";\n"
"\"Off\" = \"Off\";\n"
"\"Offset\" = \"Offset\";\n"
"\"Oman\" = \"Oman\";\n"
"\"Options:\" = \"Optionen:\";\n"
"\"Organization\" = \"Organisation\";\n"
"\"Organization Name\" = \"Name der Organisation\";\n"
"\"Other Settings\" = \"Weitere Einstellungen\";\n"
"\"Pakistan\" = \"Pakistan\";\n"
"\"Palau\" = \"Palau\";\n"
"\"Palestine, State of\" = \"Palästina\";\n"
"\"Panama\" = \"Panama\";\n"
"\"Papua New Guinea\" = \"Papua-Neuguinea\";\n"
"\"Paraguay\" = \"Paraguay\";\n"
"\"Password\" = \"Passwort\";\n"
"\"Password changed.\" = \"Passwort geändert.\";\n"
"\"Password must be at least eight characters long and contain at least one uppercase letter, one lowercase letter, and one digit.\" = \"Das Passwort muss mindestens acht Zeichen lang sein und mindestens einen Großbuchstaben, einen Kleinbuchstaben und eine Ziffer enthalten.\";\n"
"\"Passwords do not match.\" = \"Passwörter passen nicht.\";\n"
"\"Pause Printing\" = \"Drucken pausieren\";\n"
"\"Peru\" = \"Peru\";\n"
"\"Philippines\" = \"Philippinen\";\n"
"\"Pitcairn\" = \"Pitcairn\";\n"
"\"Please enter a hostname or IP address for the printer.\" = \"Bitte geben Sie einen Hostnamen oder eine IP-Adresse für den Drucker ein.\";\n"
"\"Please enter a printer name.\" = \"Bitte geben Sie einen Druckernamen ein.\";\n"
"\"Please select a device.\" = \"Bitte wählen Sie ein Gerät aus.\";\n"
"\"Please select a driver.\" = \"Bitte wählen Sie einen Treiber aus.\";\n"
"\"Please select a valid log level.\" = \"Bitte wählen Sie einen gültigen Protokollierungsgrad aus.\";\n"
"\"Poland\" = \"Polen\";\n"
"\"Portrait\" = \"Hochformat\";\n"
"\"Portugal\" = \"Portugal\";\n"
"\"Primary DNS\" = \"Primary DNS\";\n"
"\"Print Group\" = \"Drucker Gruppe\";\n"
"\"Print Test Page\" = \"Testseite drucken\";\n"
"\"Print job options:\" = \"Druckauftrag Optionen:\";\n"
"\"Printer identified.\" = \"Drucker identifiziert.\";\n"
"\"Printer is currently active.\" = \"Drucker ist derzeit aktiv.\";\n"
"\"Printer names must start with a letter or underscore and cannot contain special characters.\" = \"Druckernamen müssen mit einem Buchstaben oder Unterstrich beginnen und dürfen keine Sonderzeichen enthalten.\";\n"
"\"Printer options:\" = \"Druckeroptionen:\";\n"
"\"Printer paused.\" = \"Drucker pausiert.\";\n"
"\"Printer pausing.\" = \"Drucker pausiert.\";\n"
"\"Printer resuming.\" = \"Drucker neu gestartet.\";\n"
"\"Printers\" = \"Drucker\";\n"
"\"Printing Defaults\" = \"Drucker Voreinstellungen\";\n"
"\"Puerto Rico\" = \"Puerto Rico\";\n"
"\"Qatar\" = \"Katar\";\n"
"\"Queued %s\" = \"Queued %s\";\n"
"\"Release Held New Jobs\" = \"Release Held New Jobs\";\n"
"\"Release Job\" = \"Release Job\";\n"
"\"Released held new jobs.\" = \"Released held new jobs.\";\n"
"\"Reprint Job\" = \"Auftrag erneut drucken\";\n"
"\"Reprinted job.\" = \"Reprinted job.\";\n"
"\"Resume Printing\" = \"Druck fortsetzen\";\n"
"\"Reverse Landscape\" = \"Querformat (rotiert)\";\n"
"\"Reverse Portrait\" = \"Hochformat (rotiert)\";\n"
"\"Romania\" = \"Rumänien\";\n"
/* Running, STATE since DATE REASONS */
"\"Running, %s since %s%s.\" = \"In Bearbeitung, %s seit %s %s .\";\n"
"\"Russian Federation\" = \"Russische Föderation\";\n"
"\"Rwanda\" = \"Ruanda\";\n"
"\"Réunion\" = \"Réunion\";\n"
"\"Saint Barthélemy\" = \"Saint Barthélemy\";\n"
"\"Saint Helena, Ascension and Tristan da Cunha\" = \"St. Helena, Ascension und Tristan da Cunha\";\n"
"\"Saint Kitts and Nevis\" = \"St. Kitts und Nevis\";\n"
"\"Saint Lucia\" = \"Saint Lucia\";\n"
"\"Saint Martin (French part)\" = \"Saint Martin (französischer Teil)\";\n"
"\"Saint Pierre and Miquelon\" = \"Saint Pierre und Miquelon\";\n"
"\"Saint Vincent and the Grenadines\" = \"St. Vincent und die Grenadinen\";\n"
"\"Samoa\" = \"Samoa\";\n"
"\"San Marino\" = \"San Marino\";\n"
"\"Sao Tome and Principe\" = \"Sao Tome und Principe\";\n"
"\"Saudi Arabia\" = \"Saudi-Arabien\";\n"
"\"Save Changes\" = \"Änderungen speichern\";\n"
"\"Secondary DNS\" = \"Secondary DNS\";\n"
"\"Security\" = \"Sicherheit\";\n"
"\"Select Driver\" = \"Wählen Sie einen Treiber\";\n"
"\"Senegal\" = \"Senegal\";\n"
"\"Serbia\" = \"Serbien\";\n"
"\"Server is not running.\" = \"Server läuft nicht.\";\n"
"\"Set Access Password\" = \"Zugangspasswort setzen\";\n"
"\"Set as Default\" = \"Als Standard setzen\";\n"
"\"Seychelles\" = \"Seychellen\";\n"
"\"Sierra Leone\" = \"Sierra Leone\";\n"
"\"Singapore\" = \"Singapur\";\n"
"\"Sint Maarten (Dutch part)\" = \"Sint Maarten (niederländischer Teil)\";\n"
"\"Slovakia\" = \"Slowakei\";\n"
"\"Slovenia\" = \"Slowenien\";\n"
"\"Solomon Islands\" = \"Salomonen\";\n"
"\"Somalia\" = \"Somalia\";\n"
"\"South Africa\" = \"Südafrika\";\n"
"\"South Georgia and the South Sandwich Islands\" = \"Südgeorgien und südliche Sandwichinseln\";\n"
"\"South Sudan\" = \"Südsudan\";\n"
"\"Spain\" = \"Spanien\";\n"
"\"Sri Lanka\" = \"Sri Lanka\";\n"
"\"Started %s\" = \"Started %s\";\n"
"\"Status\" = \"Status\";\n"
"\"Sub-commands:\" = \"Unterbefehle:\";\n"
"\"Sudan\" = \"Sudan\";\n"
"\"Supplies\" = \"Verbrauchsmaterialien\";\n"
"\"Suriname\" = \"Surinam\";\n"
"\"Svalbard and Jan Mayen\" = \"Svalbard und Jan Mayen\";\n"
"\"Sweden\" = \"Schweden\";\n"
"\"Switzerland\" = \"Schweiz\";\n"
"\"Syrian Arab Republic\" = \"Arabische Republik Syrien\";\n"
"\"Taiwan, Province of China\" = \"Taiwan\";\n"
"\"Tajikistan\" = \"Tadschikistan\";\n"
"\"Tanzania, United Republic of\" = \"Tansania, Vereinigte Republik\";\n"
"\"Test page printed.\" = \"Testseite gedruckt.\";\n"
"\"Thailand\" = \"Thailand\";\n"
"\"This form creates a certificate signing request ('CSR') that you can send to a Certificate Authority ('CA') to obtain a trusted TLS certificate. The private key is saved separately for use with the certificate you get from the CA.\" = \"Dieses Formular erstellt eine Bescheinigungsunterzeichnungsanfrage (CSR), die Sie an eine Bescheinigungsbehörde (CA) senden können, um ein vertrauenswürdiges TLS-Zertifikat zu erhalten. Der private Schlüssel wird für die Verwendung mit dem Zertifikat, das Sie von der CA erhalten, separat gespeichert.\";\n"
"\"This form creates a new 'self-signed' TLS certificate for secure printing. Self-signed certificates are not automatically trusted by web browsers.\" = \"Dieses Formular erstellt ein neues selbstsigniertes TLS-Zertifikat zum sicheren Drucken. Selbstsignierte Zertifikate werden nicht automatisch von Webbrowsern akzeptiert.\";\n"
"\"This form will install a trusted TLS certificate you have obtained from a Certificate Authority ('CA'). Once installed, it will be used immediately.\" = \"Dieses Formular wird ein vertrauenswürdiges TLS-Zertifikat installieren, das Sie von einer Certificate Authority (CA.) erhalten haben. Nach der Installation wird es sofort verwendet.\";\n"
"\"Timor-Leste\" = \"Timor-Leste\";\n"
"\"Togo\" = \"Togo\";\n"
"\"Tokelau\" = \"Tokelau\";\n"
"\"Tonga\" = \"Tonga\";\n"
"\"Trinidad and Tobago\" = \"Trinidad und Tobago\";\n"
"\"Tunisia\" = \"Tunesien\";\n"
"\"Turkey\" = \"Türkei\";\n"
"\"Turkmenistan\" = \"Turkmenistan\";\n"
"\"Turks and Caicos Islands\" = \"Turks- und Caicosinseln\";\n"
"\"Tuvalu\" = \"Tuvalu\";\n"
"\"Uganda\" = \"Uganda\";\n"
"\"Ukraine\" = \"Ukraine\";\n"
"\"Unable to access test print file.\" = \"Zugriff auf Test-Druckdatei fehlgeschlagen.\";\n"
"\"Unable to copy print job.\" = \"Druckauftrag konnte nicht kopiert werden.\";\n"
"\"Unable to create certificate request.\" = \"Zertifikatsanforderung konnte nicht erstellt werden.\";\n"
"\"Unable to create certificate.\" = \"Zertifikat zu konnte nicht erstellt werden.\";\n"
"\"Unable to create test print job.\" = \"Test-Druckauftrag konnte nicht erstellt werden.\";\n"
"\"Unable to identify printer.\" = \"Drucker konnte nicht identifiziert werden.\";\n"
"\"Unable to lookup address.\" = \"Adresse nicht gefunden.\";\n"
"\"Unable to use that driver.\" = \"Dieser Treiber konnte nicht benutzt werden.\";\n"
"\"United Arab Emirates\" = \"Vereinigte Arabische Emirate\";\n"
"\"United Kingdom\" = \"Vereinigtes Königreich\";\n"
"\"United Kingdom of Great Britain and Northern Ireland\" = \"Vereinigtes Königreich Großbritannien und Nordirland\";\n"
"\"United States Minor Outlying Islands\" = \"Kleinere Inselbesitzungen der Vereinigten Staaten\";\n"
"\"United States of America\" = \"Vereinigte Staaten von Amerika\";\n"
"\"Unknown\" = \"Unbekannt\";\n"
"\"Unknown action.\" = \"Unbekannte Handlung.\";\n"
"\"Unknown form action.\" = \"Unbekannte Formular Aktivität.\";\n"
"\"Unknown form request.\" = \"Unbekannte Formularanfrage.\";\n"
"\"Updating Network Configuration\" = \"Updating Network Configuration\";\n"
"\"Uruguay\" = \"Uruguay\";\n"
"\"Usage: %s SUB-COMMAND [OPTIONS] [FILENAME]\\n\" = \"Verwendung: %s SUB-COMMAND [OPTIONEN] (DATEINAME)\\n\";\n"
"\"Use My Position\" = \"Verwenden Sie meine Position\";\n"
"\"Users\" = \"Benutzer\";\n"
"\"Uzbekistan\" = \"Usbekistan\";\n"
"\"Vanuatu\" = \"Vanuatu\";\n"
"\"Venezuela (Bolivarian Republic of)\" = \"Venezuela (Bolivarianische Republik)\";\n"
"\"Version %s\" = \"Version %s\";\n"
"\"Viet Nam\" = \"Vietnam\";\n"
"\"View Logs\" = \"Protokoll anzeigen\";\n"
"\"Virgin Islands (British)\" = \"Jungferninseln (Britisch)\";\n"
"\"Virgin Islands (U.S.)\" = \"Jungferninseln (USA)\";\n"
"\"Wallis and Futuna\" = \"Wallis und Futuna\";\n"
"\"Warning\" = \"Warnung\";\n"
"\"Western Sahara\" = \"Westsahara\";\n"
"\"Wi-Fi Configuration\" = \"Wi-Fi Konfiguration\";\n"
"\"Wi-Fi Network\" = \"WLAN-Netzwerk\";\n"
"\"Width\" = \"Breite\";\n"
"\"Wrong old password.\" = \"Altes Passwort war falsch.\";\n"
"\"Yemen\" = \"Jemen\";\n"
"\"Zambia\" = \"Sambia\";\n"
"\"Zimbabwe\" = \"Simbabwe\";\n"
"\"at %02d:%02d:%02d\" = \"at %02d:%02d:%02d\";\n"
/* IPP attribute, keyword, and enum (integer) localizations */
"\"copies\" = \"Anzahl der Kopien\";\n"
"\"default printer\" = \"Standarddrucker\";\n"
"\"finishings\" = \"Veredelung\";\n"
"\"finishings.10\" = \"Faltung\";\n"
"\"finishings.100\" = \"Z Faltung\";\n"
"\"finishings.101\" = \"Engineering Z falten\";\n"
"\"finishings.11\" = \"Schneiden\";\n"
"\"finishings.12\" = \"Balsame\";\n"
"\"finishings.13\" = \"Buchmacher\";\n"
"\"finishings.15\" = \"Beschichtung\";\n"
"\"finishings.16\" = \"Laminat\";\n"
"\"finishings.20\" = \"Oben links klammern\";\n"
"\"finishings.21\" = \"Unten links klammern\";\n"
"\"finishings.22\" = \"Oben rechts klammern\";\n"
"\"finishings.23\" = \"Unten rechts klammern\";\n"
"\"finishings.24\" = \"Randstich links\";\n"
"\"finishings.25\" = \"Randstich oben\";\n"
"\"finishings.26\" = \"Randstich rechts\";\n"
"\"finishings.27\" = \"Randstich unten\";\n"
"\"finishings.28\" = \"2 Klammern auf der linken Seite\";\n"
"\"finishings.29\" = \"2 Klammern oben\";\n"
"\"finishings.3\" = \"Keine\";\n"
"\"finishings.30\" = \"2 Klammern rechts\";\n"
"\"finishings.31\" = \"2 Klammern auf der Unterseite\";\n"
"\"finishings.32\" = \"3 Klammern auf der linken Seite\";\n"
"\"finishings.33\" = \"3 Klammern oben\";\n"
"\"finishings.34\" = \"3 Klammern rechts\";\n"
"\"finishings.35\" = \"3 Klammern auf der Unterseite\";\n"
"\"finishings.4\" = \"Stapel\";\n"
"\"finishings.5\" = \"Lochen\";\n"
"\"finishings.50\" = \"Bindung links\";\n"
"\"finishings.51\" = \"Bindung oben\";\n"
"\"finishings.52\" = \"Bindung rechts\";\n"
"\"finishings.53\" = \"Bindung unten\";\n"
"\"finishings.6\" = \"Deckblatt\";\n"
"\"finishings.60\" = \"Nach jeder Seite schneiden\";\n"
"\"finishings.61\" = \"Nach jedem Dokument schneiden\";\n"
"\"finishings.62\" = \"Nach jedem Set schneiden\";\n"
"\"finishings.63\" = \"Nach dem Job schneiden\";\n"
"\"finishings.7\" = \"Bindung\";\n"
"\"finishings.70\" = \"Punch oben links\";\n"
"\"finishings.71\" = \"Punch unten links\";\n"
"\"finishings.72\" = \"Punch oben rechts\";\n"
"\"finishings.73\" = \"Punch unten rechts\";\n"
"\"finishings.74\" = \"2-Loch-Punch links\";\n"
"\"finishings.75\" = \"2-Loch-Dämpfung\";\n"
"\"finishings.76\" = \"2-Loch-Puzzle rechts\";\n"
"\"finishings.77\" = \"2-Loch-Dämpfung\";\n"
"\"finishings.78\" = \"3-Loch-Stempel links\";\n"
"\"finishings.79\" = \"3-Loch-Puzzle\";\n"
"\"finishings.8\" = \"Sattelstich\";\n"
"\"finishings.80\" = \"3-Loch-Stempel rechts\";\n"
"\"finishings.81\" = \"3-Loch-Plattenboden\";\n"
"\"finishings.82\" = \"4-Loch-Stempel links\";\n"
"\"finishings.83\" = \"4-Loch-Puzzle\";\n"
"\"finishings.84\" = \"4-Loch-Stempel rechts\";\n"
"\"finishings.85\" = \"4-Loch-Plattenboden\";\n"
"\"finishings.86\" = \"Mehrlochstempel links\";\n"
"\"finishings.87\" = \"Multi-Loch-Stempel oben\";\n"
"\"finishings.88\" = \"Mehrlochstempel rechts\";\n"
"\"finishings.89\" = \"Mehrloch-Stanzboden\";\n"
"\"finishings.9\" = \"Randstich\";\n"
"\"finishings.90\" = \"Akkordeonfaltung\";\n"
"\"finishings.91\" = \"Doppeltorfalte\";\n"
"\"finishings.92\" = \"Torfalte\";\n"
"\"finishings.93\" = \"Halbe Falte\";\n"
"\"finishings.94\" = \"Halbe Z Falten\";\n"
"\"finishings.95\" = \"linke Torfalte\";\n"
"\"finishings.96\" = \"Brieffaltung\";\n"
"\"finishings.97\" = \"Parallelfaltung\";\n"
"\"finishings.98\" = \"Posterfaltung\";\n"
"\"finishings.99\" = \"rechte Torfalte\";\n"
"\"holding new jobs\" = \"holding new jobs\";\n"
"\"job-state-reasons.aborted-by-system\" = \"Stoppen.\";\n"
"\"job-state-reasons.compression-error\" = \"Dekompressionsfehler.\";\n"
"\"job-state-reasons.document-format-error\" = \"Dokument-Format-Fehler.\";\n"
"\"job-state-reasons.document-password-error\" = \"Dokument-Passwort-Fehler.\";\n"
"\"job-state-reasons.document-permission-error\" = \"Dokument-Berechtigungsfehler.\";\n"
"\"job-state-reasons.document-unprintable-error\" = \"Fehler: Dokument nicht druckbar.\";\n"
"\"job-state-reasons.errors-detected\" = \"Fehler erkannt.\";\n"
"\"job-state-reasons.job-canceled-at-device\" = \"Am Drucker abgebrochen.\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"Vom Benutzer abgebrochen.\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"Gedruckt.\";\n"
"\"job-state-reasons.job-completed-with-errors\" = \"Gedruckt (mit Fehlern).\";\n"
"\"job-state-reasons.job-completed-with-warnings\" = \"Gedruckt (mit Warnungen).\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"Unzureichende Daten.\";\n"
"\"job-state-reasons.job-fetchable\" = \"Abholbereit.\";\n"
"\"job-state-reasons.job-incoming\" = \"Eingehend.\";\n"
"\"job-state-reasons.job-printing\" = \"Druck läuft.\";\n"
"\"job-state-reasons.job-queued\" = \"Vorbereitung auf den Druck.\";\n"
"\"job-state-reasons.job-spooling\" = \"Warteschlange.\";\n"
"\"job-state-reasons.none\" = \"Wartend.\";\n"
"\"job-state-reasons.printer-stopped\" = \"Drucker offline.\";\n"
"\"job-state-reasons.printer-stopped-partly\" = \"Der Drucker wurde teilweise gestoppt.\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"Stoppend.\";\n"
"\"job-state-reasons.queued-in-device\" = \"Fertig.\";\n"
"\"job-state-reasons.warnings-detected\" = \"Warnungen entdeckt.\";\n"
"\"job-state.3\" = \"Anstehend\";\n"
"\"job-state.4\" = \"Zurückgehalten\";\n"
"\"job-state.5\" = \"In Verarbeitung\";\n"
"\"job-state.6\" = \"Gestoppt\";\n"
"\"job-state.7\" = \"Zurückgezogen\";\n"
"\"job-state.8\" = \"Abgebrochen\";\n"
"\"job-state.9\" = \"Abgeschlossen\";\n"
"\"joining\" = \"Fügen Sie\";\n"
"\"media\" = \"Medien\";\n"
"\"media-col\" = \"Medien\";\n"
"\"media-size\" = \"Mediengröße\";\n"
"\"media-size-name\" = \"Mediengröße\";\n"
"\"media-source\" = \"Eingabeschacht\";\n"
"\"media-source.alternate\" = \"Alternativer Ausgabeschacht\";\n"
"\"media-source.alternate-roll\" = \"Rollenwechsel\";\n"
"\"media-source.auto\" = \"Automatisch\";\n"
"\"media-source.bottom\" = \"Unten\";\n"
"\"media-source.by-pass-tray\" = \"Mehrzweck-Zuführung\";\n"
"\"media-source.center\" = \"Mitte\";\n"
"\"media-source.disc\" = \"Scheiben\";\n"
"\"media-source.envelope\" = \"Briefumschlag (Envelope)\";\n"
"\"media-source.hagaki\" = \"Postkarte ('Hagaki')\";\n"
"\"media-source.large-capacity\" = \"Große Kapazität\";\n"
"\"media-source.left\" = \"Links\";\n"
"\"media-source.main\" = \"Haupt\";\n"
"\"media-source.main-roll\" = \"Hauptrolle\";\n"
"\"media-source.manual\" = \"Handbuch\";\n"
"\"media-source.middle\" = \"Mittel\";\n"
"\"media-source.photo\" = \"Foto\";\n"
"\"media-source.rear\" = \"Rückseitig\";\n"
"\"media-source.right\" = \"Rechts\";\n"
"\"media-source.roll-1\" = \"Rolle 1\";\n"
"\"media-source.roll-10\" = \"Rolle 10\";\n"
"\"media-source.roll-2\" = \"Rolle 2\";\n"
"\"media-source.roll-3\" = \"Rolle 3\";\n"
"\"media-source.roll-4\" = \"Rolle 4\";\n"
"\"media-source.roll-5\" = \"Rolle 5\";\n"
"\"media-source.roll-6\" = \"Rolle 6\";\n"
"\"media-source.roll-7\" = \"Rolle 7\";\n"
"\"media-source.roll-8\" = \"Rolle 8\";\n"
"\"media-source.roll-9\" = \"Rolle 9\";\n"
"\"media-source.side\" = \"Seite\";\n"
"\"media-source.top\" = \"Oben\";\n"
"\"media-source.tray-1\" = \"Schacht 1\";\n"
"\"media-source.tray-10\" = \"Schacht 10\";\n"
"\"media-source.tray-11\" = \"Schacht 11\";\n"
"\"media-source.tray-12\" = \"Schacht 12\";\n"
"\"media-source.tray-13\" = \"Schacht 13\";\n"
"\"media-source.tray-14\" = \"Schacht 14\";\n"
"\"media-source.tray-15\" = \"Schacht 15\";\n"
"\"media-source.tray-16\" = \"Schacht 16\";\n"
"\"media-source.tray-17\" = \"Schacht 17\";\n"
"\"media-source.tray-18\" = \"Schacht 18\";\n"
"\"media-source.tray-19\" = \"Schacht 19\";\n"
"\"media-source.tray-2\" = \"Schacht 2\";\n"
"\"media-source.tray-20\" = \"Schacht 20\";\n"
"\"media-source.tray-3\" = \"Schacht 3\";\n"
"\"media-source.tray-4\" = \"Schacht 4\";\n"
"\"media-source.tray-5\" = \"Schacht 5\";\n"
"\"media-source.tray-6\" = \"Schacht 6\";\n"
"\"media-source.tray-7\" = \"Schacht 7\";\n"
"\"media-source.tray-8\" = \"Schacht 8\";\n"
"\"media-source.tray-9\" = \"Schacht 9\";\n"
"\"media-tracking\" = \"Medienverfolgung\";\n"
"\"media-tracking.continuous\" = \"Kontinuierlich\";\n"
"\"media-tracking.gap\" = \"Abstand\";\n"
"\"media-tracking.mark\" = \"Mark\";\n"
"\"media-tracking.web\" = \"Internet\";\n"
"\"media-type\" = \"Medientyp\";\n"
"\"media-type.aluminum\" = \"Aluminium\";\n"
"\"media-type.auto\" = \"Automatisch\";\n"
"\"media-type.back-print-film\" = \"Rückseitig bedruckte Folie\";\n"
"\"media-type.cardboard\" = \"Pappe\";\n"
"\"media-type.cardstock\" = \"Karten\";\n"
"\"media-type.cd\" = \"CD\";\n"
"\"media-type.continuous\" = \"Kontinuierlich\";\n"
"\"media-type.continuous-long\" = \"Kontinuierlich (lang)\";\n"
"\"media-type.continuous-short\" = \"Kontinuierlich (kurz)\";\n"
"\"media-type.corrugated-board\" = \"Wellpappe\";\n"
"\"media-type.disc\" = \"Optischer Datenträger\";\n"
"\"media-type.disc-glossy\" = \"Optischer Datenträger (glänzend)\";\n"
"\"media-type.disc-high-gloss\" = \"Optischer Datenträger (hochglänzend)\";\n"
"\"media-type.disc-matte\" = \"Optischer Datenträger (matt)\";\n"
"\"media-type.disc-satin\" = \"Optischer Datenträger (satin)\";\n"
"\"media-type.disc-semi-gloss\" = \"Optischer Datenträger (halbglänzend)\";\n"
"\"media-type.double-wall\" = \"Doppelwand\";\n"
"\"media-type.dry-film\" = \"Trockenfilm\";\n"
"\"media-type.dvd\" = \"DVD\";\n"
"\"media-type.embossing-foil\" = \"Prägefolie\";\n"
"\"media-type.end-board\" = \"Endpunkt\";\n"
"\"media-type.envelope\" = \"Umschlag\";\n"
"\"media-type.envelope-archival\" = \"Archiv-Umschlag\";\n"
"\"media-type.envelope-bond\" = \"Umschlag (Bond)\";\n"
"\"media-type.envelope-coated\" = \"Umschlag (Beschichtet)\";\n"
"\"media-type.envelope-cotton\" = \"Umschlag (Baumwolle)\";\n"
"\"media-type.envelope-fine\" = \"Umschlag (Fein)\";\n"
"\"media-type.envelope-heavyweight\" = \"Umschlag (schwer)\";\n"
"\"media-type.envelope-inkjet\" = \"Umschlag (Tintenstrahldruck)\";\n"
"\"media-type.envelope-lightweight\" = \"Umschlag (leicht)\";\n"
"\"media-type.envelope-plain\" = \"Umschlag (unbedruckt)\";\n"
"\"media-type.envelope-preprinted\" = \"Umschlag (bedruckt)\";\n"
"\"media-type.envelope-window\" = \"Umschlag (mit Sichtfenster)\";\n"
"\"media-type.fabric\" = \"Gewebe\";\n"
"\"media-type.fabric-archival\" = \"Gewebe (Archivierung)\";\n"
"\"media-type.fabric-glossy\" = \"Stoff (glänzend)\";\n"
"\"media-type.fabric-high-gloss\" = \"Stoff (hochglänzend)\";\n"
"\"media-type.fabric-matte\" = \"Stoff (matt)\";\n"
"\"media-type.fabric-semi-gloss\" = \"Gewebe (halbglänzend)\";\n"
"\"media-type.fabric-waterproof\" = \"Gewebe (wasserfest)\";\n"
"\"media-type.film\" = \"Film-Medium\";\n"
"\"media-type.flexo-base\" = \"Flexo-Basis\";\n"
"\"media-type.flexo-photo-polymer\" = \"Flexo-Fotopolymer\";\n"
"\"media-type.flute\" = \"Fluten\";\n"
"\"media-type.foil\" = \"Folie\";\n"
"\"media-type.full-cut-tabs\" = \"Vollschnitt Tabs\";\n"
"\"media-type.glass\" = \"Glas\";\n"
"\"media-type.glass-colored\" = \"Glas (gefärbt)\";\n"
"\"media-type.glass-opaque\" = \"Glas (undurchsichtig)\";\n"
"\"media-type.glass-surfaced\" = \"Glas (beschichtet)\";\n"
"\"media-type.glass-textured\" = \"Glas (strukturiert)\";\n"
"\"media-type.gravure-cylinder\" = \"Gravurzylinder\";\n"
"\"media-type.image-setter-paper\" = \"Belichterpapier\";\n"
"\"media-type.imaging-cylinder\" = \"Imaging-Zylinder\";\n"
"\"media-type.labels\" = \"Etiketten\";\n"
"\"media-type.labels-colored\" = \"Farbige Etiketten\";\n"
"\"media-type.labels-glossy\" = \"Glossy Etiketten\";\n"
"\"media-type.labels-high-gloss\" = \"Hochglänzende Etiketten\";\n"
"\"media-type.labels-inkjet\" = \"Inkjet Etiketten\";\n"
"\"media-type.labels-matte\" = \"Matte Etiketten\";\n"
"\"media-type.labels-permanent\" = \"Permanente Etiketten\";\n"
"\"media-type.labels-satin\" = \"Satin Etiketten\";\n"
"\"media-type.labels-security\" = \"Sicherheitsetiketten\";\n"
"\"media-type.labels-semi-gloss\" = \"Halbglänzende Etiketten\";\n"
"\"media-type.laminating-foil\" = \"Laminierfolie\";\n"
"\"media-type.letterhead\" = \"Briefkopf (vorbedruckt)\";\n"
"\"media-type.metal\" = \"Metall\";\n"
"\"media-type.metal-glossy\" = \"Metall glänzend\";\n"
"\"media-type.metal-high-gloss\" = \"Metall Hochglanz\";\n"
"\"media-type.metal-matte\" = \"Metall matt\";\n"
"\"media-type.metal-satin\" = \"Metall satiniert\";\n"
"\"media-type.metal-semi-gloss\" = \"Metall Halbglanz\";\n"
"\"media-type.mounting-tape\" = \"Montageband\";\n"
"\"media-type.multi-layer\" = \"Mehrere Lagen\";\n"
"\"media-type.multi-part-form\" = \"Mehrteilige Form\";\n"
"\"media-type.other\" = \"Sonstige\";\n"
"\"media-type.paper\" = \"Papier\";\n"
"\"media-type.photographic\" = \"Fotopapier\";\n"
"\"media-type.photographic-archival\" = \"Fotografische Archivierung\";\n"
"\"media-type.photographic-film\" = \"Fotofilm\";\n"
"\"media-type.photographic-glossy\" = \"Glossy Fotopapier\";\n"
"\"media-type.photographic-high-gloss\" = \"Hochglanz-Fotopapier\";\n"
"\"media-type.photographic-matte\" = \"Mattes Fotopapier\";\n"
"\"media-type.photographic-satin\" = \"Satin Fotopapier\";\n"
"\"media-type.photographic-semi-gloss\" = \"Halbglänzendes Fotopapier\";\n"
"\"media-type.plastic\" = \"Kunststoff\";\n"
"\"media-type.plastic-archival\" = \"Kunststoff (Archivierung)\";\n"
"\"media-type.plastic-colored\" = \"Kunststoff gefärbt\";\n"
"\"media-type.plastic-glossy\" = \"Kunststoff glänzend\";\n"
"\"media-type.plastic-high-gloss\" = \"Kunststoff Hochglanz\";\n"
"\"media-type.plastic-matte\" = \"Kunststoff matt\";\n"
"\"media-type.plastic-satin\" = \"Kunststoff satiniert\";\n"
"\"media-type.plastic-semi-gloss\" = \"Kunststoff Halbglanz\";\n"
"\"media-type.plate\" = \"Druckplatte\";\n"
"\"media-type.polyester\" = \"Polyestermaterial\";\n"
"\"media-type.pre-cut-tabs\" = \"Vorgeschnittene Tabs\";\n"
"\"media-type.roll\" = \"Rollen\";\n"
"\"media-type.screen\" = \"Bildschirm\";\n"
"\"media-type.screen-paged\" = \"Bildschirm (paginiert)\";\n"
"\"media-type.self-adhesive\" = \"Selbstklebend\";\n"
"\"media-type.self-adhesive-film\" = \"Selbstklebende Folie\";\n"
"\"media-type.shrink-foil\" = \"Schrumpffolie\";\n"
"\"media-type.single-face\" = \"Einzelfläche\";\n"
"\"media-type.single-wall\" = \"Einzelwand\";\n"
"\"media-type.sleeve\" = \"Hülse (Sleeve)\";\n"
"\"media-type.stationery\" = \"Schreibpapier\";\n"
"\"media-type.stationery-archival\" = \"Schreibpapier (für Archivierung)\";\n"
"\"media-type.stationery-coated\" = \"beschichtetes Papier\";\n"
"\"media-type.stationery-cotton\" = \"Schreibpapier (aus Baumwolle)\";\n"
"\"media-type.stationery-fine\" = \"Pergament\";\n"
"\"media-type.stationery-heavyweight\" = \"Schweres Papier\";\n"
"\"media-type.stationery-heavyweight-coated\" = \"Schreibpapier (schwer, beschichtet)\";\n"
"\"media-type.stationery-inkjet\" = \"Inkjet-Papiere für Schreibwaren\";\n"
"\"media-type.stationery-letterhead\" = \"Briefkopf (vorbedruckt)\";\n"
"\"media-type.stationery-lightweight\" = \"Leichtes Papier\";\n"
"\"media-type.stationery-preprinted\" = \"Papier (vorbedruckt)\";\n"
"\"media-type.stationery-prepunched\" = \"Papier (gelocht)\";\n"
"\"media-type.tab-stock\" = \"Auf Lager\";\n"
"\"media-type.tractor\" = \"Traktor\";\n"
"\"media-type.transfer\" = \"Transfermedium\";\n"
"\"media-type.transparency\" = \"Transparentes Medium\";\n"
"\"media-type.triple-wall\" = \"Triple Wand\";\n"
"\"media-type.wet-film\" = \"Nassfilm\";\n"
"\"media.choice_iso_a4_210x297mm_na_letter_8.5x11in\" = \"A4 oder US-Brief\";\n"
"\"media.iso_2a0_1189x1682mm\" = \"2a0\";\n"
"\"media.iso_a0_841x1189mm\" = \"A0\";\n"
"\"media.iso_a0x3_1189x2523mm\" = \"A0x3\";\n"
"\"media.iso_a10_26x37mm\" = \"A10\";\n"
"\"media.iso_a1_594x841mm\" = \"A1\";\n"
"\"media.iso_a1x3_841x1783mm\" = \"A1x3\";\n"
"\"media.iso_a1x4_841x2378mm\" = \"A1x4\";\n"
"\"media.iso_a2_420x594mm\" = \"A2\";\n"
"\"media.iso_a2x3_594x1261mm\" = \"A2x3\";\n"
"\"media.iso_a2x4_594x1682mm\" = \"A2x4\";\n"
"\"media.iso_a2x5_594x2102mm\" = \"A2x5\";\n"
"\"media.iso_a3-extra_322x445mm\" = \"A3 (extra)\";\n"
"\"media.iso_a3_297x420mm\" = \"A3\";\n"
"\"media.iso_a3x3_420x891mm\" = \"A3x3\";\n"
"\"media.iso_a3x4_420x1189mm\" = \"A3x4\";\n"
"\"media.iso_a3x5_420x1486mm\" = \"A3x5\";\n"
"\"media.iso_a3x6_420x1783mm\" = \"A3x6\";\n"
"\"media.iso_a3x7_420x2080mm\" = \"A3x7\";\n"
"\"media.iso_a4-extra_235.5x322.3mm\" = \"A4 (extra)\";\n"
"\"media.iso_a4-tab_225x297mm\" = \"A4 (tab)\";\n"
"\"media.iso_a4_210x297mm\" = \"A4\";\n"
"\"media.iso_a4x3_297x630mm\" = \"A4x3\";\n"
"\"media.iso_a4x4_297x841mm\" = \"A4x4\";\n"
"\"media.iso_a4x5_297x1051mm\" = \"A4x5\";\n"
"\"media.iso_a4x6_297x1261mm\" = \"A4x6\";\n"
"\"media.iso_a4x7_297x1471mm\" = \"A4x7\";\n"
"\"media.iso_a4x8_297x1682mm\" = \"A4x8\";\n"
"\"media.iso_a4x9_297x1892mm\" = \"A4x9\";\n"
"\"media.iso_a5-extra_174x235mm\" = \"A5 (extra)\";\n"
"\"media.iso_a5_148x210mm\" = \"A5\";\n"
"\"media.iso_a6_105x148mm\" = \"A6\";\n"
"\"media.iso_a7_74x105mm\" = \"A7\";\n"
"\"media.iso_a8_52x74mm\" = \"A8\";\n"
"\"media.iso_a9_37x52mm\" = \"A9\";\n"
"\"media.iso_b0_1000x1414mm\" = \"B0\";\n"
"\"media.iso_b10_31x44mm\" = \"B10\";\n"
"\"media.iso_b1_707x1000mm\" = \"B1\";\n"
"\"media.iso_b2_500x707mm\" = \"B2\";\n"
"\"media.iso_b3_353x500mm\" = \"B3\";\n"
"\"media.iso_b4_250x353mm\" = \"B4\";\n"
"\"media.iso_b5-extra_201x276mm\" = \"B5 (extra)\";\n"
"\"media.iso_b5_176x250mm\" = \"B5 Umschlag\";\n"
"\"media.iso_b6_125x176mm\" = \"B6\";\n"
"\"media.iso_b6c4_125x324mm\" = \"B6/C4Entwicklung\";\n"
"\"media.iso_b7_88x125mm\" = \"B7\";\n"
"\"media.iso_b8_62x88mm\" = \"B8\";\n"
"\"media.iso_b9_44x62mm\" = \"B9\";\n"
"\"media.iso_c0_917x1297mm\" = \"C0 Umschlag\";\n"
"\"media.iso_c10_28x40mm\" = \"C10 Umschlag\";\n"
"\"media.iso_c1_648x917mm\" = \"C1 Umschlag\";\n"
"\"media.iso_c2_458x648mm\" = \"C2 Umschlag\";\n"
"\"media.iso_c3_324x458mm\" = \"C3 Umschlag\";\n"
"\"media.iso_c4_229x324mm\" = \"C4 Umschlag\";\n"
"\"media.iso_c5_162x229mm\" = \"C5 Umschlag\";\n"
"\"media.iso_c6_114x162mm\" = \"C6 Umschlag\";\n"
"\"media.iso_c6c5_114x229mm\" = \"C6/C5 Umschlag\";\n"
"\"media.iso_c7_81x114mm\" = \"C7 Umschlag\";\n"
"\"media.iso_c7c6_81x162mm\" = \"C7/C6 Umschlag\";\n"
"\"media.iso_c8_57x81mm\" = \"C8 Umschlag\";\n"
"\"media.iso_c9_40x57mm\" = \"C9 Umschlag\";\n"
"\"media.iso_dl_110x220mm\" = \"DL Umschlag\";\n"
"\"media.iso_ra0_860x1220mm\" = \"ISO RA0\";\n"
"\"media.iso_ra1_610x860mm\" = \"ISO RA1\";\n"
"\"media.iso_ra2_430x610mm\" = \"ISO RA2\";\n"
"\"media.iso_ra3_305x430mm\" = \"ISO RA3\";\n"
"\"media.iso_ra4_215x305mm\" = \"ISO RA4\";\n"
"\"media.iso_sra0_900x1280mm\" = \"ISO SRA0\";\n"
"\"media.iso_sra1_640x900mm\" = \"ISO SRA1\";\n"
"\"media.iso_sra2_450x640mm\" = \"ISO SRA2\";\n"
"\"media.iso_sra3_320x450mm\" = \"ISO SRA3\";\n"
"\"media.iso_sra4_225x320mm\" = \"ISO SRA4\";\n"
"\"media.jis_b0_1030x1456mm\" = \"JIS B0\";\n"
"\"media.jis_b10_32x45mm\" = \"JIS B10\";\n"
"\"media.jis_b1_728x1030mm\" = \"JIS B1\";\n"
"\"media.jis_b2_515x728mm\" = \"JIS B2\";\n"
"\"media.jis_b3_364x515mm\" = \"JIS B3\";\n"
"\"media.jis_b4_257x364mm\" = \"JIS B4\";\n"
"\"media.jis_b5_182x257mm\" = \"JIS B5\";\n"
"\"media.jis_b6_128x182mm\" = \"JIS B6\";\n"
"\"media.jis_b7_91x128mm\" = \"JIS B7\";\n"
"\"media.jis_b8_64x91mm\" = \"JIS B8\";\n"
"\"media.jis_b9_45x64mm\" = \"JIS B9\";\n"
"\"media.jis_exec_216x330mm\" = \"JIS Exekutive\";\n"
"\"media.jpn_chou2_111.1x146mm\" = \"Umbau Chou 2\";\n"
"\"media.jpn_chou3_120x235mm\" = \"Umschlag Chou 3\";\n"
"\"media.jpn_chou40_90x225mm\" = \"Umschlag Chou 40\";\n"
"\"media.jpn_chou4_90x205mm\" = \"Umbau Chou 4\";\n"
"\"media.jpn_hagaki_100x148mm\" = \"Postkarte (Hagaki)\";\n"
"\"media.jpn_kahu_240x322.1mm\" = \"Umschlag (Kahu)\";\n"
"\"media.jpn_kaku2_240x332mm\" = \"Umschlag Kahu 2\";\n"
"\"media.jpn_oufuku_148x200mm\" = \"Antwortpostkarte (Oufuku Reply Postcard)\";\n"
"\"media.jpn_you4_105x235mm\" = \"Envelope Sie 4\";\n"
"\"media.na_a2_4.375x5.75in\" = \"Umbau A2\";\n"
"\"media.na_c5_6.5x9.5in\" = \"Umbau C5\";\n"
"\"media.na_executive_7.25x10.5in\" = \"Exekutive\";\n"
"\"media.na_fanfold-eur_8.5x12in\" = \"Endlospapier (EU)\";\n"
"\"media.na_fanfold-us_11x14.875in\" = \"Endlospapier (US)\";\n"
"\"media.na_foolscap_8.5x13in\" = \"Kanzleipapier (Foolscap)\";\n"
"\"media.na_invoice_5.5x8.5in\" = \"Rechnung\";\n"
"\"media.na_legal-extra_9.5x15in\" = \"US Legal (Extra)\";\n"
"\"media.na_legal_8.5x14in\" = \"US Legal\";\n"
"\"media.na_letter-extra_9.5x12in\" = \"US 'Letter' Format (Extra)\";\n"
"\"media.na_letter-plus_8.5x12.69in\" = \"US 'Letter' Format (Plus)\";\n"
"\"media.na_letter_8.5x11in\" = \"US 'Letter' Format\";\n"
"\"media.na_monarch_3.875x7.5in\" = \"Monarch Briefumschlag\";\n"
"\"media.na_number-10_4.125x9.5in\" = \"Briefumschlag #10\";\n"
"\"media.na_number-11_4.5x10.375in\" = \"Briefumschlag #11\";\n"
"\"media.na_number-12_4.75x11in\" = \"Briefumschlag #12\";\n"
"\"media.na_number-14_5x11.5in\" = \"Briefumschlag #14\";\n"
"\"media.na_number-9_3.875x8.875in\" = \"Briefumschlag #9\";\n"
"\"media.na_personal_3.625x6.5in\" = \"Persönlicher Umschlag\";\n"
"\"media.na_quarto_8.5x10.83in\" = \"Amerikanisches Quarto\";\n"
"\"media.om_folio-sp_215x315mm\" = \"Fohlen\";\n"
"\"media.om_folio_210x330mm\" = \"Folioformat (Spezial)\";\n"
"\"media.om_invite_220x220mm\" = \"Envelope Einladung\";\n"
"\"media.om_italian_110x230mm\" = \"Briefumschlag Italienisch\";\n"
"\"media.om_juuro-ku-kai_198x275mm\" = \"198 x 275mm\";\n"
"\"media.om_large-photo_200x300\" = \"200 x 300\";\n"
"\"media.om_medium-photo_130x180mm\" = \"130 x 180mm\";\n"
"\"media.om_pa-kai_267x389mm\" = \"267 x 389m m\";\n"
"\"media.om_postfix_114x229mm\" = \"Postfix umwandeln\";\n"
"\"media.prc_10_324x458mm\" = \"Briefumschlag chinesisch #10\";\n"
"\"media.prc_16k_146x215mm\" = \"Chinesisch 16k\";\n"
"\"media.prc_1_102x165mm\" = \"Briefumschlag chinesisch #1\";\n"
"\"media.prc_2_102x176mm\" = \"Briefumschlag chinesisch #2\";\n"
"\"media.prc_32k_97x151mm\" = \"Chinesisch 32k\";\n"
"\"media.prc_3_125x176mm\" = \"Briefumschlag chinesisch #3\";\n"
"\"media.prc_4_110x208mm\" = \"Briefumschlag chinesisch #4\";\n"
"\"media.prc_5_110x220mm\" = \"Briefumschlag chinesisch #5\";\n"
"\"media.prc_6_120x320mm\" = \"Briefumschlag chinesisch #6\";\n"
"\"media.prc_7_160x230mm\" = \"Briefumschlag chinesisch #7\";\n"
"\"media.prc_8_120x309mm\" = \"Briefumschlag chinesisch #8\";\n"
"\"media.roc_16k_7.75x10.75in\" = \"ROC/Kai 16k\";\n"
"\"media.roc_8k_10.75x15.5in\" = \"ROG 8k\";\n"
"\"not configured\" = \"nicht konfiguriert\";\n"
"\"not visible\" = \"nicht sichtbar\";\n"
"\"off\" = \"Aus\";\n"
"\"on\" = \"An\";\n"
"\"orientation-requested\" = \"Orientierung\";\n"
"\"orientation-requested.3\" = \"Hochformat (Portrait)\";\n"
"\"orientation-requested.4\" = \"Querformat (Landscape)\";\n"
"\"orientation-requested.5\" = \"Querformat (gespiegelt)\";\n"
"\"orientation-requested.6\" = \"Hochformat (gespiegelt)\";\n"
"\"orientation-requested.7\" = \"Keine\";\n"
"\"output-bin\" = \"Ausgabeschacht\";\n"
"\"output-bin.auto\" = \"Automatisch\";\n"
"\"output-bin.bottom\" = \"Unten\";\n"
"\"output-bin.center\" = \"Mitte\";\n"
"\"output-bin.face-down\" = \"Druckseite nach unten\";\n"
"\"output-bin.face-up\" = \"Druckseite nach oben\";\n"
"\"output-bin.large-capacity\" = \"Große Kapazität\";\n"
"\"output-bin.left\" = \"Links\";\n"
"\"output-bin.mailbox-1\" = \"Postfach 1\";\n"
"\"output-bin.mailbox-10\" = \"Postfach 10\";\n"
"\"output-bin.mailbox-2\" = \"Postfach 2\";\n"
"\"output-bin.mailbox-3\" = \"Postfach 3\";\n"
"\"output-bin.mailbox-4\" = \"Postfach 4\";\n"
"\"output-bin.mailbox-5\" = \"Postfach 5\";\n"
"\"output-bin.mailbox-6\" = \"Postfach 6\";\n"
"\"output-bin.mailbox-7\" = \"Postfach 7\";\n"
"\"output-bin.mailbox-8\" = \"Postfach 8\";\n"
"\"output-bin.mailbox-9\" = \"Postfach 9\";\n"
"\"output-bin.middle\" = \"Mitte\";\n"
"\"output-bin.my-mailbox\" = \"Mein Postfach\";\n"
"\"output-bin.rear\" = \"Rückseitig\";\n"
"\"output-bin.right\" = \"Rechts\";\n"
"\"output-bin.side\" = \"Seitlich\";\n"
"\"output-bin.stacker-1\" = \"Stapler 1\";\n"
"\"output-bin.stacker-10\" = \"Stapler 10\";\n"
"\"output-bin.stacker-2\" = \"Stapler 2\";\n"
"\"output-bin.stacker-3\" = \"Stapler 3\";\n"
"\"output-bin.stacker-4\" = \"Stapler 4\";\n"
"\"output-bin.stacker-5\" = \"Stapler 5\";\n"
"\"output-bin.stacker-6\" = \"Stapler 6\";\n"
"\"output-bin.stacker-7\" = \"Stapler 7\";\n"
"\"output-bin.stacker-8\" = \"Stapler 8\";\n"
"\"output-bin.stacker-9\" = \"Stapler 9\";\n"
"\"output-bin.top\" = \"Oben\";\n"
"\"output-bin.tray-1\" = \"Ausgabeschacht 1\";\n"
"\"output-bin.tray-10\" = \"Ausgabeschacht 10\";\n"
"\"output-bin.tray-2\" = \"Ausgabeschacht 2\";\n"
"\"output-bin.tray-3\" = \"Ausgabeschacht 3\";\n"
"\"output-bin.tray-4\" = \"Ausgabeschacht 4\";\n"
"\"output-bin.tray-5\" = \"Ausgabeschacht 5\";\n"
"\"output-bin.tray-6\" = \"Ausgabeschacht 6\";\n"
"\"output-bin.tray-7\" = \"Ausgabeschacht 7\";\n"
"\"output-bin.tray-8\" = \"Ausgabeschacht 8\";\n"
"\"output-bin.tray-9\" = \"Ausgabeschacht 9\";\n"
"\"print-color-mode\" = \"Druckmodus\";\n"
"\"print-color-mode.auto\" = \"Automatisch\";\n"
"\"print-color-mode.auto-monochrome\" = \"Auto monochrom\";\n"
"\"print-color-mode.bi-level\" = \"Text\";\n"
"\"print-color-mode.color\" = \"Farbe\";\n"
"\"print-color-mode.highlight\" = \"Hervorhebung\";\n"
"\"print-color-mode.monochrome\" = \"Monochrom\";\n"
"\"print-color-mode.process-bi-level\" = \"Verfahren Text\";\n"
"\"print-color-mode.process-monochrome\" = \"Verfahren monochrom\";\n"
"\"print-content-optimize\" = \"Optimieren für\";\n"
"\"print-content-optimize.auto\" = \"Automatisch\";\n"
"\"print-content-optimize.graphic\" = \"Grafik\";\n"
"\"print-content-optimize.photo\" = \"Foto\";\n"
"\"print-content-optimize.text\" = \"Text\";\n"
"\"print-content-optimize.text-and-graphic\" = \"Text und Grafik\";\n"
"\"print-darkness\" = \"Drucksättigung\";\n"
"\"print-quality\" = \"Druckqualität\";\n"
"\"print-quality.3\" = \"Entwurf\";\n"
"\"print-quality.4\" = \"Normal\";\n"
"\"print-quality.5\" = \"Beste\";\n"
"\"print-scaling\" = \"Skalierung\";\n"
"\"print-scaling.auto\" = \"Automatisch\";\n"
"\"print-scaling.auto-fit\" = \"Automatisch einpassen\";\n"
"\"print-scaling.fill\" = \"Füllung\";\n"
"\"print-scaling.fit\" = \"Einpassen\";\n"
"\"print-scaling.none\" = \"Keine\";\n"
"\"print-speed\" = \"Druckgeschwindigkeit\";\n"
"\"printer-resolution\" = \"Druckauflösung\";\n"
"\"printer-state-reasons.cover-open\" = \"Abdeckung offen.\";\n"
"\"printer-state-reasons.door-open\" = \"Tür offen.\";\n"
"\"printer-state-reasons.identify-printer-requested\" = \"Drucker identifizieren.\";\n"
"\"printer-state-reasons.input-tray-missing\" = \"Papierzuführung fehlt.\";\n"
"\"printer-state-reasons.marker-supply-empty\" = \"Tintentank leer.\";\n"
"\"printer-state-reasons.marker-supply-low\" = \"Tintenstand niedrig.\";\n"
"\"printer-state-reasons.marker-waste-almost-full\" = \"Abfallbehälter fast voll.\";\n"
"\"printer-state-reasons.marker-waste-full\" = \"Abfallbehälter voll.\";\n"
"\"printer-state-reasons.media-empty\" = \"Papierzuführung leer.\";\n"
"\"printer-state-reasons.media-jam\" = \"Papierstau.\";\n"
"\"printer-state-reasons.media-low\" = \"Füllen Sie bald Papier nach.\";\n"
"\"printer-state-reasons.media-needed\" = \"Papier laden.\";\n"
"\"printer-state-reasons.none\" = \"Fertig.\";\n"
"\"printer-state-reasons.offline\" = \"Offline.\";\n"
"\"printer-state-reasons.other\" = \"Siehe Drucker.\";\n"
"\"printer-state-reasons.spool-area-full\" = \"Drucker beschäftigt.\";\n"
"\"printer-state-reasons.toner-empty\" = \"Tonerbehälter leer.\";\n"
"\"printer-state-reasons.toner-low\" = \"Tonerstand niedrig.\";\n"
"\"printer-state.3\" = \"Leerlauf\";\n"
"\"printer-state.4\" = \"Verarbeitung\";\n"
"\"printer-state.5\" = \"Gestoppt\";\n"
"\"sides\" = \"Doppelseitiger Druck\";\n"
"\"sides.one-sided\" = \"Aus\";\n"
"\"sides.two-sided-long-edge\" = \"An (Hochformat)\";\n"
"\"sides.two-sided-short-edge\" = \"An (Querformat)\";\n"
"\"unable to join\" = \"Zusammenfügen fehlgeschlagen\";\n"
"\"yesterday at %02d:%02d:%02d\" = \"yesterday at %02d:%02d:%02d\";\n"
"\"Åland Islands\" = \"Åland (Inselgruppe)\";\n";
