static const char *ja_strings = "\"  -a               Cancel all jobs (cancel).\" = \"  -a すべてのジョブをキャンセル (cancel)\";\n"
"\"  -c COPIES\" = \"  -c コピー\";\n"
"\"  -d PRINTER       Specify printer.\" = \"  -dプリンターを指定する\";\n"
"\"  -j JOB-ID        Specify job ID (cancel).\" = \"  -j JOB-ID ジョブ ID (cancel) を指定します。\";\n"
"\"  -m DRIVER-NAME   Specify driver (add/modify).\" = \"  -m ドライバ名 ドライバーを指定(追加/変更)\";\n"
"\"  -n COPIES        Specify number of copies (submit).\" = \"  -n COPIES コピーの数を指定します (submit)\";\n"
"\"  -o %s=%s (default)\" = \"  -o %s=%s (デフォルト)\";\n"
"\"  -o NAME=VALUE    Specify option (add,modify,server,submit).\" = \"  -o 名前=値 オプションを指定します (add,modify,server,submit.)\";\n"
"\"  -o print-darkness=-100 to 100\" = \"  -o print-darkness=-100 から 100\";\n"
"\"  -o printer-darkness=0 to 100\" = \"  -o printer-darkness=0 から 100\";\n"
"\"  -o printer-geo-location='geo:LATITUDE,LONGITUDE'\" = \"  -o printer-geo-location='geo:LATITUDE、LONGITUDE\";\n"
"\"  -o printer-location='LOCATION'\" = \"  -o printer-location='LOCATION\";\n"
"\"  -o printer-organization='ORGANIZATION'\" = \"  -o printer-organization='ORGANIZATION\";\n"
"\"  -o printer-organizational-unit='UNIT/SECTION'\" = \"  -o printer-organizational-unit='UNIT/SECTION\";\n"
"\"  -u URI           Specify ipp: or ipps: printer/server.\" = \"  -u URI ipp: または ipps: プリンタ/サーバーを指定します。\";\n"
"\"  -v DEVICE-URI    Specify socket: or usb: device (add/modify).\" = \"  -v デバイス URI ソケットを指定します: または usb: デバイス (add/modify.)\";\n"
"\"  add PRINTER      Add a printer.\" = \"  add PRINTERを追加 プリンターを追加\";\n"
"\"  autoadd          Automatically add supported printers.\" = \"  autoadd 自動追加 サポートされているプリンターを自動的に追加します。\";\n"
"\"  cancel           Cancel one or more jobs.\" = \"  cancel キャンセル 1 つ以上のジョブをキャンセルします。\";\n"
"\"  default          Set the default printer.\" = \"  default デフォルト デフォルトプリンタを設定します。\";\n"
"\"  delete           Delete a printer.\" = \"  delete プリンターを削除します。\";\n"
"\"  devices          List devices.\" = \"  devices デバイス リストデバイス。\";\n"
"\"  drivers          List drivers.\" = \"  drivers ドライバー リストドライバー。\";\n"
"\"  jobs             List jobs.\" = \"  jobs 求人情報 ジョブリスト\";\n"
"\"  modify           Modify a printer.\" = \"  modify プリンターを変更します。\";\n"
"\"  options          List printer options.\" = \"  options オプション プリンターオプションをリストします。\";\n"
"\"  pause            Pause printing for a printer.\" = \"  pause 一時停止 プリンターのプリント\";\n"
"\"  printers         List printers.\" = \"  printers プリンター プリンターリスト\";\n"
"\"  resume           Resume printing for a printer.\" = \"  resume プリンター用のResumeの印刷を再開します。\";\n"
"\"  server           Run a server.\" = \"  server サーバはサーバを実行します。\";\n"
"\"  shutdown         Shutdown a running server.\" = \"  shutdown 実行中のサーバーをシャットダウンします。\";\n"
"\"  status           Show server/printer/job status.\" = \"  status ステータス サーバ/プリンター/ジョブの状態を表示します。\";\n"
"\"  submit           Submit a file for printing.\" = \"  submit 印刷用のファイルを提出してください。\";\n"
"\"%04d-%02d-%02d at %02d:%02d:%02d\" = \"%04d-%02d-%02d at %02d:%02d:%02d\";\n"
"\"%d days ago at %02d:%02d:%02d\" = \"%d days ago at %02d:%02d:%02d\";\n"
"\"%d inches/sec\" = \"%dインチ/秒\";\n"
"\"%d job\" = \"%d ジョブ\";\n"
/* Media size in millimeters */
"\"%d x %dmm\" = \"%d x %d mm\";\n"
"\"%ddpi\" = \"%dのdpi\";\n"
"\"%dx%ddpi\" = \"%d x %d dpi\";\n"
/* Media size in inches */
"\"%g x %g\\\"\" = \"%g x %g \\\"\";\n"
/* size (type+borderless) */
"\"%s (%s%s)\" = \"%s (%s%s)\";\n"
/* size (type+borderless) from source/tray */
"\"%s (%s%s) from %s\" = \"%s (%s%s) から %s\";\n"
/* Source/Tray Media */
"\"%s Media\" = \"%s メディア\";\n"
"\"%s: Bad 'server-port' value.\" = \"%s: 悪いサーバーポート値。\";\n"
"\"%s: Bad job ID.\" = \"%s: 不良ジョブID\";\n"
"\"%s: Bad printer URI '%s'.\" = \"%s: 悪いプリンター URI '%s'.\";\n"
"\"%s: Cannot specify more than one sub-command.\" = \"%s: 複数のサブコマンドを指定できません。\";\n"
"\"%s: Empty print file received on the standard input.\" = \"%s:標準入力で受け取る空のプリントファイル。\";\n"
"\"%s: Failed to create a system.\" = \"%s: システムの作成に失敗しました。\";\n"
"\"%s: Missing '-d PRINTER'.\" = \"%s: '-d PRINTER を欠く お問い合わせ\";\n"
"\"%s: Missing '-m DRIVER-NAME'.\" = \"%s: '-m DRIVER-NAME を欠く お問い合わせ\";\n"
"\"%s: Missing '-v DEVICE-URI'.\" = \"%s: \\\"-v DEVICE-URI を欠く お問い合わせ\";\n"
"\"%s: Missing copy count after '-n'.\" = \"%s: -n の後のコピーカウントを欠落させます。\";\n"
"\"%s: Missing device URI after '-v'.\" = \"%s: -v の後のデバイス URI を欠く。\";\n"
"\"%s: Missing driver name after '-m'.\" = \"%s: -m の後の運転者の名前を欠くこと。\";\n"
"\"%s: Missing filename after '--'.\" = \"%s: '--' の後のファイル名を欠く。\";\n"
"\"%s: Missing hostname after '-h'.\" = \"%s: -h の後のホスト名を欠く。\";\n"
"\"%s: Missing job ID after '-j'.\" = \"%s: -j の後のジョブ ID を欠落させます。\";\n"
"\"%s: Missing option(s) after '-o'.\" = \"%s: -o の後にオプションを欠く\";\n"
"\"%s: Missing printer URI after '-u'.\" = \"%s: -u の後のプリンター URI を欠くこと。\";\n"
"\"%s: Missing printer name after '-d'.\" = \"%s: -d の後のプリンター名を逃す。\";\n"
"\"%s: Missing space after '-o'.\" = \"%s: -o の後のスペースを逃すこと。\";\n"
"\"%s: Missing title after '-t'.\" = \"%s: -t の後のタイトルを欠く.\";\n"
"\"%s: No default printer available.\" = \"%s: デフォルトプリンタは使用できません。\";\n"
"\"%s: No files to print.\" = \"%s: 印刷するファイルはありません。\";\n"
"\"%s: Server is not running.\" = \"%s: サーバが稼働していません。\";\n"
"\"%s: Sub-command '%s' does not accept files.\" = \"%s: サブコマンド '%s' はファイルを受け入れません。\";\n"
"\"%s: Sub-command 'autoadd' is not supported.\" = \"%s: サブコマンドの自動追加はサポートされていません。\";\n"
"\"%s: Too many files.\" = \"%s: あまりにも多くのファイル。\";\n"
"\"%s: Unable to access '%s': %s\" = \"%s: '%s': %s にアクセスできない\";\n"
"\"%s: Unable to add printer: %s\" = \"%s: プリンターを追加できません: %s\";\n"
"\"%s: Unable to cancel job: %s\" = \"%s: ジョブをキャンセルできません: %s\";\n"
"\"%s: Unable to connect to printer at '%s:%d': %s\" = \"%s: プリンターに接続できない '%s:%d': %s\";\n"
"\"%s: Unable to connect to server: %s\" = \"%s: サーバーに接続できません: %s\";\n"
"\"%s: Unable to create temporary file: %s\" = \"%s: 一時ファイルを作成することができません: %s\";\n"
"\"%s: Unable to delete printer: %s\" = \"%s: プリンターを削除できません: %s\";\n"
"\"%s: Unable to get available devices: %s\" = \"%s: Unable to get available devices: %s\";\n"
"\"%s: Unable to get information for '%s': %s\" = \"%s: '%s': %s の情報を取得することができません\";\n"
"\"%s: Unable to get information for printer: %s\" = \"%s: プリンター情報を取得することができません: %s\";\n"
"\"%s: Unable to get printer options: %s\" = \"%s: プリンタのオプションを取得することができません: %s\";\n"
"\"%s: Unable to modify printer: %s\" = \"%s: プリンターの変更はできません: %s\";\n"
"\"%s: Unable to pause printer: %s\" = \"%s: プリンタを一時停止できません: %s\";\n"
"\"%s: Unable to print '%s': %s\" = \"%s: '%s': %s を印刷できません\";\n"
"\"%s: Unable to resume printer: %s\" = \"%s: プリンタを再開できません: %s\";\n"
"\"%s: Unable to set default printer: %s\" = \"%s: デフォルトプリンタを設定することができません: %s\";\n"
"\"%s: Unable to shutdown server: %s\" = \"%s: サーバをシャットダウンできない: %s\";\n"
"\"%s: Unable to start server: %s\" = \"%s: サーバーを起動できません: %s\";\n"
"\"%s: Unable to write to temporary file: %s\" = \"%s: 一時的なファイルに書き込むことができない: %s\";\n"
"\"%s: Unknown option '%s'.\" = \"%s: 不明なオプション '%s'.\";\n"
"\"%s: Unknown option '-%c'.\" = \"%s: 不明なオプション '-%c'.\";\n"
"\"%s: Unknown sub-command '%s'.\" = \"%s: 未知のサブコマンド '%s'.\";\n"
"\"%s: Unsupported URI scheme '%s'.\" = \"%s: サポートされていない URI スキーム '%s'.\";\n"
"\"%s: Warning - user credentials are not supported in URIs.\" = \"%s: 警告 - ユーザ認証情報は URI でサポートされていません。\";\n"
"\", Borderless\" = \", ボーダーレス\";\n"
"\"A printer with that name already exists.\" = \"既に存在している名前のプリンター。\";\n"
"\"Aborted %s\" = \"Aborted %s\";\n"
"\"Add Printer\" = \"プリンターを追加\";\n"
"\"Admin Group\" = \"管理者グループ\";\n"
"\"Afghanistan\" = \"アフガニスタン\";\n"
"\"Albania\" = \"アルバニア\";\n"
"\"Algeria\" = \"アルジェリア\";\n"
"\"American Samoa\" = \"アメリカ サモア\";\n"
"\"Andorra\" = \"アンドラ\";\n"
"\"Angola\" = \"アンゴラ\";\n"
"\"Anguilla\" = \"アンギラ\";\n"
"\"Antarctica\" = \"アナトリア\";\n"
"\"Antigua and Barbuda\" = \"アンティグア・バーブーダ\";\n"
"\"Argentina\" = \"アルゼンチン\";\n"
"\"Armenia\" = \"アルメニア\";\n"
"\"Aruba\" = \"アルバ\";\n"
"\"Australia\" = \"オーストラリア\";\n"
"\"Austria\" = \"オーストリア\";\n"
"\"Auto\" = \"自動車\";\n"
"\"Auto-Detect Driver\" = \"自動検出の運転者\";\n"
"\"Azerbaijan\" = \"アゼルバイジャン\";\n"
"\"Bad administration group.\" = \"悪い管理グループ。\";\n"
"\"Bad port number.\" = \"悪いポート番号。\";\n"
"\"Bad print group.\" = \"悪いプリントグループ。\";\n"
"\"Bad printer defaults.\" = \"悪いプリンタのデフォルト。\";\n"
"\"Bahamas\" = \"バハマ\";\n"
"\"Bahrain\" = \"バーレーン\";\n"
"\"Bangladesh\" = \"バングラデシュ\";\n"
"\"Barbados\" = \"バルバドス\";\n"
"\"Belarus\" = \"ベラルーシ\";\n"
"\"Belgium\" = \"ベルギー\";\n"
"\"Belize\" = \"ベリーズ\";\n"
"\"Benin\" = \"ログイン\";\n"
"\"Bermuda\" = \"バーミューダ\";\n"
"\"Bhutan\" = \"ブータン\";\n"
"\"Bolivia (Plurinational State of)\" = \"ボリビア(国)\";\n"
"\"Bonaire, Sint Eustatius and Saba\" = \"ボネール、シント・ユースタチウス、サバ\";\n"
"\"Borderless\" = \"ボーダーレス\";\n"
"\"Bosnia and Herzegovina\" = \"ボスニアとヘルツェゴビナ\";\n"
"\"Botswana\" = \"ボツワナ\";\n"
"\"Bouvet Island\" = \"ブーヴェ島\";\n"
"\"Brazil\" = \"ブラジル\";\n"
"\"British Indian Ocean Territory\" = \"イギリスのインド洋の領事\";\n"
"\"Brunei Darussalam\" = \"ブルネイ・ダルサラーム\";\n"
"\"Bulgaria\" = \"ブルガリア\";\n"
"\"Burkina Faso\" = \"ブルキナファソ\";\n"
"\"Burundi\" = \"ブルンディ\";\n"
"\"Cabo Verde\" = \"カボ・ヴェルデ\";\n"
"\"Cambodia\" = \"カンボジア\";\n"
"\"Cameroon\" = \"キャメルーン\";\n"
"\"Canada\" = \"カナダ\";\n"
"\"Cancel All Jobs\" = \"すべてのジョブをキャンセルする\";\n"
"\"Cancel Job\" = \"キャンセルジョブ\";\n"
"\"Canceled %s\" = \"Canceled %s\";\n"
"\"Canceling\" = \"キャンセル\";\n"
"\"Cayman Islands\" = \"ケイマン諸島\";\n"
"\"Central African Republic\" = \"中央アフリカ共和国\";\n"
"\"Certificate created.\" = \"証明書作成。\";\n"
"\"Certificate installed.\" = \"証明書は取付けました。\";\n"
"\"Certificate request created.\" = \"証明書作成リクエスト\";\n"
"\"Chad\" = \"チャド\";\n"
"\"Change Access Password\" = \"アクセスパスワードの変更\";\n"
"\"Change Log Level\" = \"ログレベルを変更する\";\n"
"\"Change Network Settings\" = \"Change Network Settings\";\n"
"\"Change Wi-Fi Network\" = \"Wi-Fiネットワークの変更\";\n"
"\"Changes Saved.\" = \"保存された変更。\";\n"
"\"Changes saved.\" = \"保存された変更。\";\n"
"\"Chile\" = \"チリ\";\n"
"\"China\" = \"中国の\";\n"
"\"Christmas Island\" = \"クリスマス島\";\n"
"\"City/Locality\" = \"City/Locality\";\n"
"\"Cocos (Keeling) Islands\" = \"ココス諸島(ケイリング)\";\n"
"\"Colombia\" = \"コロンビア\";\n"
"\"Comoros\" = \"コモロ\";\n"
"\"Completed %s\" = \"Completed %s\";\n"
"\"Configuration\" = \"コンテンツ\";\n"
"\"Configure Media\" = \"メディアの設定\";\n"
"\"Confirm Cancel All\" = \"キャンセル確認 すべて\";\n"
"\"Confirm Delete Printer\" = \"プリンターの削除を確認する\";\n"
"\"Congo\" = \"コンゴ\";\n"
"\"Congo, Democratic Republic of the\" = \"コンゴ、民主共和国\";\n"
"\"Contact\" = \"お問い合わせ\";\n"
"\"Cook Islands\" = \"クック諸島\";\n"
"\"Costa Rica\" = \"コスタリカ\";\n"
"\"Create Certificate Signing Request\" = \"証明書署名リクエストを作成する\";\n"
"\"Create New Certificate\" = \"新しい証明書を作成する\";\n"
"\"Create New TLS Certificate\" = \"新しい TLS 証明書を作成する\";\n"
"\"Create TLS Certificate Request\" = \"TLS の作成 証明書の要求\";\n"
"\"Croatia\" = \"クロアチア\";\n"
"\"Cuba\" = \"キューバ\";\n"
"\"Curaçao\" = \"キュラオ\";\n"
"\"Current Password\" = \"現在のパスワード\";\n"
"\"Custom Size\" = \"注文のサイズ\";\n"
"\"Cyprus\" = \"キプロス\";\n"
"\"Czechia\" = \"チェコ語\";\n"
"\"Côte d'Ivoire\" = \"Cte d'イボワール\";\n"
"\"DHCP\" = \"DHCP\";\n"
"\"DHCP w/Manual Address\" = \"DHCP w/Manual Address\";\n"
"\"DNS-SD Service Name\" = \"DNS-SDサービス名\";\n"
"\"Debugging\" = \"デバッギング\";\n"
"\"Default printer set.\" = \"デフォルトプリンターセット。\";\n"
"\"Delete\" = \"削除\";\n"
"\"Delete Printer\" = \"プリンターの削除\";\n"
"\"Denmark\" = \"デンマーク\";\n"
"\"Djibouti\" = \"ジブチ\";\n"
"\"Domain Name\" = \"Domain Name\";\n"
"\"Dominica\" = \"ドミニカ\";\n"
"\"Dominican Republic\" = \"ドミニカ共和国\";\n"
"\"Download Certificate Request File\" = \"証明書の要求ファイルのダウンロード\";\n"
"\"Ecuador\" = \"エクアドル\";\n"
"\"Egypt\" = \"エジプト\";\n"
"\"El Salvador\" = \"エルサルバドール\";\n"
"\"Equatorial Guinea\" = \"エクトリアルギニア\";\n"
"\"Eritrea\" = \"エリトリア\";\n"
"\"Errors\" = \"エラー\";\n"
"\"Estonia\" = \"エストニア\";\n"
"\"Eswatini\" = \"エスカティーニ\";\n"
"\"Ethiopia\" = \"エチオピア\";\n"
"\"Falkland Islands (Malvinas)\" = \"フォークランド諸島 (Malvinas)\";\n"
"\"Faroe Islands\" = \"フェロー諸島\";\n"
"\"Fatal Errors/Conditions\" = \"致命的な間違い/条件\";\n"
"\"Fiji\" = \"フィジー\";\n"
"\"Finland\" = \"フィンランド\";\n"
"\"France\" = \"フランス\";\n"
"\"French Guiana\" = \"フランスのガイアナ\";\n"
"\"French Polynesia\" = \"フランスのポリネシア\";\n"
"\"French Southern Territories\" = \"フランスの南地域\";\n"
"\"Gabon\" = \"ガボン\";\n"
"\"Gambia\" = \"ガンビア\";\n"
"\"Georgia\" = \"ジョージア\";\n"
"\"Germany\" = \"ドイツ\";\n"
"\"Ghana\" = \"ガーナ\";\n"
"\"Gibraltar\" = \"ジブラルタル\";\n"
"\"Greece\" = \"ギリシャ\";\n"
"\"Greenland\" = \"グリーンランド\";\n"
"\"Grenada\" = \"グレナダ\";\n"
"\"Group changes saved.\" = \"グループの変更を保存しました。\";\n"
"\"Guadeloupe\" = \"グアドルーペ\";\n"
"\"Guam\" = \"グアム\";\n"
"\"Guatemala\" = \"グアテマラ\";\n"
"\"Guernsey\" = \"グエルンシー\";\n"
"\"Guinea\" = \"ギニア\";\n"
"\"Guinea-Bissau\" = \"ギニア・ビサウ\";\n"
"\"Guyana\" = \"ガイアナ\";\n"
"\"Haiti\" = \"ハイチ\";\n"
"\"Heard Island and McDonald Islands\" = \"ヘアード島とマクドナルド諸島\";\n"
"\"Hidden SSID\" = \"Hidden SSID\";\n"
"\"Hold Job\" = \"Hold Job\";\n"
"\"Hold New Jobs\" = \"Hold New Jobs\";\n"
"\"Holding new jobs.\" = \"Holding new jobs.\";\n"
"\"Holy See\" = \"聖なる参照\";\n"
"\"Honduras\" = \"ホンジュラス\";\n"
"\"Hong Kong\" = \"香港\";\n"
"\"Hostname\" = \"ホスト名\";\n"
"\"Human-Readable Location\" = \"人間可読の場所\";\n"
"\"Hungary\" = \"ハンガリー\";\n"
"\"IPv4 Address\" = \"IPv4 Address\";\n"
"\"IPv4 Configuration\" = \"IPv4 Configuration\";\n"
"\"IPv4 Gateway\" = \"IPv4 Gateway\";\n"
"\"IPv4 Netmask\" = \"IPv4 Netmask\";\n"
"\"IPv6 Address\" = \"IPv6 Address\";\n"
"\"IPv6 Configuration\" = \"IPv6 Configuration\";\n"
"\"IPv6 Link-Local\" = \"IPv6 Link-Local\";\n"
"\"IPv6 Prefix Length\" = \"IPv6 Prefix Length\";\n"
"\"Iceland\" = \"アイスランド\";\n"
"\"Identify Printer\" = \"プリンターの識別\";\n"
"\"India\" = \"インド\";\n"
"\"Indonesia\" = \"インドネシア\";\n"
"\"Informational\" = \"インフォメーション\";\n"
"\"Install TLS Certificate\" = \"TLSをインストールする 証明書\";\n"
"\"Invalid IPv4 address.\" = \"Invalid IPv4 address.\";\n"
"\"Invalid IPv4 netmask.\" = \"Invalid IPv4 netmask.\";\n"
"\"Invalid IPv6 address.\" = \"Invalid IPv6 address.\";\n"
"\"Invalid IPv6 prefix length.\" = \"Invalid IPv6 prefix length.\";\n"
"\"Invalid Job ID.\" = \"無効なジョブID。\";\n"
"\"Invalid certificate or private key.\" = \"無効な証明書か秘密鍵。\";\n"
"\"Invalid form data.\" = \"無効なフォームデータ。\";\n"
"\"Invalid form submission.\" = \"無効なフォーム送信。\";\n"
"\"Invalid job ID.\" = \"無効なジョブID。\";\n"
"\"Invalid network configuration.\" = \"Invalid network configuration.\";\n"
"\"Iran (Islamic Republic of)\" = \"イラン(イスラム共和国)\";\n"
"\"Iraq\" = \"イラク\";\n"
"\"Ireland\" = \"アイルランド\";\n"
"\"Isle of Man\" = \"男の島\";\n"
"\"Israel\" = \"イスラエル\";\n"
"\"Italy\" = \"イタリア\";\n"
"\"Jamaica\" = \"ジャマイカ\";\n"
"\"Japan\" = \"ジャパンジャパン\";\n"
"\"Jersey\" = \"ジャージー\";\n"
"\"Job #\" = \"求人番号\";\n"
"\"Job canceled.\" = \"Job canceled.\";\n"
"\"Job held.\" = \"Job held.\";\n"
"\"Job released.\" = \"Job released.\";\n"
"\"Jobs\" = \"求人情報\";\n"
"\"Joining Wi-Fi Network\" = \"Joining Wi-Fi Network\";\n"
"\"Jordan\" = \"ヨルダン\";\n"
"\"Kazakhstan\" = \"カザフスタン\";\n"
"\"Kenya\" = \"ケニア\";\n"
"\"Kiribati\" = \"キリバティ\";\n"
"\"Korea (Democratic People's Republic of)\" = \"韓国(デモクラティック・ピープルズ・リパブリック)\";\n"
"\"Korea, Republic of\" = \"韓国、共和国\";\n"
"\"Kuwait\" = \"クウェート\";\n"
"\"Kyrgyzstan\" = \"キルギススタン\";\n"
"\"Landscape\" = \"ニュース\";\n"
"\"Lao People's Democratic Republic\" = \"ラオス人民主共和国\";\n"
"\"Latvia\" = \"ラトビア\";\n"
"\"Lebanon\" = \"レバノン\";\n"
"\"Lesotho\" = \"レソト\";\n"
"\"Level\" = \"レベル\";\n"
"\"Liberia\" = \"リベリア\";\n"
"\"Libya\" = \"リビエラ\";\n"
"\"Liechtenstein\" = \"リヒテンシュタイン\";\n"
"\"Lithuania\" = \"リトアニア\";\n"
"\"Location\" = \"アクセス\";\n"
"\"Log Level\" = \"ログレベル\";\n"
"\"Logging\" = \"ログイン\";\n"
"\"Logs\" = \"ログイン\";\n"
"\"Luxembourg\" = \"ルクセンブルク\";\n"
"\"Macao\" = \"マカオ\";\n"
"\"Madagascar\" = \"マダガスカル\";\n"
"\"Malawi\" = \"マラウイ\";\n"
"\"Malaysia\" = \"マレーシア\";\n"
"\"Maldives\" = \"モルディブ\";\n"
"\"Mali\" = \"マリ\";\n"
"\"Malta\" = \"マルタ\";\n"
"\"Manual Configuration\" = \"Manual Configuration\";\n"
"\"Marshall Islands\" = \"マーシャル諸島\";\n"
"\"Martinique\" = \"マルティニーク\";\n"
"\"Mauritania\" = \"モーリタニア\";\n"
"\"Mauritius\" = \"モーリシャス\";\n"
"\"Mayotte\" = \"マヨッテ\";\n"
"\"Media\" = \"メディア\";\n"
"\"Mexico\" = \"メキシコ\";\n"
"\"Micronesia (Federated States of)\" = \"マイクロネシア(連邦)\";\n"
"\"Missing action.\" = \"行動を欠く。\";\n"
"\"Missing job ID.\" = \"Missing job ID.\";\n"
"\"Missing network name.\" = \"Missing network name.\";\n"
"\"Missing private key.\" = \"プライベートキーを欠く。\";\n"
"\"Moldova, Republic of\" = \"モルドバ共和国\";\n"
"\"Monaco\" = \"メニュー\";\n"
"\"Mongolia\" = \"モンゴル\";\n"
"\"Montenegro\" = \"モンテネグロ\";\n"
"\"Montserrat\" = \"モンセラット\";\n"
"\"Morocco\" = \"モロッコ\";\n"
"\"Mozambique\" = \"モザンビーク\";\n"
"\"Myanmar\" = \"ミャンマー\";\n"
"\"Name\" = \"お名前 (必須)\";\n"
"\"Namibia\" = \"ナミビア\";\n"
"\"Nauru\" = \"ナウル\";\n"
"\"Nepal\" = \"ネパール\";\n"
"\"Netherlands\" = \"オランダ\";\n"
"\"Network\" = \"ネットワーク\";\n"
"\"Network Printer\" = \"ネットワークプリンター\";\n"
"\"Networking\" = \"ネットワーク\";\n"
"\"New Caledonia\" = \"ニューカレドニア\";\n"
"\"New Zealand\" = \"ニュージーランド\";\n"
"\"Nicaragua\" = \"ニカラグア\";\n"
"\"Niger\" = \"ニジェール\";\n"
"\"Nigeria\" = \"ナイジェリア\";\n"
"\"Niue\" = \"ログイン\";\n"
"\"No default printer set.\" = \"デフォルトのプリンタセットはありません。\";\n"
"\"No jobs in history.\" = \"履歴のジョブはありません。\";\n"
"\"Norfolk Island\" = \"ノーフォーク島\";\n"
"\"North Macedonia\" = \"北マケドニア\";\n"
"\"Northern Mariana Islands\" = \"北マリアナ諸島\";\n"
"\"Norway\" = \"ノルウェー\";\n"
"\"Not set\" = \"セットなし\";\n"
"\"Off\" = \"Off\";\n"
"\"Offset\" = \"オフセット\";\n"
"\"Oman\" = \"オマーン\";\n"
"\"Options:\" = \"オプション:\";\n"
"\"Organization\" = \"社会招聘\";\n"
"\"Organization Name\" = \"組織名称\";\n"
"\"Other Settings\" = \"その他の設定\";\n"
"\"Pakistan\" = \"パキスタン\";\n"
"\"Palau\" = \"パラオ\";\n"
"\"Palestine, State of\" = \"パレスチナ、州\";\n"
"\"Panama\" = \"パナマ\";\n"
"\"Papua New Guinea\" = \"パプアニューギニア\";\n"
"\"Paraguay\" = \"パラグアイ\";\n"
"\"Password\" = \"パスワード\";\n"
"\"Password changed.\" = \"パスワードが変更されました。\";\n"
"\"Password must be at least eight characters long and contain at least one uppercase letter, one lowercase letter, and one digit.\" = \"パスワードは、少なくとも8文字以上で、少なくとも1つの大文字、小文字、および1つの数字を含む必要があります。\";\n"
"\"Passwords do not match.\" = \"パスワードは一致しません。\";\n"
"\"Pause Printing\" = \"ペーパー印刷\";\n"
"\"Peru\" = \"ペルー\";\n"
"\"Philippines\" = \"フィリピン\";\n"
"\"Pitcairn\" = \"ピッツケアン\";\n"
"\"Please enter a hostname or IP address for the printer.\" = \"プリンターのホスト名またはIPアドレスを入力してください。\";\n"
"\"Please enter a printer name.\" = \"プリンター名を入力してください。\";\n"
"\"Please select a device.\" = \"デバイスを選択してください。\";\n"
"\"Please select a driver.\" = \"ドライバーをお選びください。\";\n"
"\"Please select a valid log level.\" = \"有効なログレベルを選択してください。\";\n"
"\"Poland\" = \"ポーランド\";\n"
"\"Portrait\" = \"ポートレート\";\n"
"\"Portugal\" = \"ポルトガル\";\n"
"\"Primary DNS\" = \"Primary DNS\";\n"
"\"Print Group\" = \"プリントグループ\";\n"
"\"Print Test Page\" = \"プリントテストページ\";\n"
"\"Print job options:\" = \"ジョブオプションを印刷:\";\n"
"\"Printer identified.\" = \"識別されるプリンター。\";\n"
"\"Printer is currently active.\" = \"プリンターは現在有効です。\";\n"
"\"Printer names must start with a letter or underscore and cannot contain special characters.\" = \"プリンター名は、文字またはアンダースコアで始まり、特別な文字を含むことはできません。\";\n"
"\"Printer options:\" = \"プリンター選択:\";\n"
"\"Printer paused.\" = \"プリンターはpaused。\";\n"
"\"Printer pausing.\" = \"プリンター ペーパー。\";\n"
"\"Printer resuming.\" = \"プリンター再開。\";\n"
"\"Printers\" = \"プリンター\";\n"
"\"Printing Defaults\" = \"印刷のデフォルト\";\n"
"\"Puerto Rico\" = \"プエルトリコ\";\n"
"\"Qatar\" = \"カタール\";\n"
"\"Queued %s\" = \"Queued %s\";\n"
"\"Release Held New Jobs\" = \"Release Held New Jobs\";\n"
"\"Release Job\" = \"Release Job\";\n"
"\"Released held new jobs.\" = \"Released held new jobs.\";\n"
"\"Reprint Job\" = \"再印刷ジョブ\";\n"
"\"Reprinted job.\" = \"Reprinted job.\";\n"
"\"Resume Printing\" = \"再開の印刷\";\n"
"\"Reverse Landscape\" = \"逆の風景\";\n"
"\"Reverse Portrait\" = \"逆の肖像\";\n"
"\"Romania\" = \"ルーマニア\";\n"
/* Running, STATE since DATE REASONS */
"\"Running, %s since %s%s.\" = \"%s %s以来のランニング、%s。\";\n"
"\"Russian Federation\" = \"ロシア連邦\";\n"
"\"Rwanda\" = \"ルワンダ\";\n"
"\"Réunion\" = \"ログイン\";\n"
"\"Saint Barthélemy\" = \"サン・バルトレミー\";\n"
"\"Saint Helena, Ascension and Tristan da Cunha\" = \"セントヘレナ、アセンション、トリスタン・ダ・クンハ\";\n"
"\"Saint Kitts and Nevis\" = \"セントキッツとネイビス\";\n"
"\"Saint Lucia\" = \"セントルシア\";\n"
"\"Saint Martin (French part)\" = \"聖マーティン(フランス部分)\";\n"
"\"Saint Pierre and Miquelon\" = \"サンピエールとミクロン\";\n"
"\"Saint Vincent and the Grenadines\" = \"セントビンセントとグレナディーン諸島\";\n"
"\"Samoa\" = \"サモア\";\n"
"\"San Marino\" = \"サンマリノ\";\n"
"\"Sao Tome and Principe\" = \"トームとプリンシペ\";\n"
"\"Saudi Arabia\" = \"サウジアラビア\";\n"
"\"Save Changes\" = \"変更を保存\";\n"
"\"Secondary DNS\" = \"Secondary DNS\";\n"
"\"Security\" = \"セキュリティ\";\n"
"\"Select Driver\" = \"ドライバーの選択\";\n"
"\"Senegal\" = \"セネガル\";\n"
"\"Serbia\" = \"セルビア\";\n"
"\"Server is not running.\" = \"サーバが稼働していません。\";\n"
"\"Set Access Password\" = \"アクセスパスワードを設定する\";\n"
"\"Set as Default\" = \"デフォルトで設定\";\n"
"\"Seychelles\" = \"セイシェル\";\n"
"\"Sierra Leone\" = \"シエラレオネ\";\n"
"\"Singapore\" = \"シンガポール\";\n"
"\"Sint Maarten (Dutch part)\" = \"シント・マールテン(オランダ)\";\n"
"\"Slovakia\" = \"スロバキア\";\n"
"\"Slovenia\" = \"スワッピング\";\n"
"\"Solomon Islands\" = \"ソロモン諸島\";\n"
"\"Somalia\" = \"ソマリア\";\n"
"\"South Africa\" = \"南アフリカ\";\n"
"\"South Georgia and the South Sandwich Islands\" = \"南ジョージアと南サンドイッチ諸島\";\n"
"\"South Sudan\" = \"南スーダン\";\n"
"\"Spain\" = \"スペイン\";\n"
"\"Sri Lanka\" = \"スリランカ\";\n"
"\"Started %s\" = \"Started %s\";\n"
"\"Status\" = \"ステータス\";\n"
"\"Sub-commands:\" = \"サブコマンド:\";\n"
"\"Sudan\" = \"スーダン\";\n"
"\"Supplies\" = \"アクセサリー\";\n"
"\"Suriname\" = \"スリナム\";\n"
"\"Svalbard and Jan Mayen\" = \"Svalbardと1月マレン\";\n"
"\"Sweden\" = \"スウェーデン\";\n"
"\"Switzerland\" = \"スイス\";\n"
"\"Syrian Arab Republic\" = \"シリア アラブ共和国\";\n"
"\"Taiwan, Province of China\" = \"台湾、中国省\";\n"
"\"Tajikistan\" = \"タジキスタン\";\n"
"\"Tanzania, United Republic of\" = \"タンザニア, United Kingdom\";\n"
"\"Test page printed.\" = \"印刷されたテストページ。\";\n"
"\"Thailand\" = \"タイ\";\n"
"\"This form creates a certificate signing request ('CSR') that you can send to a Certificate Authority ('CA') to obtain a trusted TLS certificate. The private key is saved separately for use with the certificate you get from the CA.\" = \"このフォームは、認証機関(CA)に送信できる証明書署名(CSR)を作成して、信頼できるTLS証明書を入手します。 秘密鍵は、CAから取得する証明書と使用するために別途保存されます。\";\n"
"\"This form creates a new 'self-signed' TLS certificate for secure printing. Self-signed certificates are not automatically trusted by web browsers.\" = \"このフォームは、安全な印刷のために新しい自己署名のTLS証明書を作成します。 自己署名証明書は、Webブラウザによって自動的に信頼されません。\";\n"
"\"This form will install a trusted TLS certificate you have obtained from a Certificate Authority ('CA'). Once installed, it will be used immediately.\" = \"このフォームは、認証機関(CA)から入手した信頼できるTLS証明書をインストールします。 インストール後すぐに利用します。\";\n"
"\"Timor-Leste\" = \"ティモール・レステ\";\n"
"\"Togo\" = \"トーゴ\";\n"
"\"Tokelau\" = \"トケラウ\";\n"
"\"Tonga\" = \"トンガ\";\n"
"\"Trinidad and Tobago\" = \"トリニダードとトバゴ\";\n"
"\"Tunisia\" = \"チュニジア\";\n"
"\"Turkey\" = \"トルコ\";\n"
"\"Turkmenistan\" = \"トルクメニスタン\";\n"
"\"Turks and Caicos Islands\" = \"タークス・カイコス諸島\";\n"
"\"Tuvalu\" = \"ツバル\";\n"
"\"Uganda\" = \"ウガンダ\";\n"
"\"Ukraine\" = \"ウクライナ\";\n"
"\"Unable to access test print file.\" = \"テストプリントファイルにアクセスできません。\";\n"
"\"Unable to copy print job.\" = \"印刷ジョブをコピーできません。\";\n"
"\"Unable to create certificate request.\" = \"証明書のリクエストを作成することができません。\";\n"
"\"Unable to create certificate.\" = \"証明書を作成することができません。\";\n"
"\"Unable to create test print job.\" = \"テストプリントジョブを作成することができません。\";\n"
"\"Unable to identify printer.\" = \"プリンターを識別できません。\";\n"
"\"Unable to lookup address.\" = \"アドレスを調べることができません。\";\n"
"\"Unable to use that driver.\" = \"そのドライバを使用できません。\";\n"
"\"United Arab Emirates\" = \"アラブ首長国連邦\";\n"
"\"United Kingdom\" = \"イギリス\";\n"
"\"United Kingdom of Great Britain and Northern Ireland\" = \"イギリス・北アイルランド王国\";\n"
"\"United States Minor Outlying Islands\" = \"アメリカ合衆国 Minor Outlying Islands\";\n"
"\"United States of America\" = \"アメリカ合衆国\";\n"
"\"Unknown\" = \"未知の\";\n"
"\"Unknown action.\" = \"未知のアクション。\";\n"
"\"Unknown form action.\" = \"未知のフォームアクション。\";\n"
"\"Unknown form request.\" = \"不明なフォームリクエスト\";\n"
"\"Updating Network Configuration\" = \"Updating Network Configuration\";\n"
"\"Uruguay\" = \"ウルグアイ\";\n"
"\"Usage: %s SUB-COMMAND [OPTIONS] [FILENAME]\\n\" = \"使用法: %s サブコマンド [操作] [ユーザー名]\\n\";\n"
"\"Use My Position\" = \"マイポジションを使用する\";\n"
"\"Users\" = \"ユーザ名\";\n"
"\"Uzbekistan\" = \"ウズベキスタン\";\n"
"\"Vanuatu\" = \"バヌアツ\";\n"
"\"Venezuela (Bolivarian Republic of)\" = \"ベネズエラ(ボリビア共和国)\";\n"
"\"Version %s\" = \"バージョン %s\";\n"
"\"Viet Nam\" = \"ベトナム\";\n"
"\"View Logs\" = \"ログを表示\";\n"
"\"Virgin Islands (British)\" = \"バージン諸島(イギリス)\";\n"
"\"Virgin Islands (U.S.)\" = \"バージン諸島(米国)\";\n"
"\"Wallis and Futuna\" = \"ウォリスとフツナ\";\n"
"\"Warning\" = \"インフォメーション\";\n"
"\"Western Sahara\" = \"西サハラ\";\n"
"\"Wi-Fi Configuration\" = \"Wi-Fiの設定\";\n"
"\"Wi-Fi Network\" = \"Wi-Fiネットワーク\";\n"
"\"Width\" = \"アクセス\";\n"
"\"Wrong old password.\" = \"古いパスワードが間違っています。\";\n"
"\"Yemen\" = \"イエメン\";\n"
"\"Zambia\" = \"ザンビア\";\n"
"\"Zimbabwe\" = \"ジンバブエ\";\n"
"\"at %02d:%02d:%02d\" = \"at %02d:%02d:%02d\";\n"
/* IPP attribute, keyword, and enum (integer) localizations */
"\"copies\" = \"コピーの数\";\n"
"\"default printer\" = \"デフォルトプリンタ\";\n"
"\"finishings\" = \"フィニッシャー\";\n"
"\"finishings.10\" = \"フォールド\";\n"
"\"finishings.100\" = \"Z の折目\";\n"
"\"finishings.101\" = \"工学Zの折目\";\n"
"\"finishings.11\" = \"カット\";\n"
"\"finishings.12\" = \"ベール\";\n"
"\"finishings.13\" = \"ブックレットメーカー\";\n"
"\"finishings.15\" = \"コーティング\";\n"
"\"finishings.16\" = \"ラミネート\";\n"
"\"finishings.20\" = \"スタプルトップ左\";\n"
"\"finishings.21\" = \"ステープルボトム左\";\n"
"\"finishings.22\" = \"右上のステープルトップ\";\n"
"\"finishings.23\" = \"右上のステープル\";\n"
"\"finishings.24\" = \"エッジステッチ左\";\n"
"\"finishings.25\" = \"エッジステッチトップ\";\n"
"\"finishings.26\" = \"エッジステッチ右\";\n"
"\"finishings.27\" = \"エッジステッチボトム\";\n"
"\"finishings.28\" = \"左に2つのステープル\";\n"
"\"finishings.29\" = \"2 トップにステープル\";\n"
"\"finishings.3\" = \"なし\";\n"
"\"finishings.30\" = \"2 右にステープル\";\n"
"\"finishings.31\" = \"底に2つのステープル\";\n"
"\"finishings.32\" = \"3 左にステープル\";\n"
"\"finishings.33\" = \"トップ3のステープル\";\n"
"\"finishings.34\" = \"3 右上のステープル\";\n"
"\"finishings.35\" = \"底の3つのステープル\";\n"
"\"finishings.4\" = \"スタプル\";\n"
"\"finishings.5\" = \"パンチング\";\n"
"\"finishings.50\" = \"左ビン\";\n"
"\"finishings.51\" = \"ビントップ\";\n"
"\"finishings.52\" = \"ビンド右\";\n"
"\"finishings.53\" = \"ビン底\";\n"
"\"finishings.6\" = \"カバー\";\n"
"\"finishings.60\" = \"すべてのページを閉じる\";\n"
"\"finishings.61\" = \"すべての文書の後にカット\";\n"
"\"finishings.62\" = \"すべてのセットの後で切れて下さい\";\n"
"\"finishings.63\" = \"ジョブ後のカット\";\n"
"\"finishings.7\" = \"ログイン\";\n"
"\"finishings.70\" = \"パンチトップ左\";\n"
"\"finishings.71\" = \"パンチボトム左\";\n"
"\"finishings.72\" = \"パンチトップ右\";\n"
"\"finishings.73\" = \"右下のパンチ\";\n"
"\"finishings.74\" = \"2穴パンチ左\";\n"
"\"finishings.75\" = \"2穴パンチトップ\";\n"
"\"finishings.76\" = \"2穴パンチ右\";\n"
"\"finishings.77\" = \"2穴パンチボトム\";\n"
"\"finishings.78\" = \"3穴パンチ左\";\n"
"\"finishings.79\" = \"3穴パンチトップ\";\n"
"\"finishings.8\" = \"サドルステッチ\";\n"
"\"finishings.80\" = \"3穴パンチ右\";\n"
"\"finishings.81\" = \"3穴パンチボトム\";\n"
"\"finishings.82\" = \"4穴パンチ左\";\n"
"\"finishings.83\" = \"4穴パンチトップ\";\n"
"\"finishings.84\" = \"4穴パンチ右\";\n"
"\"finishings.85\" = \"4穴パンチボトム\";\n"
"\"finishings.86\" = \"多穴パンチ左\";\n"
"\"finishings.87\" = \"マルチホールパンチトップ\";\n"
"\"finishings.88\" = \"多穴パンチ右\";\n"
"\"finishings.89\" = \"多穴パンチ底\";\n"
"\"finishings.9\" = \"エッジステッチ\";\n"
"\"finishings.90\" = \"アコーディオンの折目\";\n"
"\"finishings.91\" = \"二重ゲートの折目\";\n"
"\"finishings.92\" = \"ゲートの折目\";\n"
"\"finishings.93\" = \"ハーフフォールド\";\n"
"\"finishings.94\" = \"ハーフZフォールド\";\n"
"\"finishings.95\" = \"左ゲートの折目\";\n"
"\"finishings.96\" = \"手紙の折目\";\n"
"\"finishings.97\" = \"平行折目\";\n"
"\"finishings.98\" = \"ポスター折り目\";\n"
"\"finishings.99\" = \"右ゲートの折目\";\n"
"\"holding new jobs\" = \"holding new jobs\";\n"
"\"job-state-reasons.aborted-by-system\" = \"停止。\";\n"
"\"job-state-reasons.compression-error\" = \"圧縮エラー。\";\n"
"\"job-state-reasons.document-format-error\" = \"ドキュメントフォーマットエラー。\";\n"
"\"job-state-reasons.document-password-error\" = \"ドキュメントパスワードエラー。\";\n"
"\"job-state-reasons.document-permission-error\" = \"ドキュメント許可エラー。\";\n"
"\"job-state-reasons.document-unprintable-error\" = \"印刷不能なエラーを文書化します。\";\n"
"\"job-state-reasons.errors-detected\" = \"検出されたエラー。\";\n"
"\"job-state-reasons.job-canceled-at-device\" = \"プリンターでのキャンセル\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"ユーザーによるキャンセル\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"印刷される。\";\n"
"\"job-state-reasons.job-completed-with-errors\" = \"エラーで印刷。\";\n"
"\"job-state-reasons.job-completed-with-warnings\" = \"警告で印刷。\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"十分なデータ。\";\n"
"\"job-state-reasons.job-fetchable\" = \"取得可能。\";\n"
"\"job-state-reasons.job-incoming\" = \"お問い合わせ\";\n"
"\"job-state-reasons.job-printing\" = \"印刷。\";\n"
"\"job-state-reasons.job-queued\" = \"印刷する準備。\";\n"
"\"job-state-reasons.job-spooling\" = \"スプール。\";\n"
"\"job-state-reasons.none\" = \"終わり。\";\n"
"\"job-state-reasons.printer-stopped\" = \"プリンターオフライン。\";\n"
"\"job-state-reasons.printer-stopped-partly\" = \"プリンター部分的に停止。\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"停止。\";\n"
"\"job-state-reasons.queued-in-device\" = \"レディ。\";\n"
"\"job-state-reasons.warnings-detected\" = \"検出された警告。\";\n"
"\"job-state.3\" = \"ペンディング\";\n"
"\"job-state.4\" = \"開催概要\";\n"
"\"job-state.5\" = \"プロセス\";\n"
"\"job-state.6\" = \"停止\";\n"
"\"job-state.7\" = \"キャンセル\";\n"
"\"job-state.8\" = \"アボラ\";\n"
"\"job-state.9\" = \"完了しました\";\n"
"\"joining\" = \"エントリー\";\n"
"\"media\" = \"メディア\";\n"
"\"media-col\" = \"メディア\";\n"
"\"media-size\" = \"メディア サイズ\";\n"
"\"media-size-name\" = \"メディア サイズ\";\n"
"\"media-source\" = \"入力トレイ\";\n"
"\"media-source.alternate\" = \"オルタナティブ\";\n"
"\"media-source.alternate-roll\" = \"代替ロール\";\n"
"\"media-source.auto\" = \"オートマチック\";\n"
"\"media-source.bottom\" = \"ボトム\";\n"
"\"media-source.by-pass-tray\" = \"多目的トレイ\";\n"
"\"media-source.center\" = \"センター\";\n"
"\"media-source.disc\" = \"ディスク\";\n"
"\"media-source.envelope\" = \"エンベロープ\";\n"
"\"media-source.hagaki\" = \"ハガキ\";\n"
"\"media-source.large-capacity\" = \"大容量\";\n"
"\"media-source.left\" = \"ふりがな\";\n"
"\"media-source.main\" = \"メインページ\";\n"
"\"media-source.main-roll\" = \"主要なロール\";\n"
"\"media-source.manual\" = \"マニュアル\";\n"
"\"media-source.middle\" = \"ミドル\";\n"
"\"media-source.photo\" = \"プロフィール\";\n"
"\"media-source.rear\" = \"リア\";\n"
"\"media-source.right\" = \"アクセス\";\n"
"\"media-source.roll-1\" = \"ロール 1\";\n"
"\"media-source.roll-10\" = \"ロール 10\";\n"
"\"media-source.roll-2\" = \"ロール2\";\n"
"\"media-source.roll-3\" = \"ロール3\";\n"
"\"media-source.roll-4\" = \"ロール4\";\n"
"\"media-source.roll-5\" = \"ロール5\";\n"
"\"media-source.roll-6\" = \"ロール 6\";\n"
"\"media-source.roll-7\" = \"ロール 7\";\n"
"\"media-source.roll-8\" = \"ロール8\";\n"
"\"media-source.roll-9\" = \"ロール9\";\n"
"\"media-source.side\" = \"サイド\";\n"
"\"media-source.top\" = \"トップページ\";\n"
"\"media-source.tray-1\" = \"トレイ 1\";\n"
"\"media-source.tray-10\" = \"トレイ 10\";\n"
"\"media-source.tray-11\" = \"トレイ 11\";\n"
"\"media-source.tray-12\" = \"トレイ 12\";\n"
"\"media-source.tray-13\" = \"トレイ 13\";\n"
"\"media-source.tray-14\" = \"トレイ 14\";\n"
"\"media-source.tray-15\" = \"トレイ 15\";\n"
"\"media-source.tray-16\" = \"トレイ 16\";\n"
"\"media-source.tray-17\" = \"トレイ 17\";\n"
"\"media-source.tray-18\" = \"トレイ 18\";\n"
"\"media-source.tray-19\" = \"トレイ 19\";\n"
"\"media-source.tray-2\" = \"トレイ2\";\n"
"\"media-source.tray-20\" = \"トレイ 20\";\n"
"\"media-source.tray-3\" = \"トレイ 3\";\n"
"\"media-source.tray-4\" = \"トレイ 4\";\n"
"\"media-source.tray-5\" = \"トレイ 5\";\n"
"\"media-source.tray-6\" = \"トレイ 6\";\n"
"\"media-source.tray-7\" = \"トレイ 7\";\n"
"\"media-source.tray-8\" = \"トレイ 8\";\n"
"\"media-source.tray-9\" = \"トレイ 9\";\n"
"\"media-tracking\" = \"メディアトラッキング\";\n"
"\"media-tracking.continuous\" = \"連続的な\";\n"
"\"media-tracking.gap\" = \"ギャップ\";\n"
"\"media-tracking.mark\" = \"ログイン\";\n"
"\"media-tracking.web\" = \"サイトマップ\";\n"
"\"media-type\" = \"メディアタイプ\";\n"
"\"media-type.aluminum\" = \"アルミ\";\n"
"\"media-type.auto\" = \"オートマチック\";\n"
"\"media-type.back-print-film\" = \"バックプリントフィルム\";\n"
"\"media-type.cardboard\" = \"段ボール\";\n"
"\"media-type.cardstock\" = \"カードストック\";\n"
"\"media-type.cd\" = \"アルバム\";\n"
"\"media-type.continuous\" = \"連続的な\";\n"
"\"media-type.continuous-long\" = \"連続ロング\";\n"
"\"media-type.continuous-short\" = \"連続ショート\";\n"
"\"media-type.corrugated-board\" = \"波形板\";\n"
"\"media-type.disc\" = \"光学ディスク\";\n"
"\"media-type.disc-glossy\" = \"光沢のある光学ディスク\";\n"
"\"media-type.disc-high-gloss\" = \"高い光沢の光学ディスク\";\n"
"\"media-type.disc-matte\" = \"マット光学ディスク\";\n"
"\"media-type.disc-satin\" = \"サテン光学ディスク\";\n"
"\"media-type.disc-semi-gloss\" = \"セミグロス光学ディスク\";\n"
"\"media-type.double-wall\" = \"二重壁\";\n"
"\"media-type.dry-film\" = \"ドライフィルム\";\n"
"\"media-type.dvd\" = \"DVD机\";\n"
"\"media-type.embossing-foil\" = \"浮彫りになるホイル\";\n"
"\"media-type.end-board\" = \"エンドボード\";\n"
"\"media-type.envelope\" = \"エンベロープ\";\n"
"\"media-type.envelope-archival\" = \"アーカイバル封筒\";\n"
"\"media-type.envelope-bond\" = \"ボンド封筒\";\n"
"\"media-type.envelope-coated\" = \"上塗を施してある封筒\";\n"
"\"media-type.envelope-cotton\" = \"コットン封筒\";\n"
"\"media-type.envelope-fine\" = \"良い封筒\";\n"
"\"media-type.envelope-heavyweight\" = \"ヘビー級封筒\";\n"
"\"media-type.envelope-inkjet\" = \"インクジェット封筒\";\n"
"\"media-type.envelope-lightweight\" = \"軽量封筒\";\n"
"\"media-type.envelope-plain\" = \"平野封筒\";\n"
"\"media-type.envelope-preprinted\" = \"事前印刷された封筒\";\n"
"\"media-type.envelope-window\" = \"窓の封筒\";\n"
"\"media-type.fabric\" = \"ファブリック\";\n"
"\"media-type.fabric-archival\" = \"アーカイバルファブリック\";\n"
"\"media-type.fabric-glossy\" = \"光沢のある生地\";\n"
"\"media-type.fabric-high-gloss\" = \"高い光沢の生地\";\n"
"\"media-type.fabric-matte\" = \"マットの生地\";\n"
"\"media-type.fabric-semi-gloss\" = \"半光沢の生地\";\n"
"\"media-type.fabric-waterproof\" = \"防水生地\";\n"
"\"media-type.film\" = \"フィルム\";\n"
"\"media-type.flexo-base\" = \"フレキソベース\";\n"
"\"media-type.flexo-photo-polymer\" = \"フレキソフォトポリマー\";\n"
"\"media-type.flute\" = \"フルート\";\n"
"\"media-type.foil\" = \"ホイル\";\n"
"\"media-type.full-cut-tabs\" = \"フルカットタブ\";\n"
"\"media-type.glass\" = \"ガラス\";\n"
"\"media-type.glass-colored\" = \"ガラス色\";\n"
"\"media-type.glass-opaque\" = \"ガラスオパク\";\n"
"\"media-type.glass-surfaced\" = \"ガラス面\";\n"
"\"media-type.glass-textured\" = \"ガラステクスチャード\";\n"
"\"media-type.gravure-cylinder\" = \"グラビアシリンダー\";\n"
"\"media-type.image-setter-paper\" = \"イメージのセッターのペーパー\";\n"
"\"media-type.imaging-cylinder\" = \"イメージングシリンダー\";\n"
"\"media-type.labels\" = \"ラベル\";\n"
"\"media-type.labels-colored\" = \"着色されたラベル\";\n"
"\"media-type.labels-glossy\" = \"光沢のあるラベル\";\n"
"\"media-type.labels-high-gloss\" = \"高い光沢のラベル\";\n"
"\"media-type.labels-inkjet\" = \"インクジェットラベル\";\n"
"\"media-type.labels-matte\" = \"マットラベル\";\n"
"\"media-type.labels-permanent\" = \"永久的なラベル\";\n"
"\"media-type.labels-satin\" = \"サテンラベル\";\n"
"\"media-type.labels-security\" = \"セキュリティラベル\";\n"
"\"media-type.labels-semi-gloss\" = \"半光沢のラベル\";\n"
"\"media-type.laminating-foil\" = \"ラミネート箔\";\n"
"\"media-type.letterhead\" = \"レターヘッド\";\n"
"\"media-type.metal\" = \"ログイン\";\n"
"\"media-type.metal-glossy\" = \"金属の光沢のある\";\n"
"\"media-type.metal-high-gloss\" = \"金属の高い光沢\";\n"
"\"media-type.metal-matte\" = \"メタルマット\";\n"
"\"media-type.metal-satin\" = \"金属サテン\";\n"
"\"media-type.metal-semi-gloss\" = \"金属の半光沢\";\n"
"\"media-type.mounting-tape\" = \"土台テープ\";\n"
"\"media-type.multi-layer\" = \"多層層層\";\n"
"\"media-type.multi-part-form\" = \"多部分の形態\";\n"
"\"media-type.other\" = \"その他\";\n"
"\"media-type.paper\" = \"ペーパー\";\n"
"\"media-type.photographic\" = \"フォトペーパー\";\n"
"\"media-type.photographic-archival\" = \"撮影アーカイブ\";\n"
"\"media-type.photographic-film\" = \"フォトフィルム\";\n"
"\"media-type.photographic-glossy\" = \"光沢のある写真のペーパー\";\n"
"\"media-type.photographic-high-gloss\" = \"高い光沢の写真のペーパー\";\n"
"\"media-type.photographic-matte\" = \"マットフォトペーパー\";\n"
"\"media-type.photographic-satin\" = \"サテンフォトペーパー\";\n"
"\"media-type.photographic-semi-gloss\" = \"半光沢の写真のペーパー\";\n"
"\"media-type.plastic\" = \"プラスチック\";\n"
"\"media-type.plastic-archival\" = \"プラスチック アーカイブ\";\n"
"\"media-type.plastic-colored\" = \"プラスチック着色される\";\n"
"\"media-type.plastic-glossy\" = \"プラスチック光沢のある\";\n"
"\"media-type.plastic-high-gloss\" = \"プラスチック高い光沢\";\n"
"\"media-type.plastic-matte\" = \"プラスチックマット\";\n"
"\"media-type.plastic-satin\" = \"プラスチックサテン\";\n"
"\"media-type.plastic-semi-gloss\" = \"プラスチック半光沢\";\n"
"\"media-type.plate\" = \"プレート\";\n"
"\"media-type.polyester\" = \"ポリエステル\";\n"
"\"media-type.pre-cut-tabs\" = \"プリカットタブ\";\n"
"\"media-type.roll\" = \"ロール\";\n"
"\"media-type.screen\" = \"スクリーン\";\n"
"\"media-type.screen-paged\" = \"サイトマップ\";\n"
"\"media-type.self-adhesive\" = \"自己接着\";\n"
"\"media-type.self-adhesive-film\" = \"自己接着フィルム\";\n"
"\"media-type.shrink-foil\" = \"収縮ホイル\";\n"
"\"media-type.single-face\" = \"シングル\";\n"
"\"media-type.single-wall\" = \"単一の壁\";\n"
"\"media-type.sleeve\" = \"ジャケット\";\n"
"\"media-type.stationery\" = \"ステーショナリー\";\n"
"\"media-type.stationery-archival\" = \"文房具のアーカイブ\";\n"
"\"media-type.stationery-coated\" = \"塗被紙\";\n"
"\"media-type.stationery-cotton\" = \"文具の綿\";\n"
"\"media-type.stationery-fine\" = \"ベルラム紙\";\n"
"\"media-type.stationery-heavyweight\" = \"ヘビー級紙\";\n"
"\"media-type.stationery-heavyweight-coated\" = \"ステーショナリーヘビー級コーティング\";\n"
"\"media-type.stationery-inkjet\" = \"文具インクジェットペーパー\";\n"
"\"media-type.stationery-letterhead\" = \"レターヘッド\";\n"
"\"media-type.stationery-lightweight\" = \"軽量紙\";\n"
"\"media-type.stationery-preprinted\" = \"印刷されたペーパー\";\n"
"\"media-type.stationery-prepunched\" = \"パンチングペーパー\";\n"
"\"media-type.tab-stock\" = \"タブストック\";\n"
"\"media-type.tractor\" = \"トラクター\";\n"
"\"media-type.transfer\" = \"アクセス\";\n"
"\"media-type.transparency\" = \"透明性\";\n"
"\"media-type.triple-wall\" = \"トリプルウォール\";\n"
"\"media-type.wet-film\" = \"ウェットフィルム\";\n"
"\"media.choice_iso_a4_210x297mm_na_letter_8.5x11in\" = \"A4または米国手紙\";\n"
"\"media.iso_2a0_1189x1682mm\" = \"2a0の\";\n"
"\"media.iso_a0_841x1189mm\" = \"ツイート\";\n"
"\"media.iso_a0x3_1189x2523mm\" = \"A0x3\";\n"
"\"media.iso_a10_26x37mm\" = \"A10の特長\";\n"
"\"media.iso_a1_594x841mm\" = \"A1の\";\n"
"\"media.iso_a1x3_841x1783mm\" = \"A1x3の特長\";\n"
"\"media.iso_a1x4_841x2378mm\" = \"A1x4の特長\";\n"
"\"media.iso_a2_420x594mm\" = \"A2について\";\n"
"\"media.iso_a2x3_594x1261mm\" = \"A2x3の特長\";\n"
"\"media.iso_a2x4_594x1682mm\" = \"A2x4の特長\";\n"
"\"media.iso_a2x5_594x2102mm\" = \"A2x5の特長\";\n"
"\"media.iso_a3-extra_322x445mm\" = \"A3(エクストラ)\";\n"
"\"media.iso_a3_297x420mm\" = \"A3の特長\";\n"
"\"media.iso_a3x3_420x891mm\" = \"A3x3の特長\";\n"
"\"media.iso_a3x4_420x1189mm\" = \"A3x4の特長\";\n"
"\"media.iso_a3x5_420x1486mm\" = \"A3x5の特長\";\n"
"\"media.iso_a3x6_420x1783mm\" = \"A3x6の特長\";\n"
"\"media.iso_a3x7_420x2080mm\" = \"A3x7の特長\";\n"
"\"media.iso_a4-extra_235.5x322.3mm\" = \"A4(エクストラ)\";\n"
"\"media.iso_a4-tab_225x297mm\" = \"A4(タブ)\";\n"
"\"media.iso_a4_210x297mm\" = \"A4の特長\";\n"
"\"media.iso_a4x3_297x630mm\" = \"A4x3の特長\";\n"
"\"media.iso_a4x4_297x841mm\" = \"A4x4の特長\";\n"
"\"media.iso_a4x5_297x1051mm\" = \"A4x5の特長\";\n"
"\"media.iso_a4x6_297x1261mm\" = \"A4x6の特長\";\n"
"\"media.iso_a4x7_297x1471mm\" = \"A4x7の特長\";\n"
"\"media.iso_a4x8_297x1682mm\" = \"A4x8の特長\";\n"
"\"media.iso_a4x9_297x1892mm\" = \"A4x9の特長\";\n"
"\"media.iso_a5-extra_174x235mm\" = \"A5(エクストラ)\";\n"
"\"media.iso_a5_148x210mm\" = \"A5の特長\";\n"
"\"media.iso_a6_105x148mm\" = \"A6の特長\";\n"
"\"media.iso_a7_74x105mm\" = \"A7の\";\n"
"\"media.iso_a8_52x74mm\" = \"A8の特長\";\n"
"\"media.iso_a9_37x52mm\" = \"A9の特長\";\n"
"\"media.iso_b0_1000x1414mm\" = \"ツイート\";\n"
"\"media.iso_b10_31x44mm\" = \"B10の特長\";\n"
"\"media.iso_b1_707x1000mm\" = \"B1の\";\n"
"\"media.iso_b2_500x707mm\" = \"B2の\";\n"
"\"media.iso_b3_353x500mm\" = \"B3\";\n"
"\"media.iso_b4_250x353mm\" = \"B4の特長\";\n"
"\"media.iso_b5-extra_201x276mm\" = \"B5(エクストラ)\";\n"
"\"media.iso_b5_176x250mm\" = \"B5封筒\";\n"
"\"media.iso_b6_125x176mm\" = \"B6の特長\";\n"
"\"media.iso_b6c4_125x324mm\" = \"B6/C4エンベロープ\";\n"
"\"media.iso_b7_88x125mm\" = \"B7の\";\n"
"\"media.iso_b8_62x88mm\" = \"B8の特長\";\n"
"\"media.iso_b9_44x62mm\" = \"B9の特長\";\n"
"\"media.iso_c0_917x1297mm\" = \"C0封筒\";\n"
"\"media.iso_c10_28x40mm\" = \"C10封筒\";\n"
"\"media.iso_c1_648x917mm\" = \"C1封筒\";\n"
"\"media.iso_c2_458x648mm\" = \"C2封筒\";\n"
"\"media.iso_c3_324x458mm\" = \"C3封筒\";\n"
"\"media.iso_c4_229x324mm\" = \"C4封筒\";\n"
"\"media.iso_c5_162x229mm\" = \"C5封筒\";\n"
"\"media.iso_c6_114x162mm\" = \"C6封筒\";\n"
"\"media.iso_c6c5_114x229mm\" = \"C6/C5封筒\";\n"
"\"media.iso_c7_81x114mm\" = \"C7封筒\";\n"
"\"media.iso_c7c6_81x162mm\" = \"C7/C6 封筒\";\n"
"\"media.iso_c8_57x81mm\" = \"C8封筒\";\n"
"\"media.iso_c9_40x57mm\" = \"C9封筒\";\n"
"\"media.iso_dl_110x220mm\" = \"DL封筒\";\n"
"\"media.iso_ra0_860x1220mm\" = \"ISOのRA0\";\n"
"\"media.iso_ra1_610x860mm\" = \"ISOのRA1\";\n"
"\"media.iso_ra2_430x610mm\" = \"ISOのRA2\";\n"
"\"media.iso_ra3_305x430mm\" = \"ISOのRA3\";\n"
"\"media.iso_ra4_215x305mm\" = \"ISOのRA4\";\n"
"\"media.iso_sra0_900x1280mm\" = \"ISOのSRA0\";\n"
"\"media.iso_sra1_640x900mm\" = \"ISOのSRA1\";\n"
"\"media.iso_sra2_450x640mm\" = \"ISOのSRA2\";\n"
"\"media.iso_sra3_320x450mm\" = \"ISOのSRA3\";\n"
"\"media.iso_sra4_225x320mm\" = \"ISOのSRA4\";\n"
"\"media.jis_b0_1030x1456mm\" = \"三菱 B0\";\n"
"\"media.jis_b10_32x45mm\" = \"JIS B10の特長\";\n"
"\"media.jis_b1_728x1030mm\" = \"JIS B1の特長\";\n"
"\"media.jis_b2_515x728mm\" = \"JIS B2の特長\";\n"
"\"media.jis_b3_364x515mm\" = \"JIS B3の特長\";\n"
"\"media.jis_b4_257x364mm\" = \"JIS B4の特長\";\n"
"\"media.jis_b5_182x257mm\" = \"JIS B5の特長\";\n"
"\"media.jis_b6_128x182mm\" = \"JIS B6の特長\";\n"
"\"media.jis_b7_91x128mm\" = \"JIS B7の特長\";\n"
"\"media.jis_b8_64x91mm\" = \"JIS B8の特長\";\n"
"\"media.jis_b9_45x64mm\" = \"JIS B9の特長\";\n"
"\"media.jis_exec_216x330mm\" = \"ステンレス エグゼクティブ\";\n"
"\"media.jpn_chou2_111.1x146mm\" = \"エンベロープカウ 2\";\n"
"\"media.jpn_chou3_120x235mm\" = \"エンベロープカウ 3\";\n"
"\"media.jpn_chou40_90x225mm\" = \"エンベロープカウ 40\";\n"
"\"media.jpn_chou4_90x205mm\" = \"エンベロープカウ 4\";\n"
"\"media.jpn_hagaki_100x148mm\" = \"ハガキ\";\n"
"\"media.jpn_kahu_240x322.1mm\" = \"エンベロープカウ\";\n"
"\"media.jpn_kaku2_240x332mm\" = \"封筒 カウ 2\";\n"
"\"media.jpn_oufuku_148x200mm\" = \"Oufuku 返信 ポストカード\";\n"
"\"media.jpn_you4_105x235mm\" = \"エンベロープ あなた 4\";\n"
"\"media.na_a2_4.375x5.75in\" = \"封筒 A2\";\n"
"\"media.na_c5_6.5x9.5in\" = \"封筒 C5\";\n"
"\"media.na_executive_7.25x10.5in\" = \"エグゼクティブ\";\n"
"\"media.na_fanfold-eur_8.5x12in\" = \"ヨーロッパのファンフォールド\";\n"
"\"media.na_fanfold-us_11x14.875in\" = \"アメリカのファンフォールド\";\n"
"\"media.na_foolscap_8.5x13in\" = \"フットキャップ\";\n"
"\"media.na_invoice_5.5x8.5in\" = \"ニュース\";\n"
"\"media.na_legal-extra_9.5x15in\" = \"米国の法律(エクストラ)\";\n"
"\"media.na_legal_8.5x14in\" = \"米国法\";\n"
"\"media.na_letter-extra_9.5x12in\" = \"米国の手紙(元)\";\n"
"\"media.na_letter-plus_8.5x12.69in\" = \"米国の手紙(プラス)\";\n"
"\"media.na_letter_8.5x11in\" = \"米国の手紙\";\n"
"\"media.na_monarch_3.875x7.5in\" = \"Envelope モンアーチ\";\n"
"\"media.na_number-10_4.125x9.5in\" = \"封筒 #10\";\n"
"\"media.na_number-11_4.5x10.375in\" = \"封筒 #11\";\n"
"\"media.na_number-12_4.75x11in\" = \"封筒 #12\";\n"
"\"media.na_number-14_5x11.5in\" = \"封筒 #14\";\n"
"\"media.na_number-9_3.875x8.875in\" = \"封筒 #9\";\n"
"\"media.na_personal_3.625x6.5in\" = \"封筒 個人\";\n"
"\"media.na_quarto_8.5x10.83in\" = \"クアルト\";\n"
"\"media.om_folio-sp_215x315mm\" = \"フォリオ\";\n"
"\"media.om_folio_210x330mm\" = \"フォリオ(スペシャル)\";\n"
"\"media.om_invite_220x220mm\" = \"封筒の招待状\";\n"
"\"media.om_italian_110x230mm\" = \"イタリア\";\n"
"\"media.om_juuro-ku-kai_198x275mm\" = \"198 x 275mm\";\n"
"\"media.om_large-photo_200x300\" = \"200×300\";\n"
"\"media.om_medium-photo_130x180mm\" = \"130 x 180mmの\";\n"
"\"media.om_pa-kai_267x389mm\" = \"267×389m m 点\";\n"
"\"media.om_postfix_114x229mm\" = \"封筒 Postfix\";\n"
"\"media.prc_10_324x458mm\" = \"封筒の中国 #10\";\n"
"\"media.prc_16k_146x215mm\" = \"中国語 16k\";\n"
"\"media.prc_1_102x165mm\" = \"封筒 中国人 #1\";\n"
"\"media.prc_2_102x176mm\" = \"封筒 中国人 #2\";\n"
"\"media.prc_32k_97x151mm\" = \"中国語 32k\";\n"
"\"media.prc_3_125x176mm\" = \"封筒中国 #3\";\n"
"\"media.prc_4_110x208mm\" = \"封筒中国 #4\";\n"
"\"media.prc_5_110x220mm\" = \"封筒中国 #5\";\n"
"\"media.prc_6_120x320mm\" = \"封筒中国 #6\";\n"
"\"media.prc_7_160x230mm\" = \"封筒中国 #7\";\n"
"\"media.prc_8_120x309mm\" = \"封筒の中国 #8\";\n"
"\"media.roc_16k_7.75x10.75in\" = \"ROC 16Kの特長\";\n"
"\"media.roc_8k_10.75x15.5in\" = \"ロッコ 8Kの\";\n"
"\"not configured\" = \"設定されていない\";\n"
"\"not visible\" = \"見えない\";\n"
"\"off\" = \"オフ\";\n"
"\"on\" = \"お問い合わせ\";\n"
"\"orientation-requested\" = \"オリエンテーション\";\n"
"\"orientation-requested.3\" = \"ポートレート\";\n"
"\"orientation-requested.4\" = \"ニュース\";\n"
"\"orientation-requested.5\" = \"逆の風景\";\n"
"\"orientation-requested.6\" = \"逆の肖像画\";\n"
"\"orientation-requested.7\" = \"なし\";\n"
"\"output-bin\" = \"出力トレイ\";\n"
"\"output-bin.auto\" = \"オートマチック\";\n"
"\"output-bin.bottom\" = \"ボトム\";\n"
"\"output-bin.center\" = \"センター\";\n"
"\"output-bin.face-down\" = \"フェイスダウン\";\n"
"\"output-bin.face-up\" = \"フェイスアップ\";\n"
"\"output-bin.large-capacity\" = \"大容量\";\n"
"\"output-bin.left\" = \"ふりがな\";\n"
"\"output-bin.mailbox-1\" = \"メールボックス 1\";\n"
"\"output-bin.mailbox-10\" = \"メールボックス10\";\n"
"\"output-bin.mailbox-2\" = \"メールボックス2\";\n"
"\"output-bin.mailbox-3\" = \"メールボックス3\";\n"
"\"output-bin.mailbox-4\" = \"メールボックス 4\";\n"
"\"output-bin.mailbox-5\" = \"メールボックス 5\";\n"
"\"output-bin.mailbox-6\" = \"メールボックス 6\";\n"
"\"output-bin.mailbox-7\" = \"メールボックス 7\";\n"
"\"output-bin.mailbox-8\" = \"メールボックス 8\";\n"
"\"output-bin.mailbox-9\" = \"メールボックス 9\";\n"
"\"output-bin.middle\" = \"ミドル\";\n"
"\"output-bin.my-mailbox\" = \"メールボックス\";\n"
"\"output-bin.rear\" = \"リア\";\n"
"\"output-bin.right\" = \"アクセス\";\n"
"\"output-bin.side\" = \"サイド\";\n"
"\"output-bin.stacker-1\" = \"スタッカー 1\";\n"
"\"output-bin.stacker-10\" = \"スタッカー 10\";\n"
"\"output-bin.stacker-2\" = \"スタッカー 2\";\n"
"\"output-bin.stacker-3\" = \"スタッカー 3\";\n"
"\"output-bin.stacker-4\" = \"スタッカー 4\";\n"
"\"output-bin.stacker-5\" = \"スタッカー 5\";\n"
"\"output-bin.stacker-6\" = \"スタッカー 6\";\n"
"\"output-bin.stacker-7\" = \"スタッカー 7\";\n"
"\"output-bin.stacker-8\" = \"スタッカー 8\";\n"
"\"output-bin.stacker-9\" = \"スタッカー 9\";\n"
"\"output-bin.top\" = \"トップページ\";\n"
"\"output-bin.tray-1\" = \"トレイ 1\";\n"
"\"output-bin.tray-10\" = \"トレイ 10\";\n"
"\"output-bin.tray-2\" = \"トレイ2\";\n"
"\"output-bin.tray-3\" = \"トレイ 3\";\n"
"\"output-bin.tray-4\" = \"トレイ 4\";\n"
"\"output-bin.tray-5\" = \"トレイ 5\";\n"
"\"output-bin.tray-6\" = \"トレイ 6\";\n"
"\"output-bin.tray-7\" = \"トレイ 7\";\n"
"\"output-bin.tray-8\" = \"トレイ 8\";\n"
"\"output-bin.tray-9\" = \"トレイ 9\";\n"
"\"print-color-mode\" = \"プリントモード\";\n"
"\"print-color-mode.auto\" = \"オートマチック\";\n"
"\"print-color-mode.auto-monochrome\" = \"自動モノクロ\";\n"
"\"print-color-mode.bi-level\" = \"テキスト\";\n"
"\"print-color-mode.color\" = \"カラー\";\n"
"\"print-color-mode.highlight\" = \"ハイライト\";\n"
"\"print-color-mode.monochrome\" = \"モノクロ\";\n"
"\"print-color-mode.process-bi-level\" = \"プロセステキスト\";\n"
"\"print-color-mode.process-monochrome\" = \"プロセスモノクロ\";\n"
"\"print-content-optimize\" = \"最適化\";\n"
"\"print-content-optimize.auto\" = \"オートマチック\";\n"
"\"print-content-optimize.graphic\" = \"グラフィック\";\n"
"\"print-content-optimize.photo\" = \"プロフィール\";\n"
"\"print-content-optimize.text\" = \"テキスト\";\n"
"\"print-content-optimize.text-and-graphic\" = \"テキストとグラフィック\";\n"
"\"print-darkness\" = \"プリントダークネス\";\n"
"\"print-quality\" = \"印刷物の質\";\n"
"\"print-quality.3\" = \"ドラフト\";\n"
"\"print-quality.4\" = \"ノーマル\";\n"
"\"print-quality.5\" = \"ベストベスト\";\n"
"\"print-scaling\" = \"スケーリング\";\n"
"\"print-scaling.auto\" = \"オートマチック\";\n"
"\"print-scaling.auto-fit\" = \"自動フィット\";\n"
"\"print-scaling.fill\" = \"お問い合わせ\";\n"
"\"print-scaling.fit\" = \"フィット\";\n"
"\"print-scaling.none\" = \"なし\";\n"
"\"print-speed\" = \"プリント速度\";\n"
"\"printer-resolution\" = \"ソリューション\";\n"
"\"printer-state-reasons.cover-open\" = \"カバーは開きます。\";\n"
"\"printer-state-reasons.door-open\" = \"ドアを開けて下さい。\";\n"
"\"printer-state-reasons.identify-printer-requested\" = \"プリンターを識別します。\";\n"
"\"printer-state-reasons.input-tray-missing\" = \"ペーパー皿の欠落。\";\n"
"\"printer-state-reasons.marker-supply-empty\" = \"インクから。\";\n"
"\"printer-state-reasons.marker-supply-low\" = \"低いインク。\";\n"
"\"printer-state-reasons.marker-waste-almost-full\" = \"廃棄物の大箱はほぼ満たします。\";\n"
"\"printer-state-reasons.marker-waste-full\" = \"廃棄物の箱の完全。\";\n"
"\"printer-state-reasons.media-empty\" = \"ペーパーから。\";\n"
"\"printer-state-reasons.media-jam\" = \"ペーパー ジャム。\";\n"
"\"printer-state-reasons.media-low\" = \"ペーパーをすぐに取り替えて下さい。\";\n"
"\"printer-state-reasons.media-needed\" = \"ペーパーを荷を積んで下さい。\";\n"
"\"printer-state-reasons.none\" = \"レディ。\";\n"
"\"printer-state-reasons.offline\" = \"オフライン\";\n"
"\"printer-state-reasons.other\" = \"プリンターを見る\";\n"
"\"printer-state-reasons.spool-area-full\" = \"プリンターの忙しい。\";\n"
"\"printer-state-reasons.toner-empty\" = \"トナー。\";\n"
"\"printer-state-reasons.toner-low\" = \"トナーの低い。\";\n"
"\"printer-state.3\" = \"アイドル\";\n"
"\"printer-state.4\" = \"プロセス\";\n"
"\"printer-state.5\" = \"停止\";\n"
"\"sides\" = \"2-被覆印刷\";\n"
"\"sides.one-sided\" = \"オフ\";\n"
"\"sides.two-sided-long-edge\" = \"(ポートレート)\";\n"
"\"sides.two-sided-short-edge\" = \"オン(ランドスケープ)\";\n"
"\"unable to join\" = \"参加できません\";\n"
"\"yesterday at %02d:%02d:%02d\" = \"yesterday at %02d:%02d:%02d\";\n"
"\"Åland Islands\" = \"土地の島\";\n";
