static const char *fr_strings = "\"  -a               Cancel all jobs (cancel).\" = \"  -a               Annuler tous les emplois (cancel.)\";\n"
"\"  -c COPIES\" = \"-c COPIES\";\n"
"\"  -d PRINTER       Specify printer.\" = \"  -d PRINTER       Indiquez l'imprimante.\";\n"
"\"  -j JOB-ID        Specify job ID (cancel).\" = \"  -j JOB-ID        Spécifier l'identité d'emploi (cancel).\";\n"
"\"  -m DRIVER-NAME   Specify driver (add/modify).\" = \"  -m DRIVER-NAME   Indiquer le conducteur (ajouter/modifier.)\";\n"
"\"  -n COPIES        Specify number of copies (submit).\" = \"  -n COPIES        Préciser le nombre d'exemplaires (soumis.)\";\n"
"\"  -o %s=%s (default)\" = \"-o %s = %s (par défaut)\";\n"
"\"  -o NAME=VALUE    Specify option (add,modify,server,submit).\" = \"  -o NAME=VALUE    Option de spécification (add,modify,server,submit.)\";\n"
"\"  -o print-darkness=-100 to 100\" = \"  -o print-darkness=-100 à 100\";\n"
"\"  -o printer-darkness=0 to 100\" = \"  -o printer-darkness=0 à 100\";\n"
"\"  -o printer-geo-location='geo:LATITUDE,LONGITUDE'\" = \"  -o printer-geo-location='geo:LATITUDE,LONGITUDE\";\n"
"\"  -o printer-location='LOCATION'\" = \"  -o printer-location='LOCATION\";\n"
"\"  -o printer-organization='ORGANIZATION'\" = \"  -o printer-organization='ORGANIZATION\";\n"
"\"  -o printer-organizational-unit='UNIT/SECTION'\" = \"  -o printer-organizational-unit='UNIT/SECTION\";\n"
"\"  -u URI           Specify ipp: or ipps: printer/server.\" = \"  -u URI Specify ipp: or ipps: printer/server.\";\n"
"\"  -v DEVICE-URI    Specify socket: or usb: device (add/modify).\" = \"  -v DEVICE-URI    Spécifier la socket: ou usb: périphérique (add/modify.)\";\n"
"\"  add PRINTER      Add a printer.\" = \"  add PRINTER      Ajouter une imprimante.\";\n"
"\"  autoadd          Automatically add supported printers.\" = \"  autoadd          Ajoutez automatiquement les imprimantes supportées.\";\n"
"\"  cancel           Cancel one or more jobs.\" = \"  cancel           Annuler un ou plusieurs emplois.\";\n"
"\"  default          Set the default printer.\" = \"  default          Réglez l'imprimante par défaut.\";\n"
"\"  delete           Delete a printer.\" = \"  delete           Supprimer une imprimante.\";\n"
"\"  devices          List devices.\" = \"  devices          Liste des appareils.\";\n"
"\"  drivers          List drivers.\" = \"  drivers          Listez les pilotes.\";\n"
"\"  jobs             List jobs.\" = \"  jobs             Lister des emplois.\";\n"
"\"  modify           Modify a printer.\" = \"  modify           Modifier une imprimante.\";\n"
"\"  options          List printer options.\" = \"  options          Liste des options d'imprimante.\";\n"
"\"  pause            Pause printing for a printer.\" = \"  pause            Impression à la Pause pour une imprimante.\";\n"
"\"  printers         List printers.\" = \"  printers         Liste des imprimantes.\";\n"
"\"  resume           Resume printing for a printer.\" = \"  resume           Reprendre l'impression pour une imprimante.\";\n"
"\"  server           Run a server.\" = \"  server           Exécutez un serveur.\";\n"
"\"  shutdown         Shutdown a running server.\" = \"  shutdown         Fermer un serveur.\";\n"
"\"  status           Show server/printer/job status.\" = \"  status           Afficher le statut serveur/imprimante/job.\";\n"
"\"  submit           Submit a file for printing.\" = \"  submit           Soumettre un fichier pour l'impression.\";\n"
"\"%04d-%02d-%02d at %02d:%02d:%02d\" = \"%04d-%02d-%02d at %02d:%02d:%02d\";\n"
"\"%d days ago at %02d:%02d:%02d\" = \"%d days ago at %02d:%02d:%02d\";\n"
"\"%d inches/sec\" = \"%d pouces/sec\";\n"
"\"%d job\" = \"Travail de F0\";\n"
/* Media size in millimeters */
"\"%d x %dmm\" = \"%d x %d mm\";\n"
"\"%ddpi\" = \"%d dpi\";\n"
"\"%dx%ddpi\" = \"%d x %d dpi\";\n"
/* Media size in inches */
"\"%g x %g\\\"\" = \"%g x %g \\\"\";\n"
/* size (type+borderless) */
"\"%s (%s%s)\" = \"%s ( %s %s )\";\n"
/* size (type+borderless) from source/tray */
"\"%s (%s%s) from %s\" = \"%s (%s%s) de %s\";\n"
/* Source/Tray Media */
"\"%s Media\" = \"%s Médias\";\n"
"\"%s: Bad 'server-port' value.\" = \"%s: Bad server-port value.\";\n"
"\"%s: Bad job ID.\" = \"%s: Bad job ID.\";\n"
"\"%s: Bad printer URI '%s'.\" = \"%s: Bad printer URI '%s'.\";\n"
"\"%s: Cannot specify more than one sub-command.\" = \"%s: Ne pas spécifier plus d'un sous-commande.\";\n"
"\"%s: Empty print file received on the standard input.\" = \"%s: Fichier imprimé vide reçu sur l'entrée standard.\";\n"
"\"%s: Failed to create a system.\" = \"%s: Failed to create a system.\";\n"
"\"%s: Missing '-d PRINTER'.\" = \"%s: Missing '-d PRINTER. '\";\n"
"\"%s: Missing '-m DRIVER-NAME'.\" = \"%s: Missing '-m DRIVER-NAME. '\";\n"
"\"%s: Missing '-v DEVICE-URI'.\" = \"%s: Missing '-v DEVICE-URI. '\";\n"
"\"%s: Missing copy count after '-n'.\" = \"%s: Compte de copie manquante après -n.\";\n"
"\"%s: Missing device URI after '-v'.\" = \"%s: Dispositif manquant URI après -v.\";\n"
"\"%s: Missing driver name after '-m'.\" = \"%s: Nom du conducteur manquant après -m.\";\n"
"\"%s: Missing filename after '--'.\" = \"%s: Nom de fichier manquant après '-'.\";\n"
"\"%s: Missing hostname after '-h'.\" = \"%s: Nom d'hôte manquant après -h.\";\n"
"\"%s: Missing job ID after '-j'.\" = \"%s: Perte d'identité après -j.\";\n"
"\"%s: Missing option(s) after '-o'.\" = \"%s: Option(s) manquante après -o.\";\n"
"\"%s: Missing printer URI after '-u'.\" = \"%s: Imprimante manquante URI après -u.\";\n"
"\"%s: Missing printer name after '-d'.\" = \"%s: Nom d'imprimante manquant après -d.\";\n"
"\"%s: Missing space after '-o'.\" = \"%s: Espace manquant après -o.\";\n"
"\"%s: Missing title after '-t'.\" = \"%s: Titre manquant après -t.\";\n"
"\"%s: No default printer available.\" = \"%s: Pas d'imprimante par défaut disponible.\";\n"
"\"%s: No files to print.\" = \"%s: Aucun fichier à imprimer.\";\n"
"\"%s: Server is not running.\" = \"%s: Le serveur ne fonctionne pas.\";\n"
"\"%s: Sub-command '%s' does not accept files.\" = \"%s: Sous-commande '%s' n'accepte pas les fichiers.\";\n"
"\"%s: Sub-command 'autoadd' is not supported.\" = \"%s: Sub-command autoadd n'est pas pris en charge.\";\n"
"\"%s: Too many files.\" = \"%s: Trop de fichiers.\";\n"
"\"%s: Unable to access '%s': %s\" = \"%s: Impossible d'accéder à '%s': %s\";\n"
"\"%s: Unable to add printer: %s\" = \"%s: Impossible d'ajouter l'imprimante: %s\";\n"
"\"%s: Unable to cancel job: %s\" = \"%s: Impossible d'annuler: %s\";\n"
"\"%s: Unable to connect to printer at '%s:%d': %s\" = \"%s: Impossible de se connecter à l'imprimante chez '%s:%d': %s\";\n"
"\"%s: Unable to connect to server: %s\" = \"%s: Impossible de se connecter au serveur: %s\";\n"
"\"%s: Unable to create temporary file: %s\" = \"%s: Impossible de créer un fichier temporaire: %s\";\n"
"\"%s: Unable to delete printer: %s\" = \"%s: Impossible de supprimer l'imprimante: %s\";\n"
"\"%s: Unable to get available devices: %s\" = \"%s: Unable to get available devices: %s\";\n"
"\"%s: Unable to get information for '%s': %s\" = \"%s: Impossible d'obtenir des informations pour '%s': %s\";\n"
"\"%s: Unable to get information for printer: %s\" = \"%s: Impossible d'obtenir des informations pour l'imprimante: %s\";\n"
"\"%s: Unable to get printer options: %s\" = \"%s: Impossible d'obtenir des options d'imprimante: %s\";\n"
"\"%s: Unable to modify printer: %s\" = \"%s: Impossible de modifier l'imprimante: %s\";\n"
"\"%s: Unable to pause printer: %s\" = \"%s: Impossible de faire une pause imprimante: %s\";\n"
"\"%s: Unable to print '%s': %s\" = \"%s: Impossible d'imprimer '%s': %s\";\n"
"\"%s: Unable to resume printer: %s\" = \"%s: Impossible de reprendre l'imprimante: %s\";\n"
"\"%s: Unable to set default printer: %s\" = \"%s: Impossible de définir l'imprimante par défaut: %s\";\n"
"\"%s: Unable to shutdown server: %s\" = \"%s: Impossible de fermer le serveur: %s\";\n"
"\"%s: Unable to start server: %s\" = \"%s: Impossible de démarrer le serveur: %s\";\n"
"\"%s: Unable to write to temporary file: %s\" = \"%s: Impossible d'écrire au fichier temporaire: %s\";\n"
"\"%s: Unknown option '%s'.\" = \"%s: Option inconnue '%s'.\";\n"
"\"%s: Unknown option '-%c'.\" = \"%s: Option inconnue '-%c'.\";\n"
"\"%s: Unknown sub-command '%s'.\" = \"%s: Sous-commande inconnue '%s'.\";\n"
"\"%s: Unsupported URI scheme '%s'.\" = \"%s: Système URI non soutenu '%s'.\";\n"
"\"%s: Warning - user credentials are not supported in URIs.\" = \"%s: Warning - user credentials are not supported in URIs.\";\n"
"\", Borderless\" = \", Borderless\";\n"
"\"A printer with that name already exists.\" = \"Une imprimante avec ce nom existe déjà.\";\n"
"\"Aborted %s\" = \"Aborted %s\";\n"
"\"Add Printer\" = \"Add Printer\";\n"
"\"Admin Group\" = \"Groupe Admin\";\n"
"\"Afghanistan\" = \"Afghanistan\";\n"
"\"Albania\" = \"Albanie\";\n"
"\"Algeria\" = \"Algérie\";\n"
"\"American Samoa\" = \"Samoa américaines\";\n"
"\"Andorra\" = \"Andorre\";\n"
"\"Angola\" = \"Angola\";\n"
"\"Anguilla\" = \"Anguilla\";\n"
"\"Antarctica\" = \"Antarctique\";\n"
"\"Antigua and Barbuda\" = \"Antigua-et-Barbuda\";\n"
"\"Argentina\" = \"Argentine\";\n"
"\"Armenia\" = \"Arménie\";\n"
"\"Aruba\" = \"Aruba\";\n"
"\"Australia\" = \"Australie\";\n"
"\"Austria\" = \"Autriche\";\n"
"\"Auto\" = \"Auto\";\n"
"\"Auto-Detect Driver\" = \"Auto-Detect Driver\";\n"
"\"Azerbaijan\" = \"Azerbaïdjan\";\n"
"\"Bad administration group.\" = \"Bad administration group.\";\n"
"\"Bad port number.\" = \"Bad port number.\";\n"
"\"Bad print group.\" = \"Bad print group.\";\n"
"\"Bad printer defaults.\" = \"Bad printer defaults.\";\n"
"\"Bahamas\" = \"Bahamas\";\n"
"\"Bahrain\" = \"Bahreïn\";\n"
"\"Bangladesh\" = \"Bangladesh\";\n"
"\"Barbados\" = \"Barbade\";\n"
"\"Belarus\" = \"Bélarus\";\n"
"\"Belgium\" = \"Belgique\";\n"
"\"Belize\" = \"Belize\";\n"
"\"Benin\" = \"Bénin\";\n"
"\"Bermuda\" = \"Bermudes\";\n"
"\"Bhutan\" = \"Bhoutan\";\n"
"\"Bolivia (Plurinational State of)\" = \"Bolivie (État plurinational de)\";\n"
"\"Bonaire, Sint Eustatius and Saba\" = \"Bonaire, Sint Eustatius et Saba\";\n"
"\"Borderless\" = \"Borderless\";\n"
"\"Bosnia and Herzegovina\" = \"Bosnie-Herzégovine\";\n"
"\"Botswana\" = \"Botswana\";\n"
"\"Bouvet Island\" = \"Bouvet Island\";\n"
"\"Brazil\" = \"Brésil\";\n"
"\"British Indian Ocean Territory\" = \"British Indian Ocean Territory\";\n"
"\"Brunei Darussalam\" = \"Brunéi Darussalam\";\n"
"\"Bulgaria\" = \"Bulgarie\";\n"
"\"Burkina Faso\" = \"Burkina Faso\";\n"
"\"Burundi\" = \"Burundi\";\n"
"\"Cabo Verde\" = \"Cabo Verde\";\n"
"\"Cambodia\" = \"Cambodge\";\n"
"\"Cameroon\" = \"Cameroun\";\n"
"\"Canada\" = \"Canada\";\n"
"\"Cancel All Jobs\" = \"Annuler tous les emplois\";\n"
"\"Cancel Job\" = \"Annuler Job\";\n"
"\"Canceled %s\" = \"Canceled %s\";\n"
"\"Canceling\" = \"Anniversaire\";\n"
"\"Cayman Islands\" = \"Îles Caïmanes\";\n"
"\"Central African Republic\" = \"République centrafricaine\";\n"
"\"Certificate created.\" = \"Certificat créé.\";\n"
"\"Certificate installed.\" = \"Certificat installé.\";\n"
"\"Certificate request created.\" = \"Demande de certificat créée.\";\n"
"\"Chad\" = \"Tchad\";\n"
"\"Change Access Password\" = \"Change Access Password\";\n"
"\"Change Log Level\" = \"Change Log Level\";\n"
"\"Change Network Settings\" = \"Change Network Settings\";\n"
"\"Change Wi-Fi Network\" = \"Change Wi-Fi Network\";\n"
"\"Changes Saved.\" = \"Changements enregistrés.\";\n"
"\"Changes saved.\" = \"Changements enregistrés.\";\n"
"\"Chile\" = \"Chili\";\n"
"\"China\" = \"Chine\";\n"
"\"Christmas Island\" = \"Christmas Island\";\n"
"\"City/Locality\" = \"City/Locality\";\n"
"\"Cocos (Keeling) Islands\" = \"Îles de Coco (Keeling)\";\n"
"\"Colombia\" = \"Colombie\";\n"
"\"Comoros\" = \"Comores\";\n"
"\"Completed %s\" = \"Completed %s\";\n"
"\"Configuration\" = \"Configuration\";\n"
"\"Configure Media\" = \"Configurer Media\";\n"
"\"Confirm Cancel All\" = \"Confirmer Annuler Tout\";\n"
"\"Confirm Delete Printer\" = \"Confirmer Supprimer l'imprimante\";\n"
"\"Congo\" = \"Congo\";\n"
"\"Congo, Democratic Republic of the\" = \"Congo, République démocratique du Congo\";\n"
"\"Contact\" = \"Contact\";\n"
"\"Cook Islands\" = \"Îles Cook\";\n"
"\"Costa Rica\" = \"Costa Rica\";\n"
"\"Create Certificate Signing Request\" = \"Créer une demande de signature de certificat\";\n"
"\"Create New Certificate\" = \"Créer un nouveau certificat\";\n"
"\"Create New TLS Certificate\" = \"Créer un nouveau certificat TLS\";\n"
"\"Create TLS Certificate Request\" = \"Créer TLS Demande de certificat\";\n"
"\"Croatia\" = \"Croatie\";\n"
"\"Cuba\" = \"Cuba\";\n"
"\"Curaçao\" = \"Curaao\";\n"
"\"Current Password\" = \"Mot de passe actuel\";\n"
"\"Custom Size\" = \"Taille personnalisée\";\n"
"\"Cyprus\" = \"Chypre\";\n"
"\"Czechia\" = \"Czechia\";\n"
"\"Côte d'Ivoire\" = \"Cte d'Ivoire\";\n"
"\"DHCP\" = \"DHCP\";\n"
"\"DHCP w/Manual Address\" = \"DHCP w/Manual Address\";\n"
"\"DNS-SD Service Name\" = \"DNS-SD Nom de service\";\n"
"\"Debugging\" = \"Debugging\";\n"
"\"Default printer set.\" = \"Imprimante par défaut.\";\n"
"\"Delete\" = \"Supprimer\";\n"
"\"Delete Printer\" = \"Supprimer Printer\";\n"
"\"Denmark\" = \"Danemark\";\n"
"\"Djibouti\" = \"Djibouti\";\n"
"\"Domain Name\" = \"Domain Name\";\n"
"\"Dominica\" = \"Dominique\";\n"
"\"Dominican Republic\" = \"République dominicaine\";\n"
"\"Download Certificate Request File\" = \"Télécharger le fichier Demande de certificat\";\n"
"\"Ecuador\" = \"Équateur\";\n"
"\"Egypt\" = \"Égypte\";\n"
"\"El Salvador\" = \"El Salvador\";\n"
"\"Equatorial Guinea\" = \"Guinée équatoriale\";\n"
"\"Eritrea\" = \"Érythrée\";\n"
"\"Errors\" = \"Erreurs\";\n"
"\"Estonia\" = \"Estonie\";\n"
"\"Eswatini\" = \"Eswatini\";\n"
"\"Ethiopia\" = \"Éthiopie\";\n"
"\"Falkland Islands (Malvinas)\" = \"Îles Falkland (Malvinas)\";\n"
"\"Faroe Islands\" = \"Îles Féroé\";\n"
"\"Fatal Errors/Conditions\" = \"Erreurs/Conditions Fatales\";\n"
"\"Fiji\" = \"Fidji\";\n"
"\"Finland\" = \"Finlande\";\n"
"\"France\" = \"France\";\n"
"\"French Guiana\" = \"Guyane française\";\n"
"\"French Polynesia\" = \"Polynésie française\";\n"
"\"French Southern Territories\" = \"Territoires du Sud\";\n"
"\"Gabon\" = \"Gabon\";\n"
"\"Gambia\" = \"Gambie\";\n"
"\"Georgia\" = \"Géorgie\";\n"
"\"Germany\" = \"Allemagne\";\n"
"\"Ghana\" = \"Ghana\";\n"
"\"Gibraltar\" = \"Gibraltar\";\n"
"\"Greece\" = \"Grèce\";\n"
"\"Greenland\" = \"Groenland\";\n"
"\"Grenada\" = \"Grenade\";\n"
"\"Group changes saved.\" = \"Changements de groupe enregistrés.\";\n"
"\"Guadeloupe\" = \"Guadeloupe\";\n"
"\"Guam\" = \"Guam\";\n"
"\"Guatemala\" = \"Guatemala\";\n"
"\"Guernsey\" = \"Guernesey\";\n"
"\"Guinea\" = \"Guinée\";\n"
"\"Guinea-Bissau\" = \"Guinée-Bissau\";\n"
"\"Guyana\" = \"Guyana\";\n"
"\"Haiti\" = \"Haïti\";\n"
"\"Heard Island and McDonald Islands\" = \"Heard Island et McDonald Islands\";\n"
"\"Hidden SSID\" = \"Hidden SSID\";\n"
"\"Hold Job\" = \"Hold Job\";\n"
"\"Hold New Jobs\" = \"Hold New Jobs\";\n"
"\"Holding new jobs.\" = \"Holding new jobs.\";\n"
"\"Holy See\" = \"Saint-Siège\";\n"
"\"Honduras\" = \"Honduras\";\n"
"\"Hong Kong\" = \"Hong Kong\";\n"
"\"Hostname\" = \"Hostname\";\n"
"\"Human-Readable Location\" = \"Emplacement lisible\";\n"
"\"Hungary\" = \"Hongrie\";\n"
"\"IPv4 Address\" = \"IPv4 Address\";\n"
"\"IPv4 Configuration\" = \"IPv4 Configuration\";\n"
"\"IPv4 Gateway\" = \"IPv4 Gateway\";\n"
"\"IPv4 Netmask\" = \"IPv4 Netmask\";\n"
"\"IPv6 Address\" = \"IPv6 Address\";\n"
"\"IPv6 Configuration\" = \"IPv6 Configuration\";\n"
"\"IPv6 Link-Local\" = \"IPv6 Link-Local\";\n"
"\"IPv6 Prefix Length\" = \"IPv6 Prefix Length\";\n"
"\"Iceland\" = \"Islande\";\n"
"\"Identify Printer\" = \"Identifier l'imprimante\";\n"
"\"India\" = \"Inde\";\n"
"\"Indonesia\" = \"Indonésie\";\n"
"\"Informational\" = \"Informational\";\n"
"\"Install TLS Certificate\" = \"Installez TLS Certificat\";\n"
"\"Invalid IPv4 address.\" = \"Invalid IPv4 address.\";\n"
"\"Invalid IPv4 netmask.\" = \"Invalid IPv4 netmask.\";\n"
"\"Invalid IPv6 address.\" = \"Invalid IPv6 address.\";\n"
"\"Invalid IPv6 prefix length.\" = \"Invalid IPv6 prefix length.\";\n"
"\"Invalid Job ID.\" = \"Invalid Job ID.\";\n"
"\"Invalid certificate or private key.\" = \"Certificat invalide ou clé privée.\";\n"
"\"Invalid form data.\" = \"Données de forme incorrectes.\";\n"
"\"Invalid form submission.\" = \"Demande de formulaire non valide.\";\n"
"\"Invalid job ID.\" = \"Invalide.\";\n"
"\"Invalid network configuration.\" = \"Invalid network configuration.\";\n"
"\"Iran (Islamic Republic of)\" = \"Iran (République islamique d ' )\";\n"
"\"Iraq\" = \"Iraq\";\n"
"\"Ireland\" = \"Irlande\";\n"
"\"Isle of Man\" = \"Isle of Man\";\n"
"\"Israel\" = \"Israël\";\n"
"\"Italy\" = \"Italie\";\n"
"\"Jamaica\" = \"Jamaïque\";\n"
"\"Japan\" = \"Japon\";\n"
"\"Jersey\" = \"Jersey\";\n"
"\"Job #\" = \"Job\";\n"
"\"Job canceled.\" = \"Job canceled.\";\n"
"\"Job held.\" = \"Job held.\";\n"
"\"Job released.\" = \"Job released.\";\n"
"\"Jobs\" = \"Jobs\";\n"
"\"Joining Wi-Fi Network\" = \"Joining Wi-Fi Network\";\n"
"\"Jordan\" = \"Jordanie\";\n"
"\"Kazakhstan\" = \"Kazakhstan\";\n"
"\"Kenya\" = \"Kenya\";\n"
"\"Kiribati\" = \"Kiribati\";\n"
"\"Korea (Democratic People's Republic of)\" = \"Corée (République populaire démocratique de)\";\n"
"\"Korea, Republic of\" = \"République de Corée\";\n"
"\"Kuwait\" = \"Koweït\";\n"
"\"Kyrgyzstan\" = \"Kirghizistan\";\n"
"\"Landscape\" = \"Paysage\";\n"
"\"Lao People's Democratic Republic\" = \"République démocratique populaire lao\";\n"
"\"Latvia\" = \"Lettonie\";\n"
"\"Lebanon\" = \"Liban\";\n"
"\"Lesotho\" = \"Lesotho\";\n"
"\"Level\" = \"Niveau\";\n"
"\"Liberia\" = \"Libéria\";\n"
"\"Libya\" = \"Libye\";\n"
"\"Liechtenstein\" = \"Liechtenstein\";\n"
"\"Lithuania\" = \"Lituanie\";\n"
"\"Location\" = \"Lieu\";\n"
"\"Log Level\" = \"Niveau de référence\";\n"
"\"Logging\" = \"Logging\";\n"
"\"Logs\" = \"Logs\";\n"
"\"Luxembourg\" = \"Luxembourg\";\n"
"\"Macao\" = \"Macao\";\n"
"\"Madagascar\" = \"Madagascar\";\n"
"\"Malawi\" = \"Malawi\";\n"
"\"Malaysia\" = \"Malaisie\";\n"
"\"Maldives\" = \"Maldives\";\n"
"\"Mali\" = \"Mali\";\n"
"\"Malta\" = \"Malte\";\n"
"\"Manual Configuration\" = \"Manual Configuration\";\n"
"\"Marshall Islands\" = \"Îles Marshall\";\n"
"\"Martinique\" = \"Martinique\";\n"
"\"Mauritania\" = \"Mauritanie\";\n"
"\"Mauritius\" = \"Maurice\";\n"
"\"Mayotte\" = \"Mayotte\";\n"
"\"Media\" = \"Médias\";\n"
"\"Mexico\" = \"Mexique\";\n"
"\"Micronesia (Federated States of)\" = \"Micronésie (États fédérés de)\";\n"
"\"Missing action.\" = \"Manque d'action.\";\n"
"\"Missing job ID.\" = \"Missing job ID.\";\n"
"\"Missing network name.\" = \"Missing network name.\";\n"
"\"Missing private key.\" = \"La clé privée manquante.\";\n"
"\"Moldova, Republic of\" = \"République de Moldova\";\n"
"\"Monaco\" = \"Monaco\";\n"
"\"Mongolia\" = \"Mongolie\";\n"
"\"Montenegro\" = \"Monténégro\";\n"
"\"Montserrat\" = \"Montserrat\";\n"
"\"Morocco\" = \"Maroc\";\n"
"\"Mozambique\" = \"Mozambique\";\n"
"\"Myanmar\" = \"Myanmar\";\n"
"\"Name\" = \"Nom\";\n"
"\"Namibia\" = \"Namibie\";\n"
"\"Nauru\" = \"Nauru\";\n"
"\"Nepal\" = \"Népal\";\n"
"\"Netherlands\" = \"Pays-Bas\";\n"
"\"Network\" = \"Network\";\n"
"\"Network Printer\" = \"Imprimeur réseau\";\n"
"\"Networking\" = \"Networking\";\n"
"\"New Caledonia\" = \"Nouvelle-Calédonie\";\n"
"\"New Zealand\" = \"Nouvelle-Zélande\";\n"
"\"Nicaragua\" = \"Nicaragua\";\n"
"\"Niger\" = \"Niger\";\n"
"\"Nigeria\" = \"Nigéria\";\n"
"\"Niue\" = \"Nioué\";\n"
"\"No default printer set.\" = \"Aucun jeu d'imprimante par défaut.\";\n"
"\"No jobs in history.\" = \"Pas de travail dans l'histoire.\";\n"
"\"Norfolk Island\" = \"Norfolk Island\";\n"
"\"North Macedonia\" = \"Macédoine\";\n"
"\"Northern Mariana Islands\" = \"Îles Mariannes du Nord\";\n"
"\"Norway\" = \"Norvège\";\n"
"\"Not set\" = \"Pas réglé\";\n"
"\"Off\" = \"Off\";\n"
"\"Offset\" = \"Offset\";\n"
"\"Oman\" = \"Oman\";\n"
"\"Options:\" = \"Options:\";\n"
"\"Organization\" = \"Organisation\";\n"
"\"Organization Name\" = \"Nom de l ' Organisation\";\n"
"\"Other Settings\" = \"Autres paramètres\";\n"
"\"Pakistan\" = \"Pakistan\";\n"
"\"Palau\" = \"Palaos\";\n"
"\"Palestine, State of\" = \"Palestine, État\";\n"
"\"Panama\" = \"Panama\";\n"
"\"Papua New Guinea\" = \"Papouasie-Nouvelle-Guinée\";\n"
"\"Paraguay\" = \"Paraguay\";\n"
"\"Password\" = \"Mot de passe\";\n"
"\"Password changed.\" = \"Le mot de passe a changé.\";\n"
"\"Password must be at least eight characters long and contain at least one uppercase letter, one lowercase letter, and one digit.\" = \"Le mot de passe doit avoir au moins huit caractères de long et contenir au moins une lettre majuscule, une lettre minuscule et un chiffre.\";\n"
"\"Passwords do not match.\" = \"Les mots de passe ne correspondent pas.\";\n"
"\"Pause Printing\" = \"Impression sur la douleur\";\n"
"\"Peru\" = \"Pérou\";\n"
"\"Philippines\" = \"Philippines\";\n"
"\"Pitcairn\" = \"Pitcairn\";\n"
"\"Please enter a hostname or IP address for the printer.\" = \"Veuillez saisir un nom d'hôte ou une adresse IP pour l'imprimante.\";\n"
"\"Please enter a printer name.\" = \"Veuillez entrer un nom d'imprimante.\";\n"
"\"Please select a device.\" = \"Veuillez sélectionner un appareil.\";\n"
"\"Please select a driver.\" = \"Veuillez sélectionner un pilote.\";\n"
"\"Please select a valid log level.\" = \"Veuillez sélectionner un niveau de journal valide.\";\n"
"\"Poland\" = \"Pologne\";\n"
"\"Portrait\" = \"Portrait\";\n"
"\"Portugal\" = \"Portugal\";\n"
"\"Primary DNS\" = \"Primary DNS\";\n"
"\"Print Group\" = \"Groupe d ' impression\";\n"
"\"Print Test Page\" = \"Page d ' essai\";\n"
"\"Print job options:\" = \"Imprimer les options d'emploi:\";\n"
"\"Printer identified.\" = \"Imprimante identifiée.\";\n"
"\"Printer is currently active.\" = \"L'imprimante est actuellement active.\";\n"
"\"Printer names must start with a letter or underscore and cannot contain special characters.\" = \"Les noms d'imprimante doivent commencer par une lettre ou un soulignement et ne peuvent contenir des caractères spéciaux.\";\n"
"\"Printer options:\" = \"Options d'impression:\";\n"
"\"Printer paused.\" = \"Imprimante pause.\";\n"
"\"Printer pausing.\" = \"Imprimante.\";\n"
"\"Printer resuming.\" = \"L'imprimante reprend.\";\n"
"\"Printers\" = \"Imprimantes\";\n"
"\"Printing Defaults\" = \"Défauts d'impression\";\n"
"\"Puerto Rico\" = \"Porto Rico\";\n"
"\"Qatar\" = \"Qatar\";\n"
"\"Queued %s\" = \"Queued %s\";\n"
"\"Release Held New Jobs\" = \"Release Held New Jobs\";\n"
"\"Release Job\" = \"Release Job\";\n"
"\"Released held new jobs.\" = \"Released held new jobs.\";\n"
"\"Reprint Job\" = \"Reprint Job\";\n"
"\"Reprinted job.\" = \"Reprinted job.\";\n"
"\"Resume Printing\" = \"Récupérer l'impression\";\n"
"\"Reverse Landscape\" = \"Paysage\";\n"
"\"Reverse Portrait\" = \"Portrait\";\n"
"\"Romania\" = \"Roumanie\";\n"
/* Running, STATE since DATE REASONS */
"\"Running, %s since %s%s.\" = \"Courant, %s depuis %s %s .\";\n"
"\"Russian Federation\" = \"Fédération de Russie\";\n"
"\"Rwanda\" = \"Rwanda\";\n"
"\"Réunion\" = \"Runion\";\n"
"\"Saint Barthélemy\" = \"Saint-Barthlemy\";\n"
"\"Saint Helena, Ascension and Tristan da Cunha\" = \"Sainte-Hélène, Ascension et Tristan da Cunha\";\n"
"\"Saint Kitts and Nevis\" = \"Saint-Kitts-et-Nevis\";\n"
"\"Saint Lucia\" = \"Sainte-Lucie\";\n"
"\"Saint Martin (French part)\" = \"Saint Martin (partie française)\";\n"
"\"Saint Pierre and Miquelon\" = \"Saint Pierre et Miquelon\";\n"
"\"Saint Vincent and the Grenadines\" = \"Saint-Vincent-et-les Grenadines\";\n"
"\"Samoa\" = \"Samoa\";\n"
"\"San Marino\" = \"Saint-Marin\";\n"
"\"Sao Tome and Principe\" = \"Sao Tomé-et-Principe\";\n"
"\"Saudi Arabia\" = \"Saudi Arabia\";\n"
"\"Save Changes\" = \"Save Changes\";\n"
"\"Secondary DNS\" = \"Secondary DNS\";\n"
"\"Security\" = \"Sécurité\";\n"
"\"Select Driver\" = \"Sélectionnez le pilote\";\n"
"\"Senegal\" = \"Sénégal\";\n"
"\"Serbia\" = \"Serbie\";\n"
"\"Server is not running.\" = \"Le serveur ne fonctionne pas.\";\n"
"\"Set Access Password\" = \"Set Access Password\";\n"
"\"Set as Default\" = \"Par défaut\";\n"
"\"Seychelles\" = \"Seychelles\";\n"
"\"Sierra Leone\" = \"Sierra Leone\";\n"
"\"Singapore\" = \"Singapour\";\n"
"\"Sint Maarten (Dutch part)\" = \"Sint Maarten (partie néerlandaise)\";\n"
"\"Slovakia\" = \"Slovaquie\";\n"
"\"Slovenia\" = \"Slovénie\";\n"
"\"Solomon Islands\" = \"Îles Salomon\";\n"
"\"Somalia\" = \"Somalie\";\n"
"\"South Africa\" = \"Afrique du Sud\";\n"
"\"South Georgia and the South Sandwich Islands\" = \"Géorgie du Sud et îles Sandwich du Sud\";\n"
"\"South Sudan\" = \"Soudan du Sud\";\n"
"\"Spain\" = \"Espagne\";\n"
"\"Sri Lanka\" = \"Sri Lanka\";\n"
"\"Started %s\" = \"Started %s\";\n"
"\"Status\" = \"État\";\n"
"\"Sub-commands:\" = \"Sous-commandes :\";\n"
"\"Sudan\" = \"Soudan\";\n"
"\"Supplies\" = \"Fournitures\";\n"
"\"Suriname\" = \"Suriname\";\n"
"\"Svalbard and Jan Mayen\" = \"Svalbard et Jan Mayen\";\n"
"\"Sweden\" = \"Suède\";\n"
"\"Switzerland\" = \"Suisse\";\n"
"\"Syrian Arab Republic\" = \"République arabe syrienne\";\n"
"\"Taiwan, Province of China\" = \"Taiwan, Province de Chine\";\n"
"\"Tajikistan\" = \"Tadjikistan\";\n"
"\"Tanzania, United Republic of\" = \"République-Unie de Tanzanie\";\n"
"\"Test page printed.\" = \"Page d'essai imprimée.\";\n"
"\"Thailand\" = \"Thaïlande\";\n"
"\"This form creates a certificate signing request ('CSR') that you can send to a Certificate Authority ('CA') to obtain a trusted TLS certificate. The private key is saved separately for use with the certificate you get from the CA.\" = \"Ce formulaire crée une demande de signature de certificat (SRC) que vous pouvez envoyer à une autorité de certification (CA) pour obtenir un certificat de SDF fiable. La clé privée est sauvegardée séparément pour utilisation avec le certificat que vous obtenez de l'AC.\";\n"
"\"This form creates a new 'self-signed' TLS certificate for secure printing. Self-signed certificates are not automatically trusted by web browsers.\" = \"Ce formulaire crée un nouveau certificat TLS autosigné pour l'impression sécurisée. Les certificats autosignés ne sont pas automatiquement fiables par les navigateurs Web.\";\n"
"\"This form will install a trusted TLS certificate you have obtained from a Certificate Authority ('CA'). Once installed, it will be used immediately.\" = \"Ce formulaire installera un certificat TLS de confiance que vous avez obtenu auprès d'une autorité de certification (CA). Une fois installé, il sera utilisé immédiatement.\";\n"
"\"Timor-Leste\" = \"Timor-Leste\";\n"
"\"Togo\" = \"Togo\";\n"
"\"Tokelau\" = \"Tokélaou\";\n"
"\"Tonga\" = \"Tonga\";\n"
"\"Trinidad and Tobago\" = \"Trinité-et-Tobago\";\n"
"\"Tunisia\" = \"Tunisie\";\n"
"\"Turkey\" = \"Turquie\";\n"
"\"Turkmenistan\" = \"Turkménistan\";\n"
"\"Turks and Caicos Islands\" = \"Îles Turques et Caïques\";\n"
"\"Tuvalu\" = \"Tuvalu\";\n"
"\"Uganda\" = \"Ouganda\";\n"
"\"Ukraine\" = \"Ukraine\";\n"
"\"Unable to access test print file.\" = \"Impossible d'accéder au fichier d'impression de test.\";\n"
"\"Unable to copy print job.\" = \"Incapable de copier le travail.\";\n"
"\"Unable to create certificate request.\" = \"Impossible de créer une demande de certificat.\";\n"
"\"Unable to create certificate.\" = \"Impossible de créer un certificat.\";\n"
"\"Unable to create test print job.\" = \"Impossible de créer un travail d'impression test.\";\n"
"\"Unable to identify printer.\" = \"Incapable d'identifier l'imprimante.\";\n"
"\"Unable to lookup address.\" = \"Incapable de regarder l'adresse.\";\n"
"\"Unable to use that driver.\" = \"Incapable d'utiliser ce conducteur.\";\n"
"\"United Arab Emirates\" = \"Émirats arabes unis\";\n"
"\"United Kingdom\" = \"Royaume-Uni\";\n"
"\"United Kingdom of Great Britain and Northern Ireland\" = \"Royaume-Uni de Grande-Bretagne et d ' Irlande du Nord\";\n"
"\"United States Minor Outlying Islands\" = \"United States Minor Outlying Islands\";\n"
"\"United States of America\" = \"États-Unis d ' Amérique\";\n"
"\"Unknown\" = \"Inconnu\";\n"
"\"Unknown action.\" = \"Action inconnue.\";\n"
"\"Unknown form action.\" = \"Inconnue.\";\n"
"\"Unknown form request.\" = \"Demande de formulaire inconnue.\";\n"
"\"Updating Network Configuration\" = \"Updating Network Configuration\";\n"
"\"Uruguay\" = \"Uruguay\";\n"
"\"Usage: %s SUB-COMMAND [OPTIONS] [FILENAME]\\n\" = \"Utilisation: %s SUB-COMMAND [OPTIONS] [FILENAME]\\n\";\n"
"\"Use My Position\" = \"Utiliser ma position\";\n"
"\"Users\" = \"Utilisateurs\";\n"
"\"Uzbekistan\" = \"Ouzbékistan\";\n"
"\"Vanuatu\" = \"Vanuatu\";\n"
"\"Venezuela (Bolivarian Republic of)\" = \"Venezuela (République bolivarienne du)\";\n"
"\"Version %s\" = \"Version %s\";\n"
"\"Viet Nam\" = \"Viet Nam\";\n"
"\"View Logs\" = \"Voir les logos\";\n"
"\"Virgin Islands (British)\" = \"Îles Vierges britanniques\";\n"
"\"Virgin Islands (U.S.)\" = \"Îles Vierges américaines\";\n"
"\"Wallis and Futuna\" = \"Wallis et Futuna\";\n"
"\"Warning\" = \"Avertissement\";\n"
"\"Western Sahara\" = \"Sahara occidental\";\n"
"\"Wi-Fi Configuration\" = \"Configuration Wi-Fi\";\n"
"\"Wi-Fi Network\" = \"Wi-Fi Network\";\n"
"\"Width\" = \"Largeur\";\n"
"\"Wrong old password.\" = \"Un vieux mot de passe.\";\n"
"\"Yemen\" = \"Yémen\";\n"
"\"Zambia\" = \"Zambie\";\n"
"\"Zimbabwe\" = \"Zimbabwe\";\n"
"\"at %02d:%02d:%02d\" = \"at %02d:%02d:%02d\";\n"
/* IPP attribute, keyword, and enum (integer) localizations */
"\"copies\" = \"Nombre de copies\";\n"
"\"default printer\" = \"imprimante par défaut\";\n"
"\"finishings\" = \"Finisher\";\n"
"\"finishings.10\" = \"Fold\";\n"
"\"finishings.100\" = \"Z pli\";\n"
"\"finishings.101\" = \"Ingénierie pli Z\";\n"
"\"finishings.11\" = \"Coupe\";\n"
"\"finishings.12\" = \"Bale\";\n"
"\"finishings.13\" = \"Booklet maker\";\n"
"\"finishings.15\" = \"Coat\";\n"
"\"finishings.16\" = \"Laminate\";\n"
"\"finishings.20\" = \"Staple top gauche\";\n"
"\"finishings.21\" = \"En bas gauche\";\n"
"\"finishings.22\" = \"Staple top right\";\n"
"\"finishings.23\" = \"En bas droit\";\n"
"\"finishings.24\" = \"Couture gauche\";\n"
"\"finishings.25\" = \"Point de bord\";\n"
"\"finishings.26\" = \"Couture droite\";\n"
"\"finishings.27\" = \"Point inférieur\";\n"
"\"finishings.28\" = \"2 agrafes à gauche\";\n"
"\"finishings.29\" = \"2 agrafes sur le dessus\";\n"
"\"finishings.3\" = \"None\";\n"
"\"finishings.30\" = \"2 agrafes à droite\";\n"
"\"finishings.31\" = \"2 agrafes en bas\";\n"
"\"finishings.32\" = \"3 agrafes à gauche\";\n"
"\"finishings.33\" = \"3 agrafes sur le dessus\";\n"
"\"finishings.34\" = \"3 agrafes à droite\";\n"
"\"finishings.35\" = \"3 agrafes en bas\";\n"
"\"finishings.4\" = \"Staple\";\n"
"\"finishings.5\" = \"Punch\";\n"
"\"finishings.50\" = \"Bind gauche\";\n"
"\"finishings.51\" = \"Bind top\";\n"
"\"finishings.52\" = \"Bind right\";\n"
"\"finishings.53\" = \"Bind bottom\";\n"
"\"finishings.6\" = \"Couverture\";\n"
"\"finishings.60\" = \"Couper après chaque page\";\n"
"\"finishings.61\" = \"Couper après chaque document\";\n"
"\"finishings.62\" = \"Couper après chaque set\";\n"
"\"finishings.63\" = \"Couper après le travail\";\n"
"\"finishings.7\" = \"Bind\";\n"
"\"finishings.70\" = \"Punch top left\";\n"
"\"finishings.71\" = \"Punch bottom left\";\n"
"\"finishings.72\" = \"Punch top right\";\n"
"\"finishings.73\" = \"Poinçon bas droit\";\n"
"\"finishings.74\" = \"2 trous à gauche\";\n"
"\"finishings.75\" = \"Top 2 trous\";\n"
"\"finishings.76\" = \"2 trous à droite\";\n"
"\"finishings.77\" = \"2 trous en bas\";\n"
"\"finishings.78\" = \"3 trous à gauche\";\n"
"\"finishings.79\" = \"Poinçon 3 trous\";\n"
"\"finishings.8\" = \"Triste couture\";\n"
"\"finishings.80\" = \"3 trous à droite\";\n"
"\"finishings.81\" = \"3 trous en bas\";\n"
"\"finishings.82\" = \"4 trous à gauche\";\n"
"\"finishings.83\" = \"Top 4 trous\";\n"
"\"finishings.84\" = \"4 trous à droite\";\n"
"\"finishings.85\" = \"4 trous en bas\";\n"
"\"finishings.86\" = \"Poinçon multi trous à gauche\";\n"
"\"finishings.87\" = \"Poinçon multi trous\";\n"
"\"finishings.88\" = \"Poinçon multifonctions à droite\";\n"
"\"finishings.89\" = \"Poinçon multi-trouilles\";\n"
"\"finishings.9\" = \"Bordure\";\n"
"\"finishings.90\" = \"Repli d ' accord\";\n"
"\"finishings.91\" = \"Double porte pliant\";\n"
"\"finishings.92\" = \"Porte pliant\";\n"
"\"finishings.93\" = \"Demi pli\";\n"
"\"finishings.94\" = \"Half Z\";\n"
"\"finishings.95\" = \"Repli de la porte gauche\";\n"
"\"finishings.96\" = \"Lit pli\";\n"
"\"finishings.97\" = \"Repli parallèle\";\n"
"\"finishings.98\" = \"Tableau pli\";\n"
"\"finishings.99\" = \"Tour droit\";\n"
"\"holding new jobs\" = \"holding new jobs\";\n"
"\"job-state-reasons.aborted-by-system\" = \"Arrête.\";\n"
"\"job-state-reasons.compression-error\" = \"Erreur de décompression.\";\n"
"\"job-state-reasons.document-format-error\" = \"Erreur de format de document.\";\n"
"\"job-state-reasons.document-password-error\" = \"Erreur de mot de passe.\";\n"
"\"job-state-reasons.document-permission-error\" = \"Erreur de permission de document.\";\n"
"\"job-state-reasons.document-unprintable-error\" = \"Document erreur imprimable.\";\n"
"\"job-state-reasons.errors-detected\" = \"Erreurs détectées.\";\n"
"\"job-state-reasons.job-canceled-at-device\" = \"Annulé à l'imprimante.\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"Annulé par l'utilisateur.\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"Imprimé.\";\n"
"\"job-state-reasons.job-completed-with-errors\" = \"Imprimé avec des erreurs.\";\n"
"\"job-state-reasons.job-completed-with-warnings\" = \"Imprimé avec des avertissements.\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"Données insuffisantes.\";\n"
"\"job-state-reasons.job-fetchable\" = \"Incroyable.\";\n"
"\"job-state-reasons.job-incoming\" = \"J'arrive.\";\n"
"\"job-state-reasons.job-printing\" = \"Impression.\";\n"
"\"job-state-reasons.job-queued\" = \"Préparer à imprimer.\";\n"
"\"job-state-reasons.job-spooling\" = \"Covoiturage.\";\n"
"\"job-state-reasons.none\" = \"En attente.\";\n"
"\"job-state-reasons.printer-stopped\" = \"Imprimante hors ligne.\";\n"
"\"job-state-reasons.printer-stopped-partly\" = \"Imprimante partiellement arrêtée.\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"Arrête.\";\n"
"\"job-state-reasons.queued-in-device\" = \"Prêt.\";\n"
"\"job-state-reasons.warnings-detected\" = \"Avertissements détectés.\";\n"
"\"job-state.3\" = \"En attente\";\n"
"\"job-state.4\" = \"tenue\";\n"
"\"job-state.5\" = \"Traitement\";\n"
"\"job-state.6\" = \"Arrêté\";\n"
"\"job-state.7\" = \"Annulé\";\n"
"\"job-state.8\" = \"Avortée\";\n"
"\"job-state.9\" = \"Complété\";\n"
"\"joining\" = \"rejoindre\";\n"
"\"media\" = \"Médias\";\n"
"\"media-col\" = \"Médias\";\n"
"\"media-size\" = \"Taille des médias\";\n"
"\"media-size-name\" = \"Taille des médias\";\n"
"\"media-source\" = \"Input Tray\";\n"
"\"media-source.alternate\" = \"Alternate\";\n"
"\"media-source.alternate-roll\" = \"Roulement alternatif\";\n"
"\"media-source.auto\" = \"Automatique\";\n"
"\"media-source.bottom\" = \"Bottom\";\n"
"\"media-source.by-pass-tray\" = \"Plateau polyvalent\";\n"
"\"media-source.center\" = \"Center\";\n"
"\"media-source.disc\" = \"Disc\";\n"
"\"media-source.envelope\" = \"Enveloppe\";\n"
"\"media-source.hagaki\" = \"Hagaki\";\n"
"\"media-source.large-capacity\" = \"Grande capacité\";\n"
"\"media-source.left\" = \"Gauche\";\n"
"\"media-source.main\" = \"Main\";\n"
"\"media-source.main-roll\" = \"Roulement principal\";\n"
"\"media-source.manual\" = \"Manuel\";\n"
"\"media-source.middle\" = \"Moyen-Orient\";\n"
"\"media-source.photo\" = \"Photo\";\n"
"\"media-source.rear\" = \"Arrière\";\n"
"\"media-source.right\" = \"Droit\";\n"
"\"media-source.roll-1\" = \"Roll 1\";\n"
"\"media-source.roll-10\" = \"Roll 10\";\n"
"\"media-source.roll-2\" = \"Roll 2\";\n"
"\"media-source.roll-3\" = \"Roll 3\";\n"
"\"media-source.roll-4\" = \"Roll 4\";\n"
"\"media-source.roll-5\" = \"Roll 5\";\n"
"\"media-source.roll-6\" = \"Roll 6\";\n"
"\"media-source.roll-7\" = \"Roll 7\";\n"
"\"media-source.roll-8\" = \"Roll 8\";\n"
"\"media-source.roll-9\" = \"Roll 9\";\n"
"\"media-source.side\" = \"Side\";\n"
"\"media-source.top\" = \"Top\";\n"
"\"media-source.tray-1\" = \"Tray 1\";\n"
"\"media-source.tray-10\" = \"Tray 10\";\n"
"\"media-source.tray-11\" = \"Tray 11\";\n"
"\"media-source.tray-12\" = \"Tray 12\";\n"
"\"media-source.tray-13\" = \"Tray 13\";\n"
"\"media-source.tray-14\" = \"Tray 14\";\n"
"\"media-source.tray-15\" = \"Tray 15\";\n"
"\"media-source.tray-16\" = \"Tray 16\";\n"
"\"media-source.tray-17\" = \"Tray 17\";\n"
"\"media-source.tray-18\" = \"Tray 18\";\n"
"\"media-source.tray-19\" = \"Tray 19\";\n"
"\"media-source.tray-2\" = \"Tray 2\";\n"
"\"media-source.tray-20\" = \"Tray 20\";\n"
"\"media-source.tray-3\" = \"Tray 3\";\n"
"\"media-source.tray-4\" = \"Tray 4\";\n"
"\"media-source.tray-5\" = \"Tray 5\";\n"
"\"media-source.tray-6\" = \"Tray 6\";\n"
"\"media-source.tray-7\" = \"Tray 7\";\n"
"\"media-source.tray-8\" = \"Tray 8\";\n"
"\"media-source.tray-9\" = \"Tray 9\";\n"
"\"media-tracking\" = \"Suivi des médias\";\n"
"\"media-tracking.continuous\" = \"Continuous\";\n"
"\"media-tracking.gap\" = \"Gap\";\n"
"\"media-tracking.mark\" = \"Mark\";\n"
"\"media-tracking.web\" = \"Web\";\n"
"\"media-type\" = \"Type de média\";\n"
"\"media-type.aluminum\" = \"Aluminium\";\n"
"\"media-type.auto\" = \"Automatique\";\n"
"\"media-type.back-print-film\" = \"Film de retour\";\n"
"\"media-type.cardboard\" = \"Cardboard\";\n"
"\"media-type.cardstock\" = \"Cardstock\";\n"
"\"media-type.cd\" = \"CD\";\n"
"\"media-type.continuous\" = \"Continuous\";\n"
"\"media-type.continuous-long\" = \"Longtemps continu\";\n"
"\"media-type.continuous-short\" = \"Short continu\";\n"
"\"media-type.corrugated-board\" = \"Plan d ' action\";\n"
"\"media-type.disc\" = \"Disque optique\";\n"
"\"media-type.disc-glossy\" = \"Disque optique brillant\";\n"
"\"media-type.disc-high-gloss\" = \"Disque optique à haute brillance\";\n"
"\"media-type.disc-matte\" = \"Disque optique Matte\";\n"
"\"media-type.disc-satin\" = \"Disque optique satin\";\n"
"\"media-type.disc-semi-gloss\" = \"Disque optique semi-brillant\";\n"
"\"media-type.double-wall\" = \"Double mur\";\n"
"\"media-type.dry-film\" = \"Film sec\";\n"
"\"media-type.dvd\" = \"DVD\";\n"
"\"media-type.embossing-foil\" = \"Feuille d ' emballage\";\n"
"\"media-type.end-board\" = \"End board\";\n"
"\"media-type.envelope\" = \"Enveloppe\";\n"
"\"media-type.envelope-archival\" = \"Enveloppe d ' archivage\";\n"
"\"media-type.envelope-bond\" = \"Enveloppe d ' obligations\";\n"
"\"media-type.envelope-coated\" = \"Enveloppe revêtue\";\n"
"\"media-type.envelope-cotton\" = \"Enveloppe de coton\";\n"
"\"media-type.envelope-fine\" = \"Enveloppe fine\";\n"
"\"media-type.envelope-heavyweight\" = \"Enveloppe lourde\";\n"
"\"media-type.envelope-inkjet\" = \"Enveloppe de jet d ' encre\";\n"
"\"media-type.envelope-lightweight\" = \"Enveloppe légère\";\n"
"\"media-type.envelope-plain\" = \"Enveloppe plaine\";\n"
"\"media-type.envelope-preprinted\" = \"Enveloppe préimprimée\";\n"
"\"media-type.envelope-window\" = \"Enveloppe de fenêtre\";\n"
"\"media-type.fabric\" = \"Tissu\";\n"
"\"media-type.fabric-archival\" = \"Tissu d ' archivage\";\n"
"\"media-type.fabric-glossy\" = \"Tissu brillant\";\n"
"\"media-type.fabric-high-gloss\" = \"Tissu brillant\";\n"
"\"media-type.fabric-matte\" = \"Tissu mat\";\n"
"\"media-type.fabric-semi-gloss\" = \"Tissu semi-gloss\";\n"
"\"media-type.fabric-waterproof\" = \"Tissu étanche\";\n"
"\"media-type.film\" = \"Film\";\n"
"\"media-type.flexo-base\" = \"Base Flexo\";\n"
"\"media-type.flexo-photo-polymer\" = \"Flexo photo polymère\";\n"
"\"media-type.flute\" = \"Flute\";\n"
"\"media-type.foil\" = \"Foil\";\n"
"\"media-type.full-cut-tabs\" = \"onglets de coupe complète\";\n"
"\"media-type.glass\" = \"Verre\";\n"
"\"media-type.glass-colored\" = \"Verre coloré\";\n"
"\"media-type.glass-opaque\" = \"Verre opaque\";\n"
"\"media-type.glass-surfaced\" = \"Verre en surface\";\n"
"\"media-type.glass-textured\" = \"Verre texturé\";\n"
"\"media-type.gravure-cylinder\" = \"Boutet d ' échappement\";\n"
"\"media-type.image-setter-paper\" = \"Image setter paper\";\n"
"\"media-type.imaging-cylinder\" = \"Cylindre d ' image\";\n"
"\"media-type.labels\" = \"Étiquettes\";\n"
"\"media-type.labels-colored\" = \"Étiquettes colorées\";\n"
"\"media-type.labels-glossy\" = \"Étiquettes brillantes\";\n"
"\"media-type.labels-high-gloss\" = \"Étiquettes haute brillance\";\n"
"\"media-type.labels-inkjet\" = \"Étiquettes à jet d ' encre\";\n"
"\"media-type.labels-matte\" = \"Étiquettes Matte\";\n"
"\"media-type.labels-permanent\" = \"Étiquettes permanentes\";\n"
"\"media-type.labels-satin\" = \"labels satins\";\n"
"\"media-type.labels-security\" = \"Étiquettes de sécurité\";\n"
"\"media-type.labels-semi-gloss\" = \"Étiquettes semi-brillantes\";\n"
"\"media-type.laminating-foil\" = \"Feuille de plastification\";\n"
"\"media-type.letterhead\" = \"Letterhead\";\n"
"\"media-type.metal\" = \"Métal\";\n"
"\"media-type.metal-glossy\" = \"Metal glossy\";\n"
"\"media-type.metal-high-gloss\" = \"Metal high gloss\";\n"
"\"media-type.metal-matte\" = \"Métal mat\";\n"
"\"media-type.metal-satin\" = \"Metal satin\";\n"
"\"media-type.metal-semi-gloss\" = \"Metal semi gloss\";\n"
"\"media-type.mounting-tape\" = \"Bande de montage\";\n"
"\"media-type.multi-layer\" = \"Multi calque\";\n"
"\"media-type.multi-part-form\" = \"Forme multipartite\";\n"
"\"media-type.other\" = \"Autres\";\n"
"\"media-type.paper\" = \"Paper\";\n"
"\"media-type.photographic\" = \"Photo paper\";\n"
"\"media-type.photographic-archival\" = \"Archival photographique\";\n"
"\"media-type.photographic-film\" = \"Photo film\";\n"
"\"media-type.photographic-glossy\" = \"Papier photo Glossy\";\n"
"\"media-type.photographic-high-gloss\" = \"Papier photo de haute brillance\";\n"
"\"media-type.photographic-matte\" = \"Matte photo paper\";\n"
"\"media-type.photographic-satin\" = \"Papier photo satin\";\n"
"\"media-type.photographic-semi-gloss\" = \"Papier photo semi-gloss\";\n"
"\"media-type.plastic\" = \"Plastique\";\n"
"\"media-type.plastic-archival\" = \"Archival plastique\";\n"
"\"media-type.plastic-colored\" = \"Couleur plastique\";\n"
"\"media-type.plastic-glossy\" = \"Matière plastique brillante\";\n"
"\"media-type.plastic-high-gloss\" = \"Plastique haute brillance\";\n"
"\"media-type.plastic-matte\" = \"mat plastique\";\n"
"\"media-type.plastic-satin\" = \"Satin plastique\";\n"
"\"media-type.plastic-semi-gloss\" = \"Plastique semi brillant\";\n"
"\"media-type.plate\" = \"Plate-forme\";\n"
"\"media-type.polyester\" = \"Polyester\";\n"
"\"media-type.pre-cut-tabs\" = \"onglets pré-coupés\";\n"
"\"media-type.roll\" = \"Roll\";\n"
"\"media-type.screen\" = \"Écran\";\n"
"\"media-type.screen-paged\" = \"Écran paged\";\n"
"\"media-type.self-adhesive\" = \"Autocollant\";\n"
"\"media-type.self-adhesive-film\" = \"Film adhésif auto-adhésif\";\n"
"\"media-type.shrink-foil\" = \"Feuille de film\";\n"
"\"media-type.single-face\" = \"Face unique\";\n"
"\"media-type.single-wall\" = \"Mur unique\";\n"
"\"media-type.sleeve\" = \"Sleeve\";\n"
"\"media-type.stationery\" = \"Papeterie\";\n"
"\"media-type.stationery-archival\" = \"Arche de papeterie\";\n"
"\"media-type.stationery-coated\" = \"Coated paper\";\n"
"\"media-type.stationery-cotton\" = \"Coton papeterie\";\n"
"\"media-type.stationery-fine\" = \"Vellum paper\";\n"
"\"media-type.stationery-heavyweight\" = \"Papier lourd\";\n"
"\"media-type.stationery-heavyweight-coated\" = \"Stationnement lourd enduit\";\n"
"\"media-type.stationery-inkjet\" = \"Papier à jet d'encre papeterie\";\n"
"\"media-type.stationery-letterhead\" = \"Letterhead\";\n"
"\"media-type.stationery-lightweight\" = \"Papier léger\";\n"
"\"media-type.stationery-preprinted\" = \"Document préimprimé\";\n"
"\"media-type.stationery-prepunched\" = \"Papier poinçonné\";\n"
"\"media-type.tab-stock\" = \"Stock\";\n"
"\"media-type.tractor\" = \"Tractor\";\n"
"\"media-type.transfer\" = \"Transfert\";\n"
"\"media-type.transparency\" = \"Transparence\";\n"
"\"media-type.triple-wall\" = \"Mur triple\";\n"
"\"media-type.wet-film\" = \"Film humide\";\n"
"\"media.choice_iso_a4_210x297mm_na_letter_8.5x11in\" = \"A4 ou US Letter\";\n"
"\"media.iso_2a0_1189x1682mm\" = \"2a0\";\n"
"\"media.iso_a0_841x1189mm\" = \"A0\";\n"
"\"media.iso_a0x3_1189x2523mm\" = \"A0x3\";\n"
"\"media.iso_a10_26x37mm\" = \"A10\";\n"
"\"media.iso_a1_594x841mm\" = \"A1\";\n"
"\"media.iso_a1x3_841x1783mm\" = \"A1x3\";\n"
"\"media.iso_a1x4_841x2378mm\" = \"A1x4\";\n"
"\"media.iso_a2_420x594mm\" = \"A2\";\n"
"\"media.iso_a2x3_594x1261mm\" = \"A2x3\";\n"
"\"media.iso_a2x4_594x1682mm\" = \"A2x4\";\n"
"\"media.iso_a2x5_594x2102mm\" = \"A2x5\";\n"
"\"media.iso_a3-extra_322x445mm\" = \"A3 (extra)\";\n"
"\"media.iso_a3_297x420mm\" = \"A3\";\n"
"\"media.iso_a3x3_420x891mm\" = \"A3x3\";\n"
"\"media.iso_a3x4_420x1189mm\" = \"A3x4\";\n"
"\"media.iso_a3x5_420x1486mm\" = \"A3x5\";\n"
"\"media.iso_a3x6_420x1783mm\" = \"A3x6\";\n"
"\"media.iso_a3x7_420x2080mm\" = \"A3x7\";\n"
"\"media.iso_a4-extra_235.5x322.3mm\" = \"A4 (extra)\";\n"
"\"media.iso_a4-tab_225x297mm\" = \"A4 (tab)\";\n"
"\"media.iso_a4_210x297mm\" = \"A4\";\n"
"\"media.iso_a4x3_297x630mm\" = \"A4x3\";\n"
"\"media.iso_a4x4_297x841mm\" = \"A4x4\";\n"
"\"media.iso_a4x5_297x1051mm\" = \"A4x5\";\n"
"\"media.iso_a4x6_297x1261mm\" = \"A4x6\";\n"
"\"media.iso_a4x7_297x1471mm\" = \"A4x7\";\n"
"\"media.iso_a4x8_297x1682mm\" = \"A4x8\";\n"
"\"media.iso_a4x9_297x1892mm\" = \"A4x9\";\n"
"\"media.iso_a5-extra_174x235mm\" = \"A5 (extra)\";\n"
"\"media.iso_a5_148x210mm\" = \"A5\";\n"
"\"media.iso_a6_105x148mm\" = \"A6\";\n"
"\"media.iso_a7_74x105mm\" = \"A7\";\n"
"\"media.iso_a8_52x74mm\" = \"A8\";\n"
"\"media.iso_a9_37x52mm\" = \"A9\";\n"
"\"media.iso_b0_1000x1414mm\" = \"B0\";\n"
"\"media.iso_b10_31x44mm\" = \"B10\";\n"
"\"media.iso_b1_707x1000mm\" = \"B1\";\n"
"\"media.iso_b2_500x707mm\" = \"B2\";\n"
"\"media.iso_b3_353x500mm\" = \"B3\";\n"
"\"media.iso_b4_250x353mm\" = \"B4\";\n"
"\"media.iso_b5-extra_201x276mm\" = \"B5 (extra)\";\n"
"\"media.iso_b5_176x250mm\" = \"B5 Enveloppe\";\n"
"\"media.iso_b6_125x176mm\" = \"B6\";\n"
"\"media.iso_b6c4_125x324mm\" = \"B6/C4Envelope\";\n"
"\"media.iso_b7_88x125mm\" = \"B7\";\n"
"\"media.iso_b8_62x88mm\" = \"B8\";\n"
"\"media.iso_b9_44x62mm\" = \"B9\";\n"
"\"media.iso_c0_917x1297mm\" = \"C0 Enveloppe\";\n"
"\"media.iso_c10_28x40mm\" = \"C10 Enveloppe\";\n"
"\"media.iso_c1_648x917mm\" = \"C1 Enveloppe\";\n"
"\"media.iso_c2_458x648mm\" = \"C2 Enveloppe\";\n"
"\"media.iso_c3_324x458mm\" = \"C3 Enveloppe\";\n"
"\"media.iso_c4_229x324mm\" = \"C4 Enveloppe\";\n"
"\"media.iso_c5_162x229mm\" = \"C5 Enveloppe\";\n"
"\"media.iso_c6_114x162mm\" = \"C6 Enveloppe\";\n"
"\"media.iso_c6c5_114x229mm\" = \"C6/C5 Enveloppe\";\n"
"\"media.iso_c7_81x114mm\" = \"C7 Enveloppe\";\n"
"\"media.iso_c7c6_81x162mm\" = \"C7/C6 Enveloppe\";\n"
"\"media.iso_c8_57x81mm\" = \"C8 Enveloppe\";\n"
"\"media.iso_c9_40x57mm\" = \"C9 Enveloppe\";\n"
"\"media.iso_dl_110x220mm\" = \"DL Enveloppe\";\n"
"\"media.iso_ra0_860x1220mm\" = \"ISO RA0\";\n"
"\"media.iso_ra1_610x860mm\" = \"ISO RA1\";\n"
"\"media.iso_ra2_430x610mm\" = \"ISO RA2\";\n"
"\"media.iso_ra3_305x430mm\" = \"ISO RA3\";\n"
"\"media.iso_ra4_215x305mm\" = \"ISO RA4\";\n"
"\"media.iso_sra0_900x1280mm\" = \"ISO SRA0\";\n"
"\"media.iso_sra1_640x900mm\" = \"ISO SRA1\";\n"
"\"media.iso_sra2_450x640mm\" = \"ISO SRA2\";\n"
"\"media.iso_sra3_320x450mm\" = \"ISO SRA3\";\n"
"\"media.iso_sra4_225x320mm\" = \"ISO SRA4\";\n"
"\"media.jis_b0_1030x1456mm\" = \"JIS B0\";\n"
"\"media.jis_b10_32x45mm\" = \"JIS B10\";\n"
"\"media.jis_b1_728x1030mm\" = \"JIS B1\";\n"
"\"media.jis_b2_515x728mm\" = \"JIS B2\";\n"
"\"media.jis_b3_364x515mm\" = \"JIS B3\";\n"
"\"media.jis_b4_257x364mm\" = \"JIS B4\";\n"
"\"media.jis_b5_182x257mm\" = \"JIS B5\";\n"
"\"media.jis_b6_128x182mm\" = \"JIS B6\";\n"
"\"media.jis_b7_91x128mm\" = \"JIS B7\";\n"
"\"media.jis_b8_64x91mm\" = \"JIS B8\";\n"
"\"media.jis_b9_45x64mm\" = \"JIS B9\";\n"
"\"media.jis_exec_216x330mm\" = \"JIS Executive\";\n"
"\"media.jpn_chou2_111.1x146mm\" = \"Enveloppe Chou 2\";\n"
"\"media.jpn_chou3_120x235mm\" = \"Enveloppe Chou 3\";\n"
"\"media.jpn_chou40_90x225mm\" = \"Enveloppe Chou 40\";\n"
"\"media.jpn_chou4_90x205mm\" = \"Enveloppe Chou 4\";\n"
"\"media.jpn_hagaki_100x148mm\" = \"Hagaki\";\n"
"\"media.jpn_kahu_240x322.1mm\" = \"Enveloppe Kahu\";\n"
"\"media.jpn_kaku2_240x332mm\" = \"Enveloppe Kahu 2\";\n"
"\"media.jpn_oufuku_148x200mm\" = \"Oufuku Répondre Postcard\";\n"
"\"media.jpn_you4_105x235mm\" = \"Enveloppe Vous 4\";\n"
"\"media.na_a2_4.375x5.75in\" = \"Enveloppe A2\";\n"
"\"media.na_c5_6.5x9.5in\" = \"Enveloppe C5\";\n"
"\"media.na_executive_7.25x10.5in\" = \"Executive\";\n"
"\"media.na_fanfold-eur_8.5x12in\" = \"European Fanfold\";\n"
"\"media.na_fanfold-us_11x14.875in\" = \"Fanfold\";\n"
"\"media.na_foolscap_8.5x13in\" = \"Foolscap\";\n"
"\"media.na_invoice_5.5x8.5in\" = \"État\";\n"
"\"media.na_legal-extra_9.5x15in\" = \"US Legal (Extra)\";\n"
"\"media.na_legal_8.5x14in\" = \"US Legal\";\n"
"\"media.na_letter-extra_9.5x12in\" = \"Lettre américaine (Extra)\";\n"
"\"media.na_letter-plus_8.5x12.69in\" = \"Lettre américaine (Plus)\";\n"
"\"media.na_letter_8.5x11in\" = \"US Letter\";\n"
"\"media.na_monarch_3.875x7.5in\" = \"Monarque d ' enveloppe\";\n"
"\"media.na_number-10_4.125x9.5in\" = \"Enveloppe #10\";\n"
"\"media.na_number-11_4.5x10.375in\" = \"Enveloppe #11\";\n"
"\"media.na_number-12_4.75x11in\" = \"Enveloppe #12\";\n"
"\"media.na_number-14_5x11.5in\" = \"Enveloppe #14\";\n"
"\"media.na_number-9_3.875x8.875in\" = \"Enveloppe #9\";\n"
"\"media.na_personal_3.625x6.5in\" = \"Enveloppe personnelle\";\n"
"\"media.na_quarto_8.5x10.83in\" = \"Quarto\";\n"
"\"media.om_folio-sp_215x315mm\" = \"Folio\";\n"
"\"media.om_folio_210x330mm\" = \"Folio (Special)\";\n"
"\"media.om_invite_220x220mm\" = \"Invitation d ' enveloppe\";\n"
"\"media.om_italian_110x230mm\" = \"Enveloppe italienne\";\n"
"\"media.om_juuro-ku-kai_198x275mm\" = \"198 x 275mm\";\n"
"\"media.om_large-photo_200x300\" = \"200 x 300\";\n"
"\"media.om_medium-photo_130x180mm\" = \"130 x 180mm\";\n"
"\"media.om_pa-kai_267x389mm\" = \"267 x 389m m\";\n"
"\"media.om_postfix_114x229mm\" = \"Envelope Postfix\";\n"
"\"media.prc_10_324x458mm\" = \"Enveloppe chinoise #10\";\n"
"\"media.prc_16k_146x215mm\" = \"Chinois 16k\";\n"
"\"media.prc_1_102x165mm\" = \"Enveloppe chinoise #1\";\n"
"\"media.prc_2_102x176mm\" = \"Enveloppe chinoise #2\";\n"
"\"media.prc_32k_97x151mm\" = \"Chinois 32k\";\n"
"\"media.prc_3_125x176mm\" = \"Enveloppe chinoise #3\";\n"
"\"media.prc_4_110x208mm\" = \"Enveloppe chinoise #4\";\n"
"\"media.prc_5_110x220mm\" = \"Enveloppe chinoise #5\";\n"
"\"media.prc_6_120x320mm\" = \"Enveloppe chinoise #6\";\n"
"\"media.prc_7_160x230mm\" = \"Enveloppe chinoise #7\";\n"
"\"media.prc_8_120x309mm\" = \"Enveloppe chinoise #8\";\n"
"\"media.roc_16k_7.75x10.75in\" = \"ROC 16k\";\n"
"\"media.roc_8k_10.75x15.5in\" = \"ROC 8k\";\n"
"\"not configured\" = \"non configuré\";\n"
"\"not visible\" = \"non visible\";\n"
"\"off\" = \"Dégage.\";\n"
"\"on\" = \"on\";\n"
"\"orientation-requested\" = \"Orientation\";\n"
"\"orientation-requested.3\" = \"Portrait\";\n"
"\"orientation-requested.4\" = \"Paysage\";\n"
"\"orientation-requested.5\" = \"Paysage inversé\";\n"
"\"orientation-requested.6\" = \"Portrait inversé\";\n"
"\"orientation-requested.7\" = \"None\";\n"
"\"output-bin\" = \"Sortie Tray\";\n"
"\"output-bin.auto\" = \"Automatique\";\n"
"\"output-bin.bottom\" = \"Bottom\";\n"
"\"output-bin.center\" = \"Center\";\n"
"\"output-bin.face-down\" = \"Face à terre\";\n"
"\"output-bin.face-up\" = \"Face à face\";\n"
"\"output-bin.large-capacity\" = \"Grande capacité\";\n"
"\"output-bin.left\" = \"Gauche\";\n"
"\"output-bin.mailbox-1\" = \"Mailbox 1\";\n"
"\"output-bin.mailbox-10\" = \"Mailbox 10\";\n"
"\"output-bin.mailbox-2\" = \"Mailbox 2\";\n"
"\"output-bin.mailbox-3\" = \"Mailbox 3\";\n"
"\"output-bin.mailbox-4\" = \"Mailbox 4\";\n"
"\"output-bin.mailbox-5\" = \"Mailbox 5\";\n"
"\"output-bin.mailbox-6\" = \"Mailbox 6\";\n"
"\"output-bin.mailbox-7\" = \"Mailbox 7\";\n"
"\"output-bin.mailbox-8\" = \"Mailbox 8\";\n"
"\"output-bin.mailbox-9\" = \"Mailbox 9\";\n"
"\"output-bin.middle\" = \"Moyen-Orient\";\n"
"\"output-bin.my-mailbox\" = \"Ma boîte aux lettres\";\n"
"\"output-bin.rear\" = \"Arrière\";\n"
"\"output-bin.right\" = \"Droit\";\n"
"\"output-bin.side\" = \"Side\";\n"
"\"output-bin.stacker-1\" = \"Stacker 1\";\n"
"\"output-bin.stacker-10\" = \"Stacker 10\";\n"
"\"output-bin.stacker-2\" = \"Stacker 2\";\n"
"\"output-bin.stacker-3\" = \"Stacker 3\";\n"
"\"output-bin.stacker-4\" = \"Stacker 4\";\n"
"\"output-bin.stacker-5\" = \"Stacker 5\";\n"
"\"output-bin.stacker-6\" = \"Stacker 6\";\n"
"\"output-bin.stacker-7\" = \"Stacker 7\";\n"
"\"output-bin.stacker-8\" = \"Stacker 8\";\n"
"\"output-bin.stacker-9\" = \"Stacker 9\";\n"
"\"output-bin.top\" = \"Top\";\n"
"\"output-bin.tray-1\" = \"Tray 1\";\n"
"\"output-bin.tray-10\" = \"Tray 10\";\n"
"\"output-bin.tray-2\" = \"Tray 2\";\n"
"\"output-bin.tray-3\" = \"Tray 3\";\n"
"\"output-bin.tray-4\" = \"Tray 4\";\n"
"\"output-bin.tray-5\" = \"Tray 5\";\n"
"\"output-bin.tray-6\" = \"Tray 6\";\n"
"\"output-bin.tray-7\" = \"Tray 7\";\n"
"\"output-bin.tray-8\" = \"Tray 8\";\n"
"\"output-bin.tray-9\" = \"Tray 9\";\n"
"\"print-color-mode\" = \"Mode d ' impression\";\n"
"\"print-color-mode.auto\" = \"Automatique\";\n"
"\"print-color-mode.auto-monochrome\" = \"Auto monochrome\";\n"
"\"print-color-mode.bi-level\" = \"Texte\";\n"
"\"print-color-mode.color\" = \"Couleur\";\n"
"\"print-color-mode.highlight\" = \"Highlight\";\n"
"\"print-color-mode.monochrome\" = \"Monochrome\";\n"
"\"print-color-mode.process-bi-level\" = \"Texte du processus\";\n"
"\"print-color-mode.process-monochrome\" = \"Processus monochrome\";\n"
"\"print-content-optimize\" = \"Optimiser pour\";\n"
"\"print-content-optimize.auto\" = \"Automatique\";\n"
"\"print-content-optimize.graphic\" = \"Graphiques\";\n"
"\"print-content-optimize.photo\" = \"Photo\";\n"
"\"print-content-optimize.text\" = \"Texte\";\n"
"\"print-content-optimize.text-and-graphic\" = \"Texte et graphiques\";\n"
"\"print-darkness\" = \"Imprimer Darkness\";\n"
"\"print-quality\" = \"Qualité de l ' impression\";\n"
"\"print-quality.3\" = \"Draft\";\n"
"\"print-quality.4\" = \"Normal\";\n"
"\"print-quality.5\" = \"Meilleur\";\n"
"\"print-scaling\" = \"Scaling\";\n"
"\"print-scaling.auto\" = \"Automatique\";\n"
"\"print-scaling.auto-fit\" = \"Auto-fit\";\n"
"\"print-scaling.fill\" = \"Rempli\";\n"
"\"print-scaling.fit\" = \"Fit\";\n"
"\"print-scaling.none\" = \"None\";\n"
"\"print-speed\" = \"Vitesse d ' impression\";\n"
"\"printer-resolution\" = \"Résolution\";\n"
"\"printer-state-reasons.cover-open\" = \"Couverture ouverte.\";\n"
"\"printer-state-reasons.door-open\" = \"Porte ouverte.\";\n"
"\"printer-state-reasons.identify-printer-requested\" = \"Identifiez l'imprimante.\";\n"
"\"printer-state-reasons.input-tray-missing\" = \"Le papier manquant.\";\n"
"\"printer-state-reasons.marker-supply-empty\" = \"De l'encre.\";\n"
"\"printer-state-reasons.marker-supply-low\" = \"Faible encre.\";\n"
"\"printer-state-reasons.marker-waste-almost-full\" = \"La poubelle est presque pleine.\";\n"
"\"printer-state-reasons.marker-waste-full\" = \"La poubelle est pleine.\";\n"
"\"printer-state-reasons.media-empty\" = \"Hors de papier.\";\n"
"\"printer-state-reasons.media-jam\" = \"La confiture de papier.\";\n"
"\"printer-state-reasons.media-low\" = \"Remplacez le papier bientôt.\";\n"
"\"printer-state-reasons.media-needed\" = \"Le papier de charge.\";\n"
"\"printer-state-reasons.none\" = \"Prêt.\";\n"
"\"printer-state-reasons.offline\" = \"Hors ligne.\";\n"
"\"printer-state-reasons.other\" = \"Voir l'imprimante.\";\n"
"\"printer-state-reasons.spool-area-full\" = \"Imprimante occupée.\";\n"
"\"printer-state-reasons.toner-empty\" = \"Hors de tonner.\";\n"
"\"printer-state-reasons.toner-low\" = \"Plus bas.\";\n"
"\"printer-state.3\" = \"Idle\";\n"
"\"printer-state.4\" = \"Traitement\";\n"
"\"printer-state.5\" = \"Arrêté\";\n"
"\"sides\" = \"Impression 2-Sided\";\n"
"\"sides.one-sided\" = \"Officier\";\n"
"\"sides.two-sided-long-edge\" = \"Sur (portrait)\";\n"
"\"sides.two-sided-short-edge\" = \"On (landscape)\";\n"
"\"unable to join\" = \"incapable de se joindre\";\n"
"\"yesterday at %02d:%02d:%02d\" = \"yesterday at %02d:%02d:%02d\";\n"
"\"Åland Islands\" = \"Îles Salomon\";\n";
