static const char *tr_strings = "\"  -a               Cancel all jobs (cancel).\" = \"  -a               Tüm işleri iptal et (cancel).\";\n"
"\"  -c COPIES\" = \"  -c KOPYA\";\n"
"\"  -d PRINTER       Specify printer.\" = \"  -d YAZICI        Yazıcı belirt.\";\n"
"\"  -j JOB-ID        Specify job ID (cancel).\" = \"  -j İŞ-NO         İş numarası belirt (cancel).\";\n"
"\"  -m DRIVER-NAME   Specify driver (add/modify).\" = \"  -m SÜRÜCÜ-ADI    Sürücü belirt (add/modify).\";\n"
"\"  -n COPIES        Specify number of copies (submit).\" = \"  -n KOPYA         Kopya sayısını belirt (submit).\";\n"
"\"  -o %s=%s (default)\" = \"  -o %s=%s (default)\";\n"
"\"  -o NAME=VALUE    Specify option (add,modify,server,submit).\" = \"  -o AD=DEĞER      Seçenek belirt (add,modify,server,submit).\";\n"
"\"  -o print-darkness=-100 to 100\" = \"  -o print-darkness=-100 ila 100\";\n"
"\"  -o printer-darkness=0 to 100\" = \"  -o printer-darkness=0 ila 100\";\n"
"\"  -o printer-geo-location='geo:LATITUDE,LONGITUDE'\" = \"  -o printer-geo-location='geo:ENLEM,BOYLAM'\";\n"
"\"  -o printer-location='LOCATION'\" = \"  -o printer-location='KONUM'\";\n"
"\"  -o printer-organization='ORGANIZATION'\" = \"  -o printer-organization='ORGANİZASYON'\";\n"
"\"  -o printer-organizational-unit='UNIT/SECTION'\" = \"  -o printer-organizational-unit='BİRİM/BÖLÜM'\";\n"
"\"  -u URI           Specify ipp: or ipps: printer/server.\" = \"  -u URI           ipp: veya ipps: yazıcı/sunucu belirt.\";\n"
"\"  -v DEVICE-URI    Specify socket: or usb: device (add/modify).\" = \"  -v AYGIT-URI     socket: veya usb: aygıt belirt (add/modify).\";\n"
"\"  add PRINTER      Add a printer.\" = \"  add YAZICI       Yazıcı ekle.\";\n"
"\"  autoadd          Automatically add supported printers.\" = \"  autoadd          Desteklenen yazıcıları otomatik olarak ekle.\";\n"
"\"  cancel           Cancel one or more jobs.\" = \"  cancel           Bir veya daha fazla işi iptal et.\";\n"
"\"  default          Set the default printer.\" = \"  default          Öntanımlı yazıcıyı ayarla.\";\n"
"\"  delete           Delete a printer.\" = \"  delete           Yazıcı sil.\";\n"
"\"  devices          List devices.\" = \"  devices          Aygıtları listele.\";\n"
"\"  drivers          List drivers.\" = \"  drivers          Sürücüleri listele.\";\n"
"\"  jobs             List jobs.\" = \"  jobs             İşleri listele.\";\n"
"\"  modify           Modify a printer.\" = \"  modify           Yazıcı düzenle.\";\n"
"\"  options          List printer options.\" = \"  options          Yazıcı seçeneklerini listele.\";\n"
"\"  pause            Pause printing for a printer.\" = \"  pause            Bir yazıcı için yazdırmayı duraklat.\";\n"
"\"  printers         List printers.\" = \"  printers         Yazıcıları listele.\";\n"
"\"  resume           Resume printing for a printer.\" = \"  resume           Bir yazıcı için yazdırmayı devam ettir.\";\n"
"\"  server           Run a server.\" = \"  server           Sunucu çalıştır.\";\n"
"\"  shutdown         Shutdown a running server.\" = \"  shutdown         Çalışan bir sunucuyu kapat.\";\n"
"\"  status           Show server/printer/job status.\" = \"  status           Sunucu/yazıcı/iş durumunu göster.\";\n"
"\"  submit           Submit a file for printing.\" = \"  submit           Yazdırmak için bir dosya gönder.\";\n"
"\"%04d-%02d-%02d at %02d:%02d:%02d\" = \"%04d-%02d-%02d, %02d:%02d:%02d\";\n"
"\"%d days ago at %02d:%02d:%02d\" = \"%d gün önce, %02d:%02d:%02d'de\";\n"
"\"%d inches/sec\" = \"%d inç/s\";\n"
"\"%d job\" = \"%d iş\";\n"
/* Media size in millimeters */
"\"%d x %dmm\" = \"%d x %dmm\";\n"
"\"%ddpi\" = \"%ddpi\";\n"
"\"%dx%ddpi\" = \"%dx%ddpi\";\n"
/* Media size in inches */
"\"%g x %g\\\"\" = \"%g x %g\\\"\";\n"
/* size (type+borderless) */
"\"%s (%s%s)\" = \"%s (%s%s)\";\n"
/* size (type+borderless) from source/tray */
"\"%s (%s%s) from %s\" = \"%s (%s%s) kaynak: %s\";\n"
/* Source/Tray Media */
"\"%s Media\" = \"%s Ortamı\";\n"
"\"%s: Bad 'server-port' value.\" = \"%s: Hatalı 'sunucu-bağlantı noktası' değeri.\";\n"
"\"%s: Bad job ID.\" = \"%s: Hatalı iş numarası.\";\n"
"\"%s: Bad printer URI '%s'.\" = \"%s: Hatalı yazıcı URI'si: '%s'.\";\n"
"\"%s: Cannot specify more than one sub-command.\" = \"%s: Birden fazla alt komut belirtilemez.\";\n"
"\"%s: Empty print file received on the standard input.\" = \"%s: Standart girişte boş yazdırma dosyası alındı.\";\n"
"\"%s: Failed to create a system.\" = \"%s: Sistem oluşturulamadı.\";\n"
"\"%s: Missing '-d PRINTER'.\" = \"%s: '-d YAZICI' eksik.\";\n"
"\"%s: Missing '-m DRIVER-NAME'.\" = \"%s: '-m SÜRÜCÜ-ADI' eksik.\";\n"
"\"%s: Missing '-v DEVICE-URI'.\" = \"%s: '-v AYGIT-URI' eksik.\";\n"
"\"%s: Missing copy count after '-n'.\" = \"%s: '-n' seçeneğinden sonra kopya sayısı eksik.\";\n"
"\"%s: Missing device URI after '-v'.\" = \"%s: '-v' seçeneğinden sonra aygıt URI'si eksik.\";\n"
"\"%s: Missing driver name after '-m'.\" = \"%s: '-m' seçeneğinden sonra sürücü adı eksik.\";\n"
"\"%s: Missing filename after '--'.\" = \"%s: '--' sonrasında dosya adı eksik.\";\n"
"\"%s: Missing hostname after '-h'.\" = \"%s: '-h' seçeneğinden sonra ana makine adı eksik.\";\n"
"\"%s: Missing job ID after '-j'.\" = \"%s: '-j' seçeneğinden sonra iş numarası eksik.\";\n"
"\"%s: Missing option(s) after '-o'.\" = \"%s: '-o' sonrasında seçenek(ler) eksik.\";\n"
"\"%s: Missing printer URI after '-u'.\" = \"%s: '-u' seçeneğinden sonra yazıcı URI'si eksik.\";\n"
"\"%s: Missing printer name after '-d'.\" = \"%s: '-d' seçeneğinden sonra yazıcı adı eksik.\";\n"
"\"%s: Missing space after '-o'.\" = \"%s: '-o' seçeneğinden sonra boşluk eksik.\";\n"
"\"%s: Missing title after '-t'.\" = \"%s: '-t' seçeneğinden sonra başlık eksik.\";\n"
"\"%s: No default printer available.\" = \"%s: Kullanılabilir öntanımlı yazıcı yok.\";\n"
"\"%s: No files to print.\" = \"%s: Yazdırılacak dosya yok.\";\n"
"\"%s: Server is not running.\" = \"%s: Sunucu çalışmıyor.\";\n"
"\"%s: Sub-command '%s' does not accept files.\" = \"%s: '%s' alt komutu dosya kabul etmiyor.\";\n"
"\"%s: Sub-command 'autoadd' is not supported.\" = \"%s: 'autoadd' alt komutu desteklenmiyor.\";\n"
"\"%s: Too many files.\" = \"%s: Çok fazla dosya.\";\n"
"\"%s: Unable to access '%s': %s\" = \"%s: '%s' erişilebilir değil: %s\";\n"
"\"%s: Unable to add printer: %s\" = \"%s: Yazıcı eklenemiyor: %s\";\n"
"\"%s: Unable to cancel job: %s\" = \"%s: İş iptal edilemiyor: %s\";\n"
"\"%s: Unable to connect to printer at '%s:%d': %s\" = \"%s: '%s:%d' konumunda yazıcıya bağlanılamıyor: %s\";\n"
"\"%s: Unable to connect to server: %s\" = \"%s: Sunucuya bağlanılamıyor: %s\";\n"
"\"%s: Unable to create temporary file: %s\" = \"%s: Geçici dosya oluşturulamıyor: %s\";\n"
"\"%s: Unable to delete printer: %s\" = \"%s: Yazıcı silinemiyor: %s\";\n"
"\"%s: Unable to get available devices: %s\" = \"%s: Kullanılabilir aygıtlar alınamıyor: %s\";\n"
"\"%s: Unable to get information for '%s': %s\" = \"%s: '%s' için bilgi alınamıyor: %s\";\n"
"\"%s: Unable to get information for printer: %s\" = \"%s: Yazıcı için bilgi alınamıyor: %s\";\n"
"\"%s: Unable to get printer options: %s\" = \"%s: Yazıcı seçenekleri alınamıyor: %s\";\n"
"\"%s: Unable to modify printer: %s\" = \"%s: Yazıcı düzenlenemiyor: %s\";\n"
"\"%s: Unable to pause printer: %s\" = \"%s: Yazıcı duraklatılamıyor: %s\";\n"
"\"%s: Unable to print '%s': %s\" = \"%s: '%s' yazdırılamıyor: %s\";\n"
"\"%s: Unable to resume printer: %s\" = \"%s: Yazıcı devam ettirilemiyor: %s\";\n"
"\"%s: Unable to set default printer: %s\" = \"%s: Öntanımlı yazıcı ayarlanamıyor: %s\";\n"
"\"%s: Unable to shutdown server: %s\" = \"%s: Sunucu kapatılamıyor: %s\";\n"
"\"%s: Unable to start server: %s\" = \"%s: Sunucu başlatılamıyor: %s\";\n"
"\"%s: Unable to write to temporary file: %s\" = \"%s: Geçici dosyaya yazılamıyor: %s\";\n"
"\"%s: Unknown option '%s'.\" = \"%s: Bilinmeyen seçenek '%s'.\";\n"
"\"%s: Unknown option '-%c'.\" = \"%s: Bilinmeyen seçenek '-%c'.\";\n"
"\"%s: Unknown sub-command '%s'.\" = \"%s: Bilinmeyen alt komut '%s'.\";\n"
"\"%s: Unsupported URI scheme '%s'.\" = \"%s: Desteklenmeyen URI şeması '%s'.\";\n"
"\"%s: Warning - user credentials are not supported in URIs.\" = \"%s: Uyarı - URI'lerde kullanıcı kimlik bilgileri desteklenmiyor.\";\n"
"\", Borderless\" = \", Kenarlıksız\";\n"
"\"A printer with that name already exists.\" = \"Bu ada sahip bir yazıcı zaten var.\";\n"
"\"Aborted %s\" = \"%s sonlandırıldı\";\n"
"\"Add Printer\" = \"Yazıcı Ekle\";\n"
"\"Admin Group\" = \"Yönetici Grubu\";\n"
"\"Afghanistan\" = \"Afganistan\";\n"
"\"Albania\" = \"Arnavutluk\";\n"
"\"Algeria\" = \"Cezayir\";\n"
"\"American Samoa\" = \"Amerikan Samoası\";\n"
"\"Andorra\" = \"Andorra\";\n"
"\"Angola\" = \"Angola\";\n"
"\"Anguilla\" = \"Anguilla\";\n"
"\"Antarctica\" = \"Antarktika\";\n"
"\"Antigua and Barbuda\" = \"Antigua ve Barbuda\";\n"
"\"Argentina\" = \"Arjantin\";\n"
"\"Armenia\" = \"Ermenistan\";\n"
"\"Aruba\" = \"Aruba\";\n"
"\"Australia\" = \"Avustralya\";\n"
"\"Austria\" = \"Avusturya\";\n"
"\"Auto\" = \"Otomatik\";\n"
"\"Auto-Detect Driver\" = \"Sürücüyü Otomatik Algıla\";\n"
"\"Azerbaijan\" = \"Azerbaycan\";\n"
"\"Bad administration group.\" = \"Hatalı yönetim grubu.\";\n"
"\"Bad port number.\" = \"Hatalı bağlantı noktası numarası.\";\n"
"\"Bad print group.\" = \"Hatalı yazdırma grubu.\";\n"
"\"Bad printer defaults.\" = \"Hatalı yazıcı öntanımlı değerleri.\";\n"
"\"Bahamas\" = \"Bahamalar\";\n"
"\"Bahrain\" = \"Bahreyn\";\n"
"\"Bangladesh\" = \"Bangladeş\";\n"
"\"Barbados\" = \"Barbados\";\n"
"\"Belarus\" = \"Belarus\";\n"
"\"Belgium\" = \"Belçika\";\n"
"\"Belize\" = \"Belize\";\n"
"\"Benin\" = \"Benin\";\n"
"\"Bermuda\" = \"Bermuda\";\n"
"\"Bhutan\" = \"Bhutan\";\n"
"\"Bolivia (Plurinational State of)\" = \"Bolivya (Çokuluslu Devleti)\";\n"
"\"Bonaire, Sint Eustatius and Saba\" = \"Bonaire, Sint Eustatius ve Saba\";\n"
"\"Borderless\" = \"Kenarlıksız\";\n"
"\"Bosnia and Herzegovina\" = \"Bosna Hersek\";\n"
"\"Botswana\" = \"Botsvana\";\n"
"\"Bouvet Island\" = \"Bouvet Adası\";\n"
"\"Brazil\" = \"Brezilya\";\n"
"\"British Indian Ocean Territory\" = \"Britanya Hint Okyanusu Toprakları\";\n"
"\"Brunei Darussalam\" = \"Brunei Sultanlığı\";\n"
"\"Bulgaria\" = \"Bulgaristan\";\n"
"\"Burkina Faso\" = \"Burkina Faso\";\n"
"\"Burundi\" = \"Burundi\";\n"
"\"Cabo Verde\" = \"Yeşil Burun Adaları\";\n"
"\"Cambodia\" = \"Kamboçya\";\n"
"\"Cameroon\" = \"Kamerun\";\n"
"\"Canada\" = \"Kanada\";\n"
"\"Cancel All Jobs\" = \"Tüm İşleri İptal Et\";\n"
"\"Cancel Job\" = \"İşi İptal Et\";\n"
"\"Canceled %s\" = \"%s iptal edildi\";\n"
"\"Canceling\" = \"İptal ediliyor\";\n"
"\"Cayman Islands\" = \"Cayman Adaları\";\n"
"\"Central African Republic\" = \"Orta Afrika Cumhuriyeti\";\n"
"\"Certificate created.\" = \"Sertifika oluşturuldu.\";\n"
"\"Certificate installed.\" = \"Sertifika kuruldu.\";\n"
"\"Certificate request created.\" = \"Sertifika isteği oluşturuldu.\";\n"
"\"Chad\" = \"Çad\";\n"
"\"Change Access Password\" = \"Erişim Parolasını Değiştir\";\n"
"\"Change Log Level\" = \"Günlük Kaydı Seviyesini Değiştir\";\n"
"\"Change Network Settings\" = \"Ağ Ayarlarını Değiştir\";\n"
"\"Change Wi-Fi Network\" = \"Wi-Fi Ağını Değiştir\";\n"
"\"Changes Saved.\" = \"Değişiklikler Kaydedildi.\";\n"
"\"Changes saved.\" = \"Değişiklikler kaydedildi.\";\n"
"\"Chile\" = \"Şili\";\n"
"\"China\" = \"Çin\";\n"
"\"Christmas Island\" = \"Christmas Adası\";\n"
"\"City/Locality\" = \"Şehir/Yerellik\";\n"
"\"Cocos (Keeling) Islands\" = \"Cocos (Keeling) Adaları\";\n"
"\"Colombia\" = \"Kolombiya\";\n"
"\"Comoros\" = \"Komorlar\";\n"
"\"Completed %s\" = \"%s tamamlandı\";\n"
"\"Configuration\" = \"Yapılandırma\";\n"
"\"Configure Media\" = \"Ortamı Yapılandır\";\n"
"\"Confirm Cancel All\" = \"Tümünü İptal Etmeyi Onayla\";\n"
"\"Confirm Delete Printer\" = \"Yazıcıyı Silmeyi Onayla\";\n"
"\"Congo\" = \"Kongo\";\n"
"\"Congo, Democratic Republic of the\" = \"Kongo Demokratik Cumhuriyeti\";\n"
"\"Contact\" = \"İletişim\";\n"
"\"Cook Islands\" = \"Cook Adaları\";\n"
"\"Costa Rica\" = \"Kosta Rika\";\n"
"\"Create Certificate Signing Request\" = \"Sertifika İmzalama İsteği Oluştur\";\n"
"\"Create New Certificate\" = \"Yeni Sertifika Oluştur\";\n"
"\"Create New TLS Certificate\" = \"Yeni TLS Sertifikası Oluştur\";\n"
"\"Create TLS Certificate Request\" = \"TLS Sertifikası İsteği Oluştur\";\n"
"\"Croatia\" = \"Hırvatistan\";\n"
"\"Cuba\" = \"Küba\";\n"
"\"Curaçao\" = \"Curaçao\";\n"
"\"Current Password\" = \"Geçerli Parola\";\n"
"\"Custom Size\" = \"Özel Boyut\";\n"
"\"Cyprus\" = \"Kıbrıs\";\n"
"\"Czechia\" = \"Çekya\";\n"
"\"Côte d'Ivoire\" = \"Fildişi Sahili\";\n"
"\"DHCP\" = \"DHCP\";\n"
"\"DHCP w/Manual Address\" = \"DHCP ve Elle Adres\";\n"
"\"DNS-SD Service Name\" = \"DNS-SD Hizmet Adı\";\n"
"\"Debugging\" = \"Hata Ayıklama\";\n"
"\"Default printer set.\" = \"Öntanımlı yazıcı ayarlandı.\";\n"
"\"Delete\" = \"Sil\";\n"
"\"Delete Printer\" = \"Yazıcı Sil\";\n"
"\"Denmark\" = \"Danimarka\";\n"
"\"Djibouti\" = \"Cibuti\";\n"
"\"Domain Name\" = \"Etki Alanı Adı\";\n"
"\"Dominica\" = \"Dominika\";\n"
"\"Dominican Republic\" = \"Dominik Cumhuriyeti\";\n"
"\"Download Certificate Request File\" = \"Sertifika İstek Dosyasını İndir\";\n"
"\"Ecuador\" = \"Ekvador\";\n"
"\"Egypt\" = \"Mısır\";\n"
"\"El Salvador\" = \"El Salvador\";\n"
"\"Equatorial Guinea\" = \"Equatorial Guinea\";\n"
"\"Eritrea\" = \"Eritre\";\n"
"\"Errors\" = \"Hatalar\";\n"
"\"Estonia\" = \"Estonya\";\n"
"\"Eswatini\" = \"Esvatini\";\n"
"\"Ethiopia\" = \"Etiyopya\";\n"
"\"Falkland Islands (Malvinas)\" = \"Falkland Adaları (Malvinas)\";\n"
"\"Faroe Islands\" = \"Faroe Adaları\";\n"
"\"Fatal Errors/Conditions\" = \"Ölümcül Hatalar/Koşullar\";\n"
"\"Fiji\" = \"Fiji\";\n"
"\"Finland\" = \"Finlandiya\";\n"
"\"France\" = \"Fransa\";\n"
"\"French Guiana\" = \"Fransız Guyanası\";\n"
"\"French Polynesia\" = \"Fransız Polinezyası\";\n"
"\"French Southern Territories\" = \"Fransız Güney Toprakları\";\n"
"\"Gabon\" = \"Gabon\";\n"
"\"Gambia\" = \"Gambiya\";\n"
"\"Georgia\" = \"Gürcistan\";\n"
"\"Germany\" = \"Almanya\";\n"
"\"Ghana\" = \"Gana\";\n"
"\"Gibraltar\" = \"Cebelitarık\";\n"
"\"Greece\" = \"Yunanistan\";\n"
"\"Greenland\" = \"Grönland\";\n"
"\"Grenada\" = \"Grenada\";\n"
"\"Group changes saved.\" = \"Grup değişiklikleri kaydedildi.\";\n"
"\"Guadeloupe\" = \"Guadeloupe\";\n"
"\"Guam\" = \"Guam\";\n"
"\"Guatemala\" = \"Guatemala\";\n"
"\"Guernsey\" = \"Guernsey\";\n"
"\"Guinea\" = \"Gine\";\n"
"\"Guinea-Bissau\" = \"Gine-Bissau\";\n"
"\"Guyana\" = \"Guyana\";\n"
"\"Haiti\" = \"Haiti\";\n"
"\"Heard Island and McDonald Islands\" = \"Heard Adası ve McDonald Adaları\";\n"
"\"Hidden SSID\" = \"Gizli SSID\";\n"
"\"Hold Job\" = \"İşi Beklet\";\n"
"\"Hold New Jobs\" = \"Yeni İşleri Beklet\";\n"
"\"Holding new jobs.\" = \"Yeni işler bekletiliyor.\";\n"
"\"Holy See\" = \"Vatikan\";\n"
"\"Honduras\" = \"Honduras\";\n"
"\"Hong Kong\" = \"Hong Kong\";\n"
"\"Hostname\" = \"Ana Makine Adı\";\n"
"\"Human-Readable Location\" = \"İnsan Tarafından Okunabilir Konum\";\n"
"\"Hungary\" = \"Macaristan\";\n"
"\"IPv4 Address\" = \"IPv4 Adresi\";\n"
"\"IPv4 Configuration\" = \"IPv4 Yapılandırması\";\n"
"\"IPv4 Gateway\" = \"IPv4 Ağ Geçidi\";\n"
"\"IPv4 Netmask\" = \"IPv4 Ağ Maskesi\";\n"
"\"IPv6 Address\" = \"IPv6 Adresi\";\n"
"\"IPv6 Configuration\" = \"IPv6 Yapılandırması\";\n"
"\"IPv6 Link-Local\" = \"IPv6 Yerel Bağlantı\";\n"
"\"IPv6 Prefix Length\" = \"IPv6 Ön Ek Uzunluğu\";\n"
"\"Iceland\" = \"İzlanda\";\n"
"\"Identify Printer\" = \"Yazıcı Tanımla\";\n"
"\"India\" = \"Hindistan\";\n"
"\"Indonesia\" = \"Endonezya\";\n"
"\"Informational\" = \"Bilgi\";\n"
"\"Install TLS Certificate\" = \"TLS Sertifikası Kur\";\n"
"\"Invalid IPv4 address.\" = \"Geçersiz IPv4 adresi.\";\n"
"\"Invalid IPv4 netmask.\" = \"Geçersiz IPv4 ağ maskesi.\";\n"
"\"Invalid IPv6 address.\" = \"Geçersiz IPv6 adresi.\";\n"
"\"Invalid IPv6 prefix length.\" = \"Geçersiz IPv6 ön ek uzunluğu.\";\n"
"\"Invalid Job ID.\" = \"Geçersiz İş Numarası.\";\n"
"\"Invalid certificate or private key.\" = \"Geçersiz sertifika veya özel anahtar.\";\n"
"\"Invalid form data.\" = \"Geçersiz form verisi.\";\n"
"\"Invalid form submission.\" = \"Geçersiz form gönderimi.\";\n"
"\"Invalid job ID.\" = \"Geçersiz iş numarası.\";\n"
"\"Invalid network configuration.\" = \"Geçersiz ağ yapılandırması.\";\n"
"\"Iran (Islamic Republic of)\" = \"İran (İslam Cumhuriyeti)\";\n"
"\"Iraq\" = \"Irak\";\n"
"\"Ireland\" = \"İrlanda\";\n"
"\"Isle of Man\" = \"Man Adası\";\n"
"\"Israel\" = \"İsrail\";\n"
"\"Italy\" = \"İtalya\";\n"
"\"Jamaica\" = \"Jamaika\";\n"
"\"Japan\" = \"Japonya\";\n"
"\"Jersey\" = \"Jersey\";\n"
"\"Job #\" = \"İş #\";\n"
"\"Job canceled.\" = \"İş iptal edildi.\";\n"
"\"Job held.\" = \"İş bekletildi.\";\n"
"\"Job released.\" = \"İş serbest bırakıldı.\";\n"
"\"Jobs\" = \"İşler\";\n"
"\"Joining Wi-Fi Network\" = \"Wi-Fi Ağına Bağlanıyor\";\n"
"\"Jordan\" = \"Ürdün\";\n"
"\"Kazakhstan\" = \"Kazakistan\";\n"
"\"Kenya\" = \"Kenya\";\n"
"\"Kiribati\" = \"Kiribati\";\n"
"\"Korea (Democratic People's Republic of)\" = \"Kore (Demokratik Halk Cumhuriyeti)\";\n"
"\"Korea, Republic of\" = \"Kore Cumhuriyeti\";\n"
"\"Kuwait\" = \"Kuveyt\";\n"
"\"Kyrgyzstan\" = \"Kırgızistan\";\n"
"\"Landscape\" = \"Manzara\";\n"
"\"Lao People's Democratic Republic\" = \"Lao Demokratik Halk Cumhuriyeti\";\n"
"\"Latvia\" = \"Letonya\";\n"
"\"Lebanon\" = \"Lübnan\";\n"
"\"Lesotho\" = \"Lesotho\";\n"
"\"Level\" = \"Seviye\";\n"
"\"Liberia\" = \"Liberya\";\n"
"\"Libya\" = \"Libya\";\n"
"\"Liechtenstein\" = \"Lihtenştayn\";\n"
"\"Lithuania\" = \"Litvanya\";\n"
"\"Location\" = \"Konum\";\n"
"\"Log Level\" = \"Günlük Kaydı Seviyesi\";\n"
"\"Logging\" = \"Günlük Kaydı\";\n"
"\"Logs\" = \"Günlük\";\n"
"\"Luxembourg\" = \"Lüksemburg\";\n"
"\"Macao\" = \"Macao\";\n"
"\"Madagascar\" = \"Madagaskar\";\n"
"\"Malawi\" = \"Malavi\";\n"
"\"Malaysia\" = \"Malezya\";\n"
"\"Maldives\" = \"Maldivler\";\n"
"\"Mali\" = \"Mali\";\n"
"\"Malta\" = \"Malta\";\n"
"\"Manual Configuration\" = \"Elle Yapılandırma\";\n"
"\"Marshall Islands\" = \"Marshall Adaları\";\n"
"\"Martinique\" = \"Martinik\";\n"
"\"Mauritania\" = \"Moritanya\";\n"
"\"Mauritius\" = \"Mauritius\";\n"
"\"Mayotte\" = \"Mayotte\";\n"
"\"Media\" = \"Ortam\";\n"
"\"Mexico\" = \"Meksika\";\n"
"\"Micronesia (Federated States of)\" = \"Mikronezya (Federal Devletleri)\";\n"
"\"Missing action.\" = \"Eksik eylem.\";\n"
"\"Missing job ID.\" = \"İş kimliği eksik.\";\n"
"\"Missing network name.\" = \"Eksik ağ adı.\";\n"
"\"Missing private key.\" = \"Eksik özel anahtar.\";\n"
"\"Moldova, Republic of\" = \"Moldova Cumhuriyeti\";\n"
"\"Monaco\" = \"Monako\";\n"
"\"Mongolia\" = \"Moğolistan\";\n"
"\"Montenegro\" = \"Karadağ\";\n"
"\"Montserrat\" = \"Montserrat\";\n"
"\"Morocco\" = \"Fas\";\n"
"\"Mozambique\" = \"Mozambik\";\n"
"\"Myanmar\" = \"Myanmar\";\n"
"\"Name\" = \"Ad\";\n"
"\"Namibia\" = \"Namibya\";\n"
"\"Nauru\" = \"Nauru\";\n"
"\"Nepal\" = \"Nepal\";\n"
"\"Netherlands\" = \"Hollanda\";\n"
"\"Network\" = \"Ağ\";\n"
"\"Network Printer\" = \"Ağ Yazıcısı\";\n"
"\"Networking\" = \"Ağ\";\n"
"\"New Caledonia\" = \"Yeni Kaledonya\";\n"
"\"New Zealand\" = \"Yeni Zelanda\";\n"
"\"Nicaragua\" = \"Nikaragua\";\n"
"\"Niger\" = \"Nijer\";\n"
"\"Nigeria\" = \"Nijerya\";\n"
"\"Niue\" = \"Niue\";\n"
"\"No default printer set.\" = \"Öntanımlı yazıcı ayarlanmadı.\";\n"
"\"No jobs in history.\" = \"Geçmişte iş yok.\";\n"
"\"Norfolk Island\" = \"Norfolk Adası\";\n"
"\"North Macedonia\" = \"Kuzey Makedonya\";\n"
"\"Northern Mariana Islands\" = \"Kuzey Mariana Adaları\";\n"
"\"Norway\" = \"Norveç\";\n"
"\"Not set\" = \"Ayarlanmadı\";\n"
"\"Off\" = \"Kapalı\";\n"
"\"Offset\" = \"Ofset\";\n"
"\"Oman\" = \"Umman\";\n"
"\"Options:\" = \"Seçenekler:\";\n"
"\"Organization\" = \"Organizasyon\";\n"
"\"Organization Name\" = \"Organizasyon Adı\";\n"
"\"Other Settings\" = \"Diğer Ayarlar\";\n"
"\"Pakistan\" = \"Pakistan\";\n"
"\"Palau\" = \"Palau\";\n"
"\"Palestine, State of\" = \"Filistin Devleti\";\n"
"\"Panama\" = \"Panama\";\n"
"\"Papua New Guinea\" = \"Papua Yeni Gine\";\n"
"\"Paraguay\" = \"Paraguay\";\n"
"\"Password\" = \"Parola\";\n"
"\"Password changed.\" = \"Parola değiştirildi.\";\n"
"\"Password must be at least eight characters long and contain at least one uppercase letter, one lowercase letter, and one digit.\" = \"Parola en az sekiz karakter uzunluğunda olmalı ve en az bir büyük harf, bir küçük harf ve bir rakam içermelidir.\";\n"
"\"Passwords do not match.\" = \"Parolalar eşleşmiyor.\";\n"
"\"Pause Printing\" = \"Yazdırmayı Duraklat\";\n"
"\"Peru\" = \"Peru\";\n"
"\"Philippines\" = \"Filipinler\";\n"
"\"Pitcairn\" = \"Pitcairn\";\n"
"\"Please enter a hostname or IP address for the printer.\" = \"Lütfen yazıcı için bir ana makine adı veya IP adresi girin.\";\n"
"\"Please enter a printer name.\" = \"Lütfen bir yazıcı adı girin.\";\n"
"\"Please select a device.\" = \"Lütfen bir aygıt seçin.\";\n"
"\"Please select a driver.\" = \"Lütfen bir sürücü seçin.\";\n"
"\"Please select a valid log level.\" = \"Lütfen geçerli bir günlük kaydı seviyesi seçin.\";\n"
"\"Poland\" = \"Polonya\";\n"
"\"Portrait\" = \"Portre\";\n"
"\"Portugal\" = \"Portekiz\";\n"
"\"Primary DNS\" = \"Birincil DNS\";\n"
"\"Print Group\" = \"Yazdırma Grubu\";\n"
"\"Print Test Page\" = \"Test Sayfası Yazdır\";\n"
"\"Print job options:\" = \"Yazdırma işi seçenekleri:\";\n"
"\"Printer identified.\" = \"Yazıcı tanımlandı.\";\n"
"\"Printer is currently active.\" = \"Yazıcı şu anda etkin.\";\n"
"\"Printer names must start with a letter or underscore and cannot contain special characters.\" = \"Yazıcı adları bir harf veya alt çizgi ile başlamalıdır ve özel karakterler içeremez.\";\n"
"\"Printer options:\" = \"Yazıcı seçenekleri:\";\n"
"\"Printer paused.\" = \"Yazıcı duraklatıldı.\";\n"
"\"Printer pausing.\" = \"Yazıcı duraklatılıyor.\";\n"
"\"Printer resuming.\" = \"Yazıcı devam ettiriliyor.\";\n"
"\"Printers\" = \"Yazıcılar\";\n"
"\"Printing Defaults\" = \"Öntanımlı Yazdırma Ayarları\";\n"
"\"Puerto Rico\" = \"Porto Riko\";\n"
"\"Qatar\" = \"Katar\";\n"
"\"Queued %s\" = \"%s sıraya alındı\";\n"
"\"Release Held New Jobs\" = \"Bekletilen Yeni İşleri Serbest Bırak\";\n"
"\"Release Job\" = \"İşi Serbest Bırak\";\n"
"\"Released held new jobs.\" = \"Bekletilen yeni işler serbest bırakıldı.\";\n"
"\"Reprint Job\" = \"İşi Yeniden Yazdır\";\n"
"\"Reprinted job.\" = \"İş yeniden yazdırıldı.\";\n"
"\"Resume Printing\" = \"Yazdırmayı Devam Ettir\";\n"
"\"Reverse Landscape\" = \"Ters Manzara\";\n"
"\"Reverse Portrait\" = \"Ters Portre\";\n"
"\"Romania\" = \"Romanya\";\n"
/* Running, STATE since DATE REASONS */
"\"Running, %s since %s%s.\" = \"Çalışıyor, %s %s'den beri %s.\";\n"
"\"Russian Federation\" = \"Rusya Federasyonu\";\n"
"\"Rwanda\" = \"Ruanda\";\n"
"\"Réunion\" = \"Réunion\";\n"
"\"Saint Barthélemy\" = \"Saint Barthélemy\";\n"
"\"Saint Helena, Ascension and Tristan da Cunha\" = \"Saint Helena, Ascension ve Tristan da Cunha\";\n"
"\"Saint Kitts and Nevis\" = \"Saint Kitts ve Nevis\";\n"
"\"Saint Lucia\" = \"Saint Lucia\";\n"
"\"Saint Martin (French part)\" = \"Saint Martin (Fransız kısmı)\";\n"
"\"Saint Pierre and Miquelon\" = \"Saint Pierre ve Miquelon\";\n"
"\"Saint Vincent and the Grenadines\" = \"Saint Vincent ve Grenadinler\";\n"
"\"Samoa\" = \"Samoa\";\n"
"\"San Marino\" = \"San Marino\";\n"
"\"Sao Tome and Principe\" = \"Sao Tome ve Principe\";\n"
"\"Saudi Arabia\" = \"Suudi Arabistan\";\n"
"\"Save Changes\" = \"Değişiklikleri Kaydet\";\n"
"\"Secondary DNS\" = \"İkincil DNS\";\n"
"\"Security\" = \"Güvenlik\";\n"
"\"Select Driver\" = \"Sürücü Seç\";\n"
"\"Senegal\" = \"Senegal\";\n"
"\"Serbia\" = \"Sırbistan\";\n"
"\"Server is not running.\" = \"Sunucu çalışmıyor.\";\n"
"\"Set Access Password\" = \"Erişim Parolası Ayarla\";\n"
"\"Set as Default\" = \"Öntanımlı Olarak Ayarla\";\n"
"\"Seychelles\" = \"Seyşeller\";\n"
"\"Sierra Leone\" = \"Sierra Leone\";\n"
"\"Singapore\" = \"Singapur\";\n"
"\"Sint Maarten (Dutch part)\" = \"Sint Maarten (Hollanda kısmı)\";\n"
"\"Slovakia\" = \"Slovakya\";\n"
"\"Slovenia\" = \"Slovenya\";\n"
"\"Solomon Islands\" = \"Solomon Adaları\";\n"
"\"Somalia\" = \"Somali\";\n"
"\"South Africa\" = \"Güney Afrika\";\n"
"\"South Georgia and the South Sandwich Islands\" = \"Güney Georgia ve Güney Sandwich Adaları\";\n"
"\"South Sudan\" = \"Güney Sudan\";\n"
"\"Spain\" = \"İspanya\";\n"
"\"Sri Lanka\" = \"Sri Lanka\";\n"
"\"Started %s\" = \"%s başlatıldı\";\n"
"\"Status\" = \"Durum\";\n"
"\"Sub-commands:\" = \"Alt komutlar:\";\n"
"\"Sudan\" = \"Sudan\";\n"
"\"Supplies\" = \"Malzemeler\";\n"
"\"Suriname\" = \"Surinam\";\n"
"\"Svalbard and Jan Mayen\" = \"Svalbard ve Jan Mayen\";\n"
"\"Sweden\" = \"İsveç\";\n"
"\"Switzerland\" = \"İsviçre\";\n"
"\"Syrian Arab Republic\" = \"Suriye Arap Cumhuriyeti\";\n"
"\"Taiwan, Province of China\" = \"Tayvan, Çin Eyaleti\";\n"
"\"Tajikistan\" = \"Tacikistan\";\n"
"\"Tanzania, United Republic of\" = \"Tanzanya Birleşik Cumhuriyeti\";\n"
"\"Test page printed.\" = \"Test sayfası yazdırıldı.\";\n"
"\"Thailand\" = \"Tayland\";\n"
"\"This form creates a certificate signing request ('CSR') that you can send to a Certificate Authority ('CA') to obtain a trusted TLS certificate. The private key is saved separately for use with the certificate you get from the CA.\" = \"Bu form, güvenilir bir TLS sertifikası almak için Sertifika Yetkilisine (Certificate Authority - 'CA') gönderebileceğiniz bir sertifika imzalama isteği (certificate signing request - 'CSR') oluşturur. Özel anahtar, CA'dan aldığınız sertifika ile kullanılmak üzere ayrı olarak kaydedilir.\";\n"
"\"This form creates a new 'self-signed' TLS certificate for secure printing. Self-signed certificates are not automatically trusted by web browsers.\" = \"Bu form, güvenli yazdırma için yeni bir 'kendi tarafından imzalanan' TLS sertifikası oluşturur. Kendi tarafından imzalanan sertifikalara web tarayıcıları tarafından otomatik olarak güvenilmez.\";\n"
"\"This form will install a trusted TLS certificate you have obtained from a Certificate Authority ('CA'). Once installed, it will be used immediately.\" = \"Bu form, bir Sertifika Yetkilisinden ('CA') aldığınız güvenilir bir TLS sertifikasını kuracaktır. Kurulduktan sonra hemen kullanılacaktır.\";\n"
"\"Timor-Leste\" = \"Timor-Leste\";\n"
"\"Togo\" = \"Togo\";\n"
"\"Tokelau\" = \"Tokelau\";\n"
"\"Tonga\" = \"Tonga\";\n"
"\"Trinidad and Tobago\" = \"Trinidad ve Tobago\";\n"
"\"Tunisia\" = \"Tunus\";\n"
"\"Turkey\" = \"Türkiye\";\n"
"\"Turkmenistan\" = \"Türkmenistan\";\n"
"\"Turks and Caicos Islands\" = \"Turks ve Caicos Adaları\";\n"
"\"Tuvalu\" = \"Tuvalu\";\n"
"\"Uganda\" = \"Uganda\";\n"
"\"Ukraine\" = \"Ukrayna\";\n"
"\"Unable to access test print file.\" = \"Test yazdırma dosyasına erişilemiyor.\";\n"
"\"Unable to copy print job.\" = \"Yazdırma işi kopyalanamıyor.\";\n"
"\"Unable to create certificate request.\" = \"Sertifika isteği oluşturulamıyor.\";\n"
"\"Unable to create certificate.\" = \"Sertifika oluşturulamıyor.\";\n"
"\"Unable to create test print job.\" = \"Test yazdırma işi oluşturulamıyor.\";\n"
"\"Unable to identify printer.\" = \"Yazıcı tanımlanamıyor.\";\n"
"\"Unable to lookup address.\" = \"Adres aranamıyor.\";\n"
"\"Unable to use that driver.\" = \"Bu sürücü kullanılamıyor.\";\n"
"\"United Arab Emirates\" = \"Birleşik Arap Emirlikleri\";\n"
"\"United Kingdom\" = \"Birleşik Krallık\";\n"
"\"United Kingdom of Great Britain and Northern Ireland\" = \"Büyük Britanya ve Kuzey İrlanda Birleşik Krallığı\";\n"
"\"United States Minor Outlying Islands\" = \"Amerika Birleşik Devletleri Küçük Dış Adaları\";\n"
"\"United States of America\" = \"Amerika Birleşik Devletleri\";\n"
"\"Unknown\" = \"Bilinmeyen\";\n"
"\"Unknown action.\" = \"Bilinmeyen eylem.\";\n"
"\"Unknown form action.\" = \"Bilinmeyen form eylemi.\";\n"
"\"Unknown form request.\" = \"Bilinmeyen form isteği.\";\n"
"\"Updating Network Configuration\" = \"Ağ Yapılandırması Güncelleniyor\";\n"
"\"Uruguay\" = \"Uruguay\";\n"
"\"Usage: %s SUB-COMMAND [OPTIONS] [FILENAME]\\n\" = \"Kullanım: %s ALT-KOMUT [SEÇENEKLER] [DOSYA-ADI]\\n\";\n"
"\"Use My Position\" = \"Konumumu Kullan\";\n"
"\"Users\" = \"Kullanıcılar\";\n"
"\"Uzbekistan\" = \"Özbekistan\";\n"
"\"Vanuatu\" = \"Vanuatu\";\n"
"\"Venezuela (Bolivarian Republic of)\" = \"Venezuela Bolivar Cumhuriyeti\";\n"
"\"Version %s\" = \"Sürüm %s\";\n"
"\"Viet Nam\" = \"Vietnam\";\n"
"\"View Logs\" = \"Günlükleri Görüntüle\";\n"
"\"Virgin Islands (British)\" = \"Virgin Adaları (İngiliz)\";\n"
"\"Virgin Islands (U.S.)\" = \"Virgin Adaları (ABD)\";\n"
"\"Wallis and Futuna\" = \"Wallis ve Futuna\";\n"
"\"Warning\" = \"Uyarı\";\n"
"\"Western Sahara\" = \"Batı Sahra\";\n"
"\"Wi-Fi Configuration\" = \"Wi-Fi Yapılandırması\";\n"
"\"Wi-Fi Network\" = \"Wi-Fi Ağı\";\n"
"\"Width\" = \"Genişlik\";\n"
"\"Wrong old password.\" = \"Yanlış eski parola.\";\n"
"\"Yemen\" = \"Yemen\";\n"
"\"Zambia\" = \"Zambiya\";\n"
"\"Zimbabwe\" = \"Zimbabve\";\n"
"\"at %02d:%02d:%02d\" = \"%02d:%02d:%02d\";\n"
/* IPP attribute, keyword, and enum (integer) localizations */
"\"copies\" = \"Kopya Sayısı\";\n"
"\"default printer\" = \"öntanımlı yazıcı\";\n"
"\"finishings\" = \"Sonlandırıcı\";\n"
"\"finishings.10\" = \"Katla\";\n"
"\"finishings.100\" = \"Z katla\";\n"
"\"finishings.101\" = \"Mühendislik Z katla\";\n"
"\"finishings.11\" = \"Kes\";\n"
"\"finishings.12\" = \"Balya\";\n"
"\"finishings.13\" = \"Kitapçık yapıcısı\";\n"
"\"finishings.15\" = \"Kapla\";\n"
"\"finishings.16\" = \"Katmanla\";\n"
"\"finishings.20\" = \"Sol üstten zımbala\";\n"
"\"finishings.21\" = \"Sol alttan zımbala\";\n"
"\"finishings.22\" = \"Sağ üstten zımbala\";\n"
"\"finishings.23\" = \"Sağ alttan zımbala\";\n"
"\"finishings.24\" = \"Kenar dikişi solda\";\n"
"\"finishings.25\" = \"Kenar dikişi üstte\";\n"
"\"finishings.26\" = \"Kenar dikişi sağda\";\n"
"\"finishings.27\" = \"Kenar dikişi altta\";\n"
"\"finishings.28\" = \"Solda 2 zımba\";\n"
"\"finishings.29\" = \"Üstte 2 zımba\";\n"
"\"finishings.3\" = \"Hiçbiri\";\n"
"\"finishings.30\" = \"Sağda 2 zımba\";\n"
"\"finishings.31\" = \"Altta 2 zımba\";\n"
"\"finishings.32\" = \"Solda 3 zımba\";\n"
"\"finishings.33\" = \"Üstte 3 zımba\";\n"
"\"finishings.34\" = \"Sağda 3 zımba\";\n"
"\"finishings.35\" = \"Altta 3 zımba\";\n"
"\"finishings.4\" = \"Zımba\";\n"
"\"finishings.5\" = \"Delgeç\";\n"
"\"finishings.50\" = \"Sola bağla\";\n"
"\"finishings.51\" = \"Üste bağla\";\n"
"\"finishings.52\" = \"Sağa bağla\";\n"
"\"finishings.53\" = \"Alta bağla\";\n"
"\"finishings.6\" = \"Kapak\";\n"
"\"finishings.60\" = \"Her sayfadan sonra kes\";\n"
"\"finishings.61\" = \"Her belgeden sonra kes\";\n"
"\"finishings.62\" = \"Her kümeden sonra kes\";\n"
"\"finishings.63\" = \"Her işten sonra kes\";\n"
"\"finishings.7\" = \"Bağla\";\n"
"\"finishings.70\" = \"Sol üstten del\";\n"
"\"finishings.71\" = \"Sol alttan del\";\n"
"\"finishings.72\" = \"Sağ üstten del\";\n"
"\"finishings.73\" = \"Sağ alttan del\";\n"
"\"finishings.74\" = \"Soldan 2 delik del\";\n"
"\"finishings.75\" = \"Üstten 2 delik del\";\n"
"\"finishings.76\" = \"Sağdan 2 delik del\";\n"
"\"finishings.77\" = \"Alttan 2 delik del\";\n"
"\"finishings.78\" = \"Soldan 3 delik del\";\n"
"\"finishings.79\" = \"Üstten 3 delik del\";\n"
"\"finishings.8\" = \"Tel dikiş\";\n"
"\"finishings.80\" = \"Sağdan 3 delik del\";\n"
"\"finishings.81\" = \"Alttan 3 delik del\";\n"
"\"finishings.82\" = \"Soldan 4 delik del\";\n"
"\"finishings.83\" = \"Üstten 4 delik del\";\n"
"\"finishings.84\" = \"Sağdan 4 delik del\";\n"
"\"finishings.85\" = \"Alttan 4 delik del\";\n"
"\"finishings.86\" = \"Soldan çoklu delik del\";\n"
"\"finishings.87\" = \"Üstten çoklu delik del\";\n"
"\"finishings.88\" = \"Sağdan çoklu delik del\";\n"
"\"finishings.89\" = \"Alttan çoklu delik del\";\n"
"\"finishings.9\" = \"Kenar dikişi\";\n"
"\"finishings.90\" = \"Akordeon katlama\";\n"
"\"finishings.91\" = \"Çift kapı katlama\";\n"
"\"finishings.92\" = \"Kapı katlama\";\n"
"\"finishings.93\" = \"Yarım katlama\";\n"
"\"finishings.94\" = \"Yarım Z katlama\";\n"
"\"finishings.95\" = \"Sol kapı katlama\";\n"
"\"finishings.96\" = \"Mektup katlama\";\n"
"\"finishings.97\" = \"Paralel katlama\";\n"
"\"finishings.98\" = \"Poster katlama\";\n"
"\"finishings.99\" = \"Sağ kapı katlama\";\n"
"\"holding new jobs\" = \"yeni işler bekletiliyor\";\n"
"\"job-state-reasons.aborted-by-system\" = \"Durduruluyor.\";\n"
"\"job-state-reasons.compression-error\" = \"Sıkıştırma açılması hatası.\";\n"
"\"job-state-reasons.document-format-error\" = \"Belge biçimi hatası.\";\n"
"\"job-state-reasons.document-password-error\" = \"Belge parolası hatası.\";\n"
"\"job-state-reasons.document-permission-error\" = \"Belge izin hatası.\";\n"
"\"job-state-reasons.document-unprintable-error\" = \"Belge yazdırılamaz hatası.\";\n"
"\"job-state-reasons.errors-detected\" = \"Hatalar algılandı.\";\n"
"\"job-state-reasons.job-canceled-at-device\" = \"Yazıcıda iptal edildi.\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"Kullanıcı tarafından iptal edildi.\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"Yazdırıldı.\";\n"
"\"job-state-reasons.job-completed-with-errors\" = \"Hatalarla yazdırıldı.\";\n"
"\"job-state-reasons.job-completed-with-warnings\" = \"Uyarılarla yazdırıldı.\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"Yetersiz veri.\";\n"
"\"job-state-reasons.job-fetchable\" = \"Alınabilir.\";\n"
"\"job-state-reasons.job-incoming\" = \"Geliyor.\";\n"
"\"job-state-reasons.job-printing\" = \"Yazdırılıyor.\";\n"
"\"job-state-reasons.job-queued\" = \"Yazdırmaya hazırlanıyor.\";\n"
"\"job-state-reasons.job-spooling\" = \"Biriktiriliyor.\";\n"
"\"job-state-reasons.none\" = \"Bekliyor.\";\n"
"\"job-state-reasons.printer-stopped\" = \"Yazıcı çevrim dışı.\";\n"
"\"job-state-reasons.printer-stopped-partly\" = \"Yazıcı kısmen durduruldu.\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"Durduruluyor.\";\n"
"\"job-state-reasons.queued-in-device\" = \"Hazır.\";\n"
"\"job-state-reasons.warnings-detected\" = \"Uyarılar algılandı.\";\n"
"\"job-state.3\" = \"Bekliyor\";\n"
"\"job-state.4\" = \"Bekletildi\";\n"
"\"job-state.5\" = \"İşleniyor\";\n"
"\"job-state.6\" = \"Durduruldu\";\n"
"\"job-state.7\" = \"İptal edildi\";\n"
"\"job-state.8\" = \"Sonlandırıldı\";\n"
"\"job-state.9\" = \"Tamamlandı\";\n"
"\"joining\" = \"katılıyor\";\n"
"\"media\" = \"Ortam\";\n"
"\"media-col\" = \"Ortam\";\n"
"\"media-size\" = \"Ortam Boyutu\";\n"
"\"media-size-name\" = \"Ortam Boyutu\";\n"
"\"media-source\" = \"Giriş Tepsisi\";\n"
"\"media-source.alternate\" = \"Alternatif\";\n"
"\"media-source.alternate-roll\" = \"Alternatif silindir\";\n"
"\"media-source.auto\" = \"Otomatik\";\n"
"\"media-source.bottom\" = \"Alt\";\n"
"\"media-source.by-pass-tray\" = \"Çok amaçlı tepsi\";\n"
"\"media-source.center\" = \"Orta\";\n"
"\"media-source.disc\" = \"Disk\";\n"
"\"media-source.envelope\" = \"Zarf\";\n"
"\"media-source.hagaki\" = \"Hagaki\";\n"
"\"media-source.large-capacity\" = \"Büyük kapasite\";\n"
"\"media-source.left\" = \"Sol\";\n"
"\"media-source.main\" = \"Ana\";\n"
"\"media-source.main-roll\" = \"Ana silindir\";\n"
"\"media-source.manual\" = \"El ile\";\n"
"\"media-source.middle\" = \"Orta\";\n"
"\"media-source.photo\" = \"Fotoğraf\";\n"
"\"media-source.rear\" = \"Arka\";\n"
"\"media-source.right\" = \"Sağ\";\n"
"\"media-source.roll-1\" = \"Silindir 1\";\n"
"\"media-source.roll-10\" = \"Silindir 10\";\n"
"\"media-source.roll-2\" = \"Silindir 2\";\n"
"\"media-source.roll-3\" = \"Silindir 3\";\n"
"\"media-source.roll-4\" = \"Silindir 4\";\n"
"\"media-source.roll-5\" = \"Silindir 5\";\n"
"\"media-source.roll-6\" = \"Silindir 6\";\n"
"\"media-source.roll-7\" = \"Silindir 7\";\n"
"\"media-source.roll-8\" = \"Silindir 8\";\n"
"\"media-source.roll-9\" = \"Silindir 9\";\n"
"\"media-source.side\" = \"Yan\";\n"
"\"media-source.top\" = \"Üst\";\n"
"\"media-source.tray-1\" = \"Tepsi 1\";\n"
"\"media-source.tray-10\" = \"Tepsi 10\";\n"
"\"media-source.tray-11\" = \"Tepsi 11\";\n"
"\"media-source.tray-12\" = \"Tepsi 12\";\n"
"\"media-source.tray-13\" = \"Tepsi 13\";\n"
"\"media-source.tray-14\" = \"Tepsi 14\";\n"
"\"media-source.tray-15\" = \"Tepsi 15\";\n"
"\"media-source.tray-16\" = \"Tepsi 16\";\n"
"\"media-source.tray-17\" = \"Tepsi 17\";\n"
"\"media-source.tray-18\" = \"Tepsi 18\";\n"
"\"media-source.tray-19\" = \"Tepsi 19\";\n"
"\"media-source.tray-2\" = \"Tepsi 2\";\n"
"\"media-source.tray-20\" = \"Tepsi 20\";\n"
"\"media-source.tray-3\" = \"Tepsi 3\";\n"
"\"media-source.tray-4\" = \"Tepsi 4\";\n"
"\"media-source.tray-5\" = \"Tepsi 5\";\n"
"\"media-source.tray-6\" = \"Tepsi 6\";\n"
"\"media-source.tray-7\" = \"Tepsi 7\";\n"
"\"media-source.tray-8\" = \"Tepsi 8\";\n"
"\"media-source.tray-9\" = \"Tepsi 9\";\n"
"\"media-tracking\" = \"Ortam İzleme\";\n"
"\"media-tracking.continuous\" = \"Sürekli\";\n"
"\"media-tracking.gap\" = \"Boşluk\";\n"
"\"media-tracking.mark\" = \"İşaret\";\n"
"\"media-tracking.web\" = \"Web\";\n"
"\"media-type\" = \"Ortam Türü\";\n"
"\"media-type.aluminum\" = \"Alüminyum\";\n"
"\"media-type.auto\" = \"Otomatik\";\n"
"\"media-type.back-print-film\" = \"Arka baskı filmi\";\n"
"\"media-type.cardboard\" = \"Karton\";\n"
"\"media-type.cardstock\" = \"Kart\";\n"
"\"media-type.cd\" = \"CD\";\n"
"\"media-type.continuous\" = \"Sürekli\";\n"
"\"media-type.continuous-long\" = \"Sürekli uzun\";\n"
"\"media-type.continuous-short\" = \"Sürekli kısa\";\n"
"\"media-type.corrugated-board\" = \"Oluklu karton\";\n"
"\"media-type.disc\" = \"Optik disk\";\n"
"\"media-type.disc-glossy\" = \"Parlak optik disk\";\n"
"\"media-type.disc-high-gloss\" = \"Çok parlak optik disk\";\n"
"\"media-type.disc-matte\" = \"Mat optik disk\";\n"
"\"media-type.disc-satin\" = \"Saten optik disk\";\n"
"\"media-type.disc-semi-gloss\" = \"Yarı parlak optik disk\";\n"
"\"media-type.double-wall\" = \"Çift duvar\";\n"
"\"media-type.dry-film\" = \"Kuru film\";\n"
"\"media-type.dvd\" = \"DVD\";\n"
"\"media-type.embossing-foil\" = \"Kabartma folyo\";\n"
"\"media-type.end-board\" = \"Bitiş tahtası\";\n"
"\"media-type.envelope\" = \"Zarf\";\n"
"\"media-type.envelope-archival\" = \"Arşiv zarfı\";\n"
"\"media-type.envelope-bond\" = \"Bond zarfı\";\n"
"\"media-type.envelope-coated\" = \"Kaplamalı zarf\";\n"
"\"media-type.envelope-cotton\" = \"Pamuk zarf\";\n"
"\"media-type.envelope-fine\" = \"İnce zarf\";\n"
"\"media-type.envelope-heavyweight\" = \"Ağır zarf\";\n"
"\"media-type.envelope-inkjet\" = \"Mürekkep püskürtmeli zarf\";\n"
"\"media-type.envelope-lightweight\" = \"Hafif zarf\";\n"
"\"media-type.envelope-plain\" = \"Düz zarf\";\n"
"\"media-type.envelope-preprinted\" = \"Önceden baskılı zarf\";\n"
"\"media-type.envelope-window\" = \"Pencereli zarf\";\n"
"\"media-type.fabric\" = \"Kumaş\";\n"
"\"media-type.fabric-archival\" = \"Arşiv kumaşı\";\n"
"\"media-type.fabric-glossy\" = \"Parlak kumaş\";\n"
"\"media-type.fabric-high-gloss\" = \"Çok parlak kumaş\";\n"
"\"media-type.fabric-matte\" = \"Mat kumaş\";\n"
"\"media-type.fabric-semi-gloss\" = \"Yarı parlak kumaş\";\n"
"\"media-type.fabric-waterproof\" = \"Su geçirmez kumaş\";\n"
"\"media-type.film\" = \"Film\";\n"
"\"media-type.flexo-base\" = \"Flekso taban\";\n"
"\"media-type.flexo-photo-polymer\" = \"Flekso fotoğraf polimeri\";\n"
"\"media-type.flute\" = \"Oluk\";\n"
"\"media-type.foil\" = \"Folyo\";\n"
"\"media-type.full-cut-tabs\" = \"Tam kesim sekmeler\";\n"
"\"media-type.glass\" = \"Cam\";\n"
"\"media-type.glass-colored\" = \"Cam renkli\";\n"
"\"media-type.glass-opaque\" = \"Cam opak\";\n"
"\"media-type.glass-surfaced\" = \"Cam yüzeyli\";\n"
"\"media-type.glass-textured\" = \"Cam dokulu\";\n"
"\"media-type.gravure-cylinder\" = \"Gravür silindiri\";\n"
"\"media-type.image-setter-paper\" = \"Görüntü ayarlayıcı kağıt\";\n"
"\"media-type.imaging-cylinder\" = \"Görüntüleme silindiri\";\n"
"\"media-type.labels\" = \"Etiketler\";\n"
"\"media-type.labels-colored\" = \"Renkli etiketler\";\n"
"\"media-type.labels-glossy\" = \"Parlak etiketler\";\n"
"\"media-type.labels-high-gloss\" = \"Çok parlak etiketler\";\n"
"\"media-type.labels-inkjet\" = \"Mürekkep püskürtmeli etiketler\";\n"
"\"media-type.labels-matte\" = \"Mat etiketler\";\n"
"\"media-type.labels-permanent\" = \"Kalıcı etiketler\";\n"
"\"media-type.labels-satin\" = \"Saten etiketler\";\n"
"\"media-type.labels-security\" = \"Güvenlik etiketleri\";\n"
"\"media-type.labels-semi-gloss\" = \"Yarı parlak etiketler\";\n"
"\"media-type.laminating-foil\" = \"Katmanlama folyosu\";\n"
"\"media-type.letterhead\" = \"Antetli kağıt\";\n"
"\"media-type.metal\" = \"Metal\";\n"
"\"media-type.metal-glossy\" = \"Metal parlak\";\n"
"\"media-type.metal-high-gloss\" = \"Metal çok parlak\";\n"
"\"media-type.metal-matte\" = \"Metal mat\";\n"
"\"media-type.metal-satin\" = \"Metal saten\";\n"
"\"media-type.metal-semi-gloss\" = \"Metal yarı parlak\";\n"
"\"media-type.mounting-tape\" = \"Montaj bandı\";\n"
"\"media-type.multi-layer\" = \"Çok katmanlı\";\n"
"\"media-type.multi-part-form\" = \"Çok parçalı form\";\n"
"\"media-type.other\" = \"Diğer\";\n"
"\"media-type.paper\" = \"Kağıt\";\n"
"\"media-type.photographic\" = \"Fotoğraf kağıdı\";\n"
"\"media-type.photographic-archival\" = \"Fotoğraf arşivi\";\n"
"\"media-type.photographic-film\" = \"Fotoğraf filmi\";\n"
"\"media-type.photographic-glossy\" = \"Parlak fotoğraf kağıdı\";\n"
"\"media-type.photographic-high-gloss\" = \"Çok parlak fotoğraf kağıdı\";\n"
"\"media-type.photographic-matte\" = \"Mat fotoğraf kağıdı\";\n"
"\"media-type.photographic-satin\" = \"Saten fotoğraf kağıdı\";\n"
"\"media-type.photographic-semi-gloss\" = \"Yarı parlak fotoğraf kağıdı\";\n"
"\"media-type.plastic\" = \"Plastik\";\n"
"\"media-type.plastic-archival\" = \"Plastik arşiv\";\n"
"\"media-type.plastic-colored\" = \"Plastik renkli\";\n"
"\"media-type.plastic-glossy\" = \"Plastik parlak\";\n"
"\"media-type.plastic-high-gloss\" = \"Plastik çok parlak\";\n"
"\"media-type.plastic-matte\" = \"Plastik mat\";\n"
"\"media-type.plastic-satin\" = \"Plastik saten\";\n"
"\"media-type.plastic-semi-gloss\" = \"Plastik yarı parlak\";\n"
"\"media-type.plate\" = \"Levha\";\n"
"\"media-type.polyester\" = \"Polyester\";\n"
"\"media-type.pre-cut-tabs\" = \"Önceden kesilmiş sekmeler\";\n"
"\"media-type.roll\" = \"Rulo\";\n"
"\"media-type.screen\" = \"Ekran\";\n"
"\"media-type.screen-paged\" = \"Ekran sayfalı\";\n"
"\"media-type.self-adhesive\" = \"Kendinden yapışkanlı\";\n"
"\"media-type.self-adhesive-film\" = \"Kendinden yapışkanlı film\";\n"
"\"media-type.shrink-foil\" = \"Daralan folyo\";\n"
"\"media-type.single-face\" = \"Tek yüz\";\n"
"\"media-type.single-wall\" = \"Tek duvar\";\n"
"\"media-type.sleeve\" = \"Kol\";\n"
"\"media-type.stationery\" = \"Kırtasiye\";\n"
"\"media-type.stationery-archival\" = \"Kırtasiye arşiv\";\n"
"\"media-type.stationery-coated\" = \"Kaplamalı kağıt\";\n"
"\"media-type.stationery-cotton\" = \"Kırtasiye pamuk\";\n"
"\"media-type.stationery-fine\" = \"Parşömen kağıt\";\n"
"\"media-type.stationery-heavyweight\" = \"Ağır kağıt\";\n"
"\"media-type.stationery-heavyweight-coated\" = \"Kırtasiye ağır kaplamalı\";\n"
"\"media-type.stationery-inkjet\" = \"Kırtasiye mürekkep püskürtmeli kağıt\";\n"
"\"media-type.stationery-letterhead\" = \"Antetli kağıt\";\n"
"\"media-type.stationery-lightweight\" = \"Hafif kağıt\";\n"
"\"media-type.stationery-preprinted\" = \"Önceden basılmış kağıt\";\n"
"\"media-type.stationery-prepunched\" = \"Delikli kağıt\";\n"
"\"media-type.tab-stock\" = \"Sekme stoğu\";\n"
"\"media-type.tractor\" = \"Traktör\";\n"
"\"media-type.transfer\" = \"Aktarım\";\n"
"\"media-type.transparency\" = \"Şeffaflık\";\n"
"\"media-type.triple-wall\" = \"Üçlü duvar\";\n"
"\"media-type.wet-film\" = \"Islak film\";\n"
"\"media.choice_iso_a4_210x297mm_na_letter_8.5x11in\" = \"A4 veya ABD Mektup\";\n"
"\"media.iso_2a0_1189x1682mm\" = \"2a0\";\n"
"\"media.iso_a0_841x1189mm\" = \"A0\";\n"
"\"media.iso_a0x3_1189x2523mm\" = \"A0x3\";\n"
"\"media.iso_a10_26x37mm\" = \"A10\";\n"
"\"media.iso_a1_594x841mm\" = \"A1\";\n"
"\"media.iso_a1x3_841x1783mm\" = \"A1x3\";\n"
"\"media.iso_a1x4_841x2378mm\" = \"A1x4\";\n"
"\"media.iso_a2_420x594mm\" = \"A2\";\n"
"\"media.iso_a2x3_594x1261mm\" = \"A2x3\";\n"
"\"media.iso_a2x4_594x1682mm\" = \"A2x4\";\n"
"\"media.iso_a2x5_594x2102mm\" = \"A2x5\";\n"
"\"media.iso_a3-extra_322x445mm\" = \"A3 (ek)\";\n"
"\"media.iso_a3_297x420mm\" = \"A3\";\n"
"\"media.iso_a3x3_420x891mm\" = \"A3x3\";\n"
"\"media.iso_a3x4_420x1189mm\" = \"A3x4\";\n"
"\"media.iso_a3x5_420x1486mm\" = \"A3x5\";\n"
"\"media.iso_a3x6_420x1783mm\" = \"A3x6\";\n"
"\"media.iso_a3x7_420x2080mm\" = \"A3x7\";\n"
"\"media.iso_a4-extra_235.5x322.3mm\" = \"A4 (ek)\";\n"
"\"media.iso_a4-tab_225x297mm\" = \"A4 (sekme)\";\n"
"\"media.iso_a4_210x297mm\" = \"A4\";\n"
"\"media.iso_a4x3_297x630mm\" = \"A4x3\";\n"
"\"media.iso_a4x4_297x841mm\" = \"A4x4\";\n"
"\"media.iso_a4x5_297x1051mm\" = \"A4x5\";\n"
"\"media.iso_a4x6_297x1261mm\" = \"A4x6\";\n"
"\"media.iso_a4x7_297x1471mm\" = \"A4x7\";\n"
"\"media.iso_a4x8_297x1682mm\" = \"A4x8\";\n"
"\"media.iso_a4x9_297x1892mm\" = \"A4x9\";\n"
"\"media.iso_a5-extra_174x235mm\" = \"A5 (ek)\";\n"
"\"media.iso_a5_148x210mm\" = \"A5\";\n"
"\"media.iso_a6_105x148mm\" = \"A6\";\n"
"\"media.iso_a7_74x105mm\" = \"A7\";\n"
"\"media.iso_a8_52x74mm\" = \"A8\";\n"
"\"media.iso_a9_37x52mm\" = \"A9\";\n"
"\"media.iso_b0_1000x1414mm\" = \"B0\";\n"
"\"media.iso_b10_31x44mm\" = \"B10\";\n"
"\"media.iso_b1_707x1000mm\" = \"B1\";\n"
"\"media.iso_b2_500x707mm\" = \"B2\";\n"
"\"media.iso_b3_353x500mm\" = \"B3\";\n"
"\"media.iso_b4_250x353mm\" = \"B4\";\n"
"\"media.iso_b5-extra_201x276mm\" = \"B5 (ek)\";\n"
"\"media.iso_b5_176x250mm\" = \"B5 Zarf\";\n"
"\"media.iso_b6_125x176mm\" = \"B6\";\n"
"\"media.iso_b6c4_125x324mm\" = \"B6/C4Zarf\";\n"
"\"media.iso_b7_88x125mm\" = \"B7\";\n"
"\"media.iso_b8_62x88mm\" = \"B8\";\n"
"\"media.iso_b9_44x62mm\" = \"B9\";\n"
"\"media.iso_c0_917x1297mm\" = \"C0 Zarf\";\n"
"\"media.iso_c10_28x40mm\" = \"C10 Zarf\";\n"
"\"media.iso_c1_648x917mm\" = \"C1 Zarf\";\n"
"\"media.iso_c2_458x648mm\" = \"C2 Zarf\";\n"
"\"media.iso_c3_324x458mm\" = \"C3 Zarf\";\n"
"\"media.iso_c4_229x324mm\" = \"C4 Zarf\";\n"
"\"media.iso_c5_162x229mm\" = \"C5 Zarf\";\n"
"\"media.iso_c6_114x162mm\" = \"C6 Zarf\";\n"
"\"media.iso_c6c5_114x229mm\" = \"C6/C5 Zarf\";\n"
"\"media.iso_c7_81x114mm\" = \"C7 Zarf\";\n"
"\"media.iso_c7c6_81x162mm\" = \"C7/C6 Zarf\";\n"
"\"media.iso_c8_57x81mm\" = \"C8 Zarf\";\n"
"\"media.iso_c9_40x57mm\" = \"C9 Zarf\";\n"
"\"media.iso_dl_110x220mm\" = \"DL Zarf\";\n"
"\"media.iso_ra0_860x1220mm\" = \"ISO RA0\";\n"
"\"media.iso_ra1_610x860mm\" = \"ISO RA1\";\n"
"\"media.iso_ra2_430x610mm\" = \"ISO RA2\";\n"
"\"media.iso_ra3_305x430mm\" = \"ISO RA3\";\n"
"\"media.iso_ra4_215x305mm\" = \"ISO RA4\";\n"
"\"media.iso_sra0_900x1280mm\" = \"ISO SRA0\";\n"
"\"media.iso_sra1_640x900mm\" = \"ISO SRA1\";\n"
"\"media.iso_sra2_450x640mm\" = \"ISO SRA2\";\n"
"\"media.iso_sra3_320x450mm\" = \"ISO SRA3\";\n"
"\"media.iso_sra4_225x320mm\" = \"ISO SRA4\";\n"
"\"media.jis_b0_1030x1456mm\" = \"JIS B0\";\n"
"\"media.jis_b10_32x45mm\" = \"JIS B10\";\n"
"\"media.jis_b1_728x1030mm\" = \"JIS B1\";\n"
"\"media.jis_b2_515x728mm\" = \"JIS B2\";\n"
"\"media.jis_b3_364x515mm\" = \"JIS B3\";\n"
"\"media.jis_b4_257x364mm\" = \"JIS B4\";\n"
"\"media.jis_b5_182x257mm\" = \"JIS B5\";\n"
"\"media.jis_b6_128x182mm\" = \"JIS B6\";\n"
"\"media.jis_b7_91x128mm\" = \"JIS B7\";\n"
"\"media.jis_b8_64x91mm\" = \"JIS B8\";\n"
"\"media.jis_b9_45x64mm\" = \"JIS B9\";\n"
"\"media.jis_exec_216x330mm\" = \"JIS Yönetici\";\n"
"\"media.jpn_chou2_111.1x146mm\" = \"Zarf Chou 2\";\n"
"\"media.jpn_chou3_120x235mm\" = \"Zarf Chou 3\";\n"
"\"media.jpn_chou40_90x225mm\" = \"Zarf Chou 40\";\n"
"\"media.jpn_chou4_90x205mm\" = \"Zarf Chou 4\";\n"
"\"media.jpn_hagaki_100x148mm\" = \"Hagaki\";\n"
"\"media.jpn_kahu_240x322.1mm\" = \"Zarf Kahu\";\n"
"\"media.jpn_kaku2_240x332mm\" = \"Zarf Kahu 2\";\n"
"\"media.jpn_oufuku_148x200mm\" = \"Oufuku Cevap Kartpostalı\";\n"
"\"media.jpn_you4_105x235mm\" = \"Zarf Sen 4\";\n"
"\"media.na_a2_4.375x5.75in\" = \"Zarf A2\";\n"
"\"media.na_c5_6.5x9.5in\" = \"Zarf C5\";\n"
"\"media.na_executive_7.25x10.5in\" = \"Yönetici\";\n"
"\"media.na_fanfold-eur_8.5x12in\" = \"Avrupa Yelpaze\";\n"
"\"media.na_fanfold-us_11x14.875in\" = \"ABD Yelpaze\";\n"
"\"media.na_foolscap_8.5x13in\" = \"Büyük Dosya Kağıdı\";\n"
"\"media.na_invoice_5.5x8.5in\" = \"Beyanat\";\n"
"\"media.na_legal-extra_9.5x15in\" = \"ABD Yasal (Ek)\";\n"
"\"media.na_legal_8.5x14in\" = \"ABD Yasal\";\n"
"\"media.na_letter-extra_9.5x12in\" = \"ABD Mektup (Ek)\";\n"
"\"media.na_letter-plus_8.5x12.69in\" = \"ABD Mektup (Artı)\";\n"
"\"media.na_letter_8.5x11in\" = \"ABD Mektup\";\n"
"\"media.na_monarch_3.875x7.5in\" = \"Kraliyet Zarfı\";\n"
"\"media.na_number-10_4.125x9.5in\" = \"Zarf #10\";\n"
"\"media.na_number-11_4.5x10.375in\" = \"Zarf #11\";\n"
"\"media.na_number-12_4.75x11in\" = \"Zarf #12\";\n"
"\"media.na_number-14_5x11.5in\" = \"Zarf #14\";\n"
"\"media.na_number-9_3.875x8.875in\" = \"Zarf #9\";\n"
"\"media.na_personal_3.625x6.5in\" = \"Kişisel Zarf\";\n"
"\"media.na_quarto_8.5x10.83in\" = \"Çeyrek\";\n"
"\"media.om_folio-sp_215x315mm\" = \"Folyo\";\n"
"\"media.om_folio_210x330mm\" = \"Folyo (Özel)\";\n"
"\"media.om_invite_220x220mm\" = \"Davetiye Zarfı\";\n"
"\"media.om_italian_110x230mm\" = \"İtalyan Zarfı\";\n"
"\"media.om_juuro-ku-kai_198x275mm\" = \"198 x 275mm\";\n"
"\"media.om_large-photo_200x300\" = \"200 x 300\";\n"
"\"media.om_medium-photo_130x180mm\" = \"130 x 180mm\";\n"
"\"media.om_pa-kai_267x389mm\" = \"267 x 389mm\";\n"
"\"media.om_postfix_114x229mm\" = \"Postfix Zarfı\";\n"
"\"media.prc_10_324x458mm\" = \"Çin Zarfı #10\";\n"
"\"media.prc_16k_146x215mm\" = \"Çin 16k\";\n"
"\"media.prc_1_102x165mm\" = \"Çin Zarfı #1\";\n"
"\"media.prc_2_102x176mm\" = \"Çin Zarfı #2\";\n"
"\"media.prc_32k_97x151mm\" = \"Çin 32k\";\n"
"\"media.prc_3_125x176mm\" = \"Çin Zarfı #3\";\n"
"\"media.prc_4_110x208mm\" = \"Çin Zarfı #4\";\n"
"\"media.prc_5_110x220mm\" = \"Çin Zarfı #5\";\n"
"\"media.prc_6_120x320mm\" = \"Çin Zarfı #6\";\n"
"\"media.prc_7_160x230mm\" = \"Çin Zarfı #7\";\n"
"\"media.prc_8_120x309mm\" = \"Çin Zarfı #8\";\n"
"\"media.roc_16k_7.75x10.75in\" = \"ROC 16k\";\n"
"\"media.roc_8k_10.75x15.5in\" = \"ROC 8k\";\n"
"\"not configured\" = \"yapılandırılmadı\";\n"
"\"not visible\" = \"görünür değil\";\n"
"\"off\" = \"kapalı\";\n"
"\"on\" = \"açık\";\n"
"\"orientation-requested\" = \"Yön\";\n"
"\"orientation-requested.3\" = \"Portre\";\n"
"\"orientation-requested.4\" = \"Manzara\";\n"
"\"orientation-requested.5\" = \"Ters manzara\";\n"
"\"orientation-requested.6\" = \"Ters portre\";\n"
"\"orientation-requested.7\" = \"Hiçbiri\";\n"
"\"output-bin\" = \"Çıkış Tepsisi\";\n"
"\"output-bin.auto\" = \"Otomatik\";\n"
"\"output-bin.bottom\" = \"Alt\";\n"
"\"output-bin.center\" = \"Orta\";\n"
"\"output-bin.face-down\" = \"Yüzü aşağı dönük\";\n"
"\"output-bin.face-up\" = \"Yüzü yukarı dönük\";\n"
"\"output-bin.large-capacity\" = \"Büyük kapasite\";\n"
"\"output-bin.left\" = \"Sol\";\n"
"\"output-bin.mailbox-1\" = \"Posta kutusu 1\";\n"
"\"output-bin.mailbox-10\" = \"Posta kutusu 10\";\n"
"\"output-bin.mailbox-2\" = \"Posta kutusu 2\";\n"
"\"output-bin.mailbox-3\" = \"Posta kutusu 3\";\n"
"\"output-bin.mailbox-4\" = \"Posta kutusu 4\";\n"
"\"output-bin.mailbox-5\" = \"Posta kutusu 5\";\n"
"\"output-bin.mailbox-6\" = \"Posta kutusu 6\";\n"
"\"output-bin.mailbox-7\" = \"Posta kutusu 7\";\n"
"\"output-bin.mailbox-8\" = \"Posta kutusu 8\";\n"
"\"output-bin.mailbox-9\" = \"Posta kutusu 9\";\n"
"\"output-bin.middle\" = \"Orta\";\n"
"\"output-bin.my-mailbox\" = \"Posta kutum\";\n"
"\"output-bin.rear\" = \"Arka\";\n"
"\"output-bin.right\" = \"Sağ\";\n"
"\"output-bin.side\" = \"Yan\";\n"
"\"output-bin.stacker-1\" = \"Yığıcı 1\";\n"
"\"output-bin.stacker-10\" = \"Yığıcı 10\";\n"
"\"output-bin.stacker-2\" = \"Yığıcı 2\";\n"
"\"output-bin.stacker-3\" = \"Yığıcı 3\";\n"
"\"output-bin.stacker-4\" = \"Yığıcı 4\";\n"
"\"output-bin.stacker-5\" = \"Yığıcı 5\";\n"
"\"output-bin.stacker-6\" = \"Yığıcı 6\";\n"
"\"output-bin.stacker-7\" = \"Yığıcı 7\";\n"
"\"output-bin.stacker-8\" = \"Yığıcı 8\";\n"
"\"output-bin.stacker-9\" = \"Yığıcı 9\";\n"
"\"output-bin.top\" = \"Üst\";\n"
"\"output-bin.tray-1\" = \"Tepsi 1\";\n"
"\"output-bin.tray-10\" = \"Tepsi 10\";\n"
"\"output-bin.tray-2\" = \"Tepsi 2\";\n"
"\"output-bin.tray-3\" = \"Tepsi 3\";\n"
"\"output-bin.tray-4\" = \"Tepsi 4\";\n"
"\"output-bin.tray-5\" = \"Tepsi 5\";\n"
"\"output-bin.tray-6\" = \"Tepsi 6\";\n"
"\"output-bin.tray-7\" = \"Tepsi 7\";\n"
"\"output-bin.tray-8\" = \"Tepsi 8\";\n"
"\"output-bin.tray-9\" = \"Tepsi 9\";\n"
"\"print-color-mode\" = \"Yazdırma Modu\";\n"
"\"print-color-mode.auto\" = \"Otomatik\";\n"
"\"print-color-mode.auto-monochrome\" = \"Otomatik tek renkli\";\n"
"\"print-color-mode.bi-level\" = \"Metin\";\n"
"\"print-color-mode.color\" = \"Renk\";\n"
"\"print-color-mode.highlight\" = \"Vurgula\";\n"
"\"print-color-mode.monochrome\" = \"Tek renkli\";\n"
"\"print-color-mode.process-bi-level\" = \"Metin işle\";\n"
"\"print-color-mode.process-monochrome\" = \"Tek renkli işle\";\n"
"\"print-content-optimize\" = \"İyileştir\";\n"
"\"print-content-optimize.auto\" = \"Otomatik\";\n"
"\"print-content-optimize.graphic\" = \"Grafik\";\n"
"\"print-content-optimize.photo\" = \"Fotoğraf\";\n"
"\"print-content-optimize.text\" = \"Metin\";\n"
"\"print-content-optimize.text-and-graphic\" = \"Metin ve grafikler\";\n"
"\"print-darkness\" = \"Yazdırma Koyuluğu\";\n"
"\"print-quality\" = \"Yazdırma Kalitesi\";\n"
"\"print-quality.3\" = \"Taslak\";\n"
"\"print-quality.4\" = \"Normal\";\n"
"\"print-quality.5\" = \"En iyi\";\n"
"\"print-scaling\" = \"Ölçekleme\";\n"
"\"print-scaling.auto\" = \"Otomatik\";\n"
"\"print-scaling.auto-fit\" = \"Otomatik sığdır\";\n"
"\"print-scaling.fill\" = \"Doldur\";\n"
"\"print-scaling.fit\" = \"Sığdır\";\n"
"\"print-scaling.none\" = \"Hiçbiri\";\n"
"\"print-speed\" = \"Yazdırma Hızı\";\n"
"\"printer-resolution\" = \"Çözünürlük\";\n"
"\"printer-state-reasons.cover-open\" = \"Kapak açık.\";\n"
"\"printer-state-reasons.door-open\" = \"Kapı açık.\";\n"
"\"printer-state-reasons.identify-printer-requested\" = \"Yazıcı tanımla.\";\n"
"\"printer-state-reasons.input-tray-missing\" = \"Kağıt tepsisi eksik.\";\n"
"\"printer-state-reasons.marker-supply-empty\" = \"Mürekkep bitti.\";\n"
"\"printer-state-reasons.marker-supply-low\" = \"Mürekkep az kaldı.\";\n"
"\"printer-state-reasons.marker-waste-almost-full\" = \"Atık kutusu neredeyse dolu.\";\n"
"\"printer-state-reasons.marker-waste-full\" = \"Atık kutusu dolu.\";\n"
"\"printer-state-reasons.media-empty\" = \"Kağıt bitti.\";\n"
"\"printer-state-reasons.media-jam\" = \"Kağıt sıkıştı.\";\n"
"\"printer-state-reasons.media-low\" = \"Kağıdı yakında değiştir.\";\n"
"\"printer-state-reasons.media-needed\" = \"Kağıt yükle.\";\n"
"\"printer-state-reasons.none\" = \"Hazır.\";\n"
"\"printer-state-reasons.offline\" = \"Çevrim dışı.\";\n"
"\"printer-state-reasons.other\" = \"Yazıcıya bakın.\";\n"
"\"printer-state-reasons.spool-area-full\" = \"Yazıcı meşgul.\";\n"
"\"printer-state-reasons.toner-empty\" = \"Toner bitti.\";\n"
"\"printer-state-reasons.toner-low\" = \"Toner az kaldı.\";\n"
"\"printer-state.3\" = \"Boşta\";\n"
"\"printer-state.4\" = \"İşleniyor\";\n"
"\"printer-state.5\" = \"Durduruldu\";\n"
"\"sides\" = \"2 Taraflı Yazdırma\";\n"
"\"sides.one-sided\" = \"Kapalı\";\n"
"\"sides.two-sided-long-edge\" = \"Açık (portre)\";\n"
"\"sides.two-sided-short-edge\" = \"Açık (manzara)\";\n"
"\"unable to join\" = \"katılamıyor\";\n"
"\"yesterday at %02d:%02d:%02d\" = \"dün, %02d:%02d:%02d\";\n"
"\"Åland Islands\" = \"Åland Adaları\";\n";
