static const char *it_strings = "\"  -a               Cancel all jobs (cancel).\" = \"  -a               Annulla tutti i lavori (cancella.)\";\n"
"\"  -c COPIES\" = \"-c COP\";\n"
"\"  -d PRINTER       Specify printer.\" = \"  -d PRINTER       Specifica la stampante.\";\n"
"\"  -j JOB-ID        Specify job ID (cancel).\" = \"  -j JOB-ID        Specificare l'ID del lavoro (cancel.)\";\n"
"\"  -m DRIVER-NAME   Specify driver (add/modify).\" = \"  -m DRIVER-NAME   Specificare il driver (add/modify.)\";\n"
"\"  -n COPIES        Specify number of copies (submit).\" = \"  -n COPIES        Specificare il numero di copie (sottomesso.)\";\n"
"\"  -o %s=%s (default)\" = \"  -o %s=%s (default)\";\n"
"\"  -o NAME=VALUE    Specify option (add,modify,server,submit).\" = \"  -o NAME=VALUE    Specificare l'opzione (add,modify,server,submit.)\";\n"
"\"  -o print-darkness=-100 to 100\" = \"  -o print-darkness=-100 a 100\";\n"
"\"  -o printer-darkness=0 to 100\" = \"  -o printer-darkness=0 a 100\";\n"
"\"  -o printer-geo-location='geo:LATITUDE,LONGITUDE'\" = \"  -o printer-geo-location='geo:LATITUDE,LONGITUDE\";\n"
"\"  -o printer-location='LOCATION'\" = \"  -o printer-location='LOCATION\";\n"
"\"  -o printer-organization='ORGANIZATION'\" = \"  -o printer-organization='ORGANIZZAZIONE\";\n"
"\"  -o printer-organizational-unit='UNIT/SECTION'\" = \"  -o printer-organizational-unit='UNIT/SECTION\";\n"
"\"  -u URI           Specify ipp: or ipps: printer/server.\" = \"  -u URI           Specifica ipp: o ipps: stampante/server.\";\n"
"\"  -v DEVICE-URI    Specify socket: or usb: device (add/modify).\" = \"  -v DEVICE-URI    Specificare la presa: o usb: dispositivo (add/modify.)\";\n"
"\"  add PRINTER      Add a printer.\" = \"  add PRINTER      Aggiungi una stampante.\";\n"
"\"  autoadd          Automatically add supported printers.\" = \"  autoadd          Aggiungi automaticamente le stampanti supportate.\";\n"
"\"  cancel           Cancel one or more jobs.\" = \"  cancel           Cancella uno o più lavori.\";\n"
"\"  default          Set the default printer.\" = \"  default          Impostare la stampante predefinita.\";\n"
"\"  delete           Delete a printer.\" = \"  delete           Cancella una stampante.\";\n"
"\"  devices          List devices.\" = \"  devices          Elenca dispositivi.\";\n"
"\"  drivers          List drivers.\" = \"  drivers          Elenca i driver.\";\n"
"\"  jobs             List jobs.\" = \"  jobs             Lista lavori.\";\n"
"\"  modify           Modify a printer.\" = \"  modify           modificare una stampante.\";\n"
"\"  options          List printer options.\" = \"  options          Elenca le opzioni della stampante.\";\n"
"\"  pause            Pause printing for a printer.\" = \"  pause            Stampa pausa per una stampante.\";\n"
"\"  printers         List printers.\" = \"  printers         Elenca le stampanti.\";\n"
"\"  resume           Resume printing for a printer.\" = \"  resume           Riprendi la stampa per una stampante.\";\n"
"\"  server           Run a server.\" = \"  server           Eseguire un server.\";\n"
"\"  shutdown         Shutdown a running server.\" = \"  shutdown         Spegni un server in esecuzione.\";\n"
"\"  status           Show server/printer/job status.\" = \"  status           Mostra lo stato server/printer/job.\";\n"
"\"  submit           Submit a file for printing.\" = \"  submit           inviare un file per la stampa.\";\n"
"\"%04d-%02d-%02d at %02d:%02d:%02d\" = \"%04d-%02d-%02d at %02d:%02d:%02d\";\n"
"\"%d days ago at %02d:%02d:%02d\" = \"%d days ago at %02d:%02d:%02d\";\n"
"\"%d inches/sec\" = \"%d pollici/sec\";\n"
"\"%d job\" = \"%d lavoro\";\n"
/* Media size in millimeters */
"\"%d x %dmm\" = \"%d x %d mm\";\n"
"\"%ddpi\" = \"%d dpi\";\n"
"\"%dx%ddpi\" = \"%d x %d dpi\";\n"
/* Media size in inches */
"\"%g x %g\\\"\" = \"%g x %g \\\"\";\n"
/* size (type+borderless) */
"\"%s (%s%s)\" = \"%s ( %s %s )\";\n"
/* size (type+borderless) from source/tray */
"\"%s (%s%s) from %s\" = \"%s (%s%s) da %s\";\n"
/* Source/Tray Media */
"\"%s Media\" = \"%s Media\";\n"
"\"%s: Bad 'server-port' value.\" = \"%s: Bad server-port value.\";\n"
"\"%s: Bad job ID.\" = \"Bad job ID.\";\n"
"\"%s: Bad printer URI '%s'.\" = \"%s: Scarsa URI stampante ' %s '.\";\n"
"\"%s: Cannot specify more than one sub-command.\" = \"%s: Non è possibile specificare più di un sottocomando.\";\n"
"\"%s: Empty print file received on the standard input.\" = \"%s: File di stampa vuoto ricevuto sull'ingresso standard.\";\n"
"\"%s: Failed to create a system.\" = \"%s: Non è riuscito a creare un sistema.\";\n"
"\"%s: Missing '-d PRINTER'.\" = \"%s: Manca il \\\"-d PRINTER\\\". '\";\n"
"\"%s: Missing '-m DRIVER-NAME'.\" = \"%s: Mancano '-m DRIVER-NAME. '\";\n"
"\"%s: Missing '-v DEVICE-URI'.\" = \"%s: Manca \\\"-v DEVICE-URI\\\". '\";\n"
"\"%s: Missing copy count after '-n'.\" = \"%s: Conto di copia mancante dopo -n.\";\n"
"\"%s: Missing device URI after '-v'.\" = \"%s: URI dispositivo mancante dopo -v.\";\n"
"\"%s: Missing driver name after '-m'.\" = \"%s: Nome del conducente mancante dopo -m.\";\n"
"\"%s: Missing filename after '--'.\" = \"%s: Nome file mancante dopo \\\"--\\\".\";\n"
"\"%s: Missing hostname after '-h'.\" = \"%s: Nome host mancante dopo -h.\";\n"
"\"%s: Missing job ID after '-j'.\" = \"%s: Identificazione del lavoro dopo -j.\";\n"
"\"%s: Missing option(s) after '-o'.\" = \"%s: opzione mancante (s) dopo -o.\";\n"
"\"%s: Missing printer URI after '-u'.\" = \"%s: URI della stampante mancante dopo -u.\";\n"
"\"%s: Missing printer name after '-d'.\" = \"%s: Nome della stampante mancante dopo -d.\";\n"
"\"%s: Missing space after '-o'.\" = \"%s: Manca spazio dopo -o.\";\n"
"\"%s: Missing title after '-t'.\" = \"%s: Titolo mancante dopo -t.\";\n"
"\"%s: No default printer available.\" = \"%s: Nessuna stampante predefinita disponibile.\";\n"
"\"%s: No files to print.\" = \"%s: Nessun file da stampare.\";\n"
"\"%s: Server is not running.\" = \"%s: Il server non è in esecuzione.\";\n"
"\"%s: Sub-command '%s' does not accept files.\" = \"%s: Sub-command '%s' non accetta i file.\";\n"
"\"%s: Sub-command 'autoadd' is not supported.\" = \"%s: L'autoadd subcomand non è supportato.\";\n"
"\"%s: Too many files.\" = \"%s: Troppi file.\";\n"
"\"%s: Unable to access '%s': %s\" = \"%s: Incapace di accedere '%s': %s\";\n"
"\"%s: Unable to add printer: %s\" = \"%s: Incapace di aggiungere la stampante: %s\";\n"
"\"%s: Unable to cancel job: %s\" = \"%s: Incapace di annullare il lavoro: %s\";\n"
"\"%s: Unable to connect to printer at '%s:%d': %s\" = \"%s: Incapace di connettersi alla stampante a '%s:%d': %s\";\n"
"\"%s: Unable to connect to server: %s\" = \"%s: Incapace di connettersi al server: %s\";\n"
"\"%s: Unable to create temporary file: %s\" = \"%s: Incapace di creare file temporanei: %s\";\n"
"\"%s: Unable to delete printer: %s\" = \"%s: Incapace di eliminare la stampante: %s\";\n"
"\"%s: Unable to get available devices: %s\" = \"%s: Unable to get available devices: %s\";\n"
"\"%s: Unable to get information for '%s': %s\" = \"%s: Incapace di ottenere informazioni per '%s': %s\";\n"
"\"%s: Unable to get information for printer: %s\" = \"%s: Incapace di ottenere informazioni per la stampante: %s\";\n"
"\"%s: Unable to get printer options: %s\" = \"%s: Incapace di ottenere le opzioni della stampante: %s\";\n"
"\"%s: Unable to modify printer: %s\" = \"%s: Incapace di modificare la stampante: %s\";\n"
"\"%s: Unable to pause printer: %s\" = \"%s: Incapace di mettere in pausa la stampante: %s\";\n"
"\"%s: Unable to print '%s': %s\" = \"%s: Incapace di stampare ' %s ': %s\";\n"
"\"%s: Unable to resume printer: %s\" = \"%s: Incapace di riprendere la stampante: %s\";\n"
"\"%s: Unable to set default printer: %s\" = \"%s: Non è possibile impostare la stampante predefinita: %s\";\n"
"\"%s: Unable to shutdown server: %s\" = \"%s: Non è possibile disattivare il server: %s\";\n"
"\"%s: Unable to start server: %s\" = \"%s: Incapace di avviare il server: %s\";\n"
"\"%s: Unable to write to temporary file: %s\" = \"%s: Incapace di scrivere a file temporanei: %s\";\n"
"\"%s: Unknown option '%s'.\" = \"%s: Opzione sconosciuta '%s'.\";\n"
"\"%s: Unknown option '-%c'.\" = \"%s: Opzione sconosciuta '-%c'.\";\n"
"\"%s: Unknown sub-command '%s'.\" = \"%s: Sconosciuto sottocomandi '%s'.\";\n"
"\"%s: Unsupported URI scheme '%s'.\" = \"%s: Schema URI non supportato %s '.\";\n"
"\"%s: Warning - user credentials are not supported in URIs.\" = \"%s: Attenzione: le credenziali dell'utente non sono supportate negli URI.\";\n"
"\", Borderless\" = \"♪\";\n"
"\"A printer with that name already exists.\" = \"Una stampante con quel nome esiste già.\";\n"
"\"Aborted %s\" = \"Aborted %s\";\n"
"\"Add Printer\" = \"Aggiungi stampante\";\n"
"\"Admin Group\" = \"Gruppo di amministrazione\";\n"
"\"Afghanistan\" = \"Afghanistan\";\n"
"\"Albania\" = \"Albania\";\n"
"\"Algeria\" = \"Algeria\";\n"
"\"American Samoa\" = \"American Samoa\";\n"
"\"Andorra\" = \"Andorra\";\n"
"\"Angola\" = \"Angola\";\n"
"\"Anguilla\" = \"Anguilla\";\n"
"\"Antarctica\" = \"Antartide\";\n"
"\"Antigua and Barbuda\" = \"Antigua e Barbuda\";\n"
"\"Argentina\" = \"Argentina\";\n"
"\"Armenia\" = \"Armenia\";\n"
"\"Aruba\" = \"Aruba\";\n"
"\"Australia\" = \"Australia\";\n"
"\"Austria\" = \"Austria\";\n"
"\"Auto\" = \"Auto\";\n"
"\"Auto-Detect Driver\" = \"Driver di rilevamento automatico\";\n"
"\"Azerbaijan\" = \"Azerbaigian\";\n"
"\"Bad administration group.\" = \"Brutto gruppo amministrativo.\";\n"
"\"Bad port number.\" = \"Brutto numero di porta.\";\n"
"\"Bad print group.\" = \"Cattivo gruppo di stampa.\";\n"
"\"Bad printer defaults.\" = \"Bad default della stampante.\";\n"
"\"Bahamas\" = \"Bahamas\";\n"
"\"Bahrain\" = \"Bahrain\";\n"
"\"Bangladesh\" = \"Bangladesh\";\n"
"\"Barbados\" = \"Barbados\";\n"
"\"Belarus\" = \"Bielorussia\";\n"
"\"Belgium\" = \"Belgio\";\n"
"\"Belize\" = \"Belize\";\n"
"\"Benin\" = \"Benin\";\n"
"\"Bermuda\" = \"Bermuda\";\n"
"\"Bhutan\" = \"Bhutan\";\n"
"\"Bolivia (Plurinational State of)\" = \"Bolivia (Stato nazionale)\";\n"
"\"Bonaire, Sint Eustatius and Saba\" = \"Bonaire, Sint Eustatius e Saba\";\n"
"\"Borderless\" = \"Borderless\";\n"
"\"Bosnia and Herzegovina\" = \"Bosnia-Erzegovina\";\n"
"\"Botswana\" = \"Botswana\";\n"
"\"Bouvet Island\" = \"Isola di Bouvet\";\n"
"\"Brazil\" = \"Brasile\";\n"
"\"British Indian Ocean Territory\" = \"British Indian Ocean Territorio\";\n"
"\"Brunei Darussalam\" = \"Brunei Darussalam\";\n"
"\"Bulgaria\" = \"Bulgaria\";\n"
"\"Burkina Faso\" = \"Burkina Faso\";\n"
"\"Burundi\" = \"Burundi\";\n"
"\"Cabo Verde\" = \"Cabo Verde\";\n"
"\"Cambodia\" = \"Cambogia\";\n"
"\"Cameroon\" = \"Camerun\";\n"
"\"Canada\" = \"Canada\";\n"
"\"Cancel All Jobs\" = \"Annulla tutti i lavori\";\n"
"\"Cancel Job\" = \"Annullare il lavoro\";\n"
"\"Canceled %s\" = \"Canceled %s\";\n"
"\"Canceling\" = \"Annullamento\";\n"
"\"Cayman Islands\" = \"Isole Cayman\";\n"
"\"Central African Republic\" = \"Repubblica Centrafricana\";\n"
"\"Certificate created.\" = \"Certificato creato.\";\n"
"\"Certificate installed.\" = \"Certificato installato.\";\n"
"\"Certificate request created.\" = \"Richiesta certificato creata.\";\n"
"\"Chad\" = \"Ciad\";\n"
"\"Change Access Password\" = \"Cambia password di accesso\";\n"
"\"Change Log Level\" = \"Cambia il livello di registro\";\n"
"\"Change Network Settings\" = \"Change Network Settings\";\n"
"\"Change Wi-Fi Network\" = \"Modifica della rete Wi-Fi\";\n"
"\"Changes Saved.\" = \"Cambiamenti salvati.\";\n"
"\"Changes saved.\" = \"Cambiamenti salvati.\";\n"
"\"Chile\" = \"Cile\";\n"
"\"China\" = \"Cina\";\n"
"\"Christmas Island\" = \"Isola di Natale\";\n"
"\"City/Locality\" = \"City/Locality\";\n"
"\"Cocos (Keeling) Islands\" = \"Isole Cocos (Keeling)\";\n"
"\"Colombia\" = \"Colombia\";\n"
"\"Comoros\" = \"Comore\";\n"
"\"Completed %s\" = \"Completed %s\";\n"
"\"Configuration\" = \"Configurazione\";\n"
"\"Configure Media\" = \"Configurare i media\";\n"
"\"Confirm Cancel All\" = \"Confermare Annulla Tutti\";\n"
"\"Confirm Delete Printer\" = \"Conferma Cancella stampante\";\n"
"\"Congo\" = \"Congo\";\n"
"\"Congo, Democratic Republic of the\" = \"Congo, Repubblica Democratica del\";\n"
"\"Contact\" = \"Contatto\";\n"
"\"Cook Islands\" = \"Isole Cook\";\n"
"\"Costa Rica\" = \"Costa Rica\";\n"
"\"Create Certificate Signing Request\" = \"Crea richiesta di firma del certificato\";\n"
"\"Create New Certificate\" = \"Crea nuovo certificato\";\n"
"\"Create New TLS Certificate\" = \"Crea nuovo certificato TLS\";\n"
"\"Create TLS Certificate Request\" = \"Creare TLS Richiesta certificato\";\n"
"\"Croatia\" = \"Croazia\";\n"
"\"Cuba\" = \"Cuba\";\n"
"\"Curaçao\" = \"Curaa\";\n"
"\"Current Password\" = \"Password corrente\";\n"
"\"Custom Size\" = \"Dimensione personalizzata\";\n"
"\"Cyprus\" = \"Cipro\";\n"
"\"Czechia\" = \"Repubblica ceca\";\n"
"\"Côte d'Ivoire\" = \"Cte d'Ivoire\";\n"
"\"DHCP\" = \"DHCP\";\n"
"\"DHCP w/Manual Address\" = \"DHCP w/Manual Address\";\n"
"\"DNS-SD Service Name\" = \"Nome di servizio DNS-SD\";\n"
"\"Debugging\" = \"Debug\";\n"
"\"Default printer set.\" = \"Set stampante predefinito.\";\n"
"\"Delete\" = \"Cancella\";\n"
"\"Delete Printer\" = \"Eliminare la stampante\";\n"
"\"Denmark\" = \"Danimarca\";\n"
"\"Djibouti\" = \"Gibuti\";\n"
"\"Domain Name\" = \"Domain Name\";\n"
"\"Dominica\" = \"Dominica\";\n"
"\"Dominican Republic\" = \"Repubblica Dominicana\";\n"
"\"Download Certificate Request File\" = \"Scarica il file di richiesta del certificato\";\n"
"\"Ecuador\" = \"Ecuador\";\n"
"\"Egypt\" = \"Egitto\";\n"
"\"El Salvador\" = \"El Salvador\";\n"
"\"Equatorial Guinea\" = \"Guinea equatoriale\";\n"
"\"Eritrea\" = \"Eritrea\";\n"
"\"Errors\" = \"Errori\";\n"
"\"Estonia\" = \"Estonia\";\n"
"\"Eswatini\" = \"Eswatini\";\n"
"\"Ethiopia\" = \"Etiopia\";\n"
"\"Falkland Islands (Malvinas)\" = \"Isole Falkland (Malvinas)\";\n"
"\"Faroe Islands\" = \"Isole Faroe\";\n"
"\"Fatal Errors/Conditions\" = \"Errori/Condizioni\";\n"
"\"Fiji\" = \"Fiji\";\n"
"\"Finland\" = \"Finlandia\";\n"
"\"France\" = \"Francia\";\n"
"\"French Guiana\" = \"Guiana francese\";\n"
"\"French Polynesia\" = \"Polinesia francese\";\n"
"\"French Southern Territories\" = \"Territori del Sud francese\";\n"
"\"Gabon\" = \"Gabon\";\n"
"\"Gambia\" = \"Gambia\";\n"
"\"Georgia\" = \"Georgia\";\n"
"\"Germany\" = \"Germania\";\n"
"\"Ghana\" = \"Ghana\";\n"
"\"Gibraltar\" = \"Gibilterra\";\n"
"\"Greece\" = \"Grecia\";\n"
"\"Greenland\" = \"Groenlandia\";\n"
"\"Grenada\" = \"Grenada\";\n"
"\"Group changes saved.\" = \"Cambiamenti di gruppo salvati.\";\n"
"\"Guadeloupe\" = \"Guadalupa\";\n"
"\"Guam\" = \"Guam\";\n"
"\"Guatemala\" = \"Guatemala\";\n"
"\"Guernsey\" = \"Guernsey\";\n"
"\"Guinea\" = \"Guinea\";\n"
"\"Guinea-Bissau\" = \"Guinea-Bissau\";\n"
"\"Guyana\" = \"Guyana\";\n"
"\"Haiti\" = \"Haiti\";\n"
"\"Heard Island and McDonald Islands\" = \"Heard Island e McDonald Islands\";\n"
"\"Hidden SSID\" = \"Hidden SSID\";\n"
"\"Hold Job\" = \"Hold Job\";\n"
"\"Hold New Jobs\" = \"Hold New Jobs\";\n"
"\"Holding new jobs.\" = \"Holding new jobs.\";\n"
"\"Holy See\" = \"Santa Sede\";\n"
"\"Honduras\" = \"Honduras\";\n"
"\"Hong Kong\" = \"Hong Kong\";\n"
"\"Hostname\" = \"Nome host\";\n"
"\"Human-Readable Location\" = \"Posizione leggibile umana\";\n"
"\"Hungary\" = \"Ungheria\";\n"
"\"IPv4 Address\" = \"IPv4 Address\";\n"
"\"IPv4 Configuration\" = \"IPv4 Configuration\";\n"
"\"IPv4 Gateway\" = \"IPv4 Gateway\";\n"
"\"IPv4 Netmask\" = \"IPv4 Netmask\";\n"
"\"IPv6 Address\" = \"IPv6 Address\";\n"
"\"IPv6 Configuration\" = \"IPv6 Configuration\";\n"
"\"IPv6 Link-Local\" = \"IPv6 Link-Local\";\n"
"\"IPv6 Prefix Length\" = \"IPv6 Prefix Length\";\n"
"\"Iceland\" = \"Islanda\";\n"
"\"Identify Printer\" = \"Identificare la stampante\";\n"
"\"India\" = \"India\";\n"
"\"Indonesia\" = \"Indonesia\";\n"
"\"Informational\" = \"Informazioni\";\n"
"\"Install TLS Certificate\" = \"Installare TLS Certificato\";\n"
"\"Invalid IPv4 address.\" = \"Invalid IPv4 address.\";\n"
"\"Invalid IPv4 netmask.\" = \"Invalid IPv4 netmask.\";\n"
"\"Invalid IPv6 address.\" = \"Invalid IPv6 address.\";\n"
"\"Invalid IPv6 prefix length.\" = \"Invalid IPv6 prefix length.\";\n"
"\"Invalid Job ID.\" = \"Invalid Job ID.\";\n"
"\"Invalid certificate or private key.\" = \"Certificato non valido o chiave privata.\";\n"
"\"Invalid form data.\" = \"Dati formali non validi.\";\n"
"\"Invalid form submission.\" = \"Modulo non valido.\";\n"
"\"Invalid job ID.\" = \"ID del lavoro non valido.\";\n"
"\"Invalid network configuration.\" = \"Invalid network configuration.\";\n"
"\"Iran (Islamic Republic of)\" = \"Iran (Repubblica Islamica di)\";\n"
"\"Iraq\" = \"Iraq\";\n"
"\"Ireland\" = \"Irlanda\";\n"
"\"Isle of Man\" = \"Isle of Man\";\n"
"\"Israel\" = \"Israele\";\n"
"\"Italy\" = \"Italia\";\n"
"\"Jamaica\" = \"Giamaica\";\n"
"\"Japan\" = \"Giappone\";\n"
"\"Jersey\" = \"Jersey\";\n"
"\"Job #\" = \"Lavoro\";\n"
"\"Job canceled.\" = \"Job canceled.\";\n"
"\"Job held.\" = \"Job held.\";\n"
"\"Job released.\" = \"Job released.\";\n"
"\"Jobs\" = \"Lavoro\";\n"
"\"Joining Wi-Fi Network\" = \"Joining Wi-Fi Network\";\n"
"\"Jordan\" = \"Giordania\";\n"
"\"Kazakhstan\" = \"Kazakistan\";\n"
"\"Kenya\" = \"Kenya\";\n"
"\"Kiribati\" = \"Kiribati\";\n"
"\"Korea (Democratic People's Republic of)\" = \"Corea (Repubblica popolare democratica)\";\n"
"\"Korea, Republic of\" = \"Repubblica di Corea\";\n"
"\"Kuwait\" = \"Kuwait\";\n"
"\"Kyrgyzstan\" = \"Kirghizistan\";\n"
"\"Landscape\" = \"paesaggio paesaggio\";\n"
"\"Lao People's Democratic Republic\" = \"Lao Repubblica Democratica del Popolo\";\n"
"\"Latvia\" = \"Lettonia\";\n"
"\"Lebanon\" = \"Libano\";\n"
"\"Lesotho\" = \"Lesotho\";\n"
"\"Level\" = \"Livello\";\n"
"\"Liberia\" = \"Liberia\";\n"
"\"Libya\" = \"Libia\";\n"
"\"Liechtenstein\" = \"Liechtenstein\";\n"
"\"Lithuania\" = \"Lituania\";\n"
"\"Location\" = \"Location\";\n"
"\"Log Level\" = \"Livello di log\";\n"
"\"Logging\" = \"Registrazione\";\n"
"\"Logs\" = \"Log\";\n"
"\"Luxembourg\" = \"Lussemburgo\";\n"
"\"Macao\" = \"Macao\";\n"
"\"Madagascar\" = \"Madagascar\";\n"
"\"Malawi\" = \"Malawi\";\n"
"\"Malaysia\" = \"Malesia\";\n"
"\"Maldives\" = \"Maldive\";\n"
"\"Mali\" = \"Mali\";\n"
"\"Malta\" = \"Malta\";\n"
"\"Manual Configuration\" = \"Manual Configuration\";\n"
"\"Marshall Islands\" = \"Isole Marshall\";\n"
"\"Martinique\" = \"Martinica\";\n"
"\"Mauritania\" = \"Mauritania\";\n"
"\"Mauritius\" = \"Mauritius\";\n"
"\"Mayotte\" = \"Mayotte\";\n"
"\"Media\" = \"Media\";\n"
"\"Mexico\" = \"Messico\";\n"
"\"Micronesia (Federated States of)\" = \"Micronesia (Stati federali)\";\n"
"\"Missing action.\" = \"Azione mancante.\";\n"
"\"Missing job ID.\" = \"Missing job ID.\";\n"
"\"Missing network name.\" = \"Missing network name.\";\n"
"\"Missing private key.\" = \"Manca la chiave privata.\";\n"
"\"Moldova, Republic of\" = \"Moldavia, Repubblica\";\n"
"\"Monaco\" = \"Monaco\";\n"
"\"Mongolia\" = \"Mongolia\";\n"
"\"Montenegro\" = \"Montenegro\";\n"
"\"Montserrat\" = \"Montserrat\";\n"
"\"Morocco\" = \"Marocco\";\n"
"\"Mozambique\" = \"Mozambico\";\n"
"\"Myanmar\" = \"Myanmar\";\n"
"\"Name\" = \"Nome\";\n"
"\"Namibia\" = \"Namibia\";\n"
"\"Nauru\" = \"Nauru\";\n"
"\"Nepal\" = \"Nepal\";\n"
"\"Netherlands\" = \"Paesi Bassi\";\n"
"\"Network\" = \"Rete di rete\";\n"
"\"Network Printer\" = \"Stampante di rete\";\n"
"\"Networking\" = \"Networking\";\n"
"\"New Caledonia\" = \"Nuova Caledonia\";\n"
"\"New Zealand\" = \"Nuova Zelanda\";\n"
"\"Nicaragua\" = \"Nicaragua\";\n"
"\"Niger\" = \"Niger\";\n"
"\"Nigeria\" = \"Nigeria\";\n"
"\"Niue\" = \"Niue\";\n"
"\"No default printer set.\" = \"Nessuna stampante predefinita impostata.\";\n"
"\"No jobs in history.\" = \"Nessun lavoro nella storia.\";\n"
"\"Norfolk Island\" = \"Isola di Norfolk\";\n"
"\"North Macedonia\" = \"Macedonia settentrionale\";\n"
"\"Northern Mariana Islands\" = \"Isole Marianne Settentrionali\";\n"
"\"Norway\" = \"Norvegia\";\n"
"\"Not set\" = \"Non impostato\";\n"
"\"Off\" = \"Off\";\n"
"\"Offset\" = \"Offset\";\n"
"\"Oman\" = \"Oman\";\n"
"\"Options:\" = \"Opzioni:\";\n"
"\"Organization\" = \"Organizzazione\";\n"
"\"Organization Name\" = \"Nome dell'organizzazione\";\n"
"\"Other Settings\" = \"Altre impostazioni\";\n"
"\"Pakistan\" = \"Pakistan\";\n"
"\"Palau\" = \"Palau\";\n"
"\"Palestine, State of\" = \"Palestina, Stato di\";\n"
"\"Panama\" = \"Panama\";\n"
"\"Papua New Guinea\" = \"Papua Nuova Guinea\";\n"
"\"Paraguay\" = \"Paraguay\";\n"
"\"Password\" = \"Password\";\n"
"\"Password changed.\" = \"La password è cambiata.\";\n"
"\"Password must be at least eight characters long and contain at least one uppercase letter, one lowercase letter, and one digit.\" = \"La password deve essere lunga almeno otto caratteri e contenere almeno una lettera maiuscola, una lettera minuscola e una cifra.\";\n"
"\"Passwords do not match.\" = \"Le password non corrispondono.\";\n"
"\"Pause Printing\" = \"Stampa Pausa\";\n"
"\"Peru\" = \"Perù\";\n"
"\"Philippines\" = \"Filippine\";\n"
"\"Pitcairn\" = \"Pitcairn\";\n"
"\"Please enter a hostname or IP address for the printer.\" = \"Inserisci un nome host o un indirizzo IP per la stampante.\";\n"
"\"Please enter a printer name.\" = \"Inserisci un nome della stampante.\";\n"
"\"Please select a device.\" = \"Selezionare un dispositivo.\";\n"
"\"Please select a driver.\" = \"Si prega di selezionare un driver.\";\n"
"\"Please select a valid log level.\" = \"Si prega di selezionare un livello di registro valido.\";\n"
"\"Poland\" = \"Polonia\";\n"
"\"Portrait\" = \"Ritratto\";\n"
"\"Portugal\" = \"Portogallo\";\n"
"\"Primary DNS\" = \"Primary DNS\";\n"
"\"Print Group\" = \"Gruppo di stampa\";\n"
"\"Print Test Page\" = \"Pagina di test di stampa\";\n"
"\"Print job options:\" = \"Stampa opzioni di lavoro:\";\n"
"\"Printer identified.\" = \"Stampante identificata.\";\n"
"\"Printer is currently active.\" = \"La stampante è attualmente attiva.\";\n"
"\"Printer names must start with a letter or underscore and cannot contain special characters.\" = \"I nomi della stampante devono iniziare con una lettera o un sottoscopo e non possono contenere caratteri speciali.\";\n"
"\"Printer options:\" = \"Opzioni di stampa:\";\n"
"\"Printer paused.\" = \"Stampante in pausa.\";\n"
"\"Printer pausing.\" = \"Stampante pausing.\";\n"
"\"Printer resuming.\" = \"Stampante che riprende.\";\n"
"\"Printers\" = \"Stampanti\";\n"
"\"Printing Defaults\" = \"Stampa di default\";\n"
"\"Puerto Rico\" = \"Porto Rico\";\n"
"\"Qatar\" = \"Qatar\";\n"
"\"Queued %s\" = \"Queued %s\";\n"
"\"Release Held New Jobs\" = \"Release Held New Jobs\";\n"
"\"Release Job\" = \"Release Job\";\n"
"\"Released held new jobs.\" = \"Released held new jobs.\";\n"
"\"Reprint Job\" = \"Ristampa lavoro\";\n"
"\"Reprinted job.\" = \"Reprinted job.\";\n"
"\"Resume Printing\" = \"Riprendi la stampa\";\n"
"\"Reverse Landscape\" = \"Paesaggio inverso\";\n"
"\"Reverse Portrait\" = \"Ritratto inverso\";\n"
"\"Romania\" = \"Romania\";\n"
/* Running, STATE since DATE REASONS */
"\"Running, %s since %s%s.\" = \"Correre, %s da %s %s .\";\n"
"\"Russian Federation\" = \"Federazione russa\";\n"
"\"Rwanda\" = \"Ruanda\";\n"
"\"Réunion\" = \"Runion\";\n"
"\"Saint Barthélemy\" = \"San Bartolomeo\";\n"
"\"Saint Helena, Ascension and Tristan da Cunha\" = \"Sant'Elena, Ascensione e Tristan da Cunha\";\n"
"\"Saint Kitts and Nevis\" = \"Saint Kitts e Nevis\";\n"
"\"Saint Lucia\" = \"Santa Lucia\";\n"
"\"Saint Martin (French part)\" = \"Saint Martin (parte francese)\";\n"
"\"Saint Pierre and Miquelon\" = \"Saint Pierre e Miquelon\";\n"
"\"Saint Vincent and the Grenadines\" = \"Saint Vincent e Grenadine\";\n"
"\"Samoa\" = \"Samoa\";\n"
"\"San Marino\" = \"San Marino\";\n"
"\"Sao Tome and Principe\" = \"Sao Tome e Principe\";\n"
"\"Saudi Arabia\" = \"Arabia Saudita\";\n"
"\"Save Changes\" = \"Salvare le modifiche\";\n"
"\"Secondary DNS\" = \"Secondary DNS\";\n"
"\"Security\" = \"Sicurezza\";\n"
"\"Select Driver\" = \"Selezionare il driver\";\n"
"\"Senegal\" = \"Senegal\";\n"
"\"Serbia\" = \"Serbia\";\n"
"\"Server is not running.\" = \"Il server non è in esecuzione.\";\n"
"\"Set Access Password\" = \"Impostare la password di accesso\";\n"
"\"Set as Default\" = \"Impostare come predefinito\";\n"
"\"Seychelles\" = \"Seychelles\";\n"
"\"Sierra Leone\" = \"Sierra Leone\";\n"
"\"Singapore\" = \"Singapore\";\n"
"\"Sint Maarten (Dutch part)\" = \"Sint Maarten (parte olandese)\";\n"
"\"Slovakia\" = \"Slovacchia\";\n"
"\"Slovenia\" = \"Slovenia\";\n"
"\"Solomon Islands\" = \"Isole Salomone\";\n"
"\"Somalia\" = \"Somalia\";\n"
"\"South Africa\" = \"Sudafrica\";\n"
"\"South Georgia and the South Sandwich Islands\" = \"Georgia del Sud e Isole Sandwich del Sud\";\n"
"\"South Sudan\" = \"Sudan del Sud\";\n"
"\"Spain\" = \"Spagna\";\n"
"\"Sri Lanka\" = \"Sri Lanka\";\n"
"\"Started %s\" = \"Started %s\";\n"
"\"Status\" = \"Stato\";\n"
"\"Sub-commands:\" = \"Sottocomandi:\";\n"
"\"Sudan\" = \"Sudan\";\n"
"\"Supplies\" = \"Forniture\";\n"
"\"Suriname\" = \"Suriname\";\n"
"\"Svalbard and Jan Mayen\" = \"Svalbard e Jan Mayen\";\n"
"\"Sweden\" = \"Svezia\";\n"
"\"Switzerland\" = \"Svizzera\";\n"
"\"Syrian Arab Republic\" = \"Repubblica araba siriana\";\n"
"\"Taiwan, Province of China\" = \"Taiwan, Provincia della Cina\";\n"
"\"Tajikistan\" = \"Tajikistan\";\n"
"\"Tanzania, United Republic of\" = \"Tanzania, Regno Unito\";\n"
"\"Test page printed.\" = \"Testa stampata.\";\n"
"\"Thailand\" = \"Thailandia\";\n"
"\"This form creates a certificate signing request ('CSR') that you can send to a Certificate Authority ('CA') to obtain a trusted TLS certificate. The private key is saved separately for use with the certificate you get from the CA.\" = \"Questo modulo crea una richiesta di firma del certificato (CSR) che è possibile inviare a un'Autorità di certificazione (CA) per ottenere un certificato TLS affidabile. La chiave privata viene salvata separatamente per l'uso con il certificato che si ottiene dalla CA.\";\n"
"\"This form creates a new 'self-signed' TLS certificate for secure printing. Self-signed certificates are not automatically trusted by web browsers.\" = \"Questo modulo crea un nuovo certificato TLS autofirmato per la stampa sicura. I certificati auto-firmati non sono automaticamente affidabili dai browser web.\";\n"
"\"This form will install a trusted TLS certificate you have obtained from a Certificate Authority ('CA'). Once installed, it will be used immediately.\" = \"Questo modulo installerà un certificato TLS di fiducia che hai ottenuto da un'Autorità di certificazione (CA.) Una volta installato, verrà utilizzato immediatamente.\";\n"
"\"Timor-Leste\" = \"Timor Est\";\n"
"\"Togo\" = \"Togo\";\n"
"\"Tokelau\" = \"Tokelau\";\n"
"\"Tonga\" = \"Tonga\";\n"
"\"Trinidad and Tobago\" = \"Trinidad e Tobago\";\n"
"\"Tunisia\" = \"Tunisia\";\n"
"\"Turkey\" = \"Turchia\";\n"
"\"Turkmenistan\" = \"Turkmenistan\";\n"
"\"Turks and Caicos Islands\" = \"Isole Turks e Caicos\";\n"
"\"Tuvalu\" = \"Tuvalu\";\n"
"\"Uganda\" = \"Uganda\";\n"
"\"Ukraine\" = \"Ucraina\";\n"
"\"Unable to access test print file.\" = \"Non è possibile accedere al file di stampa di prova.\";\n"
"\"Unable to copy print job.\" = \"Incapace di copiare il lavoro di stampa.\";\n"
"\"Unable to create certificate request.\" = \"Non è possibile creare una richiesta di certificato.\";\n"
"\"Unable to create certificate.\" = \"Non è possibile creare un certificato.\";\n"
"\"Unable to create test print job.\" = \"Incapace di creare un lavoro di stampa di prova.\";\n"
"\"Unable to identify printer.\" = \"Incapace di identificare la stampante.\";\n"
"\"Unable to lookup address.\" = \"Non riesco a cercare l'indirizzo.\";\n"
"\"Unable to use that driver.\" = \"Non riesco a usare quel conducente.\";\n"
"\"United Arab Emirates\" = \"Emirati Arabi Uniti\";\n"
"\"United Kingdom\" = \"Regno Unito\";\n"
"\"United Kingdom of Great Britain and Northern Ireland\" = \"Regno Unito di Gran Bretagna e Irlanda del Nord\";\n"
"\"United States Minor Outlying Islands\" = \"Isole Minori degli Stati Uniti\";\n"
"\"United States of America\" = \"Stati Uniti d'America\";\n"
"\"Unknown\" = \"Sconosciuto\";\n"
"\"Unknown action.\" = \"Azione sconosciuta.\";\n"
"\"Unknown form action.\" = \"Azione forma sconosciuta.\";\n"
"\"Unknown form request.\" = \"Richiesta forma sconosciuta.\";\n"
"\"Updating Network Configuration\" = \"Updating Network Configuration\";\n"
"\"Uruguay\" = \"Uruguay\";\n"
"\"Usage: %s SUB-COMMAND [OPTIONS] [FILENAME]\\n\" = \"Utilizzo: %s SUB-COMMAND [OPTIONS] [FILENAME]\\n\";\n"
"\"Use My Position\" = \"Usa la mia posizione\";\n"
"\"Users\" = \"Utenti\";\n"
"\"Uzbekistan\" = \"Uzbekistan\";\n"
"\"Vanuatu\" = \"Vanuatu\";\n"
"\"Venezuela (Bolivarian Republic of)\" = \"Venezuela (Repubblica bolivariana di)\";\n"
"\"Version %s\" = \"Versione %s\";\n"
"\"Viet Nam\" = \"Viet Nam\";\n"
"\"View Logs\" = \"Visualizza i log\";\n"
"\"Virgin Islands (British)\" = \"Isole Vergini (britanniche)\";\n"
"\"Virgin Islands (U.S.)\" = \"Isole Vergini (USA)\";\n"
"\"Wallis and Futuna\" = \"Wallis e Futuna\";\n"
"\"Warning\" = \"Avvertenza\";\n"
"\"Western Sahara\" = \"Sahara occidentale\";\n"
"\"Wi-Fi Configuration\" = \"Configurazione Wi-Fi\";\n"
"\"Wi-Fi Network\" = \"Rete Wi-Fi\";\n"
"\"Width\" = \"Larghezza\";\n"
"\"Wrong old password.\" = \"Una vecchia password sbagliata.\";\n"
"\"Yemen\" = \"Yemen\";\n"
"\"Zambia\" = \"Zambia\";\n"
"\"Zimbabwe\" = \"Zimbabwe\";\n"
"\"at %02d:%02d:%02d\" = \"at %02d:%02d:%02d\";\n"
/* IPP attribute, keyword, and enum (integer) localizations */
"\"copies\" = \"Numero di copie\";\n"
"\"default printer\" = \"stampante predefinita\";\n"
"\"finishings\" = \"Finitura\";\n"
"\"finishings.10\" = \"Piegare\";\n"
"\"finishings.100\" = \"Z fold\";\n"
"\"finishings.101\" = \"Ingegneria Z fold\";\n"
"\"finishings.11\" = \"Taglio\";\n"
"\"finishings.12\" = \"Bale\";\n"
"\"finishings.13\" = \"Produttore di libri\";\n"
"\"finishings.15\" = \"Cappotto\";\n"
"\"finishings.16\" = \"Laminato\";\n"
"\"finishings.20\" = \"Piano a sinistra\";\n"
"\"finishings.21\" = \"Fondo a sinistra\";\n"
"\"finishings.22\" = \"Staple top destra\";\n"
"\"finishings.23\" = \"Fondo a destra\";\n"
"\"finishings.24\" = \"Cucitura bordo sinistra\";\n"
"\"finishings.25\" = \"Maglia di punto bordo\";\n"
"\"finishings.26\" = \"Cucitura bordo destra\";\n"
"\"finishings.27\" = \"Bordo punto inferiore\";\n"
"\"finishings.28\" = \"2 graffe a sinistra\";\n"
"\"finishings.29\" = \"2 graffe in alto\";\n"
"\"finishings.3\" = \"Nessuno\";\n"
"\"finishings.30\" = \"2 graffe a destra\";\n"
"\"finishings.31\" = \"2 graffe sul fondo\";\n"
"\"finishings.32\" = \"3 graffe a sinistra\";\n"
"\"finishings.33\" = \"3 graffe in alto\";\n"
"\"finishings.34\" = \"3 graffe a destra\";\n"
"\"finishings.35\" = \"3 graffe sul fondo\";\n"
"\"finishings.4\" = \"Staple\";\n"
"\"finishings.5\" = \"Punch\";\n"
"\"finishings.50\" = \"Bind sinistra\";\n"
"\"finishings.51\" = \"Top Bind\";\n"
"\"finishings.52\" = \"A destra binaria\";\n"
"\"finishings.53\" = \"Fondo legato\";\n"
"\"finishings.6\" = \"Copertura\";\n"
"\"finishings.60\" = \"Tagliare ogni pagina\";\n"
"\"finishings.61\" = \"Tagliare dopo ogni documento\";\n"
"\"finishings.62\" = \"Tagliare dopo ogni set\";\n"
"\"finishings.63\" = \"Tagliare dopo il lavoro\";\n"
"\"finishings.7\" = \"Bind\";\n"
"\"finishings.70\" = \"In alto a sinistra\";\n"
"\"finishings.71\" = \"In basso a sinistra\";\n"
"\"finishings.72\" = \"Cima a destra\";\n"
"\"finishings.73\" = \"Taglio basso a destra\";\n"
"\"finishings.74\" = \"2 buche a sinistra\";\n"
"\"finishings.75\" = \"Pugno a 2 buche\";\n"
"\"finishings.76\" = \"Pugno a 2 buche a destra\";\n"
"\"finishings.77\" = \"2 buche fondo del pugno\";\n"
"\"finishings.78\" = \"Punzone a 3 buche sinistra\";\n"
"\"finishings.79\" = \"Top a 3 buche\";\n"
"\"finishings.8\" = \"Cucitura della sella\";\n"
"\"finishings.80\" = \"3 buche destra\";\n"
"\"finishings.81\" = \"3 buche di fondo\";\n"
"\"finishings.82\" = \"Punzone a 4 buche sinistra\";\n"
"\"finishings.83\" = \"Top a 4 buche\";\n"
"\"finishings.84\" = \"4 buche destra\";\n"
"\"finishings.85\" = \"4 buche di fondo\";\n"
"\"finishings.86\" = \"Punzone a più buche sinistra\";\n"
"\"finishings.87\" = \"Taglio a foro multiplo\";\n"
"\"finishings.88\" = \"Pugno multiforo a destra\";\n"
"\"finishings.89\" = \"Taglio a foro multi\";\n"
"\"finishings.9\" = \"Cucitura bordo\";\n"
"\"finishings.90\" = \"Piega di accordo\";\n"
"\"finishings.91\" = \"Doppio cancello pieghevole\";\n"
"\"finishings.92\" = \"Cancello pieghevole\";\n"
"\"finishings.93\" = \"Mezza piega\";\n"
"\"finishings.94\" = \"Piega mezza Z\";\n"
"\"finishings.95\" = \"Cancello sinistro\";\n"
"\"finishings.96\" = \"Letter fold\";\n"
"\"finishings.97\" = \"Piega parallela\";\n"
"\"finishings.98\" = \"Poster fold\";\n"
"\"finishings.99\" = \"Cancello destro\";\n"
"\"holding new jobs\" = \"holding new jobs\";\n"
"\"job-state-reasons.aborted-by-system\" = \"Stoccata.\";\n"
"\"job-state-reasons.compression-error\" = \"Errore di decompressione.\";\n"
"\"job-state-reasons.document-format-error\" = \"Errore formato documento.\";\n"
"\"job-state-reasons.document-password-error\" = \"Errore della password del documento.\";\n"
"\"job-state-reasons.document-permission-error\" = \"Errore di autorizzazione del documento.\";\n"
"\"job-state-reasons.document-unprintable-error\" = \"Documento errore non stampabile.\";\n"
"\"job-state-reasons.errors-detected\" = \"Errori rilevati.\";\n"
"\"job-state-reasons.job-canceled-at-device\" = \"Annullato alla stampante.\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"Annullato dall'utente.\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"Stampato.\";\n"
"\"job-state-reasons.job-completed-with-errors\" = \"Stampato con errori.\";\n"
"\"job-state-reasons.job-completed-with-warnings\" = \"Stampato con avvisi.\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"Dati insufficienti.\";\n"
"\"job-state-reasons.job-fetchable\" = \"In piedi.\";\n"
"\"job-state-reasons.job-incoming\" = \"In arrivo.\";\n"
"\"job-state-reasons.job-printing\" = \"Stampa.\";\n"
"\"job-state-reasons.job-queued\" = \"Prepararsi alla stampa.\";\n"
"\"job-state-reasons.job-spooling\" = \"Spooling.\";\n"
"\"job-state-reasons.none\" = \"In attesa.\";\n"
"\"job-state-reasons.printer-stopped\" = \"Stampante offline.\";\n"
"\"job-state-reasons.printer-stopped-partly\" = \"Stampante parzialmente interrotta.\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"Stoccata.\";\n"
"\"job-state-reasons.queued-in-device\" = \"Pronti.\";\n"
"\"job-state-reasons.warnings-detected\" = \"Avvertenze rilevate.\";\n"
"\"job-state.3\" = \"Finanziamenti\";\n"
"\"job-state.4\" = \"Tenuto\";\n"
"\"job-state.5\" = \"Trattamento\";\n"
"\"job-state.6\" = \"Fermata\";\n"
"\"job-state.7\" = \"Annullamento\";\n"
"\"job-state.8\" = \"Abortito\";\n"
"\"job-state.9\" = \"Completato\";\n"
"\"joining\" = \"unirsi\";\n"
"\"media\" = \"Media\";\n"
"\"media-col\" = \"Media\";\n"
"\"media-size\" = \"Dimensioni media\";\n"
"\"media-size-name\" = \"Dimensioni media\";\n"
"\"media-source\" = \"Vassoio di ingresso\";\n"
"\"media-source.alternate\" = \"Alternare\";\n"
"\"media-source.alternate-roll\" = \"Rotolo alternativo\";\n"
"\"media-source.auto\" = \"Automatico\";\n"
"\"media-source.bottom\" = \"Fondo\";\n"
"\"media-source.by-pass-tray\" = \"Vassoio multiuso\";\n"
"\"media-source.center\" = \"Centro\";\n"
"\"media-source.disc\" = \"Disc\";\n"
"\"media-source.envelope\" = \"Busta\";\n"
"\"media-source.hagaki\" = \"Hagaki\";\n"
"\"media-source.large-capacity\" = \"Grande capacità\";\n"
"\"media-source.left\" = \"Sinistra\";\n"
"\"media-source.main\" = \"Principale\";\n"
"\"media-source.main-roll\" = \"Rullo principale\";\n"
"\"media-source.manual\" = \"Manuale\";\n"
"\"media-source.middle\" = \"Medio\";\n"
"\"media-source.photo\" = \"Foto\";\n"
"\"media-source.rear\" = \"Indietro\";\n"
"\"media-source.right\" = \"Giusto.\";\n"
"\"media-source.roll-1\" = \"Rotolo 1\";\n"
"\"media-source.roll-10\" = \"Rotolo 10\";\n"
"\"media-source.roll-2\" = \"Rotolo 2\";\n"
"\"media-source.roll-3\" = \"Rotolo 3\";\n"
"\"media-source.roll-4\" = \"Rotolo 4\";\n"
"\"media-source.roll-5\" = \"Rotolo 5\";\n"
"\"media-source.roll-6\" = \"Rotolo 6\";\n"
"\"media-source.roll-7\" = \"Rotolo 7\";\n"
"\"media-source.roll-8\" = \"Rotolo 8\";\n"
"\"media-source.roll-9\" = \"Rotolo 9\";\n"
"\"media-source.side\" = \"Lato\";\n"
"\"media-source.top\" = \"Top\";\n"
"\"media-source.tray-1\" = \"Vassoio 1\";\n"
"\"media-source.tray-10\" = \"Vassoio 10\";\n"
"\"media-source.tray-11\" = \"Vassoio 11\";\n"
"\"media-source.tray-12\" = \"Vassoio 12\";\n"
"\"media-source.tray-13\" = \"Vassoio 13\";\n"
"\"media-source.tray-14\" = \"Vassoio 14\";\n"
"\"media-source.tray-15\" = \"Vassoio 15\";\n"
"\"media-source.tray-16\" = \"Vassoio 16\";\n"
"\"media-source.tray-17\" = \"Vassoio 17\";\n"
"\"media-source.tray-18\" = \"Vassoio 18\";\n"
"\"media-source.tray-19\" = \"Vassoio 19\";\n"
"\"media-source.tray-2\" = \"Vassoio 2\";\n"
"\"media-source.tray-20\" = \"Vassoio 20\";\n"
"\"media-source.tray-3\" = \"Vassoio 3\";\n"
"\"media-source.tray-4\" = \"Vassoio 4\";\n"
"\"media-source.tray-5\" = \"Vassoio 5\";\n"
"\"media-source.tray-6\" = \"Vassoio 6\";\n"
"\"media-source.tray-7\" = \"Vassoio 7\";\n"
"\"media-source.tray-8\" = \"Vassoio 8\";\n"
"\"media-source.tray-9\" = \"Vassoio 9\";\n"
"\"media-tracking\" = \"Monitoraggio dei media\";\n"
"\"media-tracking.continuous\" = \"Continuo\";\n"
"\"media-tracking.gap\" = \"Gap\";\n"
"\"media-tracking.mark\" = \"Mark\";\n"
"\"media-tracking.web\" = \"Web\";\n"
"\"media-type\" = \"Tipo di mezzo\";\n"
"\"media-type.aluminum\" = \"Alluminio\";\n"
"\"media-type.auto\" = \"Automatico\";\n"
"\"media-type.back-print-film\" = \"Film di stampa\";\n"
"\"media-type.cardboard\" = \"Carta\";\n"
"\"media-type.cardstock\" = \"Carni bovine\";\n"
"\"media-type.cd\" = \"CD\";\n"
"\"media-type.continuous\" = \"Continuo\";\n"
"\"media-type.continuous-long\" = \"Lunga durata continua\";\n"
"\"media-type.continuous-short\" = \"Basso continuo\";\n"
"\"media-type.corrugated-board\" = \"Consiglio ondulato\";\n"
"\"media-type.disc\" = \"Disco ottico\";\n"
"\"media-type.disc-glossy\" = \"Disco ottico lucido\";\n"
"\"media-type.disc-high-gloss\" = \"Disco ottico lucido\";\n"
"\"media-type.disc-matte\" = \"Disco ottico opaco\";\n"
"\"media-type.disc-satin\" = \"Disco ottico raso\";\n"
"\"media-type.disc-semi-gloss\" = \"Disco ottico semiglossa\";\n"
"\"media-type.double-wall\" = \"Doppia parete\";\n"
"\"media-type.dry-film\" = \"Film secco\";\n"
"\"media-type.dvd\" = \"DVD\";\n"
"\"media-type.embossing-foil\" = \"Foglio di goffratura\";\n"
"\"media-type.end-board\" = \"Pensione finale\";\n"
"\"media-type.envelope\" = \"Busta\";\n"
"\"media-type.envelope-archival\" = \"Busta Archival\";\n"
"\"media-type.envelope-bond\" = \"Busta di legame\";\n"
"\"media-type.envelope-coated\" = \"Busta rivestita\";\n"
"\"media-type.envelope-cotton\" = \"Busta di cotone\";\n"
"\"media-type.envelope-fine\" = \"Fine busta\";\n"
"\"media-type.envelope-heavyweight\" = \"Busta pesante\";\n"
"\"media-type.envelope-inkjet\" = \"Busta a getto d'inchiostro\";\n"
"\"media-type.envelope-lightweight\" = \"Busta leggera\";\n"
"\"media-type.envelope-plain\" = \"Busta di lamina\";\n"
"\"media-type.envelope-preprinted\" = \"Busta prestampata\";\n"
"\"media-type.envelope-window\" = \"Busta finestrata\";\n"
"\"media-type.fabric\" = \"Tessuto\";\n"
"\"media-type.fabric-archival\" = \"Tessuto d'archival\";\n"
"\"media-type.fabric-glossy\" = \"Tessuto lucido\";\n"
"\"media-type.fabric-high-gloss\" = \"Tessuto lucido\";\n"
"\"media-type.fabric-matte\" = \"Tessuto opaco\";\n"
"\"media-type.fabric-semi-gloss\" = \"Tessuto semi-glossa\";\n"
"\"media-type.fabric-waterproof\" = \"Tessuto impermeabile\";\n"
"\"media-type.film\" = \"Film\";\n"
"\"media-type.flexo-base\" = \"Base Flexo\";\n"
"\"media-type.flexo-photo-polymer\" = \"Polimero fotografico Flexo\";\n"
"\"media-type.flute\" = \"Flusso\";\n"
"\"media-type.foil\" = \"Foil\";\n"
"\"media-type.full-cut-tabs\" = \"Tavole di taglio complete\";\n"
"\"media-type.glass\" = \"Vetro\";\n"
"\"media-type.glass-colored\" = \"Vetro colorato\";\n"
"\"media-type.glass-opaque\" = \"Vetro opaco\";\n"
"\"media-type.glass-surfaced\" = \"Vetro superficiale\";\n"
"\"media-type.glass-textured\" = \"Vetro strutturato\";\n"
"\"media-type.gravure-cylinder\" = \"Cilindro di scarico\";\n"
"\"media-type.image-setter-paper\" = \"Immagine carta setter\";\n"
"\"media-type.imaging-cylinder\" = \"Cilindro di imaging\";\n"
"\"media-type.labels\" = \"Etichette\";\n"
"\"media-type.labels-colored\" = \"Etichette colorate\";\n"
"\"media-type.labels-glossy\" = \"Etichette lucide\";\n"
"\"media-type.labels-high-gloss\" = \"Etichette ad alta lucentezza\";\n"
"\"media-type.labels-inkjet\" = \"Etichette inkjet\";\n"
"\"media-type.labels-matte\" = \"Etichette opzionali\";\n"
"\"media-type.labels-permanent\" = \"Etichette permanenti\";\n"
"\"media-type.labels-satin\" = \"Etichette in raso\";\n"
"\"media-type.labels-security\" = \"Etichette di sicurezza\";\n"
"\"media-type.labels-semi-gloss\" = \"Etichette semi-glossa\";\n"
"\"media-type.laminating-foil\" = \"Laminazione\";\n"
"\"media-type.letterhead\" = \"Lettera\";\n"
"\"media-type.metal\" = \"Metallo\";\n"
"\"media-type.metal-glossy\" = \"Metallo lucido\";\n"
"\"media-type.metal-high-gloss\" = \"Metallo lucido\";\n"
"\"media-type.metal-matte\" = \"Metallo opaco\";\n"
"\"media-type.metal-satin\" = \"Metallo satinato\";\n"
"\"media-type.metal-semi-gloss\" = \"Metal semi lucido\";\n"
"\"media-type.mounting-tape\" = \"Nastro di montaggio\";\n"
"\"media-type.multi-layer\" = \"Multi strato\";\n"
"\"media-type.multi-part-form\" = \"Forma a più parti\";\n"
"\"media-type.other\" = \"Altri\";\n"
"\"media-type.paper\" = \"Carta\";\n"
"\"media-type.photographic\" = \"Carta fotografica\";\n"
"\"media-type.photographic-archival\" = \"Archivio fotografico\";\n"
"\"media-type.photographic-film\" = \"Film fotografici\";\n"
"\"media-type.photographic-glossy\" = \"Carta fotografica lucida\";\n"
"\"media-type.photographic-high-gloss\" = \"Carta fotografica lucida\";\n"
"\"media-type.photographic-matte\" = \"Carta fotografica opaca\";\n"
"\"media-type.photographic-satin\" = \"Carta fotografica raso\";\n"
"\"media-type.photographic-semi-gloss\" = \"Carta fotografica semiglossa\";\n"
"\"media-type.plastic\" = \"Plastica\";\n"
"\"media-type.plastic-archival\" = \"Archivio plastica\";\n"
"\"media-type.plastic-colored\" = \"Plastica colorata\";\n"
"\"media-type.plastic-glossy\" = \"Plastica lucida\";\n"
"\"media-type.plastic-high-gloss\" = \"Plastica alta lucentezza\";\n"
"\"media-type.plastic-matte\" = \"opaco di plastica\";\n"
"\"media-type.plastic-satin\" = \"Raso di plastica\";\n"
"\"media-type.plastic-semi-gloss\" = \"Plastica semiluce\";\n"
"\"media-type.plate\" = \"Piatto\";\n"
"\"media-type.polyester\" = \"Poliestere\";\n"
"\"media-type.pre-cut-tabs\" = \"Tavole pre-taglio\";\n"
"\"media-type.roll\" = \"Roll\";\n"
"\"media-type.screen\" = \"Schermo\";\n"
"\"media-type.screen-paged\" = \"Pagina dello schermo\";\n"
"\"media-type.self-adhesive\" = \"Autoadesivo\";\n"
"\"media-type.self-adhesive-film\" = \"Film autoadesivo\";\n"
"\"media-type.shrink-foil\" = \"Lamina di gamberetti\";\n"
"\"media-type.single-face\" = \"Faccia singola\";\n"
"\"media-type.single-wall\" = \"Singola parete\";\n"
"\"media-type.sleeve\" = \"Manica\";\n"
"\"media-type.stationery\" = \"Cancelleria\";\n"
"\"media-type.stationery-archival\" = \"Archivio della Cancelleria\";\n"
"\"media-type.stationery-coated\" = \"Carta rivestita\";\n"
"\"media-type.stationery-cotton\" = \"Cotone di cancelleria\";\n"
"\"media-type.stationery-fine\" = \"Carta di velluto\";\n"
"\"media-type.stationery-heavyweight\" = \"Carta resistente\";\n"
"\"media-type.stationery-heavyweight-coated\" = \"Posteriore pesante rivestito\";\n"
"\"media-type.stationery-inkjet\" = \"Carta a getto d'inchiostro\";\n"
"\"media-type.stationery-letterhead\" = \"Lettera\";\n"
"\"media-type.stationery-lightweight\" = \"Carta leggera\";\n"
"\"media-type.stationery-preprinted\" = \"Carta stampata\";\n"
"\"media-type.stationery-prepunched\" = \"Carta perforata\";\n"
"\"media-type.tab-stock\" = \"Tab stock\";\n"
"\"media-type.tractor\" = \"Trattore\";\n"
"\"media-type.transfer\" = \"Trasferimento\";\n"
"\"media-type.transparency\" = \"Trasparenza\";\n"
"\"media-type.triple-wall\" = \"Tripla parete\";\n"
"\"media-type.wet-film\" = \"Wet film\";\n"
"\"media.choice_iso_a4_210x297mm_na_letter_8.5x11in\" = \"A4 o US Letter\";\n"
"\"media.iso_2a0_1189x1682mm\" = \"2.\";\n"
"\"media.iso_a0_841x1189mm\" = \"A.\";\n"
"\"media.iso_a0x3_1189x2523mm\" = \"A0x3\";\n"
"\"media.iso_a10_26x37mm\" = \"A10\";\n"
"\"media.iso_a1_594x841mm\" = \"A1\";\n"
"\"media.iso_a1x3_841x1783mm\" = \"A1x3\";\n"
"\"media.iso_a1x4_841x2378mm\" = \"A1x4\";\n"
"\"media.iso_a2_420x594mm\" = \"A2\";\n"
"\"media.iso_a2x3_594x1261mm\" = \"A2x3\";\n"
"\"media.iso_a2x4_594x1682mm\" = \"A2x4\";\n"
"\"media.iso_a2x5_594x2102mm\" = \"A2x5\";\n"
"\"media.iso_a3-extra_322x445mm\" = \"A3 (extra)\";\n"
"\"media.iso_a3_297x420mm\" = \"A3\";\n"
"\"media.iso_a3x3_420x891mm\" = \"A3x3\";\n"
"\"media.iso_a3x4_420x1189mm\" = \"A3x4\";\n"
"\"media.iso_a3x5_420x1486mm\" = \"A3x5\";\n"
"\"media.iso_a3x6_420x1783mm\" = \"A3x6\";\n"
"\"media.iso_a3x7_420x2080mm\" = \"A3x7\";\n"
"\"media.iso_a4-extra_235.5x322.3mm\" = \"A4 (extra)\";\n"
"\"media.iso_a4-tab_225x297mm\" = \"A4 (tab)\";\n"
"\"media.iso_a4_210x297mm\" = \"A4\";\n"
"\"media.iso_a4x3_297x630mm\" = \"A4x3\";\n"
"\"media.iso_a4x4_297x841mm\" = \"A4x4\";\n"
"\"media.iso_a4x5_297x1051mm\" = \"A4x5\";\n"
"\"media.iso_a4x6_297x1261mm\" = \"A4x6\";\n"
"\"media.iso_a4x7_297x1471mm\" = \"A4x7\";\n"
"\"media.iso_a4x8_297x1682mm\" = \"A4x8\";\n"
"\"media.iso_a4x9_297x1892mm\" = \"A4x9\";\n"
"\"media.iso_a5-extra_174x235mm\" = \"A5 (extra)\";\n"
"\"media.iso_a5_148x210mm\" = \"A5\";\n"
"\"media.iso_a6_105x148mm\" = \"A6\";\n"
"\"media.iso_a7_74x105mm\" = \"A7\";\n"
"\"media.iso_a8_52x74mm\" = \"A8\";\n"
"\"media.iso_a9_37x52mm\" = \"A9\";\n"
"\"media.iso_b0_1000x1414mm\" = \"B0\";\n"
"\"media.iso_b10_31x44mm\" = \"B10\";\n"
"\"media.iso_b1_707x1000mm\" = \"B1\";\n"
"\"media.iso_b2_500x707mm\" = \"B2\";\n"
"\"media.iso_b3_353x500mm\" = \"B3-3\";\n"
"\"media.iso_b4_250x353mm\" = \"B4\";\n"
"\"media.iso_b5-extra_201x276mm\" = \"B5 (extra)\";\n"
"\"media.iso_b5_176x250mm\" = \"B5 busta\";\n"
"\"media.iso_b6_125x176mm\" = \"B6\";\n"
"\"media.iso_b6c4_125x324mm\" = \"B6/C4\";\n"
"\"media.iso_b7_88x125mm\" = \"B7\";\n"
"\"media.iso_b8_62x88mm\" = \"B8\";\n"
"\"media.iso_b9_44x62mm\" = \"B.\";\n"
"\"media.iso_c0_917x1297mm\" = \"C0 busta\";\n"
"\"media.iso_c10_28x40mm\" = \"C10 busta\";\n"
"\"media.iso_c1_648x917mm\" = \"C1 busta\";\n"
"\"media.iso_c2_458x648mm\" = \"C2 busta\";\n"
"\"media.iso_c3_324x458mm\" = \"C3 busta\";\n"
"\"media.iso_c4_229x324mm\" = \"C4 busta\";\n"
"\"media.iso_c5_162x229mm\" = \"C5 busta\";\n"
"\"media.iso_c6_114x162mm\" = \"C6 busta\";\n"
"\"media.iso_c6c5_114x229mm\" = \"C6/C5 busta\";\n"
"\"media.iso_c7_81x114mm\" = \"C7 busta\";\n"
"\"media.iso_c7c6_81x162mm\" = \"C7/C6\";\n"
"\"media.iso_c8_57x81mm\" = \"C8 busta\";\n"
"\"media.iso_c9_40x57mm\" = \"C9 busta\";\n"
"\"media.iso_dl_110x220mm\" = \"Busta DL\";\n"
"\"media.iso_ra0_860x1220mm\" = \"ISO RA0\";\n"
"\"media.iso_ra1_610x860mm\" = \"ISO RA1\";\n"
"\"media.iso_ra2_430x610mm\" = \"ISO RA2\";\n"
"\"media.iso_ra3_305x430mm\" = \"ISO RA3\";\n"
"\"media.iso_ra4_215x305mm\" = \"ISO RA4\";\n"
"\"media.iso_sra0_900x1280mm\" = \"ISO SRA0\";\n"
"\"media.iso_sra1_640x900mm\" = \"ISO SRA1\";\n"
"\"media.iso_sra2_450x640mm\" = \"ISO SRA2\";\n"
"\"media.iso_sra3_320x450mm\" = \"ISO SRA3\";\n"
"\"media.iso_sra4_225x320mm\" = \"ISO SRA4\";\n"
"\"media.jis_b0_1030x1456mm\" = \"JIS B0\";\n"
"\"media.jis_b10_32x45mm\" = \"JIS B10\";\n"
"\"media.jis_b1_728x1030mm\" = \"JIS B1\";\n"
"\"media.jis_b2_515x728mm\" = \"JIS B2\";\n"
"\"media.jis_b3_364x515mm\" = \"JIS B3\";\n"
"\"media.jis_b4_257x364mm\" = \"JIS B4\";\n"
"\"media.jis_b5_182x257mm\" = \"JIS B5\";\n"
"\"media.jis_b6_128x182mm\" = \"JIS B6\";\n"
"\"media.jis_b7_91x128mm\" = \"JIS B7\";\n"
"\"media.jis_b8_64x91mm\" = \"JIS B8\";\n"
"\"media.jis_b9_45x64mm\" = \"JIS B9\";\n"
"\"media.jis_exec_216x330mm\" = \"JIS Esecutivo\";\n"
"\"media.jpn_chou2_111.1x146mm\" = \"Busta Chou 2\";\n"
"\"media.jpn_chou3_120x235mm\" = \"Busta Chou 3\";\n"
"\"media.jpn_chou40_90x225mm\" = \"Busta Chou 40\";\n"
"\"media.jpn_chou4_90x205mm\" = \"Busta Chou 4\";\n"
"\"media.jpn_hagaki_100x148mm\" = \"Hagaki\";\n"
"\"media.jpn_kahu_240x322.1mm\" = \"Busta Kahu\";\n"
"\"media.jpn_kaku2_240x332mm\" = \"Busta Kahu 2\";\n"
"\"media.jpn_oufuku_148x200mm\" = \"Oufuku Rispondi\";\n"
"\"media.jpn_you4_105x235mm\" = \"Busta 4\";\n"
"\"media.na_a2_4.375x5.75in\" = \"Busta A2\";\n"
"\"media.na_c5_6.5x9.5in\" = \"Busta C5\";\n"
"\"media.na_executive_7.25x10.5in\" = \"Esecutivo\";\n"
"\"media.na_fanfold-eur_8.5x12in\" = \"Fanfold europeo\";\n"
"\"media.na_fanfold-us_11x14.875in\" = \"Fanfold USA\";\n"
"\"media.na_foolscap_8.5x13in\" = \"Schiuma\";\n"
"\"media.na_invoice_5.5x8.5in\" = \"Dichiarazione\";\n"
"\"media.na_legal-extra_9.5x15in\" = \"US Legal (Extra)\";\n"
"\"media.na_legal_8.5x14in\" = \"Legale USA\";\n"
"\"media.na_letter-extra_9.5x12in\" = \"Lettera degli Stati Uniti (Extra)\";\n"
"\"media.na_letter-plus_8.5x12.69in\" = \"Lettera degli Stati Uniti (Plus)\";\n"
"\"media.na_letter_8.5x11in\" = \"Lettera degli Stati Uniti\";\n"
"\"media.na_monarch_3.875x7.5in\" = \"Busta Monarch\";\n"
"\"media.na_number-10_4.125x9.5in\" = \"Busta #10\";\n"
"\"media.na_number-11_4.5x10.375in\" = \"Busta #11\";\n"
"\"media.na_number-12_4.75x11in\" = \"Busta #12\";\n"
"\"media.na_number-14_5x11.5in\" = \"Busta #14\";\n"
"\"media.na_number-9_3.875x8.875in\" = \"Busta #9\";\n"
"\"media.na_personal_3.625x6.5in\" = \"Busta personale\";\n"
"\"media.na_quarto_8.5x10.83in\" = \"Quarto\";\n"
"\"media.om_folio-sp_215x315mm\" = \"Folio\";\n"
"\"media.om_folio_210x330mm\" = \"Folio (Special)\";\n"
"\"media.om_invite_220x220mm\" = \"Invito alla busta\";\n"
"\"media.om_italian_110x230mm\" = \"Busta italiana\";\n"
"\"media.om_juuro-ku-kai_198x275mm\" = \"198 x 275mm\";\n"
"\"media.om_large-photo_200x300\" = \"200 x 300\";\n"
"\"media.om_medium-photo_130x180mm\" = \"130 x 180 mm\";\n"
"\"media.om_pa-kai_267x389mm\" = \"267 x 389m m\";\n"
"\"media.om_postfix_114x229mm\" = \"Postfix della busta\";\n"
"\"media.prc_10_324x458mm\" = \"Busta cinese #10\";\n"
"\"media.prc_16k_146x215mm\" = \"Cinese 16k\";\n"
"\"media.prc_1_102x165mm\" = \"Busta cinese #1\";\n"
"\"media.prc_2_102x176mm\" = \"Busta cinese #2\";\n"
"\"media.prc_32k_97x151mm\" = \"Cinese 32k\";\n"
"\"media.prc_3_125x176mm\" = \"Busta cinese #3\";\n"
"\"media.prc_4_110x208mm\" = \"Busta cinese #4\";\n"
"\"media.prc_5_110x220mm\" = \"Busta cinese #5\";\n"
"\"media.prc_6_120x320mm\" = \"Busta cinese #6\";\n"
"\"media.prc_7_160x230mm\" = \"Busta cinese #7\";\n"
"\"media.prc_8_120x309mm\" = \"Busta cinese #8\";\n"
"\"media.roc_16k_7.75x10.75in\" = \"ROC 16k\";\n"
"\"media.roc_8k_10.75x15.5in\" = \"ROC 8.\";\n"
"\"not configured\" = \"non configurato\";\n"
"\"not visible\" = \"non visibile\";\n"
"\"off\" = \"Fuori\";\n"
"\"on\" = \"su\";\n"
"\"orientation-requested\" = \"Orientamento\";\n"
"\"orientation-requested.3\" = \"Ritratto\";\n"
"\"orientation-requested.4\" = \"paesaggio paesaggio\";\n"
"\"orientation-requested.5\" = \"Paesaggio inverso\";\n"
"\"orientation-requested.6\" = \"Ritratto inverso\";\n"
"\"orientation-requested.7\" = \"Nessuno\";\n"
"\"output-bin\" = \"Vassoio di uscita\";\n"
"\"output-bin.auto\" = \"Automatico\";\n"
"\"output-bin.bottom\" = \"Fondo\";\n"
"\"output-bin.center\" = \"Centro\";\n"
"\"output-bin.face-down\" = \"Faccia a terra\";\n"
"\"output-bin.face-up\" = \"Faccia in su\";\n"
"\"output-bin.large-capacity\" = \"Grande capacità\";\n"
"\"output-bin.left\" = \"Sinistra\";\n"
"\"output-bin.mailbox-1\" = \"Mailbox 1\";\n"
"\"output-bin.mailbox-10\" = \"Mailbox 10\";\n"
"\"output-bin.mailbox-2\" = \"Mailbox 2\";\n"
"\"output-bin.mailbox-3\" = \"Mailbox 3\";\n"
"\"output-bin.mailbox-4\" = \"Mailbox 4\";\n"
"\"output-bin.mailbox-5\" = \"Mailbox 5\";\n"
"\"output-bin.mailbox-6\" = \"Mailbox 6\";\n"
"\"output-bin.mailbox-7\" = \"Mailbox 7\";\n"
"\"output-bin.mailbox-8\" = \"Mailbox 8\";\n"
"\"output-bin.mailbox-9\" = \"Mailbox 9\";\n"
"\"output-bin.middle\" = \"Medio\";\n"
"\"output-bin.my-mailbox\" = \"La mia casella di posta\";\n"
"\"output-bin.rear\" = \"Indietro\";\n"
"\"output-bin.right\" = \"Giusto.\";\n"
"\"output-bin.side\" = \"Lato\";\n"
"\"output-bin.stacker-1\" = \"Stacker 1\";\n"
"\"output-bin.stacker-10\" = \"Stacker 10\";\n"
"\"output-bin.stacker-2\" = \"Stacker 2\";\n"
"\"output-bin.stacker-3\" = \"Stacker 3\";\n"
"\"output-bin.stacker-4\" = \"Stacker 4\";\n"
"\"output-bin.stacker-5\" = \"Stacker 5\";\n"
"\"output-bin.stacker-6\" = \"Stacker 6\";\n"
"\"output-bin.stacker-7\" = \"Stacker 7\";\n"
"\"output-bin.stacker-8\" = \"Stacker 8\";\n"
"\"output-bin.stacker-9\" = \"Stacker 9\";\n"
"\"output-bin.top\" = \"Top\";\n"
"\"output-bin.tray-1\" = \"Vassoio 1\";\n"
"\"output-bin.tray-10\" = \"Vassoio 10\";\n"
"\"output-bin.tray-2\" = \"Vassoio 2\";\n"
"\"output-bin.tray-3\" = \"Vassoio 3\";\n"
"\"output-bin.tray-4\" = \"Vassoio 4\";\n"
"\"output-bin.tray-5\" = \"Vassoio 5\";\n"
"\"output-bin.tray-6\" = \"Vassoio 6\";\n"
"\"output-bin.tray-7\" = \"Vassoio 7\";\n"
"\"output-bin.tray-8\" = \"Vassoio 8\";\n"
"\"output-bin.tray-9\" = \"Vassoio 9\";\n"
"\"print-color-mode\" = \"Modalità di stampa\";\n"
"\"print-color-mode.auto\" = \"Automatico\";\n"
"\"print-color-mode.auto-monochrome\" = \"Auto monocromatica\";\n"
"\"print-color-mode.bi-level\" = \"Testo\";\n"
"\"print-color-mode.color\" = \"Colore\";\n"
"\"print-color-mode.highlight\" = \"In evidenza\";\n"
"\"print-color-mode.monochrome\" = \"Monocromatico\";\n"
"\"print-color-mode.process-bi-level\" = \"Testo di processo\";\n"
"\"print-color-mode.process-monochrome\" = \"Processo monocromatico\";\n"
"\"print-content-optimize\" = \"Ottimizzazione per\";\n"
"\"print-content-optimize.auto\" = \"Automatico\";\n"
"\"print-content-optimize.graphic\" = \"Grafica\";\n"
"\"print-content-optimize.photo\" = \"Foto\";\n"
"\"print-content-optimize.text\" = \"Testo\";\n"
"\"print-content-optimize.text-and-graphic\" = \"Testo e grafica\";\n"
"\"print-darkness\" = \"Stampa Oscurità\";\n"
"\"print-quality\" = \"Qualità della stampa\";\n"
"\"print-quality.3\" = \"Progetto\";\n"
"\"print-quality.4\" = \"Normale\";\n"
"\"print-quality.5\" = \"Migliore\";\n"
"\"print-scaling\" = \"Scala\";\n"
"\"print-scaling.auto\" = \"Automatico\";\n"
"\"print-scaling.auto-fit\" = \"Autofit\";\n"
"\"print-scaling.fill\" = \"Riempi\";\n"
"\"print-scaling.fit\" = \"Fit\";\n"
"\"print-scaling.none\" = \"Nessuno\";\n"
"\"print-speed\" = \"Velocità di stampa\";\n"
"\"printer-resolution\" = \"Risoluzione\";\n"
"\"printer-state-reasons.cover-open\" = \"Copertina aperta.\";\n"
"\"printer-state-reasons.door-open\" = \"Porta aperta.\";\n"
"\"printer-state-reasons.identify-printer-requested\" = \"Identificare la stampante.\";\n"
"\"printer-state-reasons.input-tray-missing\" = \"Vassoio di carta mancante.\";\n"
"\"printer-state-reasons.marker-supply-empty\" = \"Fuori dall'inchiostro.\";\n"
"\"printer-state-reasons.marker-supply-low\" = \"Inchiostro basso.\";\n"
"\"printer-state-reasons.marker-waste-almost-full\" = \"Cestino quasi pieno.\";\n"
"\"printer-state-reasons.marker-waste-full\" = \"Cestino pieno.\";\n"
"\"printer-state-reasons.media-empty\" = \"Fuori carta.\";\n"
"\"printer-state-reasons.media-jam\" = \"La marmellata di carta.\";\n"
"\"printer-state-reasons.media-low\" = \"Sostituisci la carta presto.\";\n"
"\"printer-state-reasons.media-needed\" = \"Carta di carico.\";\n"
"\"printer-state-reasons.none\" = \"Pronti.\";\n"
"\"printer-state-reasons.offline\" = \"Offline.\";\n"
"\"printer-state-reasons.other\" = \"Vedi la stampante.\";\n"
"\"printer-state-reasons.spool-area-full\" = \"Stampante occupata.\";\n"
"\"printer-state-reasons.toner-empty\" = \"Fuori dal toner.\";\n"
"\"printer-state-reasons.toner-low\" = \"Toner basso.\";\n"
"\"printer-state.3\" = \"Idle\";\n"
"\"printer-state.4\" = \"Trattamento\";\n"
"\"printer-state.5\" = \"Fermata\";\n"
"\"sides\" = \"Stampa a 2 posizioni\";\n"
"\"sides.one-sided\" = \"Fuori\";\n"
"\"sides.two-sided-long-edge\" = \"Su (portrait)\";\n"
"\"sides.two-sided-short-edge\" = \"Su (paesaggio)\";\n"
"\"unable to join\" = \"in grado di aderire\";\n"
"\"yesterday at %02d:%02d:%02d\" = \"yesterday at %02d:%02d:%02d\";\n"
"\"Åland Islands\" = \"Isole\";\n";
